#!/usr/bin/perl
# /bin/perl
# /usr/contrib/bin/perl
#
# This script tests SPKDIFF. It includes two rouines: test_data and run_test.
# test_data is called once to generate all needed kernel; run_test is
# call once for each test case and reports to the screen.
#
$version = "2.0.0 -- October 27, 2008 -- BVS/NAIF";

#---------------------------------------------------------------------------
# Begin of configuration parameter section. See descritions below.
#---------------------------------------------------------------------------

#
# For UNIX.
#
$spkdiff       = "./spkdiff";
$mkspk         = "./mkspk";
$maxtocompare  = "";
$shortonly     = "no";
$checkcount    = "yes";
$qt            = "'";

#
# For Windows
#
#$spkdiff       = ".\\spkdiff";
#$mkspk         = ".\\mkspk";
#$maxtocompare  = "77";
#$shortonly     = "yes";
#$checkcount    = "no";
#$qt            = "";

#
# For CYGWIN.
#
#$spkdiff       = "spkdiff";
#$mkspk         = "mkspk";
#$maxtocompare  = "";
#$shortonly     = "no";
#$checkcount    = "yes";
#$qt            = "'";

#
# $spkdiff          Executables invoked by and other files used by the
# $mkspk            script.
#
# $reporttype       Information types that test cases should report
#                   (space delimited list including any combination of
#                   these words "command output expvalues")
#
# $maxtocompare     The number of characters of each expected value to
#                   be used in comparison. To use all characters it
#                   must be set to "".
#
# $shortonly        Flag indicating whether for failure-type cases only
#                   short error message should be checked ("yes" or
#                   "no").
#
# $checkcount       Flag indicating whether the output line count
#                   should be checked ("yes" or "no").
#
# $logname          Log file name (to be passed as argument to
# $logopt           run_test) and log file option (to be included in
#                   the command line passed to run_test).
#
# $qt               Quote used to quote command line keys and values
#                   that cannot be specified unquoted (for example []
#                   must be passed as '[]' to Unix shells)
#
# $maxsteps         SPKDIFF buffers are too large for some platforms
#                   (such as HP). For these platforms they should be
#                   reduced and all test cases exercising changed
#                   accordingly.
#
$reporttype = " ";

$logname = "";
$logopt  = "";
#$logname = "tmp.log";
#$logopt  = "-l tmp.log ";

$maxsteps = "1000000";
#$maxsteps = "100000";

#---------------------------------------------------------------------------
# End of configuration parameter section.
#---------------------------------------------------------------------------

#
# These counters are global variables incremented by run_test routine. (Yuck!)
#
$counttotal = 0;
$countpass  = 0;
$countfail  = 0;

#
# Generate test report banner. Include OS name and date.
#
$seconds = time;
($sec,$min,$hours,$mday,$mon,$year,$wday,$yday) = gmtime($seconds);

print  "\n";
print  "SPKDIFF Test Suite, Version -- $version\n";
print  "\n";
printf "--- DATE: %4d-%02d-%02d %02d:%02d:%02d GMT\n",
       $year+1900, $mon+1, $mday, $hours, $min, $sec;
print  "--- OS:   $^O\n";

#
# Run SPKDIFF with put command line arguments and dump its output to
# the screen to remove any ambiguity of what version is tested.
#

$result = `$spkdiff 2>&1`;
print "\n";
print "Testing the following SPKDIFF:\n";
print "\n";
print "--- $spkdiff\n";
print "\n";
print "$result";

#
# Prepare test data
#
print "\n";
print "Preparing test data ...\n";
print "\n";
&test_data( $mkspk, "make" );

#
# Run tests.
#
print "\n";
print "Executing tests ...\n";
print "\n";

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'first SPK is not an SPK',
  'failure',
  $spkdiff,
  'naif0008.tls spkdiff_b222_s444.bsp',
  14,
  "SPICE(NOTANSPKFILE1)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'first SPK does not exist',
  'failure',
  $spkdiff,
  'spkdiff_b222_s444_boo.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(SPK1DOESNOTEXIST)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'second SPK is not an SPK',
  'failure',
  $spkdiff,
  'spkdiff_b222_s444.bsp naif0008.tls',
  14,
  "SPICE(NOTANSPKFILE2)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'second SPK does not exist',
  'failure',
  $spkdiff,
  'spkdiff_b222_s444.bsp spkdiff_b222_s444_boo.bsp',
  14,
  "SPICE(SPK2DOESNOTEXIST)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-k option is present but no files follow it',
  'failure',
  $spkdiff,
  '-k spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(MISSINGKERNELNAMES)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'non-existing kernel is provided with -k',
  'failure',
  $spkdiff,
  '-k nonamepck.tpc spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(NOSUCHFILE)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad input provided with -c1 (neither ID not recongnized name)',
  'failure',
  $spkdiff,
  '-c1 nonamecenter spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(BADCENTER1SPEC)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad input provided with -b1 (neither ID not recongnized name)',
  'failure',
  $spkdiff,
  '-b1 nonamebody spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(BADBODY1SPEC)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'unrecongnized frame provide with -r1',
  'failure',
  $spkdiff,
  '-r1 nonameframe spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(BADFRAME1NAME)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad input provided with -c2 (neither ID not recongnized name)',
  'failure',
  $spkdiff,
  '-c2 nonamecenter spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(BADCENTER2SPEC)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'bad input provided with -b2 (neither ID not recongnized name)',
  'failure',
  $spkdiff,
  '-b2 nonamebody spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(BADBODY2SPEC)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'unrecongnized frame provide with -r2',
  'failure',
  $spkdiff,
  '-r2 nonameframe spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(BADFRAME2NAME)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'specifying time with -b fails if LSK was not provided',
  'failure',
  $spkdiff,
  '-b 2000-01-02 00:00:00 spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  15,
  "SPICE(NOLEAPSECONDS)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'specifying time with -e fails if LSK was not provided',
  'failure',
  $spkdiff,
  '-e 2000-01-02 00:00:00 spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  15,
  "SPICE(NOLEAPSECONDS)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'unparsable time provided with -b',
  'failure',
  $spkdiff,
  '-k naif0008.tls -b not-a-time spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(UNPARSEDTIME)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'unparsable time provided with -e',
  'failure',
  $spkdiff,
  '-k naif0008.tls -e not-a-time spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(UNPARSEDTIME)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'specified start time is greater than stop time',
  'failure',
  $spkdiff,
  '-k naif0008.tls -b 2000-01-02 01:00:00 -e 2000-01-02 00:00:00 spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(INCONSISTENTTIMES)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'same object specified by name with -b1 and -c1',
  'failure',
  $spkdiff,
  '-b1 MOON -c1 MOON spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(SAMEBODY1CENTER1)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'same object specified by ID with -b1 and -c1',
  'failure',
  $spkdiff,
  '-b1 301 -c1 301 spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(SAMEBODY1CENTER1)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'same object specified by name with -b1 and by ID -c1',
  'failure',
  $spkdiff,
  '-b1 MOON -c1 301 spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(SAMEBODY1CENTER1)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'same object specified by ID with -b1 and by name -c1',
  'failure',
  $spkdiff,
  '-b1 301 -c1 MOON spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(SAMEBODY1CENTER1)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'same object specified by name with -b2 and -c2',
  'failure',
  $spkdiff,
  '-b2 MOON -c2 MOON spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(SAMEBODY2CENTER2)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'same object specified by ID with -b2 and -c2',
  'failure',
  $spkdiff,
  '-b2 301 -c2 301 spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(SAMEBODY2CENTER2)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'same object specified by name with -b2 and by ID -c2',
  'failure',
  $spkdiff,
  '-b2 MOON -c2 301 spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(SAMEBODY2CENTER2)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'same object specified by ID with -b2 and by name -c2',
  'failure',
  $spkdiff,
  '-b2 301 -c2 MOON spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(SAMEBODY2CENTER2)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'same object specified by name with -b1 and -c2',
  'failure',
  $spkdiff,
  '-b1 MOON -c2 MOON spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(SAMEBODY1CENTER2)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'same object specified by ID with -b1 and -c2',
  'failure',
  $spkdiff,
  '-b1 301 -c2 301 spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(SAMEBODY1CENTER2)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'same object specified by name with -b1 and by ID -c2',
  'failure',
  $spkdiff,
  '-b1 MOON -c2 301 spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(SAMEBODY1CENTER2)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'same object specified by ID with -b1 and by name -c2',
  'failure',
  $spkdiff,
  '-b1 301 -c2 MOON spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(SAMEBODY1CENTER2)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'same object specified by name with -b2 and -c1',
  'failure',
  $spkdiff,
  '-b2 MOON -c1 MOON spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(SAMEBODY2CENTER1)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'same object specified by ID with -b2 and -c1',
  'failure',
  $spkdiff,
  '-b2 301 -c1 301 spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(SAMEBODY2CENTER1)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'same object specified by name with -b2 and by ID -c1',
  'failure',
  $spkdiff,
  '-b2 MOON -c1 301 spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(SAMEBODY2CENTER1)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'same object specified by ID with -b2 and by name -c1',
  'failure',
  $spkdiff,
  '-b2 301 -c1 MOON spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(SAMEBODY2CENTER1)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'not data for body specified with -b1 in first SPK',
  'failure',
  $spkdiff,
  '-b1 -333 spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(1NODATAFORBODY)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'not data for body specified with -b2 in first SPK',
  'failure',
  $spkdiff,
  '-b2 -333 spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(1NODATAFORBODY)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'frame determined from first SPK is not recognized',
  'failure',
  $spkdiff,
  'spkdiff_b555_s444.bsp spkdiff_b555_s444.bsp',
  14,
  "SPICE(CANNOTPICKFRAME)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'same center given as ID with -c1 and body picked from first SPK',
  'failure',
  $spkdiff,
  '-c1 222 spkdiff_b111_b222.bsp spkdiff_b111_b222.bsp',
  14,
  "SPICE(SAMEBODYANDCENTER3)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'same center given as name with -c1 and body picked from first SPK',
  'failure',
  $spkdiff,
  '-k spkdiff_test.tf -c1 BODY222 spkdiff_b111_b222.bsp spkdiff_b111_b222.bsp',
  14,
  "SPICE(SAMEBODYANDCENTER3)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'same center given as ID with -c2 (no -c1) and body picked from first SPK',
  'failure',
  $spkdiff,
  '-c2 222 spkdiff_b111_b222.bsp spkdiff_b111_b222.bsp',
  14,
  "SPICE(SAMEBODYANDCENTER3)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'same center given as name with -c2 (no -c1) and body picked from first SPK',
  'failure',
  $spkdiff,
  '-k spkdiff_test.tf -c2 BODY222 spkdiff_b111_b222.bsp spkdiff_b111_b222.bsp',
  14,
  "SPICE(SAMEBODYANDCENTER3)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'same center given as ID with -c2 (with -c1) and body picked from first SPK',
  'failure',
  $spkdiff,
  '-c1 111 -c2 222 spkdiff_b111_b222.bsp spkdiff_b111_b222.bsp',
  14,
  "SPICE(SAMEBODYANDCENTER4)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'same center given as name with -c2 (with -c1) and body picked from first SPK',
  'failure',
  $spkdiff,
  '-k spkdiff_test.tf -c1 111 -c2 BODY222 spkdiff_b111_b222.bsp spkdiff_b111_b222.bsp',
  14,
  "SPICE(SAMEBODYANDCENTER4)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'first SPK does not provide data for specified body',
  'failure',
  $spkdiff,
  '-b1 -333 -c1 222 -r1 J2000 spkdiff_b222_s444.bsp spkdiff_b222_s333.bsp',
  14,
  "SPICE(2NODATAFORBODY)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'second SPK does not provide data for specified body',
  'failure',
  $spkdiff,
  '-b1 -333 spkdiff_b222_s333.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(3NODATAFORBODY)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'no overlap between two files',
  'failure',
  $spkdiff,
  'spkdiff_b222_s444.bsp spkdiff_b222_s444_day3.bsp',
  15,
  "SPICE(NOOVERLAP1)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'more than 1 overlap window without times on command line',
  'failure',
  $spkdiff,
  'spkdiff_b222_s444_day1_3.bsp spkdiff_b222_s444_2days.bsp',
  15,
  "SPICE(MORETHAN1INTERVAL1)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'no overlap because of too-early stop time given with -e',
  'failure',
  $spkdiff,
  '-k naif0008.tls -e 2000-01-01 00:00:00.000 TDB spkdiff_b222_s444.bsp spkdiff_b222_s444_2days.bsp',
  16,
  "SPICE(NOOVERLAP2)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'more than 1 overlap window with stop time provided with -e',
  'failure',
  $spkdiff,
  '-k naif0008.tls -e 2000-01-03 18:00:00.000 TDB spkdiff_b222_s444_day1_3.bsp spkdiff_b222_s444_2days.bsp',
  16,
  "SPICE(MORETHAN1INTERVAL2)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'no overlap because of too-late start time given with -e',
  'failure',
  $spkdiff,
  '-k naif0008.tls -b 2000-01-03 00:00:00.000 TDB spkdiff_b222_s444.bsp spkdiff_b222_s444_2days.bsp',
  16,
  "SPICE(NOOVERLAP3)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'more than 1 overlap window with start time provided with -b',
  'failure',
  $spkdiff,
  '-k naif0008.tls -b 2000-01-02 06:00:00.000 TDB spkdiff_b222_s444_day1_3.bsp spkdiff_b222_s444_2days.bsp',
  16,
  "SPICE(MORETHAN1INTERVAL3)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'negative step specified with -s',
  'failure',
  $spkdiff,
  '-s -1 spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(STEPTOOSMALL1)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'zero size step specified with -s',
  'failure',
  $spkdiff,
  '-s 0 spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(STEPTOOSMALL1)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'step smaller than smallest allowed specified with -s',
  'failure',
  $spkdiff,
  '-s 0.0000000001 spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(STEPTOOSMALL1)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'step small enough to generate too many points over coverage',
  'failure',
  $spkdiff,
  '-s 0.01 spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  18,
  "SPICE(STEPTOOSMALL2)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'step small enough to generate too many points over coverage, int overflow',
  'failure',
  $spkdiff,
  '-s 0.000001 spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  18,
  "SPICE(STEPTOOSMALL2)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'step specified with -s is not a number',
  'failure',
  $spkdiff,
  '-s notnumber spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  13,
  "SPICE(NOTANDPNUMBER)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'step specified with -s is not a number (number with units)',
  'failure',
  $spkdiff,
  '-s 2 seconds spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  13,
  "SPICE(NOTANDPNUMBER)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'too few states specified with -n',
  'failure',
  $spkdiff,
  '-n 1 spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  13,
  "SPICE(BADNOFSTATES)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'too many states specified with -n',
  'failure',
  $spkdiff,
  '-n 1000001 spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(BADNOFSTATES)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'number of step provided with -n is not a number',
  'failure',
  $spkdiff,
  '-n 20 steps spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  13,
  "SPICE(NOTANINTEGERNUMBER)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'unrecognized output type',
  'failure',
  $spkdiff,
  '-t table spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(BADOUTPUTTYPE)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'supporting kernels provide data sought from first SPK',
  'failure',
  $spkdiff,
  '-b1 -333 -b2 -444 -k spkdiff_b222_s333_b111.bsp spkdiff_b222_s333.bsp spkdiff_b222_s444.bsp',
  38,
  "SPICE(JEOPARDIZEDRUN1)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'supporting kernels provide data sought from second SPK',
  'failure',
  $spkdiff,
  '-b1 -444 -b2 -333 -k spkdiff_b222_s333_b111.bsp spkdiff_b222_s444.bsp spkdiff_b222_s333.bsp',
  38,
  "SPICE(JEOPARDIZEDRUN2)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'time format option -f not followed by value',
  'failure',
  $spkdiff,
  '-t dump -f spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  13,
  "SPICE(BLANKTIMEFORMAT)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'blank values provived with options, -b1',
  'failure',
  $spkdiff,
  '-b1 spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(BADBODY1SPEC)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'blank values provived with options, -c1',
  'failure',
  $spkdiff,
  '-c1 spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(BADCENTER1SPEC)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'blank values provived with options, -r1',
  'failure',
  $spkdiff,
  '-r1 spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  13,
  "SPICE(BADFRAME1NAME)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'blank values provived with options, -b2',
  'failure',
  $spkdiff,
  '-b2 spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(BADBODY2SPEC)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'blank values provived with options, -c2',
  'failure',
  $spkdiff,
  '-c2 spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(BADCENTER2SPEC)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'blank values provived with options, -r2',
  'failure',
  $spkdiff,
  '-r2 spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  13,
  "SPICE(BADFRAME2NAME)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'blank values provived with options, -k',
  'failure',
  $spkdiff,
  '-k spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(MISSINGKERNELNAMES)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'blank values provived with options, -b',
  'failure',
  $spkdiff,
  '-b spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  13,
  "SPICE(UNPARSEDTIME)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'blank values provived with options, -e',
  'failure',
  $spkdiff,
  '-e spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  13,
  "SPICE(UNPARSEDTIME)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'blank values provived with options, -s',
  'failure',
  $spkdiff,
  '-s spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  13,
  "SPICE(NOTANDPNUMBER)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'blank values provived with options, -n',
  'failure',
  $spkdiff,
  '-n spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  13,
  "SPICE(NOTANINTEGERNUMBER)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'blank values provived with options, -f',
  'failure',
  $spkdiff,
  '-t dump -f spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  13,
  "SPICE(BLANKTIMEFORMAT)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'blank values provived with options, -t',
  'failure',
  $spkdiff,
  '-t spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  14,
  "SPICE(BADOUTPUTTYPE)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'unsufficient data, no supporting data for specified center in first SPK',
  'failure',
  $spkdiff,
  '-c1 111 -c2 222 spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  33,
  "SPICE(UNSUFFSPK1DATA)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'unsufficient data, time range too wide for first SPK',
  'failure',
  $spkdiff,
  '-k naif0008.tls -b 2000-01-01 TDB -e 2000-01-03 TDB spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  37,
  "SPICE(UNSUFFSPK1DATA)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'unsufficient data, no supporting data for specified center in second SPK',
  'failure',
  $spkdiff,
  '-c1 222 -c2 111 spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  33,
  "SPICE(UNSUFFSPK2DATA)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'unsufficient data, time range too wide for second SPK',
  'failure',
  $spkdiff,
  '-k naif0008.tls -b 2000-01-02 TDB -e 2000-01-03 TDB spkdiff_b222_s444_2days.bsp spkdiff_b222_s444.bsp',
  37,
  "SPICE(UNSUFFSPK2DATA)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'unsufficient data, all body/center/frame options provided for first SPK',
  'failure',
  $spkdiff,
  '-k naif0008.tls -b1 -333 -c1 222 -r1 J2000 -b 2000-01-02 TDB -e 2000-01-02 TDB spkdiff_b222_s444.bsp spkdiff_b222_s333.bsp',
  37,
  "SPICE(UNSUFFSPK1DATA)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'unsufficient data, all body/center/frame options provided for second SPK',
  'failure',
  $spkdiff,
  '-k naif0008.tls -b1 -333 -c1 222 -r1 J2000  -b 2000-01-02 TDB -e 2000-01-02 TDB spkdiff_b222_s333.bsp spkdiff_b222_s444.bsp',
  37,
  "SPICE(UNSUFFSPK2DATA)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'unsufficient data, missing supporting kernels for first SPK',
  'failure',
  $spkdiff,
  '-k naif0008.tls -b1 -333 -c1 111 -r1 J2000 -b2 -333 -c2 222 -r2 J2000 -b 2000-01-02 TDB -e 2000-01-02 TDB spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  "SPICE(UNSUFFSPK1DATA)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'unsufficient data, missing supporting kernels for second SPK',
  'failure',
  $spkdiff,
  '-k naif0008.tls -b1 -333 -c1 222 -r1 J2000 -b2 -333 -c2 111 -r2 J2000 -b 2000-01-02 TDB -e 2000-01-02 TDB spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  "SPICE(UNSUFFSPK2DATA)"
);

#
# Tests in this block check lineraly dependednt cases which are neither
# successes nor failures.
#

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'linearly dependent position and velocity, no stats report',
  'success',
  $spkdiff,
  '-t stats spkdiff_b111_b222.bsp spkdiff_b111_b222.bsp',
  22,
  "No view frame statistical data can be generated because in one or more cases",
  "the state computed from the first SPK has linearly dependent position and",
  "velocity, which makes constructing the view frame impossible.",
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'linearly dependent position and velocity, no dumpvf report',
  'success',
  $spkdiff,
  '-t dumpvf spkdiff_b111_b222.bsp spkdiff_b111_b222.bsp',
  22,
  "No view frame difference table can be generated because in one or more cases",
  "the state computed from the first SPK has linearly dependent position and",
  "velocity, which makes constructing the view frame impossible."
);

#
# Tests in this block compare trajectories with known differences.
# Various types of reports are generated and checked.
#

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to different: moving faster in all directions, dumpvf output',
  'success',
  $spkdiff,
  '-t dumpvf -n 3 spkdiff_b222_s444.bsp spkdiff_b222_s444_fast.bsp',
  21,
  "# time, down_track_p_diff, normal_to_plane_p_diff, in_plane_p_diff, down_track_v_diff, normal_to_plane_v_diff, in_plane_v_diff",
"0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 -1.0000000000000E+00 +1.0000000000000E+00 -1.0000000000000E+00",
"4.3200000000000E+04 -4.3200000000000E+04 +4.3200000000000E+04 -4.3200000000000E+04 -1.0000000000000E+00 +1.0000000000000E+00 -1.0000000000000E+00",
"8.6400000000000E+04 -8.6400000000000E+04 +8.6400000000000E+04 -8.6400000000000E+04 -1.0000000000000E+00 +1.0000000000000E+00 -1.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to different: moving faster in all directions, dump output',
  'success',
  $spkdiff,
  '-t dump -n 3 spkdiff_b222_s444.bsp spkdiff_b222_s444_fast.bsp',
  21,
  "# time, (x1-x2), (y1-y2), (z1-z2), (vx1-vx2), (vy1-vy2), (vz1-vz2)",
  "0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 -1.0000000000000E+00 -1.0000000000000E+00 -1.0000000000000E+00",
  "4.3200000000000E+04 -4.3200000000000E+04 -4.3200000000000E+04 -4.3200000000000E+04 -1.0000000000000E+00 -1.0000000000000E+00 -1.0000000000000E+00",
  "8.6400000000000E+04 -8.6400000000000E+04 -8.6400000000000E+04 -8.6400000000000E+04 -1.0000000000000E+00 -1.0000000000000E+00 -1.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to different: moving faster in all directions, stats output',
  'success',
  $spkdiff,
  '-n 2 -t stats spkdiff_b222_s444.bsp spkdiff_b222_s444_fast.bsp',
  86,
  "1a) Down track (km):                       -43200.0000000",
  "1b) In orbit plane (km):                   -43200.0000000",
  "1c) Normal to orbit plane (km):             43200.0000000",
  "1d) Average delta time down track (sec):   -43200.0000000",
  "2a) Down track (km):                        43200.0000000",
  "2b) In orbit plane (km):                    43200.0000000",
  "2c) Normal to orbit plane (km):             43200.0000000",
  "2d) Average |delta time| down track (sec):  43200.0000000",
  "3a) Down track (km):                        61094.0258945",
  "3b) In orbit plane (km):                    61094.0258945",
  "3c) Normal to orbit plane (km):             61094.0258945",
  "3d) RMS delta time down track (sec):        61094.0258945",
  "4a) Down track (km):                       -86400.0000000",
  "4b) In orbit plane (km):                   -86400.0000000",
  "4c) Normal to orbit plane (km):             86400.0000000",
  "4d) Delta time down track (sec):           -86400.0000000",
  "4e) Epoch (TDB, seconds past J2000):        86400.0000000",
  "4f) Epoch (TDB, calendar format):           2000-JAN-02-12:00:00.000",
  "5a) Down track (km):                       -86400.0000000",
  "5b) In orbit plane (km):                   -86400.0000000",
  "5c) Normal to orbit plane (km):             86400.0000000",
  "5d) Delta time down track (sec):           -86400.0000000",
  "5e) Epoch (TDB, seconds past J2000):        86400.0000000",
  "5f) Epoch (TDB, calendar format):           2000-JAN-02-12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to different: moving faster in all directions, basic output',
  'success',
  $spkdiff,
  '-n 2 -t basic spkdiff_b222_s444.bsp spkdiff_b222_s444_fast.bsp',
  33,
  "Position:             7.0573884961131E-01      3.5286942480565E-01",
  "Velocity:             7.0710678118655E-01      7.0710678118655E-01",
  "Position (km):        1.4964918977395E+05      7.4824594886976E+04",
  "Velocity (km/s):      1.7320508075689E+00      1.7320508075689E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to different: moving in opposite direction, dumpvf output',
  'success',
  $spkdiff,
  '-t dumpvf -n 3 spkdiff_b222_s444.bsp spkdiff_b222_s444_opp.bsp',
  21,
  "# time, down_track_p_diff, normal_to_plane_p_diff, in_plane_p_diff, down_track_v_diff, normal_to_plane_v_diff, in_plane_v_diff",
"0.0000000000000E+00 -8.6400000000000E+04 +0.0000000000000E+00 +0.0000000000000E+00 +2.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
"4.3200000000000E+04 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +2.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
"8.6400000000000E+04 +8.6400000000000E+04 +0.0000000000000E+00 +0.0000000000000E+00 +2.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to different: moving in opposite direction, dump output',
  'success',
  $spkdiff,
  '-t dump -n 3 spkdiff_b222_s444.bsp spkdiff_b222_s444_opp.bsp',
  21,
  "# time, (x1-x2), (y1-y2), (z1-z2), (vx1-vx2), (vy1-vy2), (vz1-vz2)",
  "0.0000000000000E+00 -8.6400000000000E+04 +0.0000000000000E+00 +0.0000000000000E+00 +2.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
  "4.3200000000000E+04 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +2.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
  "8.6400000000000E+04 +8.6400000000000E+04 +0.0000000000000E+00 +0.0000000000000E+00 +2.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to different: moving in opposite direction, stats output',
  'success',
  $spkdiff,
  '-n 3 -t stats spkdiff_b222_s444.bsp spkdiff_b222_s444_opp.bsp',
  86,
  "1a) Down track (km):                        0.00000000000",
  "2a) Down track (km):                        57600.0000000",
  "3a) Down track (km):                        70545.3045921",
  "4a) Down track (km):                       -86400.0000000",
  "5a) Down track (km):                       -86400.0000000",
  "5d) Delta time down track (sec):           -86400.0000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to different: moving in opposite direction, basic output',
  'success',
  $spkdiff,
  '-n 3 -t basic spkdiff_b222_s444.bsp spkdiff_b222_s444_opp.bsp',
  33,
  "Position (km):        8.6400000000000E+04      5.7600000000000E+04",
  "Velocity (km/s):      2.0000000000000E+00      2.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to different: downtrack/in plane/normal to plane, dumpvf output',
  'success',
  $spkdiff,
  '-t dumpvf -n 3 spkdiff_b222_s444.bsp spkdiff_b222_s444_all.bsp',
  21,
  "# time, down_track_p_diff, normal_to_plane_p_diff, in_plane_p_diff, down_track_v_diff, normal_to_plane_v_diff, in_plane_v_diff",
  "0.0000000000000E+00 -1.0000000000000E+00 +1.0000000000000E+00 -1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
  "4.3200000000000E+04 -1.0000000000000E+00 +1.0000000000000E+00 -1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
  "8.6400000000000E+04 -1.0000000000000E+00 +1.0000000000000E+00 -1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to different: downtrack/in plane/normal to plane, dump output',
  'success',
  $spkdiff,
  '-t dump -n 3 spkdiff_b222_s444.bsp spkdiff_b222_s444_all.bsp',
  21,
  "# time, (x1-x2), (y1-y2), (z1-z2), (vx1-vx2), (vy1-vy2), (vz1-vz2)",
  "0.0000000000000E+00 -1.0000000000000E+00 -1.0000000000000E+00 -1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
  "4.3200000000000E+04 -1.0000000000000E+00 -1.0000000000000E+00 -1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
  "8.6400000000000E+04 -1.0000000000000E+00 -1.0000000000000E+00 -1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to different: downtrack/in plane/normal to plane, stats output',
  'success',
  $spkdiff,
  '-t stats spkdiff_b222_s444.bsp spkdiff_b222_s444_all.bsp',
  86,
  "5a) Down track (km):                       -1.0000000000",
  "5b) In orbit plane (km):                   -1.0000000000",
  "5c) Normal to orbit plane (km):             1.0000000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to different: downtrack/in plane/normal to plane, basic output',
  'success',
  $spkdiff,
  '-t basic spkdiff_b222_s444.bsp spkdiff_b222_s444_all.bsp',
  33,
  "Position (km):        1.7320508075???E+00      1.7320508075???E+00",
  "Velocity (km/s):      0.0000000000000E+00      0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to different: normal to plane only, dumpvf output',
  'success',
  $spkdiff,
  '-t dumpvf -n 3 spkdiff_b222_s444.bsp spkdiff_b222_s444_np1.bsp',
  21,
  "# time, down_track_p_diff, normal_to_plane_p_diff, in_plane_p_diff, down_track_v_diff, normal_to_plane_v_diff, in_plane_v_diff",
  "0.0000000000000E+00 +0.0000000000000E+00 +1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
  "4.3200000000000E+04 +0.0000000000000E+00 +1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
  "8.6400000000000E+04 +0.0000000000000E+00 +1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to different: normal to plane only, dump output',
  'success',
  $spkdiff,
  '-t dump -n 3 spkdiff_b222_s444.bsp spkdiff_b222_s444_np1.bsp',
  21,
  "# time, (x1-x2), (y1-y2), (z1-z2), (vx1-vx2), (vy1-vy2), (vz1-vz2)",
  "0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 -1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
  "4.3200000000000E+04 +0.0000000000000E+00 +0.0000000000000E+00 -1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
  "8.6400000000000E+04 +0.0000000000000E+00 +0.0000000000000E+00 -1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to different: normal to plane only, stats output',
  'success',
  $spkdiff,
  '-t stats spkdiff_b222_s444.bsp spkdiff_b222_s444_np1.bsp',
  86,
  "5a) Down track (km):                        0.0000000000",
  "5b) In orbit plane (km):                    0.0000000000",
  "5c) Normal to orbit plane (km):             1.0000000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to different: normal to plane only, basic output',
  'success',
  $spkdiff,
  '-t basic spkdiff_b222_s444.bsp spkdiff_b222_s444_np1.bsp',
  33,
  "Position (km):        1.0000000000000E+00      1.0000000000000E+00",
  "Velocity (km/s):      0.0000000000000E+00      0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to different: in plane only, dumpvf output',
  'success',
  $spkdiff,
  '-t dumpvf -n 3 spkdiff_b222_s444.bsp spkdiff_b222_s444_ip1.bsp',
  21,
  "# time, down_track_p_diff, normal_to_plane_p_diff, in_plane_p_diff, down_track_v_diff, normal_to_plane_v_diff, in_plane_v_diff",
  "0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 -1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
  "4.3200000000000E+04 +0.0000000000000E+00 +0.0000000000000E+00 -1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
  "8.6400000000000E+04 +0.0000000000000E+00 +0.0000000000000E+00 -1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to different: in plane only, dump output',
  'success',
  $spkdiff,
  '-t dump -n 3 spkdiff_b222_s444.bsp spkdiff_b222_s444_ip1.bsp',
  21,
  "# time, (x1-x2), (y1-y2), (z1-z2), (vx1-vx2), (vy1-vy2), (vz1-vz2)",
  "0.0000000000000E+00 +0.0000000000000E+00 -1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
  "4.3200000000000E+04 +0.0000000000000E+00 -1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
  "8.6400000000000E+04 +0.0000000000000E+00 -1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to different: in plane only, stats output',
  'success',
  $spkdiff,
  '-t stats spkdiff_b222_s444.bsp spkdiff_b222_s444_ip1.bsp',
  86,
  "5a) Down track (km):                        0.0000000000",
  "5b) In orbit plane (km):                   -1.0000000000",
  "5c) Normal to orbit plane (km):             0.0000000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to different: in plane only, basic output',
  'success',
  $spkdiff,
  '-t basic spkdiff_b222_s444.bsp spkdiff_b222_s444_ip1.bsp',
  33,
  "Position (km):        1.0000000000???E+00      ?.?????????????E???",
  "Velocity (km/s):      0.0000000000000E+00      0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to different: downtrack only, dumpvf output',
  'success',
  $spkdiff,
  '-t dumpvf -n 3 spkdiff_b222_s444.bsp spkdiff_b222_s444_dt1.bsp',
  21,
  "# time, down_track_p_diff, normal_to_plane_p_diff, in_plane_p_diff, down_track_v_diff, normal_to_plane_v_diff, in_plane_v_diff",
  "0.0000000000000E+00 -1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
  "4.3200000000000E+04 -1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
  "8.6400000000000E+04 -1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to different: downtrack only, dump output',
  'success',
  $spkdiff,
  '-t dump -n 3 spkdiff_b222_s444.bsp spkdiff_b222_s444_dt1.bsp',
  21,
  "# time, (x1-x2), (y1-y2), (z1-z2), (vx1-vx2), (vy1-vy2), (vz1-vz2)",
  "0.0000000000000E+00 -1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
  "4.3200000000000E+04 -1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
  "8.6400000000000E+04 -1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to different: downtrack only, stats output',
  'success',
  $spkdiff,
  '-t stats spkdiff_b222_s444.bsp spkdiff_b222_s444_dt1.bsp',
  86,
  "5a) Down track (km):                       -1.0000000000",
  "5b) In orbit plane (km):                    0.0000000000",
  "5c) Normal to orbit plane (km):             0.0000000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to different: downtrack only, basic output',
  'success',
  $spkdiff,
  '-t basic spkdiff_b222_s444.bsp spkdiff_b222_s444_dt1.bsp',
  33,
  "Position (km):        1.000000000????E+00      ?.?????????????E???",
  "Velocity (km/s):      0.0000000000000E+00      0.0000000000000E+00"
);

#
# Test in this block verify that times in dump and dumpvf reports are
# displayed in specified format.
#

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to same: dumpvf output, JULIAND.######### time format',
  'success',
  $spkdiff,
  '-k naif0008.tls -t dumpvf -n 3 -f '.$qt.'JULIAND.#########'.$qt.' spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  25,
  "# time, down_track_p_diff, normal_to_plane_p_diff, in_plane_p_diff, down_track_v_diff, normal_to_plane_v_diff, in_plane_v_diff",
  "2451544.999257100 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
  "2451545.499257100 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
  "2451545.999257100 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to same: dumpvf output, YYYY-MM-DDTHR:MN:SC.### time format',
  'success',
  $spkdiff,
  '-k naif0008.tls -t dumpvf -n 3 -f '.$qt.'YYYY-MM-DDTHR:MN:SC.###'.$qt.' spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  25,
  "# time, down_track_p_diff, normal_to_plane_p_diff, in_plane_p_diff, down_track_v_diff, normal_to_plane_v_diff, in_plane_v_diff",
  "2000-01-01T11:58:55.816 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
  "2000-01-01T23:58:55.816 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
  "2000-01-02T11:58:55.816 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to same: dumpvf output, default time format',
  'success',
  $spkdiff,
  '-t dumpvf -n 3 spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  21,
  "# time, down_track_p_diff, normal_to_plane_p_diff, in_plane_p_diff, down_track_v_diff, normal_to_plane_v_diff, in_plane_v_diff",
  "0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
  "4.3200000000000E+04 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
  "8.6400000000000E+04 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to same: dump output, JULIAND.######### time format',
  'success',
  $spkdiff,
  '-k naif0008.tls -t dump -n 3 -f '.$qt.'JULIAND.#########'.$qt.' spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  25,
  "# time, (x1-x2), (y1-y2), (z1-z2), (vx1-vx2), (vy1-vy2), (vz1-vz2)",
  "2451544.999257100 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
  "2451545.499257100 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
  "2451545.999257100 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to same: dump output, YYYY-MM-DDTHR:MN:SC.### time format',
  'success',
  $spkdiff,
  '-k naif0008.tls -t dump -n 3 -f '.$qt.'YYYY-MM-DDTHR:MN:SC.###'.$qt.' spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  25,
  "# time, (x1-x2), (y1-y2), (z1-z2), (vx1-vx2), (vy1-vy2), (vz1-vz2)",
  "2000-01-01T11:58:55.816 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
  "2000-01-01T23:58:55.816 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
  "2000-01-02T11:58:55.816 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to same: dump output, default time format',
  'success',
  $spkdiff,
  '-t dump -n 3 spkdiff_b222_s444.bsp spkdiff_b222_s444.bsp',
  21,
  "# time, (x1-x2), (y1-y2), (z1-z2), (vx1-vx2), (vy1-vy2), (vz1-vz2)",
  "0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
  "4.3200000000000E+04 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
  "8.6400000000000E+04 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00"
);

#
# Tests in this block should display stat report with all zeros
# (set aside numeric "garbage") because the file is compared to
# another file with the same trajectory. The purpose of these tests is to
# excercise comparisons over overlaping intervals.
#
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to same: basic output, complete overlap with first SPK outside',
  'success',
  $spkdiff,
  '-t stats  spkdiff_b222_s444_2days.bsp spkdiff_b222_s444_day2.bsp',
  86,
  "from '2000 JAN 02 12:00:00.000 TDB'",
  "to   '2000 JAN 03 12:00:00.000 TDB'",
  "5a) Down track (km):                       ?0.000000????",
  "5b) In orbit plane (km):                   ?0.000000????",
  "5c) Normal to orbit plane (km):            ?0.000000????"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to same: basic output, complete overlap with first SPK within',
  'success',
  $spkdiff,
  '-t stats spkdiff_b222_s444_day2.bsp spkdiff_b222_s444_2days.bsp',
  86,
  "from '2000 JAN 02 12:00:00.000 TDB'",
  "to   '2000 JAN 03 12:00:00.000 TDB'",
  "5a) Down track (km):                       ?0.000000????",
  "5b) In orbit plane (km):                   ?0.000000????",
  "5c) Normal to orbit plane (km):            ?0.000000????"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to same: basic output, right endpoint overlap',
  'success',
  $spkdiff,
  '-t stats spkdiff_b222_s444.bsp spkdiff_b222_s444_day2.bsp',
  86,
  "from '2000 JAN 02 12:00:00.000 TDB'",
  "to   '2000 JAN 02 12:00:00.000 TDB'",
  "5a) Down track (km):                        0.0000000000",
  "5b) In orbit plane (km):                    0.0000000000",
  "5c) Normal to orbit plane (km):             0.0000000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to same: basic output, left endpoint overlap',
  'success',
  $spkdiff,
  '-t stats spkdiff_b222_s444_day3.bsp spkdiff_b222_s444_day2.bsp',
  86,
  "from '2000 JAN 03 12:00:00.000 TDB'",
  "to   '2000 JAN 03 12:00:00.000 TDB'",
  "5a) Down track (km):                        0.0000000000",
  "5b) In orbit plane (km):                    0.0000000000",
  "5c) Normal to orbit plane (km):             0.0000000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to same: basic output, big overlap on the right',
  'success',
  $spkdiff,
  '-t stats spkdiff_b222_s444.bsp spkdiff_b222_s444_2days.bsp',
  86,
  "from '2000 JAN 02 00:00:00.000 TDB'",
  "to   '2000 JAN 02 12:00:00.000 TDB'",
  "5a) Down track (km):                       ?0.000000????",
  "5b) In orbit plane (km):                   ?0.000000????",
  "5c) Normal to orbit plane (km):            ?0.000000????"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to same: basic output, big overlap on the left',
  'success',
  $spkdiff,
  '-t stats spkdiff_b222_s444_day3.bsp spkdiff_b222_s444_2days.bsp',
  86,
  "from '2000 JAN 03 12:00:00.000 TDB'",
  "to   '2000 JAN 04 00:00:00.000 TDB'",
  "5a) Down track (km):                        0.0000000000",
  "5b) In orbit plane (km):                    0.0000000000",
  "5c) Normal to orbit plane (km):             0.0000000000"
);

#
# Tests in this block should display basic report with all zeros
# because either the file is compared to itself or it is compared to
# the file with identical data. The purpose of these tests is to
# excercise all possible successful combinations of the
# body/center/frame and other selection arguments.
#
@basiczero = (
"Position:             0.0000000000000E+00      0.0000000000000E+00",
"Velocity:             0.0000000000000E+00      0.0000000000000E+00",
"Position (km):        0.0000000000000E+00      0.0000000000000E+00",
"Velocity (km/s):      0.0000000000000E+00      0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to same: basic output, resolved non-builtin frame from segment',
  'success',
  $spkdiff,
  '-k spkdiff_test.tf spkdiff_b555_s444.bsp spkdiff_b555_s444.bsp',
  37,
  "Comparison of 1000 'J2000_TEST'-referenced geometric states",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to same: basic output, body picked ahead of s/c if given with -b2',
  'success',
  $spkdiff,
  '-b2 222 spkdiff_b222_s333_b111.bsp spkdiff_b111_b222.bsp',
  33,
  "of '222' (222) relative to '111' (111)",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to same: basic output, body picked ahead of s/c if given with -b1',
  'success',
  $spkdiff,
  '-b1 222 spkdiff_b222_s333_b111.bsp spkdiff_b111_b222.bsp',
  33,
  "of '222' (222) relative to '111' (111)",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to same: basic output, s/c picked ahead of body',
  'success',
  $spkdiff,
  'spkdiff_b222_s333_b111.bsp spkdiff_b222_s333.bsp',
  33,
  "of '-333' (-333) relative to '222' (222)",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to same: basic output, body from last segment is picked',
  'success',
  $spkdiff,
  'spkdiff_b111_b222_b555.bsp spkdiff_b111_b555.bsp',
  33,
  "of '555' (555) relative to '111' (111)",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to same: basic output, s/c picked ahead of last if given with -b2',
  'success',
  $spkdiff,
  '-b2 -333 spkdiff_b222_s333_s444.bsp spkdiff_b222_s333.bsp',
  33,
  "of '-333' (-333) relative to '222' (222)",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to same: basic output, s/c picked ahead of last if given with -b1',
  'success',
  $spkdiff,
  '-b1 -333 spkdiff_b222_s333_s444.bsp spkdiff_b222_s333.bsp',
  33,
  "of '-333' (-333) relative to '222' (222)",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to same: basic output, s/c from last segment is picked',
  'success',
  $spkdiff,
  'spkdiff_b222_s333_s444.bsp spkdiff_b222_s444.bsp',
  33,
  "of '-444' (-444) relative to '222' (222)",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to same: basic output, relative to center from supporting SPKs',
  'success',
  $spkdiff,
  '-k spkdiff_b111_b222.bsp spkdiff_b111_b555.bsp -c1 111 spkdiff_b222_s333.bsp spkdiff_b555_s333.bsp',
  37,
  "of '-333' (-333) relative to '111' (111)",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to same: basic output, different bodies/centers/frames',
  'success',
  $spkdiff,
  '-k spkdiff_test.tf -b1 -333 -c1 222 -r1 J2000 -b2 -444 -c2 555 -r2 J2000_TEST spkdiff_b222_s333.bsp spkdiff_b555_s444.bsp',
  37,
  "of 'SC-333' (-333) relative to 'BODY222' (222)",
  "of 'SC-444' (-444) relative to 'BODY555' (555)",
  "Comparison of 1000 'J2000'-referenced geometric states",
  "with 1000 'J2000_TEST'-referenced geometric states",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to same: basic output, different frames',
  'success',
  $spkdiff,
  '-r1 J2000 -r2 B1950 spkdiff_b222_s333.bsp spkdiff_b222_s333_b1950.bsp',
  33,
  "of '-333' (-333) relative to '222' (222)",
  "Comparison of 1000 'J2000'-referenced geometric states",
  "with 1000 'B1950'-referenced geometric states",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to same: basic output, different centers',
  'success',
  $spkdiff,
  '-c1 222 -c2 555 spkdiff_b222_s333.bsp spkdiff_b555_s333.bsp',
  33,
  "of '-333' (-333) relative to '222' (222)",
  "of '-333' (-333) relative to '555' (555)",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to same: basic output, different bodies',
  'success',
  $spkdiff,
  '-b1 -333 -b2 -444 spkdiff_b222_s333.bsp spkdiff_b222_s444.bsp',
  33,
  "of '-333' (-333) relative to '222' (222)",
  "of '-444' (-444) relative to '222' (222)",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, all arguments',
  'success',
  $spkdiff,
  '-b1 -333 -c1 222 -r1 J2000 -b2 SC-333 -c2 BODY222 -r2 J2000 -n 2 -s 10 -k naif0008.tls spkdiff_test.tf -b 2000-01-01 12:00:00.000 TDB -e 2000-01-02 12:00:00.000 TDB -t basic spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  "from '2000 JAN 01 12:00:00.000 TDB'",
  "to   '2000 JAN 02 12:00:00.000 TDB'",
  "Comparison of 8641 ",
  "(0d 0h 0m 10.000000s)",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, time spec (ignored)',
  'success',
  $spkdiff,
  '-f '.$qt.'JUALIAND.######'.$qt.' spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  33,
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, step size supersedes number of steps',
  'success',
  $spkdiff,
  '-n 2 -s 10 -k naif0008.tls -b 2000-01-01 12:00:00.000 TDB -e 2000-01-02 12:00:00.000 TDB spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  "Comparison of 8641 ",
  "(0d 0h 0m 10.000000s)",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  "Compare to itself: basic output, number of steps $maxsteps (largest allowed)",
  'success',
  $spkdiff,
  "-n $maxsteps -k naif0008.tls -b 2000-01-01 12:00:00.000 TDB -e 2000-01-02 12:00:00.000 TDB spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp",
  37,
  "Comparison of $maxsteps ",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, number of steps 8641',
  'success',
  $spkdiff,
  '-n 8641 -k naif0008.tls -b 2000-01-01 12:00:00.000 TDB -e 2000-01-02 12:00:00.000 TDB spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  "Comparison of 8641 ",
  "(0d 0h 0m 10.000000s)",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, number of steps 2 (smallest allowed)',
  'success',
  $spkdiff,
  '-n 2 -k naif0008.tls -b 2000-01-01 12:00:00.000 TDB -e 2000-01-02 12:00:00.000 TDB spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  "Comparison of 2 ",
  "(1d 0h 0m 0.000000s)",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, step 3.661111e+03 (scientific notation)',
  'success',
  $spkdiff,
  '-s 3.661111e+03 -k naif0008.tls -b 2000-01-01 12:00:00.000 TDB -e 2000-01-02 12:00:00.000 TDB spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  "Comparison of 25 ",
  "(0d 1h 1m 1.111000s)",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, step 172799.999',
  'success',
  $spkdiff,
  '-s 172799.999 -k naif0008.tls -b 2000-01-01 12:00:00.000 TDB -e 2000-01-02 12:00:00.000 TDB spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  "Comparison of 2 ",
  "(1d 23h 59m 59.999000s)",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, step 86400.0',
  'success',
  $spkdiff,
  '-s 86400.0 -k naif0008.tls -b 2000-01-01 12:00:00.000 TDB -e 2000-01-02 12:00:00.000 TDB spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  "Comparison of 2 ",
  "(1d 0h 0m 0.000000s)",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, step 3661.111',
  'success',
  $spkdiff,
  '-s 3661.111 -k naif0008.tls -b 2000-01-01 12:00:00.000 TDB -e 2000-01-02 12:00:00.000 TDB spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  "Comparison of 25 ",
  "(0d 1h 1m 1.111000s)",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, step 3600.0',
  'success',
  $spkdiff,
  '-s 3600.0 -k naif0008.tls -b 2000-01-01 12:00:00.000 TDB -e 2000-01-02 12:00:00.000 TDB spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  "Comparison of 25 ",
  "(0d 1h 0m 0.000000s)",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, step 60.0',
  'success',
  $spkdiff,
  '-s 60.0 -k naif0008.tls -b 2000-01-01 12:00:00.000 TDB -e 2000-01-01 13:00:00.000 TDB spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  "Comparison of 61 ",
  "(0d 0h 1m 0.000000s)",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, step 1.0',
  'success',
  $spkdiff,
  '-s 1.0 -k naif0008.tls -b 2000-01-01 12:00:00.000 TDB -e 2000-01-01 13:00:00.000 TDB spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  "Comparison of 3601 ",
  "(0d 0h 0m 1.000000s)",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, step 0.1',
  'success',
  $spkdiff,
  '-s 0.1 -k naif0008.tls -b 2000-01-01 12:00:00.000 TDB -e 2000-01-01 12:10:00.000 TDB spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  "Comparison of 6001 ",
  "(0d 0h 0m 0.100000s)",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, step 0.01',
  'success',
  $spkdiff,
  '-s 0.01 -k naif0008.tls -b 2000-01-01 12:00:00.000 TDB -e 2000-01-01 12:00:10.000 TDB spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  "Comparison of 1001 ",
  "(0d 0h 0m 0.010000s)",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, step 0.001',
  'success',
  $spkdiff,
  '-s 0.001 -k naif0008.tls -b 2000-01-01 12:00:00.000 TDB -e 2000-01-01 12:00:01.000 TDB spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  "Comparison of 1001 ",
  "(0d 0h 0m 0.001000s)",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, step 0.000001',
  'success',
  $spkdiff,
  '-s 0.000001 -k naif0008.tls -b 2000-01-01 12:00:00.000 TDB -e 2000-01-01 12:00:00.001 TDB spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  "Comparison of 1001 ",
  "(0d 0h 0m 0.000001s)",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, step 0.00000001 (smallest allowed)',
  'success',
  $spkdiff,
  '-s 0.00000001 -k naif0008.tls -b 2000-01-01 12:00:00.000 TDB -e 2000-01-01 12:00:00.0001 TDB spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  "Comparison of 10000 ",
  "(0d 0h 0m 0.000000s)",
  @basiczero
);


&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, begin equal to begin, end within',
  'success',
  $spkdiff,
  '-k naif0008.tls -b 2000-01-01 12:00:00.000 TDB -e 2000-01-02 00:00:00.000 TDB spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  "from '2000 JAN 01 12:00:00.000 TDB'",
  "to   '2000 JAN 02 00:00:00.000 TDB'",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, begin within, end equal to end',
  'success',
  $spkdiff,
  '-k naif0008.tls -b 2000-01-02 00:00:00.000 TDB -e 2000-01-02 12:00:00.000 TDB spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  "from '2000 JAN 02 00:00:00.000 TDB'",
  "to   '2000 JAN 02 12:00:00.000 TDB'",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, begin/end equal to end',
  'success',
  $spkdiff,
  '-k naif0008.tls -b 2000-01-02 12:00:00.000 TDB -e 2000-01-02 12:00:00.000 TDB spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  "from '2000 JAN 02 12:00:00.000 TDB'",
  "to   '2000 JAN 02 12:00:00.000 TDB'",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, begin/end equal to begin',
  'success',
  $spkdiff,
  '-k naif0008.tls -b 2000-01-01 12:00:00.000 TDB -e 2000-01-01 12:00:00.000 TDB spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  "from '2000 JAN 01 12:00:00.000 TDB'",
  "to   '2000 JAN 01 12:00:00.000 TDB'",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, begin/end within begin/end',
  'success',
  $spkdiff,
  '-k naif0008.tls -b 2000-01-01 13:00:00.000 TDB -e 2000-01-02 11:00:00.000 TDB spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  "from '2000 JAN 01 13:00:00.000 TDB'",
  "to   '2000 JAN 02 11:00:00.000 TDB'",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, begin/end equal to begin/end',
  'success',
  $spkdiff,
  '-k naif0008.tls -b 2000-01-01 12:00:00.000 TDB -e 2000-01-02 12:00:00.000 TDB spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  "from '2000 JAN 01 12:00:00.000 TDB'",
  "to   '2000 JAN 02 12:00:00.000 TDB'",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, end time after end',
  'success',
  $spkdiff,
  '-k naif0008.tls -e 2000-01-03 12:00:00.000 TDB spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  "to   '2000 JAN 02 12:00:00.000 TDB'",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, end time equal to end',
  'success',
  $spkdiff,
  '-k naif0008.tls -e 2000-01-02 12:00:00.000 TDB spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  "to   '2000 JAN 02 12:00:00.000 TDB'",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, end time in the middle',
  'success',
  $spkdiff,
  '-k naif0008.tls -e 2000-01-02 00:00:00.000 TDB spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  "to   '2000 JAN 02 00:00:00.000 TDB'",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, end time equal to start',
  'success',
  $spkdiff,
  '-k naif0008.tls -e 2000-01-01 12:00:00.000 TDB spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  "to   '2000 JAN 01 12:00:00.000 TDB'",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, begin time equal to end',
  'success',
  $spkdiff,
  '-k naif0008.tls -b 2000-01-02 12:00:00.000 TDB spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  "from '2000 JAN 02 12:00:00.000 TDB'",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, begin time in the middle',
  'success',
  $spkdiff,
  '-k naif0008.tls -b 2000-01-02 00:00:00.000 TDB spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  "from '2000 JAN 02 00:00:00.000 TDB'",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, begin time equal to start',
  'success',
  $spkdiff,
  '-k naif0008.tls -b 2000-01-01 12:00:00.000 TDB spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  "from '2000 JAN 01 12:00:00.000 TDB'",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, begin time before start',
  'success',
  $spkdiff,
  '-k naif0008.tls -b 2000-01-01 11:00:00.000 TDB spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  "from '2000 JAN 01 12:00:00.000 TDB'",
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, all name/center/frame arguments',
  'success',
  $spkdiff,
  '-k spkdiff_test.tf -b1 -333 -c1 222 -r1 J2000 -b2 SC-333 -c2 BODY222 -r2 J2000 spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, -r1 name and -r2 name, different frame',
  'success',
  $spkdiff,
  '-r1 B1950 -r2 B1950 spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  33,
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, -r1 name and -r2 name',
  'success',
  $spkdiff,
  '-r1 J2000 -r2 J2000 spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  33,
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, -r2 name only',
  'success',
  $spkdiff,
  '-r2 J2000 spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  33,
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, -r1 name only',
  'success',
  $spkdiff,
  '-r1 J2000 spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  33,
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, -c1 name and -c2 ID',
  'success',
  $spkdiff,
  '-k spkdiff_test.tf -c1 BODY222 -c2 222 spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, -c1 ID and -c2 name',
  'success',
  $spkdiff,
  '-k spkdiff_test.tf -c1 222 -c2 BODY222 spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, -c1 name and -c2 name',
  'success',
  $spkdiff,
  '-k spkdiff_test.tf -c1 BODY222 -c2 BODY222 spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, -c2 name only',
  'success',
  $spkdiff,
  '-k spkdiff_test.tf -c2 BODY222 spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, -c1 name only',
  'success',
  $spkdiff,
  '-k spkdiff_test.tf -c1 BODY222 spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, -b1 name and -b2 ID',
  'success',
  $spkdiff,
  '-k spkdiff_test.tf -b1 SC-333 -b2 -333 spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, -b1 ID and -b2 name',
  'success',
  $spkdiff,
  '-k spkdiff_test.tf -b1 -333 -b2 SC-333 spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, -b1 name and -b2 name',
  'success',
  $spkdiff,
  '-k spkdiff_test.tf -b1 SC-333 -b2 SC-333 spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, -b2 name only',
  'success',
  $spkdiff,
  '-k spkdiff_test.tf -b2 SC-333 spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, -b1 name only',
  'success',
  $spkdiff,
  '-k spkdiff_test.tf -b1 SC-333 spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, -c1 ID and -c2 ID',
  'success',
  $spkdiff,
  '-c1 222 -c2 222 spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  33,
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, -c2 ID only',
  'success',
  $spkdiff,
  '-c2 222 spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  33,
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, -c1 ID only',
  'success',
  $spkdiff,
  '-c1 222 spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  33,
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, -b1 ID and -b2 ID',
  'success',
  $spkdiff,
  '-b1 -333 -b2 -333 spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  33,
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, -b2 ID only',
  'success',
  $spkdiff,
  '-b2 -333 spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  33,
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, -b1 ID only',
  'success',
  $spkdiff,
  '-b1 -333 spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  33,
  @basiczero
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: basic output, no arguments',
  'success',
  $spkdiff,
  'spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  33,
  @basiczero
);

#
# Tests in this block do literal check of COMPLETE images for various
# report types for a file compared to itself.
#
@basicwkreport = (
"# Comparison of 1000 'J2000'-referenced geometric states",
"#    of 'SC-333' (-333) relative to 'BODY222' (222)",
"#    from SPK 'spkdiff_b222_s333.bsp'",
"# with 1000 'J2000'-referenced geometric states",
"#    of 'SC-333' (-333) relative to 'BODY222' (222)",
"#    from SPK 'spkdiff_b222_s333.bsp'",
"# evenly-spaced with 86.486486486486 second (0d 0h 1m 26.486486s) step size",
"# within the time interval",
"#    from '2000 JAN 01 12:00:00.000 TDB' (0.00000000000000 TDB seconds)",
"#    to   '2000 JAN 02 12:00:00.000 TDB' (86400.000000000 TDB seconds)",
"# using additional data from these kernels",
"#    'naif0008.tls spkdiff_test.tf'",
"Relative differences in state vectors:",
"                              maximum                 average",
"  Position:             0.0000000000000E+00      0.0000000000000E+00",
"  Velocity:             0.0000000000000E+00      0.0000000000000E+00",
"Absolute differences in state vectors:",
"                              maximum                 average",
"  Position (km):        0.0000000000000E+00      0.0000000000000E+00",
"  Velocity (km/s):      0.0000000000000E+00      0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: complete basic output with extra kernels',
  'success',
  $spkdiff,
  '-k naif0008.tls spkdiff_test.tf spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  37,
  @basicwkreport
);


@basicreport = (
"# Comparison of 1000 'J2000'-referenced geometric states",
"#    of '-333' (-333) relative to '222' (222)",
"#    from SPK 'spkdiff_b222_s333.bsp'",
"# with 1000 'J2000'-referenced geometric states",
"#    of '-333' (-333) relative to '222' (222)",
"#    from SPK 'spkdiff_b222_s333.bsp'",
"# evenly-spaced with 86.486486486486 second (0d 0h 1m 26.486486s) step size",
"# within the time interval",
"#    from '2000 JAN 01 12:00:00.000 TDB' (0.00000000000000 TDB seconds)",
"#    to   '2000 JAN 02 12:00:00.000 TDB' (86400.000000000 TDB seconds)",
"Relative differences in state vectors:",
"                              maximum                 average",
"  Position:             0.0000000000000E+00      0.0000000000000E+00",
"  Velocity:             0.0000000000000E+00      0.0000000000000E+00",
"Absolute differences in state vectors:",
"                              maximum                 average",
"  Position (km):        0.0000000000000E+00      0.0000000000000E+00",
"  Velocity (km/s):      0.0000000000000E+00      0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: complete basic output',
  'success',
  $spkdiff,
  'spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  33,
  @basicreport
);

@statsreport = (
"# Comparison of 1000 'J2000'-referenced geometric states",
"#    of '-333' (-333) relative to '222' (222)",
"#    from SPK 'spkdiff_b222_s333.bsp'",
"# with 1000 'J2000'-referenced geometric states",
"#    of '-333' (-333) relative to '222' (222)",
"#    from SPK 'spkdiff_b222_s333.bsp'",
"# evenly-spaced with 86.486486486486 second (0d 0h 1m 26.486486s) step size",
"# within the time interval",
"#    from '2000 JAN 01 12:00:00.000 TDB' (0.00000000000000 TDB seconds)",
"#    to   '2000 JAN 02 12:00:00.000 TDB' (86400.000000000 TDB seconds)",
"1) Average components of position difference vectors in view",
"   frame coordinates:",
"   1a) Down track (km):                        0.0000000000000",
"   1b) In orbit plane (km):                    0.0000000000000",
"   1c) Normal to orbit plane (km):             0.0000000000000",
"   1d) Average delta time down track (sec):    0.0000000000000",
"2) Average |components| of position difference vectors in",
"   view frame coordinates:",
"   2a) Down track (km):                        0.0000000000000",
"   2b) In orbit plane (km):                    0.0000000000000",
"   2c) Normal to orbit plane (km):             0.0000000000000",
"   2d) Average |delta time| down track (sec):  0.0000000000000",
"3) RMS of position difference vectors in view frame coordinates:",
"   3a) Down track (km):                        0.0000000000000",
"   3b) In orbit plane (km):                    0.0000000000000",
"   3c) Normal to orbit plane (km):             0.0000000000000",
"   3d) RMS delta time down track (sec):        0.0000000000000",
"4) Components of the position difference vector in view frame",
"   coordinates for the states with the MAXIMUM RELATIVE",
"   difference in position:",
"   4a) Down track (km):                        0.0000000000000",
"   4b) In orbit plane (km):                    0.0000000000000",
"   4c) Normal to orbit plane (km):             0.0000000000000",
"   4d) Delta time down track (sec):            0.0000000000000",
"   4e) Epoch (TDB, seconds past J2000):        0.0000000000000",
"   4f) Epoch (TDB, calendar format):           2000-JAN-01-12:00:00.000",
"5) Components of the position difference vector in view frame",
"   coordinates for the states with the MAXIMUM ABSOLUTE",
"   difference in position:",
"   5a) Down track (km):                        0.0000000000000",
"   5b) In orbit plane (km):                    0.0000000000000",
"   5c) Normal to orbit plane (km):             0.0000000000000",
"   5d) Delta time down track (sec):            0.0000000000000",
"   5e) Epoch (TDB, seconds past J2000):        0.0000000000000",
"   5f) Epoch (TDB, calendar format):           2000-JAN-01-12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: complete stats output',
  'success',
  $spkdiff,
  '-t stats spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  86,
  @statsreport
);

@dumpreport = (
"# Comparison of 3 'J2000'-referenced geometric states",
"#    of '-333' (-333) relative to '222' (222)",
"#    from SPK 'spkdiff_b222_s333.bsp'",
"# with 3 'J2000'-referenced geometric states",
"#    of '-333' (-333) relative to '222' (222)",
"#    from SPK 'spkdiff_b222_s333.bsp'",
"# evenly-spaced with 43200.000000000 second (0d 12h 0m 0.000000s) step size",
"# within the time interval",
"#    from '2000 JAN 01 12:00:00.000 TDB' (0.00000000000000 TDB seconds)",
"#    to   '2000 JAN 02 12:00:00.000 TDB' (86400.000000000 TDB seconds)",
"# time, (x1-x2), (y1-y2), (z1-z2), (vx1-vx2), (vy1-vy2), (vz1-vz2)",
"0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
"4.3200000000000E+04 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
"8.6400000000000E+04 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: complete dump output',
  'success',
  $spkdiff,
  '-t dump -n 3 spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  21,
  @dumpreport
);

@dumpvfreport = (
"# Comparison of 3 'J2000'-referenced geometric states",
"#    of '-333' (-333) relative to '222' (222)",
"#    from SPK 'spkdiff_b222_s333.bsp'",
"# with 3 'J2000'-referenced geometric states",
"#    of '-333' (-333) relative to '222' (222)",
"#    from SPK 'spkdiff_b222_s333.bsp'",
"# evenly-spaced with 43200.000000000 second (0d 12h 0m 0.000000s) step size",
"# within the time interval",
"#    from '2000 JAN 01 12:00:00.000 TDB' (0.00000000000000 TDB seconds)",
"#    to   '2000 JAN 02 12:00:00.000 TDB' (86400.000000000 TDB seconds)",
"# time, down_track_p_diff, normal_to_plane_p_diff, in_plane_p_diff, down_track_v_diff, normal_to_plane_v_diff, in_plane_v_diff",
"0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
"4.3200000000000E+04 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
"8.6400000000000E+04 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Compare to itself: complete dumpvf output',
  'success',
  $spkdiff,
  '-t dumpvf -n 3 spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  21,
  @dumpvfreport
);

#
# Tests in this block should display the following usage.
#
@usage = (
"   spkdiff computes differences between geometric states obtained from",
"   two SPK files and either displays these differences or shows statistics",
"   about them (see the User's Guide for more details.) The program usage is:",
"      % spkdiff [options] <first SPK file> <second SPK file>",
"   Options are shown below. Order and case of keys are not significant.",
"   Values must be space-separated from keys, i.e. '-n 10', not '-n10'.",
"      -b1 <first body name or ID>",
"      -c1 <first center name or ID>",
"      -r1 <first reference frame name>",
"      -b2 <second body name or ID>",
"      -c2 <second center name or ID>",
"      -r2 <second reference frame name>",
"      -k  <other kernel file name(s)>",
"      -b  <interval start time>",
"      -e  <interval stop time>",
"      -s  <time step in seconds>",
"      -n  <number of states: 2 to $maxsteps (default: 1000)>",
"      -f  <output time format (default: TDB seconds past J2000)>",
"      -t  <report type: basic|stats|dump|dumpvf (default: basic)>"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Usage display: -usage argument, with files',
  'success',
  $spkdiff,
  '-usage spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  26,
  @usage
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Usage display: -u argument, with files',
  'success',
  $spkdiff,
  '-u spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  26,
  @usage
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Usage display: -help argument, with files',
  'success',
  $spkdiff,
  '-help spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  26,
  @usage
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Usage display: -h argument, with files',
  'success',
  $spkdiff,
  '-h spkdiff_b222_s333.bsp spkdiff_b222_s333.bsp',
  26,
  @usage
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Usage display: -Usage (mixed case) argument, no files',
  'success',
  $spkdiff,
  '-Usage',
  26,
  @usage
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Usage display: -Help  (mixed case) argument, no files',
  'success',
  $spkdiff,
  '-Help',
  26,
  @usage
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Usage display: -USAGE (uppercase) argument, no files',
  'success',
  $spkdiff,
  '-USAGE',
  26,
  @usage
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Usage display: -U (uppercase) argument, no files',
  'success',
  $spkdiff,
  '-U',
  26,
  @usage
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Usage display: -HELP (uppercase) argument, no files',
  'success',
  $spkdiff,
  '-HELP',
  26,
  @usage
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Usage display: -H (uppercase) argument, no files',
  'success',
  $spkdiff,
  '-H',
  26,
  @usage
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Usage display: -usage argument, no files',
  'success',
  $spkdiff,
  '-usage',
  26,
  @usage
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Usage display: -u argument, no files',
  'success',
  $spkdiff,
  '-u',
  26,
  @usage
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Usage display: -help argument, no files',
  'success',
  $spkdiff,
  '-help',
  26,
  @usage
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Usage display: -h argument, no files',
  'success',
  $spkdiff,
  '-h',
  26,
  @usage
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Usage display: too few command line arguments',
  'success',
  $spkdiff,
  'spkdiff_b111_b222.bsp',
  26,
  @usage
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Usage display: no command line arguments',
  'success',
  $spkdiff,
  ' ',
  26,
  @usage
);

#
# Prepare test data
#
print "\n";
print "Deleting test data ...\n";
print "\n";
&test_data( $mkspk, "delete" );

#
# All done.
#
print "\n";
print "Total: $counttotal --- Passed: $countpass  --- Failed: $countfail\n";
print "\n";

exit;

#
# This routine runs the specified test and prints results to the screen.
#
sub run_test {

  #
  # All argument are inputs. Output is via displaying report message to
  # the screen. Arguments are:
  #
  #    $reporttype  -- lists all types of info to be included into the report
  #                    (possible values are "command", "output", "expvalues")
  #    $maxtocompare - maximum number of characters from each @expvalue line
  #                    to check in inputs; if "", check complete lines
  #    $shortonly   -- flag indicating whether only 'SPICE(...)' line from
  #                    @expvalue should be checked in the output for 
  #                    failure-type cases; "yes" or "no"
  #    $checkcount  -- flag indicating whether the count of output lines
  #                    should be checked; "yes" or "no"
  #    $logname     -- the name of a log file, the contents of which should be
  #                    checked instead of captured STDOUT output; if "",
  #                    STDOUT is checked
  #    $testdesc    -- text line describing test
  #    $testtype    -- "success" or "failure" for expected status 0 or non 0
  #    $progname    -- name of program to run
  #    $commandline -- complete command line
  #    $expcount    -- expected count of output lines
  #    @expvalue    -- an array of strings to look for in the output.
  #                    "?" in these string stands for "any one character".
  #
  ( $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
    $testdesc,
    $testtype,
    $progname,
    $commandline,
    $expcount,
    @expvalue ) = @_;
  $infotypes = $reporttype;
  $report = "";

  $counttotal++;

  #
  # Run the test and save screen output.
  #
  $result = `$progname $commandline 2>&1`;

  #
  # Check exit status vs expected status and reflect then in the report.
  #
  $status = ( $? >> 8 );
  if (    ( ( ! $status ) && $testtype eq "success" ) ||
          ( (   $status ) && $testtype eq "failure" )    ) {
    #
    # Expected status matches returned status. Good.
    #
    $report = "";
  } elsif ( ( ! $status ) && $testtype eq "failure" ) {
    #
    # Expected failure, got success. Bad.
    #
    $report = "\n   ERROR: expected failure but returned with success.\n ";
  } elsif ( (   $status ) && $testtype eq "success" ) {
    #
    # Expected success, got failure. Bad.
    #
    $report = "\n   ERROR: expected success but returned with failure.\n ";
  }

  #
  # Check that output has expected number of lines.
  #
  if ( $checkcount eq "yes" ) {
    $rescount = 0;
    while( $result =~ m/\n/g ) {
      $rescount++;
    }
    if ( $rescount != $expcount ) {
      $report = $report.
      "\n   ERROR: expected $expcount output lines but got $rescount.\n";
    }
  }

  #
  # Check that each of expected lines is present in the output.
  #
  $checkedcount = 0;

  for ($i = 0; $i <= $#expvalue; $i++ ) {

    #
    # Take all or a part of expected value based on $maxtocompare.
    #
    if ( $maxtocompare eq "" ) {
      $shortexpvalue = $expvalue[$i];
    } else {
      $shortexpvalue = substr( $expvalue[$i], 0, $maxtocompare );
    }

    #
    # Pre-process expected value to escape all special regex characters
    # except "?" which, from this routine's point of view, stands for
    # "any one character" and, therefore, get replaced with ".".
    #
    $modexpvalue = $shortexpvalue;
    $modexpvalue =~ s/\\/\\\\/g;
    $modexpvalue =~ s/\n/\\n/g;
    $modexpvalue =~ s/\./\\./g;
    $modexpvalue =~ s/\^/\\^/g;
    $modexpvalue =~ s/\$/\\\$/g;
    $modexpvalue =~ s/\*/\\*/g;
    $modexpvalue =~ s/\+/\\+/g;
    $modexpvalue =~ s/\{/\\{/g;
    $modexpvalue =~ s/\}/\\}/g;
    $modexpvalue =~ s/\[/\\[/g;
    $modexpvalue =~ s/\]/\\]/g;
    $modexpvalue =~ s/\(/\\(/g;
    $modexpvalue =~ s/\)/\\)/g;
    $modexpvalue =~ s/\|/\\|/g;

    $modexpvalue =~ s/\?/\./g;

    #
    # Check if the output contained expected string. First, make an exception
    # for failure-type runs checking only short error messages.
    #
    if ( $testtype  eq "failure" &&
         $shortonly eq "yes"     &&
         ! ( $shortexpvalue =~ /^SPICE\(.+\)$/ ) ) {

      #
      # Don't check this line because it is not a short error message.
      #

    } else {

      if ( $result =~ /$modexpvalue/ ) {

	#
	# Expected string is present in the output. Good.
	#

      } else {

	#
	# Expected string is NOT present in the output. Bad.
	#
	$report = $report.
	 "\n   ERROR: expected string '$shortexpvalue' was not in the output.\n";

      }

      $checkedcount++;

    }

  }

  #
  # Safety belt against poor test setups: verify that we checked at
  # least one line.
  #
  if ( $checkedcount == "0" ) {
    $report = $report.
      "\n   ERROR: bad test case setup: no lines from expected values were checked.\n";
  }

  #
  # Finalize report.
  #
  if ( $report eq "" ) {

    $countpass++;
    $report = "--- passed --- ($testtype) $testdesc\n";

  } else {

    $countfail++;
    $report = "\n".
              "--- FAILED --- ($testtype) $testdesc\n".
              "$report";

    $infotypes = "command output expvalues";

  }

  #
  # Add additonal information to the report as needed.
  #
  if ( $infotypes =~ /command/ ) {
    $report = "$report".
              "\n".
              "   COMMAND --- \n".
              "\n".
              "$progname $commandline\n".
              "\n";
  }

  if ( $infotypes =~ /output/ ) {
    $report = "$report".
              "\n".
              "   OUTPUT --- \n".
              "\n".
              "$result\n".
              "\n";
  }

  if ( $infotypes =~ /expvalues/ ) {
    $report = "$report".
              "\n".
              "   EXPECTED VALUES --- \n".
              "\n";

    for ($i = 0; $i <= $#expvalue; $i++ ) {
      if ( $maxtocompare eq "" ) {
	$report = "$report".
	          "$expvalue[$i]\n";
      } else {
	$report = "$report".
	          substr( $expvalue[$i], 0, $maxtocompare )."\n";
      }
    }
    $report = "$report\n";
  }

  #
  # Display report.
  #
  print $report;

}

#
# This routine generates all necessary kernels.
#
sub test_data {

  #
  # The only inputs are MKSPK exe location and action ("make" or "delete"). 
  # Outputs are files needed for the test.
  #
  ( $mkspk, $action ) = @_;
  $myaction = $action;

  #
  # The following files will be made
  #
  # 1)  naif0008.tls --- LSK
  #
  # 2)  spkdiff_test.tf --- FK with name/ID mappings and one frame J2000_TEST
  #
  # 3)  spkdiff_b111_b222.bsp --- fixed pos of 222 wrt 111 in J2000
  #
  # 4)  spkdiff_b111_b555.bsp --- same as file 3) but for body 555
  #
  # 5)  spkdiff_b111_b222_b555.bsp --- merge of 3) and 4)
  #
  # 6)  spkdiff_b222_s333.bsp --- nominal(*) traj of -333 wrt 222 in J2000
  #
  # 7)  spkdiff_b222_s444.bsp --- same as 6) but for -444
  #
  # 8)  spkdiff_b222_s333_s444.bsp --- merge of 6) and 7)
  #
  # 9)  spkdiff_b222_s333_b111.bsp --- merge 3) and 6)
  #
  # 10) spkdiff_b222_s333_b1950.bsp --- nominal* traj of -333 wrt 222 in B1950
  #
  # 11) spkdiff_b555_s333.bsp --- nominal* traj of -333 wrt 555 in J2000
  #
  # 12) spkdiff_b222_s444_2days.bsp --- nominal* traj of -444 wrt 222 in J2000
  #                    for 2000-01-02 00:00 TDB to 2000-01-04 00:00 TDB
  #
  # 13) spkdiff_b222_s444_day2.bsp --- nominal* traj of -444 wrt 222 in J2000
  #                    for 2000-01-02 12:00 TDB to 2000-01-03 12:00 TDB
  #
  # 14) spkdiff_b222_s444_day3.bsp --- nominal* traj of -444 wrt 222 in J2000
  #                    for 2000-01-03 12:00 TDB to 2000-01-04 12:00 TDB
  #
  # 15) spkdiff_b222_s444_day1_3.bsp --- merge of 7) and 14)
  #
  # 16) spkdiff_b222_s444_dt1.bsp --- nominal traj shifted in X by 1 km
  #
  # 17) spkdiff_b222_s444_ip1.bsp --- nominal traj shifted in Y by 1 km
  #
  # 18) spkdiff_b222_s444_np1.bsp --- nominal traj shifted in Z by 1 km
  #
  # 19) spkdiff_b222_s444_all.bsp --- nominal traj shifted in X, Y, Z by 1 km
  #
  # 20) spkdiff_b222_s444_fast.bsp --- traj string in the same place as
  #                                    nominal but moving with [2,1,1] velocity
  #
  # 21) spkdiff_b222_s444_opp.bsp --- traj opposite to nominal: from [86400,
  #                                   1000, 0] to [0, 1000, 0] with [1,0,0]
  #                                   velocity during the same period
  #
  # 22) spkdiff_b555_s444.bsp --- nominal traj of -444 wrt 555 in J2000_TEST
  #
  # (*) nominal trajectory is from 2000-01-01 12:00 TDB to 2000-01-02 12:00
  #     TDB moving from [0, 1000, 0] to [86400, 1000, 0] with velocity [1,0,0];
  #     in longer/later SPK this line motion is simply extended for further
  #     days.
  #
  # LSK and any other text kernels that are needed should be at the
  # top of the list to be made first):
  #
  @files = (
            "naif0008.tls",
            "spkdiff_test.tf",
            "spkdiff_b111_b222.bsp",
            "spkdiff_b111_b222_b555.bsp",
            "spkdiff_b111_b555.bsp",
            "spkdiff_b222_s333.bsp",
            "spkdiff_b222_s333_s444.bsp",
            "spkdiff_b222_s333_b111.bsp",
            "spkdiff_b222_s333_b1950.bsp",
            "spkdiff_b555_s333.bsp",
            "spkdiff_b222_s444.bsp",
            "spkdiff_b222_s444_2days.bsp",
            "spkdiff_b222_s444_all.bsp",
            "spkdiff_b222_s444_day2.bsp",
            "spkdiff_b222_s444_day3.bsp",
            "spkdiff_b222_s444_day1_3.bsp",
            "spkdiff_b222_s444_dt1.bsp",
            "spkdiff_b222_s444_ip1.bsp",
            "spkdiff_b222_s444_np1.bsp",
            "spkdiff_b222_s444_fast.bsp",
            "spkdiff_b222_s444_opp.bsp",
            "spkdiff_b555_s444.bsp"
           );

  #
  # Loop through the file list.
  #
  foreach $file ( @files ) {

    #
    # Check if there is anything to be done for this file. Report if
    # there is.
    #
    $myaction = $action;
    if (      (   -e $file && $myaction eq "make"   ) ) {
      print "--- no need to make existing $file ... \n";
      $myaction = "do nothing";
    } elsif ( ( ! -e $file && $myaction eq "delete" )   ) {
      print "--- no need to delete non-existing $file ... \n";
      $myaction = "do nothing";
    } elsif ( ( ! -e $file && $myaction eq "make"   ) ) {
      print "--- creating $file ...\n";
    } elsif ( (   -e $file && $myaction eq "delete" ) ) {
      print "--- deleting $file ...\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "spkdiff_b111_b222.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of SPKDIFF.
Body 222 wrt body 111; fixed position.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = 222
   CENTER_ID         = 111
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for SPKDIFF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB, 0, 1000, 0, 0, 0, 0
2000-01-02 12:00:00 TDB, 0, 1000, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "spkdiff_b111_b222.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "spkdiff_b111_b222_b555.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of SPKDIFF.
Body 222 wrt body 111; fixed position.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = 222
   CENTER_ID         = 111
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for SPKDIFF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB, 0, 1000, 0, 0, 0, 0
2000-01-02 12:00:00 TDB, 0, 1000, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of SPKDIFF.
Body 555 wrt body 111; fixed position.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = 555
   CENTER_ID         = 111
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for SPKDIFF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB, 0, 1000, 0, 0, 0, 0
2000-01-02 12:00:00 TDB, 0, 1000, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file -append 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "spkdiff_b111_b222_b555.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "spkdiff_b111_b555.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of SPKDIFF.
Body 555 wrt body 111; fixed position.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = 555
   CENTER_ID         = 111
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for SPKDIFF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB, 0, 1000, 0, 0, 0, 0
2000-01-02 12:00:00 TDB, 0, 1000, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "spkdiff_b111_b555.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "spkdiff_b222_s333.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of SPKDIFF.
Spacecraft -333 wrt body 222; nominal file.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -333
   CENTER_ID         = 222
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for SPKDIFF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB,     0, 1000, 0, 1, 0, 0
2000-01-02 12:00:00 TDB, 86400, 1000, 0, 1, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "spkdiff_b222_s333.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "spkdiff_b222_s333_s444.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of SPKDIFF.
Spacecraft -333 wrt body 222; nominal file.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -333
   CENTER_ID         = 222
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for SPKDIFF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB,     0, 1000, 0, 1, 0, 0
2000-01-02 12:00:00 TDB, 86400, 1000, 0, 1, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of SPKDIFF.
Spacecraft -444 wrt body 222; nominal file.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -444
   CENTER_ID         = 222
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for SPKDIFF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB,     0, 1000, 0, 1, 0, 0
2000-01-02 12:00:00 TDB, 86400, 1000, 0, 1, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file -append 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "spkdiff_b222_s333_s444.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "spkdiff_b222_s333_b111.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of SPKDIFF.
Spacecraft -333 wrt body 222; nominal file.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -333
   CENTER_ID         = 222
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for SPKDIFF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB,     0, 1000, 0, 1, 0, 0
2000-01-02 12:00:00 TDB, 86400, 1000, 0, 1, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of SPKDIFF.
Body 222 wrt body 111; fixed position.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = 222
   CENTER_ID         = 111
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for SPKDIFF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB, 0, 1000, 0, 0, 0, 0
2000-01-02 12:00:00 TDB, 0, 1000, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file -append 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "spkdiff_b222_s333_b111.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "spkdiff_b222_s333_b1950.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of SPKDIFF.
Spacecraft -333 wrt body 222; nominal file.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -333
   CENTER_ID         = 222
   REF_FRAME_NAME    = 'B1950'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for SPKDIFF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB,     0, 1000, 0, 1, 0, 0
2000-01-02 12:00:00 TDB, 86400, 1000, 0, 1, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "spkdiff_b222_s333_b1950.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "spkdiff_b555_s333.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of SPKDIFF.
Spacecraft -333 wrt body 555; nominal file.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -333
   CENTER_ID         = 555
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for SPKDIFF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB,     0, 1000, 0, 1, 0, 0
2000-01-02 12:00:00 TDB, 86400, 1000, 0, 1, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "spkdiff_b555_s333.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "spkdiff_b222_s444.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of SPKDIFF.
Spacecraft -444 wrt body 222; nominal file.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -444
   CENTER_ID         = 222
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for SPKDIFF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB,     0, 1000, 0, 1, 0, 0
2000-01-02 12:00:00 TDB, 86400, 1000, 0, 1, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "spkdiff_b222_s444.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "spkdiff_b222_s444_2days.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of SPKDIFF.
Spacecraft -444 wrt body 222; covering from half day to 2.5 days out.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -444
   CENTER_ID         = 222
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for SPKDIFF test'
\\begintext

MKSPK input data:

2000-01-02 00:00:00 TDB,  43200, 1000, 0, 1, 0, 0
2000-01-04 00:00:00 TDB, 216000, 1000, 0, 1, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "spkdiff_b222_s444_2days.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "spkdiff_b222_s444_all.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of SPKDIFF.
Spacecraft -444 wrt body 222; down/normal/in-plane deltas of 1 km.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -444
   CENTER_ID         = 222
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for SPKDIFF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB,     1, 1001, 1, 1, 0, 0
2000-01-02 12:00:00 TDB, 86401, 1001, 1, 1, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "spkdiff_b222_s444_all.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "spkdiff_b222_s444_day2.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of SPKDIFF.
Spacecraft -444 wrt body 222; covering next day.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -444
   CENTER_ID         = 222
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for SPKDIFF test'
\\begintext

MKSPK input data:

2000-01-02 12:00:00 TDB,  86400, 1000, 0, 1, 0, 0
2000-01-03 12:00:00 TDB, 172800, 1000, 0, 1, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "spkdiff_b222_s444_day2.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "spkdiff_b222_s444_day3.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of SPKDIFF.
Spacecraft -444 wrt body 222; covering day after next day.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -444
   CENTER_ID         = 222
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for SPKDIFF test'
\\begintext

MKSPK input data:

2000-01-03 12:00:00 TDB, 172800, 1000, 0, 1, 0, 0
2000-01-04 12:00:00 TDB, 259200, 1000, 0, 1, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "spkdiff_b222_s444_day3.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "spkdiff_b222_s444_day1_3.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of SPKDIFF.
Spacecraft -444 wrt body 222; nominal file.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -444
   CENTER_ID         = 222
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for SPKDIFF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB,     0, 1000, 0, 1, 0, 0
2000-01-02 12:00:00 TDB, 86400, 1000, 0, 1, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of SPKDIFF.
Spacecraft -444 wrt body 222; covering day after next day.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -444
   CENTER_ID         = 222
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for SPKDIFF test'
\\begintext

MKSPK input data:

2000-01-03 12:00:00 TDB, 172800, 1000, 0, 1, 0, 0
2000-01-04 12:00:00 TDB, 259200, 1000, 0, 1, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file -append 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "spkdiff_b222_s444_day1_3.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "spkdiff_b222_s444_dt1.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of SPKDIFF.
Spacecraft -444 wrt body 222; down track delta of 1 km.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -444
   CENTER_ID         = 222
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for SPKDIFF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB,     1, 1000, 0, 1, 0, 0
2000-01-02 12:00:00 TDB, 86401, 1000, 0, 1, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "spkdiff_b222_s444_dt1.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "spkdiff_b222_s444_ip1.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of SPKDIFF.
Spacecraft -444 wrt body 222; in plane delta of 1 km.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -444
   CENTER_ID         = 222
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for SPKDIFF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB,     0, 1001, 0, 1, 0, 0
2000-01-02 12:00:00 TDB, 86400, 1001, 0, 1, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "spkdiff_b222_s444_ip1.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "spkdiff_b222_s444_np1.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of SPKDIFF.
Spacecraft -444 wrt body 222; normal to plane delta of 1 km.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -444
   CENTER_ID         = 222
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for SPKDIFF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB,     0, 1000, 1, 1, 0, 0
2000-01-02 12:00:00 TDB, 86400, 1000, 1, 1, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "spkdiff_b222_s444_np1.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "spkdiff_b222_s444_fast.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of SPKDIFF.
Spacecraft -444 wrt body 222; going faster in all directions..

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -444
   CENTER_ID         = 222
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for SPKDIFF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB,      0,  1000,     0, 2, 1, 1
2000-01-02 12:00:00 TDB, 172800, 87400, 86400, 2, 1, 1
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "spkdiff_b222_s444_fast.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "spkdiff_b222_s444_opp.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of SPKDIFF.
Spacecraft -444 wrt body 222; moving in opposite direction.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -444
   CENTER_ID         = 222
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for SPKDIFF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB, 86400, 1000, 0, -1, 0, 0
2000-01-02 12:00:00 TDB,     0, 1000, 0, -1, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "spkdiff_b222_s444_opp.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "spkdiff_b555_s444.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of SPKDIFF.
Spacecraft -444 wrt body 555; nominal file.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -444
   CENTER_ID         = 555
   REF_FRAME_NAME    = 'J2000_TEST'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   FRAME_DEF_FILE    = 'spkdiff_test.tf'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 26
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for SPKDIFF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB,     0, 1000, 0, 1, 0, 0
2000-01-02 12:00:00 TDB, 86400, 1000, 0, 1, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "spkdiff_b555_s444.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "naif0008.tls" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
KPL/LSK

\\begindata

DELTET/DELTA_T_A       =   32.184
DELTET/K               =    1.657D-3
DELTET/EB              =    1.671D-2
DELTET/M               = (  6.239996D0   1.99096871D-7 )

DELTET/DELTA_AT        = ( 10,   \@1972-JAN-1
                           11,   \@1972-JUL-1
                           12,   \@1973-JAN-1
                           13,   \@1974-JAN-1
                           14,   \@1975-JAN-1
                           15,   \@1976-JAN-1
                           16,   \@1977-JAN-1
                           17,   \@1978-JAN-1
                           18,   \@1979-JAN-1
                           19,   \@1980-JAN-1
                           20,   \@1981-JUL-1
                           21,   \@1982-JUL-1
                           22,   \@1983-JUL-1
                           23,   \@1985-JUL-1
                           24,   \@1988-JAN-1
                           25,   \@1990-JAN-1
                           26,   \@1991-JAN-1
                           27,   \@1992-JUL-1
                           28,   \@1993-JUL-1
                           29,   \@1994-JUL-1
                           30,   \@1996-JAN-1
                           31,   \@1997-JUL-1
                           32,   \@1999-JAN-1
                           33,   \@2006-JAN-1 )

\\begintext
EndBlock

      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }

    if ( $file eq "naif0008.tls" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "spkdiff_test.tf" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
KPL/FK

This is a special FK for testing of SPKDIFF. It defines name-ID
mappings for bodies and s/c in SPKDIFF test SPK and a fixed frame
coaligned with J2000.

\\begindata

   NAIF_BODY_NAME += ( 'BODY111' )
   NAIF_BODY_CODE += ( 111       )

   NAIF_BODY_NAME += ( 'BODY222' )
   NAIF_BODY_CODE += ( 222       )

   NAIF_BODY_NAME += ( 'BODY555' )
   NAIF_BODY_CODE += ( 555       )

   NAIF_BODY_NAME += ( 'SC-333'  )
   NAIF_BODY_CODE += ( -333      )

   NAIF_BODY_NAME += ( 'SC-444'  )
   NAIF_BODY_CODE += ( -444      )

   FRAME_J2000_TEST                =  111111
   FRAME_111111_NAME               = 'J2000_TEST'
   FRAME_111111_CLASS              =  4
   FRAME_111111_CLASS_ID           =  111111
   FRAME_111111_CENTER             =  111
   TKFRAME_111111_RELATIVE         = 'J2000'
   TKFRAME_111111_SPEC             = 'ANGLES'
   TKFRAME_111111_UNITS            = 'DEGREES'
   TKFRAME_111111_AXES             = ( 1,   2,   3   )
   TKFRAME_111111_ANGLES           = ( 0.0, 0.0, 0.0 )

\\begintext
EndBlock

      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }

    if ( $file eq "spkdiff_test.tf" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

  }

}
