#!/usr/bin/perl
# /bin/perl
# /usr/contrib/bin/perl
#
# This script tests BRIEF. It includes two routines: test_data and run_test.
# test_data is called once to generate all needed kernels; run_test is
# call once for each test case and reports to the screen.
#
$version = "2.0.0 -- October 15, 2008 -- BVS/NAIF";

#
# Version 2.0.0 -- October 15, 2008 -- BVS/NAIF
#
#    Updated for run_test with line counting and single-character pattern.
#
# Version 1.1.0 -- February 22, 2008 -- BVS/NAIF
#
#    Made text .xc and .xu files larger to prevent GETFAT failure in
#    TOBIN. Replaced SDU with NEXT and adjusted output benchmark lines
#    indentation as needed.
#
# Version 1.0.0 -- January 14, 2008 -- BVS/NAIF
#
#    Initial version.
#
#---------------------------------------------------------------------------
# Begin of configuration parameter section. For descriptions, see below.
#---------------------------------------------------------------------------

#
# For UNIX:
#
$brief         = "./brief";
$mkspk         = "./mkspk";
$tobin         = "./tobin";
$maxtocompare  = "";
$shortonly     = "no";
$checkcount    = "yes";
$qt            = "'";

#
# For Windows.
#
#$brief         = ".\\brief";
#$mkspk         = ".\\mkspk";
#$tobin         = ".\\tobin";
#$maxtocompare  = "77";
#$shortonly     = "yes";
#$checkcount    = "no";
#$qt            = "";

#
# For CYGWIN:
#
#$brief         = "brief";
#$mkspk         = "mkspk";
#$tobin         = "tobin";
#$maxtocompare  = "";
#$shortonly     = "no";
#$checkcount    = "yes";
#$qt            = "'";

#
# Configurable parameter descriptions:
#
# $brief         Executables invoked by and other files used by the
# $mkspk         script.
# $tobin
#
# $maxtocompare  the number of characters of each expected value to be
#                used in comparison. To use all characters it must be
#                set to "".
#
# $shortonly     flag indicating whether for failure-type cases only
#                short error message should be checked ("yes" or "no").
#
# $checkcount    flag indicating whether the output line count should
#                be checked ("yes" or "no").
#
# $qt            quote used to quote command line keys and values that
#                cannot be specified unquoted (for example [] must be
#                passed as '[]' to Unix shells)
#
# $reporttype    information types that test cases should report (space
#                delimited list including any combination of these
#                words "command output expvalues")
#
# $logname       log file name (to be passed as argument to run_test)
# $logopt        and log file option (to be included in the command
#                line passed to run_test).
#

$reporttype = " ";

$logname = "";
$logopt  = "";
#$logname = "tmp.log";
#$logopt  = "-l tmp.log ";

#---------------------------------------------------------------------------
# End of configuration parameter section.
#---------------------------------------------------------------------------

#
# These counters are global variables incremented by run_test routine. (Yuck!)
#
$counttotal = 0;
$countpass  = 0;
$countfail  = 0;

#
# Generate test report banner. Include OS name and date.
#
$seconds = time;
($sec,$min,$hours,$mday,$mon,$year,$wday,$yday) = gmtime($seconds);

print  "\n";
print  "BRIEF Test Suite, Version -- $version\n";
print  "\n";
printf "--- DATE: %4d-%02d-%02d %02d:%02d:%02d GMT\n",
       $year+1900, $mon+1, $mday, $hours, $min, $sec;
print  "--- OS:   $^O\n";

#
# Run BRIEF without command line arguments and dump its output to
# the screen to remove any ambiguity of what version is tested.
#

$result = `$brief 2>&1`;
print "\n";
print "Testing the following BRIEF:\n";
print "\n";
print "--- $brief\n";
print "\n";
print "$result";

#
# Prepare test data
#
print "\n";
print "Preparing test data ...\n";
print "\n";
&test_data( $mkspk, $tobin, "make" );

#
# Run tests.
#
print "\n";
print "Executing tests ...\n";
print "\n";

#
# Tests in this block test exceptions.
#

#
# The following exceptions can be caused only by bugs in BRIEF
# and for this reason are not exersized. They are (module/error):
#
#   distim/BADTIMEFORMAT
#   objadd/BUG
#   objchk/BADOBJECTID
#   objchk/BADOBJECTID
#   objchk/BADOBJECTID
#   objchk/BADOBJECTID
#   objchk/BADOBJECTID
#   objget/INACTIVEOBJECT
#   objmod/INACTIVEOBJECT
#   objmod/BADCOMPNUMBER
#   objset/INACTIVEOBJECT
#   objval/INACTIVEOBJECT
#   objval/BADCOMPNUMBER
#

#
# The following exceptions can be caused only by buffer overflows and
# are not covered due to impracticality of pushing the large limits set
# for buffers:
#
#   brief/wnunid/WINDOWEXCESS   -- too many windows for a body
#                                  (limit LRGWIN in brief.inc)
#
#   brief/syputd/NAMETABLEFULL  -- too many bodies
#                                  (limit MAXBOD in brief.inc)
#
#   brief/syputd/VALUETABLEFULL -- too many total windows for all bodies
#                                  (limit MAXBOD*AVEWIN in brief.pgm)
#

#
# Exceptions yet to cover: command line syntax, other?
#

#
# Exceptions yet to cover: boundary conditions: long file names, too
# many files too many segments (if applicable),
# WHAT ELSE?
#

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: LSK data no loaded for UTC output',
  'failure',
  $brief,
  '-utc brief_sc_1seg.bsp',
  28,
  "SPICE(MISSINGTIMEINFO)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: LSK data no loaded for UTC/DOY output',
  'failure',
  $brief,
  '-utcdoy brief_sc_1seg.bsp',
  28,
  "SPICE(MISSINGTIMEINFO)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: file specified on command line does not exist',
  'failure',
  $brief,
  'ghost1_spk.bsp',
  16,
  "The kernel file 'ghost1_spk.bsp' does not exist.",
  "SPICE(FILENOTFOUND)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: file specified in the list file does not exist',
  'failure',
  $brief,
  '-f brief_list_bad_nonexisting.lst',
  16,
  "The kernel file 'ghost2_spk.bsp' does not exist.",
  "SPICE(FILENOTFOUND)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: attempt to summarize a CK file',
  'failure',
  $brief,
  'brief_ck.bc',
  17,
  "SPICE(CKFILE)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: attempt to summarize an EK file',
  'failure',
  $brief,
  'brief_ek.bes',
  17,
  "SPICE(EKFILE)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: attempt to summarize a transfer file',
  'failure',
  $brief,
  'brief_ek.xes',
  17,
  "SPICE(TRANSFERFORMAT)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: attempt to summarize an old transfer file',
  'failure',
  $brief,
  'brief_dec.xdc',
  17,
  "SPICE(TRANSFERFORMAT)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: attempt to summarize an unknown binary DAF file',
  'failure',
  $brief,
  'brief_uk.bu',
  17,
  "SPICE(BADKERNELTYPE)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: attempt to summarize an unknown binary DAS file',
  'failure',
  $brief,
  'brief_dsk.bds',
  17,
  "SPICE(BADARCHITECTURE)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: a kernel file specified with -f',
  'failure',
  $brief,
  '-f brief_sc_1seg.bsp',
  18,
  "SPICE(NOTATEXTFILE)"
);

#&run_test (
#  $reporttype,
#  'Checking error: attempt to summarize an TE1 file',
#  'failure',
#  $brief,
#  'brief_te1.xt1',
#  ,
#  "SPICE(BADARCHITECTURE)"
#);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: no SPKs and PCKs are given on command line',
  'failure',
  $brief,
  'naif0008.tls',
  16,
  "SPICE(NOFILES)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: no SPKs and PCKs are given in list file',
  'failure',
  $brief,
  '-f brief_list_no_spk_pck.lst',
  16,
  "SPICE(NOFILES)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: no SPKs are given in meta kernel',
  'failure',
  $brief,
  'brief_mk_pck_lsk.tm',
  16,
  "SPICE(NOFILES)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: SPKs and PCKs in list file',
  'failure',
  $brief,
  '-f brief_list_spk_pck.lst',
  16,
  "SPICE(NOCANDOSPKSPCKS)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: SPKs and PCKs on command line',
  'failure',
  $brief,
  'brief_pck.bpc brief_sc_1seg.bsp',
  16,
  "SPICE(NOCANDOSPKSPCKS)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: SPKs in list file, PCKs on command line',
  'failure',
  $brief,
  'brief_pck.bpc -f brief_list_one.lst',
  16,
  "SPICE(NOCANDOSPKSPCKS)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: PCKs in list file, SPKs on command line',
  'failure',
  $brief,
  'brief_sc_1seg.bsp -f brief_list_pck_only.lst',
  16,
  "SPICE(NOCANDOSPKSPCKS)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: PCKs on command line, SPKs in MK on command line',
  'failure',
  $brief,
  'brief_pck.bpc brief_mk_spk.tm',
  16,
  "SPICE(NOCANDOSPKSPCKS)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: PCKs on command line, SPKs in MK in list file',
  'failure',
  $brief,
  'brief_pck.bpc -f brief_list_mk_only.lst',
  16,
  "SPICE(NOCANDOSPKSPCKS)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: PCKs in list file, SPKs in MK in list file',
  'failure',
  $brief,
  '-f brief_list_mk_pck.lst',
  16,
  "SPICE(NOCANDOSPKSPCKS)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: PCKs in list file, SPKs in MK on command line',
  'failure',
  $brief,
  'brief_mk_spk.tm -f brief_list_pck_only.lst',
  16,
  "SPICE(NOCANDOSPKSPCKS)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: no list file name provided after -f',
  'failure',
  $brief,
  '-f',
  16,
  "SPICE(NOLISTFILENAME)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: bad from time provided after -from ',
  'failure',
  $brief,
  '-from boo1',
  16,
  "SPICE(BADFROMTIME)",
  "boo1"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: no from time provided after -from',
  'failure',
  $brief,
  '-from',
  16,
  "SPICE(NOFROMTIME)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: bad to time provided after -to',
  'failure',
  $brief,
  '-to boo2',
  16,
  "SPICE(BADTOTIME)",
  "boo2"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: no to time provided after -to',
  'failure',
  $brief,
  '-to',
  16,
  "SPICE(NOTOTIME)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: bad at time provided after -at',
  'failure',
  $brief,
  '-at boo3',
  16,
  "SPICE(BADATTIME)",
  "boo3"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: no at time provided after at',
  'failure',
  $brief,
  '-at',
  16,
  "SPICE(NOATTIME)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: time with blanks after -at',
  'failure',
  $brief,
  '-at 2000-01-01 00:00:00 brief_sc_1seg.bsp',
  16,
  "The kernel file '00:00:00' does not exist.",
  "SPICE(FILENOTFOUND)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: time with blanks after -to',
  'failure',
  $brief,
  '-to 2000-01-01 00:00:01 brief_sc_1seg.bsp',
  16,
  "The kernel file '00:00:01' does not exist.",
  "SPICE(FILENOTFOUND)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: time with blanks after -from',
  'failure',
  $brief,
  '-from 2000-01-01 00:00:02 brief_sc_1seg.bsp',
  16,
  "The kernel file '00:00:02' does not exist.",
  "SPICE(FILENOTFOUND)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: name with blanks after -',
  'failure',
  $brief,
  '-MARS BARYCENTER brief_sc_1seg.bsp',
  16,
  "The kernel file 'BARYCENTER' does not exist.",
  "SPICE(FILENOTFOUND)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: name with blanks after -sc',
  'failure',
  $brief,
  '-scMARS BARYCENTER brief_sc_1seg.bsp',
  16,
  "The kernel file 'BARYCENTER' does not exist.",
  "SPICE(FILENOTFOUND)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: name with blanks after -sb',
  'failure',
  $brief,
  '-sbMARS BARYCENTER brief_sc_1seg.bsp',
  16,
  "The kernel file 'BARYCENTER' does not exist.",
  "SPICE(FILENOTFOUND)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: non-existing list file',
  'failure',
  $brief,
  '-f bogus.lst',
  16,
  "SPICE(BADLISTFILENAME)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: object list full, using -',
  'failure',
  $brief,
  'brief_sc_1seg.bsp -1 -2 -3 -4 -5 -6 -7 -8 -9 -10 -11 -12 -13 -14 -15 -16 -17 -18 -19 -20 -21 -22 -23 -24 -25 -26 -27 -28 -29 -30 -31 -32 -33 -34 -35 -36 -37 -38 -39 -40 -41 -42 -43 -44 -45 -46 -47 -48 -49 -50 -51 -52 -53 -54 -55 -56 -57 -58 -59 -60 -61 -62 -63 -64 -65 -66 -67 -68 -69 -70 -71 -72 -73 -74 -75 -76 -77 -78 -79 -80 -81 -82 -83 -84 -85 -86 -87 -88 -89 -90 -91 -92 -93 -94 -95 -96 -97 -98 -99 -100 -101',
  18,
  "SPICE(OBJECTLISTFULL)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: object list full, using -sc',
  'failure',
  $brief,
  'brief_sc_1seg.bsp -sc1 -sc2 -sc3 -sc4 -sc5 -sc6 -sc7 -sc8 -sc9 -sc10 -sc11 -sc12 -sc13 -sc14 -sc15 -sc16 -sc17 -sc18 -sc19 -sc20 -sc21 -sc22 -sc23 -sc24 -sc25 -sc26 -sc27 -sc28 -sc29 -sc30 -sc31 -sc32 -sc33 -sc34 -sc35 -sc36 -sc37 -sc38 -sc39 -sc40 -sc41 -sc42 -sc43 -sc44 -sc45 -sc46 -sc47 -sc48 -sc49 -sc50 -sc51 -sc52 -sc53 -sc54 -sc55 -sc56 -sc57 -sc58 -sc59 -sc60 -sc61 -sc62 -sc63 -sc64 -sc65 -sc66 -sc67 -sc68 -sc69 -sc70 -sc71 -sc72 -sc73 -sc74 -sc75 -sc76 -sc77 -sc78 -sc79 -sc80 -sc81 -sc82 -sc83 -sc84 -sc85 -sc86 -sc87 -sc88 -sc89 -sc90 -sc91 -sc92 -sc93 -sc94 -sc95 -sc96 -sc97 -sc98 -sc99 -sc100 -sc101',
  18,
  "SPICE(OBJECTLISTFULL)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: object list full, using -sc',
  'failure',
  $brief,
  'brief_sc_1seg.bsp -sb1 -sb2 -sb3 -sb4 -sb5 -sb6 -sb7 -sb8 -sb9 -sb10 -sb11 -sb12 -sb13 -sb14 -sb15 -sb16 -sb17 -sb18 -sb19 -sb20 -sb21 -sb22 -sb23 -sb24 -sb25 -sb26 -sb27 -sb28 -sb29 -sb30 -sb31 -sb32 -sb33 -sb34 -sb35 -sb36 -sb37 -sb38 -sb39 -sb40 -sb41 -sb42 -sb43 -sb44 -sb45 -sb46 -sb47 -sb48 -sb49 -sb50 -sb51 -sb52 -sb53 -sb54 -sb55 -sb56 -sb57 -sb58 -sb59 -sb60 -sb61 -sb62 -sb63 -sb64 -sb65 -sb66 -sb67 -sb68 -sb69 -sb70 -sb71 -sb72 -sb73 -sb74 -sb75 -sb76 -sb77 -sb78 -sb79 -sb80 -sb81 -sb82 -sb83 -sb84 -sb85 -sb86 -sb87 -sb88 -sb89 -sb90 -sb91 -sb92 -sb93 -sb94 -sb95 -sb96 -sb97 -sb98 -sb99 -sb100 -sb101',
  18,
  "SPICE(OBJECTLISTFULL)"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Checking error: object list full, using -/-sc/-sb',
  'failure',
  $brief,
  'brief_sc_1seg.bsp -1 -sc2 -sb3 -sb4 -sb5 -sb6 -sb7 -sb8 -sb9 -sb10 -sb11 -sb12 -sb13 -sb14 -sb15 -sb16 -sb17 -sb18 -sb19 -sb20 -sb21 -sb22 -sb23 -sb24 -sb25 -sb26 -sb27 -sb28 -sb29 -sb30 -sb31 -sb32 -sb33 -sb34 -sb35 -sb36 -sb37 -sb38 -sb39 -sb40 -sb41 -sb42 -sb43 -sb44 -sb45 -sb46 -sb47 -sb48 -sb49 -sb50 -sb51 -sb52 -sb53 -sb54 -sb55 -sb56 -sb57 -sb58 -sb59 -sb60 -sb61 -sb62 -sb63 -sb64 -sb65 -sb66 -sb67 -sb68 -sb69 -sb70 -sb71 -sb72 -sb73 -sb74 -sb75 -sb76 -sb77 -sb78 -sb79 -sb80 -sb81 -sb82 -sb83 -sb84 -sb85 -sb86 -sb87 -sb88 -sb89 -sb90 -sb91 -sb92 -sb93 -sb94 -sb95 -sb96 -sb97 -sb98 -sb99 -sb100 -sb101',
  18,
  "SPICE(OBJECTLISTFULL)"
);

#
# Tests in this block test output time formats.
#
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Displaying times ET',
  'success',
  $brief,
  'naif0008.tls brief_sc_1seg.bsp',
  11,
"Summary for: brief_sc_1seg.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Displaying times UTC',
  'success',
  $brief,
  'naif0008.tls brief_sc_1seg.bsp -utc',
  11,
"Summary for: brief_sc_1seg.bsp",
"Body: NEXT (-29)",
"      Start of Interval (UTC)             End of Interval (UTC)",
"      -----------------------------       -----------------------------",
"      2000-JAN-01 11:58:55.816            2000-JAN-02 11:58:55.816"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Displaying times UTC/DOY',
  'success',
  $brief,
  'naif0008.tls brief_sc_1seg.bsp -utcdoy',
  11,
"Summary for: brief_sc_1seg.bsp",
"Body: NEXT (-29)",
"      Start of Interval (UTC)             End of Interval (UTC)",
"      -----------------------------       -----------------------------",
"      2000-001 // 11:58:55.816            2000-002 // 11:58:55.816"
);


&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Displaying times ET seconds',
  'success',
  $brief,
  'naif0008.tls brief_sc_1seg.bsp -etsec',
  11,
"Summary for: brief_sc_1seg.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"                      0.000000                        86400.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Displaying times ET, tabular output, no grouping',
  'success',
  $brief,
  'naif0008.tls brief_sc_bc_pl_sat_dcov1.bsp -t',
  12,
"Summary for: brief_sc_bc_pl_sat_dcov1.bsp",
"Bodies             Start of Interval (ET)          End of Interval (ET)",
"-------            -----------------------------   -----------------------------",
"-254 MER-2         2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"4 MARS BARYCENTER  2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"401 PHOBOS         2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"499 MARS           2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Displaying times UTC, tabular output, no grouping',
  'success',
  $brief,
  'naif0008.tls brief_sc_bc_pl_sat_dcov1.bsp -t -utc',
  12,
"Summary for: brief_sc_bc_pl_sat_dcov1.bsp",
"Bodies             Start of Interval (UTC)         End of Interval (UTC)",
"-------            -----------------------------   -----------------------------",
"-254 MER-2         2000-JAN-01 11:58:55.816        2000-JAN-02 11:58:55.816",
"4 MARS BARYCENTER  2000-JAN-01 11:58:55.816        2000-JAN-03 11:58:55.816",
"401 PHOBOS         2000-JAN-01 11:58:55.816        2000-JAN-02 11:58:55.816",
"499 MARS           2000-JAN-01 11:58:55.816        2000-JAN-03 11:58:55.816"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Displaying times UTC/DOY, tabular output, no grouping',
  'success',
  $brief,
  'naif0008.tls brief_sc_bc_pl_sat_dcov1.bsp -t -utcdoy',
  12,
"Summary for: brief_sc_bc_pl_sat_dcov1.bsp",
"Bodies             Start of Interval (UTC)         End of Interval (UTC)",
"-------            -----------------------------   -----------------------------",
"-254 MER-2         2000-001 // 11:58:55.816        2000-002 // 11:58:55.816",
"4 MARS BARYCENTER  2000-001 // 11:58:55.816        2000-003 // 11:58:55.816",
"401 PHOBOS         2000-001 // 11:58:55.816        2000-002 // 11:58:55.816",
"499 MARS           2000-001 // 11:58:55.816        2000-003 // 11:58:55.816"
);


&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Displaying times ET seconds, tabular output, no grouping',
  'success',
  $brief,
  'naif0008.tls brief_sc_bc_pl_sat_dcov1.bsp -t -etsec',
  12,
"Summary for: brief_sc_bc_pl_sat_dcov1.bsp",
"Bodies             Start of Interval (ET)          End of Interval (ET)",
"-------            -----------------------------   -----------------------------",
"-254 MER-2                         0.000000                    86400.000000",
"4 MARS BARYCENTER                  0.000000                   172800.000000",
"401 PHOBOS                         0.000000                    86400.000000",
"499 MARS                           0.000000                   172800.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Displaying times ET, tabular output, with grouping',
  'success',
  $brief,
  'naif0008.tls brief_sc_bc_pl_sat_dcov1.bsp -t -g',
  12,
"Summary for: brief_sc_bc_pl_sat_dcov1.bsp",
"Bodies             Start of Interval (ET)          End of Interval (ET)",
"-------            -----------------------------   -----------------------------",
"-254 MER-2         2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"401 PHOBOS                     Same coverage as previous object",
"4 MARS BARYCENTER  2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"499 MARS                       Same coverage as previous object"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Displaying times UTC, tabular output, with grouping',
  'success',
  $brief,
  'naif0008.tls brief_sc_bc_pl_sat_dcov1.bsp -t -g -utc',
  12,
"Summary for: brief_sc_bc_pl_sat_dcov1.bsp",
"Bodies             Start of Interval (UTC)         End of Interval (UTC)",
"-------            -----------------------------   -----------------------------",
"-254 MER-2         2000-JAN-01 11:58:55.816        2000-JAN-02 11:58:55.816",
"401 PHOBOS                     Same coverage as previous object",
"4 MARS BARYCENTER  2000-JAN-01 11:58:55.816        2000-JAN-03 11:58:55.816",
"499 MARS                       Same coverage as previous object"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Displaying times UTC/DOY, tabular output, with grouping',
  'success',
  $brief,
  'naif0008.tls brief_sc_bc_pl_sat_dcov1.bsp -t -g -utcdoy',
  12,
"Summary for: brief_sc_bc_pl_sat_dcov1.bsp",
"Bodies             Start of Interval (UTC)         End of Interval (UTC)",
"-------            -----------------------------   -----------------------------",
"-254 MER-2         2000-001 // 11:58:55.816        2000-002 // 11:58:55.816",
"401 PHOBOS                     Same coverage as previous object",
"4 MARS BARYCENTER  2000-001 // 11:58:55.816        2000-003 // 11:58:55.816",
"499 MARS                       Same coverage as previous object"
);


&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Displaying times ET seconds, tabular output, with grouping',
  'success',
  $brief,
  'naif0008.tls brief_sc_bc_pl_sat_dcov1.bsp -t -g -etsec',
  12,
"Summary for: brief_sc_bc_pl_sat_dcov1.bsp",
"Bodies             Start of Interval (ET)          End of Interval (ET)",
"-------            -----------------------------   -----------------------------",
"-254 MER-2                         0.000000                    86400.000000",
"401 PHOBOS                     Same coverage as previous object",
"4 MARS BARYCENTER                  0.000000                   172800.000000",
"499 MARS                       Same coverage as previous object"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Displaying times, many keys, -utc last',
  'success',
  $brief,
  'naif0008.tls brief_sc_bc_pl_sat_dcov1.bsp -t -g -utcdoy -etsec -utc',
  12,
"Summary for: brief_sc_bc_pl_sat_dcov1.bsp",
"Bodies             Start of Interval (UTC)         End of Interval (UTC)",
"-------            -----------------------------   -----------------------------",
"-254 MER-2         2000-JAN-01 11:58:55.816        2000-JAN-02 11:58:55.816",
"401 PHOBOS                     Same coverage as previous object",
"4 MARS BARYCENTER  2000-JAN-01 11:58:55.816        2000-JAN-03 11:58:55.816",
"499 MARS                       Same coverage as previous object"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Displaying times, many keys, -utcdoy last',
  'success',
  $brief,
  'naif0008.tls brief_sc_bc_pl_sat_dcov1.bsp -t -g -utc -etsec -utcdoy',
  12,
"Summary for: brief_sc_bc_pl_sat_dcov1.bsp",
"Bodies             Start of Interval (UTC)         End of Interval (UTC)",
"-------            -----------------------------   -----------------------------",
"-254 MER-2         2000-001 // 11:58:55.816        2000-002 // 11:58:55.816",
"401 PHOBOS                     Same coverage as previous object",
"4 MARS BARYCENTER  2000-001 // 11:58:55.816        2000-003 // 11:58:55.816",
"499 MARS                       Same coverage as previous object"
);


&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Displaying times, many keys, -etsec last',
  'success',
  $brief,
  'naif0008.tls brief_sc_bc_pl_sat_dcov1.bsp -t -g -utc -utcdoy -etsec',
  12,
"Summary for: brief_sc_bc_pl_sat_dcov1.bsp",
"Bodies             Start of Interval (ET)          End of Interval (ET)",
"-------            -----------------------------   -----------------------------",
"-254 MER-2                         0.000000                    86400.000000",
"401 PHOBOS                     Same coverage as previous object",
"4 MARS BARYCENTER                  0.000000                   172800.000000",
"499 MARS                       Same coverage as previous object"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -sec ignored with -utc',
  'success',
  $brief,
  'naif0008.tls brief_sc_1seg_times.bsp -utc -sec',
  11,
"Summary for: brief_sc_1seg_times.bsp",
"Body: NEXT (-29)",
"      Start of Interval (UTC)             End of Interval (UTC)",
"      -----------------------------       -----------------------------",
"      2000-JAN-01 15:14:10.966            2000-JAN-03 08:07:03.896"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -sec ignored with -utcdoy',
  'success',
  $brief,
  'naif0008.tls brief_sc_1seg_times.bsp -utcdoy -sec',
  11,
"Summary for: brief_sc_1seg_times.bsp",
"Body: NEXT (-29)",
"      Start of Interval (UTC)             End of Interval (UTC)",
"      -----------------------------       -----------------------------",
"      2000-001 // 15:14:10.966            2000-003 // 08:07:03.896"
);


&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -sec ignored with -etsec',
  'success',
  $brief,
  'naif0008.tls brief_sc_1seg_times.bsp -etsec -sec',
  11,
"Summary for: brief_sc_1seg_times.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"                  11715.150000                       158888.080000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -min ignored with -utc',
  'success',
  $brief,
  'naif0008.tls brief_sc_1seg_times.bsp -utc -min',
  11,
"Summary for: brief_sc_1seg_times.bsp",
"Body: NEXT (-29)",
"      Start of Interval (UTC)             End of Interval (UTC)",
"      -----------------------------       -----------------------------",
"      2000-JAN-01 15:14:10.966            2000-JAN-03 08:07:03.896"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -min ignored with -utcdoy',
  'success',
  $brief,
  'naif0008.tls brief_sc_1seg_times.bsp -utcdoy -min',
  11,
"Summary for: brief_sc_1seg_times.bsp",
"Body: NEXT (-29)",
"      Start of Interval (UTC)             End of Interval (UTC)",
"      -----------------------------       -----------------------------",
"      2000-001 // 15:14:10.966            2000-003 // 08:07:03.896"
);


&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -min ignored with -etsec',
  'success',
  $brief,
  'naif0008.tls brief_sc_1seg_times.bsp -etsec -min',
  11,
"Summary for: brief_sc_1seg_times.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"                  11715.150000                       158888.080000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -hour ignored with -utc',
  'success',
  $brief,
  'naif0008.tls brief_sc_1seg_times.bsp -utc -hour',
  11,
"Summary for: brief_sc_1seg_times.bsp",
"Body: NEXT (-29)",
"      Start of Interval (UTC)             End of Interval (UTC)",
"      -----------------------------       -----------------------------",
"      2000-JAN-01 15:14:10.966            2000-JAN-03 08:07:03.896"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -hour ignored with -utcdoy',
  'success',
  $brief,
  'naif0008.tls brief_sc_1seg_times.bsp -utcdoy -hour',
  11,
"Summary for: brief_sc_1seg_times.bsp",
"Body: NEXT (-29)",
"      Start of Interval (UTC)             End of Interval (UTC)",
"      -----------------------------       -----------------------------",
"      2000-001 // 15:14:10.966            2000-003 // 08:07:03.896"
);


&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -hour ignored with -etsec',
  'success',
  $brief,
  'naif0008.tls brief_sc_1seg_times.bsp -etsec -hour',
  11,
"Summary for: brief_sc_1seg_times.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"                  11715.150000                       158888.080000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -day ignored with -utc',
  'success',
  $brief,
  'naif0008.tls brief_sc_1seg_times.bsp -utc -day',
  11,
"Summary for: brief_sc_1seg_times.bsp",
"Body: NEXT (-29)",
"      Start of Interval (UTC)             End of Interval (UTC)",
"      -----------------------------       -----------------------------",
"      2000-JAN-01 15:14:10.966            2000-JAN-03 08:07:03.896"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -day ignored with -utcdoy',
  'success',
  $brief,
  'naif0008.tls brief_sc_1seg_times.bsp -utcdoy -day',
  11,
"Summary for: brief_sc_1seg_times.bsp",
"Body: NEXT (-29)",
"      Start of Interval (UTC)             End of Interval (UTC)",
"      -----------------------------       -----------------------------",
"      2000-001 // 15:14:10.966            2000-003 // 08:07:03.896"
);


&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -day ignored with -etsec',
  'success',
  $brief,
  'naif0008.tls brief_sc_1seg_times.bsp -etsec -day',
  11,
"Summary for: brief_sc_1seg_times.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"                  11715.150000                       158888.080000"
);

#
# Tests in this block test rounding.
#
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding <NONE>, single segment',
  'success',
  $brief,
  'brief_sc_1seg_times.bsp',
  11,
"Summary for: brief_sc_1seg_times.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 15:15:15.150            2000 JAN 03 08:08:08.080"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -sec, single segment',
  'success',
  $brief,
  'brief_sc_1seg_times.bsp -sec',
  11,
"Summary for: brief_sc_1seg_times.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 15:15:16.000            2000 JAN 03 08:08:08.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -min, single segment',
  'success',
  $brief,
  'brief_sc_1seg_times.bsp -min',
  11,
"Summary for: brief_sc_1seg_times.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 15:16:00.000            2000 JAN 03 08:08:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -hour, single segment',
  'success',
  $brief,
  'brief_sc_1seg_times.bsp -hour',
  11,
"Summary for: brief_sc_1seg_times.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 16:00:00.000            2000 JAN 03 08:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -day, single segment',
  'success',
  $brief,
  'brief_sc_1seg_times.bsp -day',
  11,
"Summary for: brief_sc_1seg_times.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 00:00:00.000            2000 JAN 03 00:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding <NONE>, 3 overlapping segments',
  'success',
  $brief,
  'brief_sc_3seg.bsp',
  11,
"Summary for: brief_sc_3seg.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 01:01:01.010            2000 JAN 05 06:06:06.059"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -sec, 3 overlapping segments',
  'success',
  $brief,
  'brief_sc_3seg.bsp -sec',
  11,
"Summary for: brief_sc_3seg.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 01:01:02.000            2000 JAN 05 06:06:06.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -min, 3 overlapping segments',
  'success',
  $brief,
  'brief_sc_3seg.bsp -min',
  11,
"Summary for: brief_sc_3seg.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 01:02:00.000            2000 JAN 05 06:06:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -hour, 3 overlapping segments',
  'success',
  $brief,
  'brief_sc_3seg.bsp -hour',
  11,
"Summary for: brief_sc_3seg.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 02:00:00.000            2000 JAN 05 06:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -day, 3 overlapping segments',
  'success',
  $brief,
  'brief_sc_3seg.bsp -day',
  11,
"Summary for: brief_sc_3seg.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 03 00:00:00.000            2000 JAN 05 00:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding <NONE>, 3 non-overlapping segments',
  'success',
  $brief,
  'brief_sc_3seg_gaps.bsp',
  13,
"Summary for: brief_sc_3seg_gaps.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 04 05:05:05.049            2000 JAN 06 05:05:05.049",
"      2000 JAN 06 07:07:07.070            2000 JAN 07 06:06:06.060",
"      2000 JAN 07 08:08:08.080            2000 JAN 08 07:07:07.069"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -sec, 3 non-overlapping segments',
  'success',
  $brief,
  'brief_sc_3seg_gaps.bsp -sec',
  13,
"Summary for: brief_sc_3seg_gaps.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 04 05:05:06.000            2000 JAN 06 05:05:05.000",
"      2000 JAN 06 07:07:08.000            2000 JAN 07 06:06:06.000",
"      2000 JAN 07 08:08:09.000            2000 JAN 08 07:07:07.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -min, 3 non-overlapping segments',
  'success',
  $brief,
  'brief_sc_3seg_gaps.bsp -min',
  13,
"Summary for: brief_sc_3seg_gaps.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 04 05:06:00.000            2000 JAN 06 05:05:00.000",
"      2000 JAN 06 07:08:00.000            2000 JAN 07 06:06:00.000",
"      2000 JAN 07 08:09:00.000            2000 JAN 08 07:07:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -hour, 3 non-overlapping segments',
  'success',
  $brief,
  'brief_sc_3seg_gaps.bsp -hour',
  13,
"Summary for: brief_sc_3seg_gaps.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 04 06:00:00.000            2000 JAN 06 05:00:00.000",
"      2000 JAN 06 08:00:00.000            2000 JAN 07 06:00:00.000",
"      2000 JAN 07 09:00:00.000            2000 JAN 08 07:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -day, 3 non-overlapping segments',
  'success',
  $brief,
  'brief_sc_3seg_gaps.bsp -day',
  13,
"Summary for: brief_sc_3seg_gaps.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 05 00:00:00.000            2000 JAN 06 00:00:00.000",
"      2000 JAN 07 00:00:00.000            2000 JAN 07 00:00:00.000",
"      2000 JAN 08 00:00:00.000            2000 JAN 08 00:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding <NONE>, .lt. 1 second',
  'success',
  $brief,
  'brief_sc_1seg_short1.bsp',
  11,
"Summary for: brief_sc_1seg_short1.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 12:00:00.100            2000 JAN 02 12:00:00.899"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -sec, .lt. 1 second',
  'success',
  $brief,
  'brief_sc_1seg_short1.bsp -sec',
  11,
"Summary for: brief_sc_1seg_short1.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 12:00:00.899            2000 JAN 02 12:00:00.899"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -min, .lt. 1 second',
  'success',
  $brief,
  'brief_sc_1seg_short1.bsp -min',
  11,
"Summary for: brief_sc_1seg_short1.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 12:00:00.899            2000 JAN 02 12:00:00.899"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -hour, .lt. 1 second',
  'success',
  $brief,
  'brief_sc_1seg_short1.bsp -hour',
  11,
"Summary for: brief_sc_1seg_short1.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 12:00:00.899            2000 JAN 02 12:00:00.899"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -day, .lt. 1 second',
  'success',
  $brief,
  'brief_sc_1seg_short1.bsp -day',
  11,
"Summary for: brief_sc_1seg_short1.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 12:00:00.899            2000 JAN 02 12:00:00.899"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding <NONE>, .lt. 1 minute',
  'success',
  $brief,
  'brief_sc_1seg_short2.bsp',
  11,
"Summary for: brief_sc_1seg_short2.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 12:00:01.000            2000 JAN 02 12:00:59.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -sec, .lt. 1 minute',
  'success',
  $brief,
  'brief_sc_1seg_short2.bsp -sec',
  11,
"Summary for: brief_sc_1seg_short2.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 12:00:01.000            2000 JAN 02 12:00:59.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -min, .lt. 1 minute',
  'success',
  $brief,
  'brief_sc_1seg_short2.bsp -min',
  11,
"Summary for: brief_sc_1seg_short2.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 12:00:59.000            2000 JAN 02 12:00:59.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -hour, .lt. 1 minute',
  'success',
  $brief,
  'brief_sc_1seg_short2.bsp -hour',
  11,
"Summary for: brief_sc_1seg_short2.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 12:00:59.000            2000 JAN 02 12:00:59.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -day, .lt. 1 minute',
  'success',
  $brief,
  'brief_sc_1seg_short2.bsp -day',
  11,
"Summary for: brief_sc_1seg_short2.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 12:00:59.000            2000 JAN 02 12:00:59.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding <NONE>, .lt. 1 hour',
  'success',
  $brief,
  'brief_sc_1seg_short3.bsp',
  11,
"Summary for: brief_sc_1seg_short3.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 12:01:00.000            2000 JAN 02 12:59:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -sec, .lt. 1 hour',
  'success',
  $brief,
  'brief_sc_1seg_short3.bsp -sec',
  11,
"Summary for: brief_sc_1seg_short3.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 12:01:00.000            2000 JAN 02 12:59:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -min, .lt. 1 hour',
  'success',
  $brief,
  'brief_sc_1seg_short3.bsp -min',
  11,
"Summary for: brief_sc_1seg_short3.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 12:01:00.000            2000 JAN 02 12:59:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -hour, .lt. 1 hour',
  'success',
  $brief,
  'brief_sc_1seg_short3.bsp -hour',
  11,
"Summary for: brief_sc_1seg_short3.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 12:59:00.000            2000 JAN 02 12:59:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -day, .lt. 1 hour',
  'success',
  $brief,
  'brief_sc_1seg_short3.bsp -day',
  11,
"Summary for: brief_sc_1seg_short3.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 12:59:00.000            2000 JAN 02 12:59:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding <NONE>, .lt. 1 day',
  'success',
  $brief,
  'brief_sc_1seg_short4.bsp',
  11,
"Summary for: brief_sc_1seg_short4.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 01:00:00.000            2000 JAN 02 23:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -sec, .lt. 1 day',
  'success',
  $brief,
  'brief_sc_1seg_short4.bsp -sec',
  11,
"Summary for: brief_sc_1seg_short4.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 01:00:00.000            2000 JAN 02 23:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -min, .lt. 1 day',
  'success',
  $brief,
  'brief_sc_1seg_short4.bsp -min',
  11,
"Summary for: brief_sc_1seg_short4.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 01:00:00.000            2000 JAN 02 23:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -hour, .lt. 1 day',
  'success',
  $brief,
  'brief_sc_1seg_short4.bsp -hour',
  11,
"Summary for: brief_sc_1seg_short4.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 01:00:00.000            2000 JAN 02 23:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -day, .lt. 1 day',
  'success',
  $brief,
  'brief_sc_1seg_short4.bsp -day',
  11,
"Summary for: brief_sc_1seg_short4.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 23:00:00.000            2000 JAN 02 23:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding <NONE>, over boundary, .lt. 1 second',
  'success',
  $brief,
  'brief_sc_1seg_bnd_short1.bsp',
  11,
"Summary for: brief_sc_1seg_bnd_short1.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 23:59:59.580            2000 JAN 02 00:00:00.010"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -sec, over boundary, .lt. 1 second',
  'success',
  $brief,
  'brief_sc_1seg_bnd_short1.bsp -sec',
  11,
"Summary for: brief_sc_1seg_bnd_short1.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 00:00:00.000            2000 JAN 02 00:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -min, over boundary, .lt. 1 second',
  'success',
  $brief,
  'brief_sc_1seg_bnd_short1.bsp -min',
  11,
"Summary for: brief_sc_1seg_bnd_short1.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 00:00:00.000            2000 JAN 02 00:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -hour, over boundary, .lt. 1 second',
  'success',
  $brief,
  'brief_sc_1seg_bnd_short1.bsp -hour',
  11,
"Summary for: brief_sc_1seg_bnd_short1.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 00:00:00.000            2000 JAN 02 00:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -day, over boundary, .lt. 1 second',
  'success',
  $brief,
  'brief_sc_1seg_bnd_short1.bsp -day',
  11,
"Summary for: brief_sc_1seg_bnd_short1.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 00:00:00.000            2000 JAN 02 00:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding <NONE>, over boundary, .lt. 1 minute',
  'success',
  $brief,
  'brief_sc_1seg_bnd_short2.bsp',
  11,
"Summary for: brief_sc_1seg_bnd_short2.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 23:59:58.580            2000 JAN 02 00:00:01.010"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -sec, over boundary, .lt. 1 minute',
  'success',
  $brief,
  'brief_sc_1seg_bnd_short2.bsp -sec',
  11,
"Summary for: brief_sc_1seg_bnd_short2.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 23:59:59.000            2000 JAN 02 00:00:01.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -min, over boundary, .lt. 1 minute',
  'success',
  $brief,
  'brief_sc_1seg_bnd_short2.bsp -min',
  11,
"Summary for: brief_sc_1seg_bnd_short2.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 00:00:00.000            2000 JAN 02 00:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -hour, over boundary, .lt. 1 minute',
  'success',
  $brief,
  'brief_sc_1seg_bnd_short2.bsp -hour',
  11,
"Summary for: brief_sc_1seg_bnd_short2.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 00:00:00.000            2000 JAN 02 00:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -day, over boundary, .lt. 1 minute',
  'success',
  $brief,
  'brief_sc_1seg_bnd_short2.bsp -day',
  11,
"Summary for: brief_sc_1seg_bnd_short2.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 00:00:00.000            2000 JAN 02 00:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding <NONE>, over boundary, .lt. 1 hour',
  'success',
  $brief,
  'brief_sc_1seg_bnd_short3.bsp',
  11,
"Summary for: brief_sc_1seg_bnd_short3.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 23:58:58.580            2000 JAN 02 00:01:01.010"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -sec, over boundary, .lt. 1 hour',
  'success',
  $brief,
  'brief_sc_1seg_bnd_short3.bsp -sec',
  11,
"Summary for: brief_sc_1seg_bnd_short3.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 23:58:59.000            2000 JAN 02 00:01:01.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -min, over boundary, .lt. 1 hour',
  'success',
  $brief,
  'brief_sc_1seg_bnd_short3.bsp -min',
  11,
"Summary for: brief_sc_1seg_bnd_short3.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 23:59:00.000            2000 JAN 02 00:01:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -hour, over boundary, .lt. 1 hour',
  'success',
  $brief,
  'brief_sc_1seg_bnd_short3.bsp -hour',
  11,
"Summary for: brief_sc_1seg_bnd_short3.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 00:00:00.000            2000 JAN 02 00:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -day, over boundary, .lt. 1 hour',
  'success',
  $brief,
  'brief_sc_1seg_bnd_short3.bsp -day',
  11,
"Summary for: brief_sc_1seg_bnd_short3.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 00:00:00.000            2000 JAN 02 00:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding <NONE>, over boundary, .lt. 1 day',
  'success',
  $brief,
  'brief_sc_1seg_bnd_short4.bsp',
  11,
"Summary for: brief_sc_1seg_bnd_short4.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 22:58:58.580            2000 JAN 02 01:01:01.010"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -sec, over boundary, .lt. 1 day',
  'success',
  $brief,
  'brief_sc_1seg_bnd_short4.bsp -sec',
  11,
"Summary for: brief_sc_1seg_bnd_short4.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 22:58:59.000            2000 JAN 02 01:01:01.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -min, over boundary, .lt. 1 day',
  'success',
  $brief,
  'brief_sc_1seg_bnd_short4.bsp -min',
  11,
"Summary for: brief_sc_1seg_bnd_short4.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 22:59:00.000            2000 JAN 02 01:01:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -hour, over boundary, .lt. 1 day',
  'success',
  $brief,
  'brief_sc_1seg_bnd_short4.bsp -hour',
  11,
"Summary for: brief_sc_1seg_bnd_short4.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 23:00:00.000            2000 JAN 02 01:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Rounding -day, over boundary, .lt. 1 day',
  'success',
  $brief,
  'brief_sc_1seg_bnd_short4.bsp -day',
  11,
"Summary for: brief_sc_1seg_bnd_short4.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 00:00:00.000            2000 JAN 02 00:00:00.000"
);

#
# Tests displays with only numeric IDs.
#
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Displaying numeric IDs only (-n), one file',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov1.bsp -n',
  16,
"Summary for: brief_sc_bc_pl_sat_dcov1.bsp",
"Bodies: -254  401",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000",
"Bodies: 4     499",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 03 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Displaying numeric IDs only (-n), one file, -t',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov1.bsp -n -t',
  12,
"Summary for: brief_sc_bc_pl_sat_dcov1.bsp",
"BodiesStart of Interval (ET)          End of Interval (ET)",
"-----------------------------------   -----------------------------",
"-254  2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"4     2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"401   2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"499   2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Displaying numeric IDs only (-n), one file, -g',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov1.bsp -n -g',
  16,
"Summary for: brief_sc_bc_pl_sat_dcov1.bsp",
"Bodies: -254  401",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000",
"Bodies: 4     499",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 03 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Displaying numeric IDs only (-n), one file, -t -g',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov1.bsp -n -t -g',
  12,
"Summary for: brief_sc_bc_pl_sat_dcov1.bsp",
"BodiesStart of Interval (ET)          End of Interval (ET)",
"-----------------------------------   -----------------------------",
"-254  2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"401               Same coverage as previous object",
"4     2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"499               Same coverage as previous object"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Displaying numeric IDs only (-n), two files',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov1.bsp brief_sc_1seg_unk_id.bsp -a -n',
  16,
"Summary for all files.",
"Bodies: -111  -254  401",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000",
"Bodies: 4     499",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 03 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Displaying numeric IDs only (-n), two files, -a -t',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov1.bsp brief_sc_1seg_unk_id.bsp -a -n -t',
  13,
"Summary for all files.",
"BodiesStart of Interval (ET)          End of Interval (ET)",
"-----------------------------------   -----------------------------",
"-111  2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"-254              Same coverage as previous object",
"4     2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"401   2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"499   2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Displaying numeric IDs only (-n), two files, -a -g',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov1.bsp brief_sc_1seg_unk_id.bsp -a -n -g',
  16,
"Summary for all files.",
"Bodies: -111  -254  401",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000",
"Bodies: 4     499",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 03 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Displaying numeric IDs only (-n), two files, -a -t -g',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov1.bsp brief_sc_1seg_unk_id.bsp -a -n -t -g',
  13,
"Summary for all files.",
"BodiesStart of Interval (ET)          End of Interval (ET)",
"-----------------------------------   -----------------------------",
"-111  2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"-254              Same coverage as previous object",
"401               Same coverage as previous object",
"4     2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"499               Same coverage as previous object"
);


#
# Tests displays with only names.
#
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Displaying ordered by name (-o), one file',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov1.bsp -o',
  16,
"Summary for: brief_sc_bc_pl_sat_dcov1.bsp",
"Bodies: MARS (499)           MARS BARYCENTER (4)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 03 12:00:00.000",
"Bodies: MER-2 (-254)         PHOBOS (401)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Displaying ordered by name (-o), one file, -t',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov1.bsp -o -t',
  12,
"Summary for: brief_sc_bc_pl_sat_dcov1.bsp",
"Bodies               Start of Interval (ET)          End of Interval (ET)",
"-------              -----------------------------   -----------------------------",
"MARS (499)           2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"MARS BARYCENTER (4)              Same coverage as previous object",
"MER-2 (-254)         2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"PHOBOS (401)                     Same coverage as previous object"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Displaying ordered by name (-o), one file, -g',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov1.bsp -o -g',
  16,
"Summary for: brief_sc_bc_pl_sat_dcov1.bsp",
"Bodies: MARS (499)           MARS BARYCENTER (4)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 03 12:00:00.000",
"Bodies: MER-2 (-254)         PHOBOS (401)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Displaying ordered by name (-o), one file, -t -g',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov1.bsp -o -t -g',
  12,
"Summary for: brief_sc_bc_pl_sat_dcov1.bsp",
"Bodies               Start of Interval (ET)          End of Interval (ET)",
"-------              -----------------------------   -----------------------------",
"MARS (499)           2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"MARS BARYCENTER (4)              Same coverage as previous object",
"MER-2 (-254)         2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"PHOBOS (401)                     Same coverage as previous object"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Displaying ordered by name (-o), two files',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov1.bsp brief_sc_1seg_unk_id.bsp -a -o',
  16,
"Summary for all files.",
"Bodies: -111                 MER-2 (-254)         PHOBOS (401)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000",
"Bodies: MARS (499)           MARS BARYCENTER (4)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 03 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Displaying ordered by name (-o), two files, -a -t',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov1.bsp brief_sc_1seg_unk_id.bsp -a -o -t',
  13,
"Summary for all files.",
"Bodies               Start of Interval (ET)          End of Interval (ET)",
"-------              -----------------------------   -----------------------------",
"-111                 2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"MARS (499)           2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"MARS BARYCENTER (4)              Same coverage as previous object",
"MER-2 (-254)         2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"PHOBOS (401)                     Same coverage as previous object"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Displaying ordered by name (-o), two files, -a -g',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov1.bsp brief_sc_1seg_unk_id.bsp -a -o -g',
  16,
"Summary for all files.",
"Bodies: -111                 MER-2 (-254)         PHOBOS (401)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000",
"Bodies: MARS (499)           MARS BARYCENTER (4)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 03 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Displaying ordered by name (-o), two files, -a -t -g',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov1.bsp brief_sc_1seg_unk_id.bsp -a -o -t -g',
  13,
"Summary for all files.",
"Bodies               Start of Interval (ET)          End of Interval (ET)",
"-------              -----------------------------   -----------------------------",
"-111                 2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"MER-2 (-254)                     Same coverage as previous object",
"PHOBOS (401)                     Same coverage as previous object",
"MARS (499)           2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"MARS BARYCENTER (4)              Same coverage as previous object"
);

#
# Tests comprehensively covering all displays formats for SPKs.
#
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK: -t',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov3.bsp -t',
  14,
"Summary for: brief_sc_bc_pl_sat_dcov3.bsp",
"Bodies             Start of Interval (ET)          End of Interval (ET)",
"-------            -----------------------------   -----------------------------",
"-253 MER-1         2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"-254 MER-2         2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"4 MARS BARYCENTER  2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"401 PHOBOS         2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"402 DEIMOS                     Same coverage as previous object",
"499 MARS           2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK: -t -n',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov3.bsp -t -n',
  14,
"Summary for: brief_sc_bc_pl_sat_dcov3.bsp",
"BodiesStart of Interval (ET)          End of Interval (ET)",
"-----------------------------------   -----------------------------",
"-253  2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"-254  2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"4     2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"401   2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"402               Same coverage as previous object",
"499   2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK: -t -n -c',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov3.bsp -t -n -c',
  14,
"Summary for: brief_sc_bc_pl_sat_dcov3.bsp",
"Bodies         Start of Interval (ET)          End of Interval (ET)",
"-------        -----------------------------   -----------------------------",
"-253 w.r.t. 0  2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"-254 w.r.t. 0  2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"4 w.r.t. 0     2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"401 w.r.t. 4   2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"402 w.r.t. 4               Same coverage as previous object",
"499 w.r.t. 4   2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK: -t -n -c -o',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov3.bsp -t -n -c -o',
  14,
"Summary for: brief_sc_bc_pl_sat_dcov3.bsp",
"Bodies         Start of Interval (ET)          End of Interval (ET)",
"-------        -----------------------------   -----------------------------",
"-253 w.r.t. 0  2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"-254 w.r.t. 0  2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"4 w.r.t. 0     2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"401 w.r.t. 4   2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"402 w.r.t. 4               Same coverage as previous object",
"499 w.r.t. 4   2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK: -t -n -o',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov3.bsp -t -n -o',
  14,
"Summary for: brief_sc_bc_pl_sat_dcov3.bsp",
"BodiesStart of Interval (ET)          End of Interval (ET)",
"-----------------------------------   -----------------------------",
"-253  2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"-254  2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"4     2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"401   2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"402               Same coverage as previous object",
"499   2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK: -t -c',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov3.bsp -t -c',
  14,
"Summary for: brief_sc_bc_pl_sat_dcov3.bsp",
"Bodies                                              Start of Interval (ET)          End of Interval (ET)",
"-------                                             -----------------------------   -----------------------------",
"-253 MER-1 w.r.t. 0 SOLAR SYSTEM BARYCENTER         2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"-254 MER-2 w.r.t. 0 SOLAR SYSTEM BARYCENTER         2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"4 MARS BARYCENTER w.r.t. 0 SOLAR SYSTEM BARYCENTER  2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"401 PHOBOS w.r.t. 4 MARS BARYCENTER                 2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"402 DEIMOS w.r.t. 4 MARS BARYCENTER                             Same coverage as previous object",
"499 MARS w.r.t. 4 MARS BARYCENTER                   2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK: -t -c -o',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov3.bsp -t -c -o',
  14,
"Summary for: brief_sc_bc_pl_sat_dcov3.bsp",
"Bodies                                                  Start of Interval (ET)          End of Interval (ET)",
"-------                                                 -----------------------------   -----------------------------",
"DEIMOS (402) w.r.t. MARS BARYCENTER (4)                 2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"MARS BARYCENTER (4) w.r.t. SOLAR SYSTEM BARYCENTER (0)  2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"MARS (499) w.r.t. MARS BARYCENTER (4)                               Same coverage as previous object",
"MER-1 (-253) w.r.t. SOLAR SYSTEM BARYCENTER (0)                     Same coverage as previous object",
"MER-2 (-254) w.r.t. SOLAR SYSTEM BARYCENTER (0)         2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"PHOBOS (401) w.r.t. MARS BARYCENTER (4)                             Same coverage as previous object"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK: -t -o',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov3.bsp -t -o',
  14,
"Summary for: brief_sc_bc_pl_sat_dcov3.bsp",
"Bodies               Start of Interval (ET)          End of Interval (ET)",
"-------              -----------------------------   -----------------------------",
"DEIMOS (402)         2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"MARS (499)           2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"MARS BARYCENTER (4)              Same coverage as previous object",
"MER-1 (-253)                     Same coverage as previous object",
"MER-2 (-254)         2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"PHOBOS (401)                     Same coverage as previous object"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK: -n',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov3.bsp -n',
  16,
"Summary for: brief_sc_bc_pl_sat_dcov3.bsp",
"Bodies: -253  4     499",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 03 12:00:00.000",
"Bodies: -254  401   402",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK: -n -c',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov3.bsp -n -c',
  16,
"Summary for: brief_sc_bc_pl_sat_dcov3.bsp",
"Bodies: -253 w.r.t. 0  4 w.r.t. 0     499 w.r.t. 4",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 03 12:00:00.000",
"Bodies: -254 w.r.t. 0  401 w.r.t. 4   402 w.r.t. 4",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK: -n -c -o',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov3.bsp -n -c -o',
  16,
"Summary for: brief_sc_bc_pl_sat_dcov3.bsp",
"Bodies: -253 w.r.t. 0  4 w.r.t. 0     499 w.r.t. 4",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 03 12:00:00.000",
"Bodies: -254 w.r.t. 0  401 w.r.t. 4   402 w.r.t. 4",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK: -n -o',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov3.bsp -n -o',
  16,
"Summary for: brief_sc_bc_pl_sat_dcov3.bsp",
"Bodies: -253  4     499",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 03 12:00:00.000",
"Bodies: -254  401   402",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK: -c',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov3.bsp -c',
  20,
"Summary for: brief_sc_bc_pl_sat_dcov3.bsp",
"Bodies: MER-1 (-253) w.r.t. SOLAR SYSTEM BARYCENTER (0)",
"        MARS BARYCENTER (4) w.r.t. SOLAR SYSTEM BARYCENTER (0)",
"        MARS (499) w.r.t. MARS BARYCENTER (4)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 03 12:00:00.000",
"Bodies: MER-2 (-254) w.r.t. SOLAR SYSTEM BARYCENTER (0)",
"        PHOBOS (401) w.r.t. MARS BARYCENTER (4)",
"        DEIMOS (402) w.r.t. MARS BARYCENTER (4)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK: -c -o',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov3.bsp -c -o',
  20,
"Summary for: brief_sc_bc_pl_sat_dcov3.bsp",
"Bodies: DEIMOS (402) w.r.t. MARS BARYCENTER (4)",
"        MER-2 (-254) w.r.t. SOLAR SYSTEM BARYCENTER (0)",
"        PHOBOS (401) w.r.t. MARS BARYCENTER (4)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000",
"Bodies: MARS BARYCENTER (4) w.r.t. SOLAR SYSTEM BARYCENTER (0)",
"        MARS (499) w.r.t. MARS BARYCENTER (4)",
"        MER-1 (-253) w.r.t. SOLAR SYSTEM BARYCENTER (0)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 03 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK: -o',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov3.bsp -o',
  16,
"Summary for: brief_sc_bc_pl_sat_dcov3.bsp",
"Bodies: DEIMOS (402)         MER-2 (-254)         PHOBOS (401)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000",
"Bodies: MARS (499)           MARS BARYCENTER (4)  MER-1 (-253)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 03 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK: <NONE>',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov3.bsp',
  16,
"Summary for: brief_sc_bc_pl_sat_dcov3.bsp",
"Bodies: MER-1 (-253)         MARS BARYCENTER (4)  MARS (499)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 03 12:00:00.000",
"Bodies: MER-2 (-254)         PHOBOS (401)         DEIMOS (402)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

#
# Tests comprehensively covering all displays formats for SPKs with
# non-intertial frame.
#
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK (*): for -t',
  'success',
  $brief,
  'brief_sc_1seg_niframe.bsp -t',
  9,
"Summary for: brief_sc_1seg_niframe.bsp",
"Bodies     Start of Interval (ET)          End of Interval (ET)",
"-------    -----------------------------   -----------------------------",
"-29 NEXT*  2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK (*): for -t -n',
  'success',
  $brief,
  'brief_sc_1seg_niframe.bsp -t -n',
  9,
"Summary for: brief_sc_1seg_niframe.bsp",
"BodiesStart of Interval (ET)          End of Interval (ET)",
"-----------------------------------   -----------------------------",
"-29*  2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK (*): for -t -n -c',
  'success',
  $brief,
  'brief_sc_1seg_niframe.bsp -t -n -c',
  9,
"Summary for: brief_sc_1seg_niframe.bsp",
"Bodies         Start of Interval (ET)          End of Interval (ET)",
"-------        -----------------------------   -----------------------------",
"-29* w.r.t. 0  2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK (*): for -t -n -c -o',
  'success',
  $brief,
  'brief_sc_1seg_niframe.bsp -t -n -c -o',
  9,
"Summary for: brief_sc_1seg_niframe.bsp",
"Bodies         Start of Interval (ET)          End of Interval (ET)",
"-------        -----------------------------   -----------------------------",
"-29* w.r.t. 0  2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK (*): for -t -n -o',
  'success',
  $brief,
  'brief_sc_1seg_niframe.bsp -t -n -o',
  9,
"Summary for: brief_sc_1seg_niframe.bsp",
"BodiesStart of Interval (ET)          End of Interval (ET)",
"-----------------------------------   -----------------------------",
"-29*  2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000");

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK (*): for -t -c',
  'success',
  $brief,
  'brief_sc_1seg_niframe.bsp -t -c',
  9,
"Summary for: brief_sc_1seg_niframe.bsp",
"Bodies                                      Start of Interval (ET)          End of Interval (ET)",
"-------                                     -----------------------------   -----------------------------",
"-29 NEXT* w.r.t. 0 SOLAR SYSTEM BARYCENTER  2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK (*): for -t -c -o',
  'success',
  $brief,
  'brief_sc_1seg_niframe.bsp -t -c -o',
  9,
"Summary for: brief_sc_1seg_niframe.bsp",
"Bodies                                          Start of Interval (ET)          End of Interval (ET)",
"-------                                         -----------------------------   -----------------------------",
"NEXT (-29)* w.r.t. SOLAR SYSTEM BARYCENTER (0)  2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK (*): for -t -o',
  'success',
  $brief,
  'brief_sc_1seg_niframe.bsp -t -o',
  9,
"Summary for: brief_sc_1seg_niframe.bsp",
"Bodies       Start of Interval (ET)          End of Interval (ET)",
"-------      -----------------------------   -----------------------------",
"NEXT (-29)*  2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK (*): for -n',
  'success',
  $brief,
  'brief_sc_1seg_niframe.bsp -n',
  11,
"Summary for: brief_sc_1seg_niframe.bsp",
"Body: -29*",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK (*): for -n -c',
  'success',
  $brief,
  'brief_sc_1seg_niframe.bsp -n -c',
  11,
"Summary for: brief_sc_1seg_niframe.bsp",
"Body: -29* w.r.t. 0",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK (*): for -n -c -o',
  'success',
  $brief,
  'brief_sc_1seg_niframe.bsp -n -c -o',
  11,
"Summary for: brief_sc_1seg_niframe.bsp",
"Body: -29* w.r.t. 0",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK (*): for -n -o',
  'success',
  $brief,
  'brief_sc_1seg_niframe.bsp -n -o',
  11,
"Summary for: brief_sc_1seg_niframe.bsp",
"Body: -29*",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK (*): for -c',
  'success',
  $brief,
  'brief_sc_1seg_niframe.bsp -c',
  11,
"Summary for: brief_sc_1seg_niframe.bsp",
"Body: NEXT (-29)* w.r.t. SOLAR SYSTEM BARYCENTER (0)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK (*): for -c -o',
  'success',
  $brief,
  'brief_sc_1seg_niframe.bsp -c -o',
  11,
"Summary for: brief_sc_1seg_niframe.bsp",
"Body: NEXT (-29)* w.r.t. SOLAR SYSTEM BARYCENTER (0)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK (*): for -o',
  'success',
  $brief,
  'brief_sc_1seg_niframe.bsp -o',
  11,
"Summary for: brief_sc_1seg_niframe.bsp",
"Body: NEXT (-29)*",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK (*): for <NONE>',
  'success',
  $brief,
  'brief_sc_1seg_niframe.bsp',
  11,
"Summary for: brief_sc_1seg_niframe.bsp",
"Body: NEXT (-29)*",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

#
# Tests comprehensively covering all displays formats with grouping for SPKs.
#
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK: -g -t',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov3.bsp -g -t',
  14,
"Summary for: brief_sc_bc_pl_sat_dcov3.bsp",
"Bodies             Start of Interval (ET)          End of Interval (ET)",
"-------            -----------------------------   -----------------------------",
"-253 MER-1         2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"4 MARS BARYCENTER              Same coverage as previous object",
"499 MARS                       Same coverage as previous object",
"-254 MER-2         2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"401 PHOBOS                     Same coverage as previous object",
"402 DEIMOS                     Same coverage as previous object"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK: -g -t -n',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov3.bsp -g -t -n',
  14,
"Summary for: brief_sc_bc_pl_sat_dcov3.bsp",
"BodiesStart of Interval (ET)          End of Interval (ET)",
"-----------------------------------   -----------------------------",
"-253  2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"4                 Same coverage as previous object",
"499               Same coverage as previous object",
"-254  2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"401               Same coverage as previous object",
"402               Same coverage as previous object"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK: -g -t -n -c',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov3.bsp -g -t -n -c',
  14,
"Summary for: brief_sc_bc_pl_sat_dcov3.bsp",
"Bodies         Start of Interval (ET)          End of Interval (ET)",
"-------        -----------------------------   -----------------------------",
"-253 w.r.t. 0  2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"4 w.r.t. 0                 Same coverage as previous object",
"499 w.r.t. 4               Same coverage as previous object",
"-254 w.r.t. 0  2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"401 w.r.t. 4               Same coverage as previous object",
"402 w.r.t. 4               Same coverage as previous object"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK: -g -t -n -c -o',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov3.bsp -g -t -n -c -o',
  14,
"Summary for: brief_sc_bc_pl_sat_dcov3.bsp",
"Bodies         Start of Interval (ET)          End of Interval (ET)",
"-------        -----------------------------   -----------------------------",
"-253 w.r.t. 0  2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"4 w.r.t. 0                 Same coverage as previous object",
"499 w.r.t. 4               Same coverage as previous object",
"-254 w.r.t. 0  2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"401 w.r.t. 4               Same coverage as previous object",
"402 w.r.t. 4               Same coverage as previous object"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK: -g -t -n -o',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov3.bsp -g -t -n -o',
  14,
"Summary for: brief_sc_bc_pl_sat_dcov3.bsp",
"BodiesStart of Interval (ET)          End of Interval (ET)",
"-----------------------------------   -----------------------------",
"-253  2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"4                 Same coverage as previous object",
"499               Same coverage as previous object",
"-254  2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"401               Same coverage as previous object",
"402               Same coverage as previous object"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK: -g -t -c',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov3.bsp -g -t -c',
  14,
"Summary for: brief_sc_bc_pl_sat_dcov3.bsp",
"Bodies                                              Start of Interval (ET)          End of Interval (ET)",
"-------                                             -----------------------------   -----------------------------",
"-253 MER-1 w.r.t. 0 SOLAR SYSTEM BARYCENTER         2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"4 MARS BARYCENTER w.r.t. 0 SOLAR SYSTEM BARYCENTER              Same coverage as previous object",
"499 MARS w.r.t. 4 MARS BARYCENTER                               Same coverage as previous object",
"-254 MER-2 w.r.t. 0 SOLAR SYSTEM BARYCENTER         2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"401 PHOBOS w.r.t. 4 MARS BARYCENTER                             Same coverage as previous object",
"402 DEIMOS w.r.t. 4 MARS BARYCENTER                             Same coverage as previous object"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK: -g -t -c -o',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov3.bsp -g -t -c -o',
  14,
"Summary for: brief_sc_bc_pl_sat_dcov3.bsp",
"Bodies                                                  Start of Interval (ET)          End of Interval (ET)",
"-------                                                 -----------------------------   -----------------------------",
"DEIMOS (402) w.r.t. MARS BARYCENTER (4)                 2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"MER-2 (-254) w.r.t. SOLAR SYSTEM BARYCENTER (0)                     Same coverage as previous object",
"PHOBOS (401) w.r.t. MARS BARYCENTER (4)                             Same coverage as previous object",
"MARS BARYCENTER (4) w.r.t. SOLAR SYSTEM BARYCENTER (0)  2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"MARS (499) w.r.t. MARS BARYCENTER (4)                               Same coverage as previous object",
"MER-1 (-253) w.r.t. SOLAR SYSTEM BARYCENTER (0)                     Same coverage as previous object"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK: -g -t -o',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov3.bsp -g -t -o',
  14,
"Bodies               Start of Interval (ET)          End of Interval (ET)",
"-------              -----------------------------   -----------------------------",
"DEIMOS (402)         2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"MER-2 (-254)                     Same coverage as previous object",
"PHOBOS (401)                     Same coverage as previous object",
"MARS (499)           2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"MARS BARYCENTER (4)              Same coverage as previous object",
"MER-1 (-253)                     Same coverage as previous object"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK: -g -n',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov3.bsp -g -n',
  16,
"Summary for: brief_sc_bc_pl_sat_dcov3.bsp",
"Bodies: -253  4     499",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 03 12:00:00.000",
"Bodies: -254  401   402",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK: -g -n -c',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov3.bsp -g -n -c',
  16,
"Summary for: brief_sc_bc_pl_sat_dcov3.bsp",
"Bodies: -253 w.r.t. 0  4 w.r.t. 0     499 w.r.t. 4",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 03 12:00:00.000",
"Bodies: -254 w.r.t. 0  401 w.r.t. 4   402 w.r.t. 4",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK: -g -n -c -o',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov3.bsp -g -n -c -o',
  16,
"Summary for: brief_sc_bc_pl_sat_dcov3.bsp",
"Bodies: -253 w.r.t. 0  4 w.r.t. 0     499 w.r.t. 4",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 03 12:00:00.000",
"Bodies: -254 w.r.t. 0  401 w.r.t. 4   402 w.r.t. 4",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK: -g -n -o',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov3.bsp -g -n -o',
  16,
"Summary for: brief_sc_bc_pl_sat_dcov3.bsp",
"Bodies: -253  4     499",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 03 12:00:00.000",
"Bodies: -254  401   402",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK: -g -c',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov3.bsp -g -c',
  20,
"Summary for: brief_sc_bc_pl_sat_dcov3.bsp",
"Bodies: MER-1 (-253) w.r.t. SOLAR SYSTEM BARYCENTER (0)",
"        MARS BARYCENTER (4) w.r.t. SOLAR SYSTEM BARYCENTER (0)",
"        MARS (499) w.r.t. MARS BARYCENTER (4)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 03 12:00:00.000",
"Bodies: MER-2 (-254) w.r.t. SOLAR SYSTEM BARYCENTER (0)",
"        PHOBOS (401) w.r.t. MARS BARYCENTER (4)",
"        DEIMOS (402) w.r.t. MARS BARYCENTER (4)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK: -g -c -o',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov3.bsp -g -c -o',
  20,
"Summary for: brief_sc_bc_pl_sat_dcov3.bsp",
"Bodies: DEIMOS (402) w.r.t. MARS BARYCENTER (4)",
"        MER-2 (-254) w.r.t. SOLAR SYSTEM BARYCENTER (0)",
"        PHOBOS (401) w.r.t. MARS BARYCENTER (4)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000",
"Bodies: MARS BARYCENTER (4) w.r.t. SOLAR SYSTEM BARYCENTER (0)",
"        MARS (499) w.r.t. MARS BARYCENTER (4)",
"        MER-1 (-253) w.r.t. SOLAR SYSTEM BARYCENTER (0)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 03 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK: -g -o',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov3.bsp -g -o',
  16,
"Summary for: brief_sc_bc_pl_sat_dcov3.bsp",
"Bodies: DEIMOS (402)         MER-2 (-254)         PHOBOS (401)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000",
"Bodies: MARS (499)           MARS BARYCENTER (4)  MER-1 (-253)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 03 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting SPK: -g <NONE>',
  'success',
  $brief,
  'brief_sc_bc_pl_sat_dcov3.bsp -g',
  16,
"Summary for: brief_sc_bc_pl_sat_dcov3.bsp",
"Bodies: MER-1 (-253)         MARS BARYCENTER (4)  MARS (499)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 03 12:00:00.000",
"Bodies: MER-2 (-254)         PHOBOS (401)         DEIMOS (402)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

#
# Test summarizing meta-kernels.
#
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Summaring MK: MK with one SPK',
  'success',
  $brief,
  'brief_mk_spk.tm -t',
  9,
"Summary for: brief_sc_1seg.bsp",
"Bodies    Start of Interval (ET)          End of Interval (ET)",
"-------   -----------------------------   -----------------------------",
"-29 NEXT  2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Summaring MK: MK with many SPKs',
  'success',
  $brief,
  'brief_mk_2spks.tm -t',
  20,
"Summary for: brief_sc_3seg_gaps.bsp",
"Bodies    Start of Interval (ET)          End of Interval (ET)",
"-------   -----------------------------   -----------------------------",
"-29 NEXT  2000 JAN 04 05:05:05.049        2000 JAN 06 05:05:05.049",
"          2000 JAN 06 07:07:07.070        2000 JAN 07 06:06:06.060",
"          2000 JAN 07 08:08:08.080        2000 JAN 08 07:07:07.069",
"Summary for: brief_sc_bc_pl_sat_dcov1.bsp",
"Bodies             Start of Interval (ET)          End of Interval (ET)",
"-------            -----------------------------   -----------------------------",
"-254 MER-2         2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"4 MARS BARYCENTER  2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"401 PHOBOS         2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"499 MARS           2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Summaring MK: MK with SPK and LSK',
  'success',
  $brief,
  'brief_mk_spk_lsk.tm -utc -t',
  9,
"Summary for: brief_sc_1seg.bsp",
"Bodies    Start of Interval (UTC)         End of Interval (UTC)",
"-------   -----------------------------   -----------------------------",
"-29 NEXT  2000-JAN-01 11:58:55.816        2000-JAN-02 11:58:55.816"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Summaring MK: MK with SPK and PCK',
  'success',
  $brief,
  'brief_mk_spk_pck.tm -t',
  9,
"Summary for: brief_sc_1seg.bsp",
"Bodies    Start of Interval (ET)          End of Interval (ET)",
"-------   -----------------------------   -----------------------------",
"-29 NEXT  2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Summaring MK: MK and SPK on command line',
  'success',
  $brief,
  'brief_mk_spk.tm brief_sc_bc_pl_sat_dcov3.bsp',
  24,
"Summary for: brief_sc_bc_pl_sat_dcov3.bsp",
"Bodies: MER-1 (-253)         MARS BARYCENTER (4)  MARS (499)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 03 12:00:00.000",
"Bodies: MER-2 (-254)         PHOBOS (401)         DEIMOS (402)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000",
"Summary for: brief_sc_1seg.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Summaring MK: MK in list file, SPK on command line',
  'success',
  $brief,
  '-f brief_list_mk_only.lst brief_sc_bc_pl_sat_dcov3.bsp -t',
  20,
"Summary for: brief_sc_bc_pl_sat_dcov3.bsp",
"Bodies             Start of Interval (ET)          End of Interval (ET)",
"-------            -----------------------------   -----------------------------",
"-253 MER-1         2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"-254 MER-2         2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"4 MARS BARYCENTER  2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"401 PHOBOS         2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"402 DEIMOS                     Same coverage as previous object",
"499 MARS           2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"Summary for: brief_sc_1seg.bsp",
"Bodies    Start of Interval (ET)          End of Interval (ET)",
"-------   -----------------------------   -----------------------------",
"-29 NEXT  2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Summaring MK: MK on command line, SPK in list file',
  'success',
  $brief,
  '-f brief_list_one.lst brief_mk_2spks.tm -t',
  26,
"Summary for: brief_sc_1seg.bsp",
"Bodies    Start of Interval (ET)          End of Interval (ET)",
"-------   -----------------------------   -----------------------------",
"-29 NEXT  2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"Summary for: brief_sc_3seg_gaps.bsp",
"Bodies    Start of Interval (ET)          End of Interval (ET)",
"-------   -----------------------------   -----------------------------",
"-29 NEXT  2000 JAN 04 05:05:05.049        2000 JAN 06 05:05:05.049",
"          2000 JAN 06 07:07:07.070        2000 JAN 07 06:06:06.060",
"          2000 JAN 07 08:08:08.080        2000 JAN 08 07:07:07.069",
"Summary for: brief_sc_bc_pl_sat_dcov1.bsp",
"Bodies             Start of Interval (ET)          End of Interval (ET)",
"-------            -----------------------------   -----------------------------",
"-254 MER-2         2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"4 MARS BARYCENTER  2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"401 PHOBOS         2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"499 MARS           2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Summaring MK: MK and PSK in list file',
  'success',
  $brief,
  '-f brief_list_mk_spk.lst -t',
  20,
"Summary for: brief_sc_bc_pl_sat_dcov3.bsp",
"Bodies             Start of Interval (ET)          End of Interval (ET)",
"-------            -----------------------------   -----------------------------",
"-253 MER-1         2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"-254 MER-2         2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"4 MARS BARYCENTER  2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"401 PHOBOS         2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"402 DEIMOS                     Same coverage as previous object",
"499 MARS           2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"Summary for: brief_sc_1seg.bsp",
"Bodies    Start of Interval (ET)          End of Interval (ET)",
"-------   -----------------------------   -----------------------------",
"-29 NEXT  2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Summaring MK: MK in list file, MK on command line',
  'success',
  $brief,
  '-f brief_list_mk_only.lst brief_mk_2spks.tm -t',
  26,
"Summary for: brief_sc_3seg_gaps.bsp",
"Bodies    Start of Interval (ET)          End of Interval (ET)",
"-------   -----------------------------   -----------------------------",
"-29 NEXT  2000 JAN 04 05:05:05.049        2000 JAN 06 05:05:05.049",
"          2000 JAN 06 07:07:07.070        2000 JAN 07 06:06:06.060",
"          2000 JAN 07 08:08:08.080        2000 JAN 08 07:07:07.069",
"Summary for: brief_sc_bc_pl_sat_dcov1.bsp",
"Bodies             Start of Interval (ET)          End of Interval (ET)",
"-------            -----------------------------   -----------------------------",
"-254 MER-2         2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"4 MARS BARYCENTER  2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"401 PHOBOS         2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000",
"499 MARS           2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"Summary for: brief_sc_1seg.bsp",
"Bodies    Start of Interval (ET)          End of Interval (ET)",
"-------   -----------------------------   -----------------------------",
"-29 NEXT  2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000"
);

#
# Tests for file names provided in a file.
#
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Summarizing list file: one name, one line',
  'success',
  $brief,
  '-f brief_list_one.lst',
  11,
"Summary for: brief_sc_1seg.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Summarizing list file: list file contains TABs',
  'success',
  $brief,
  '-f brief_list_bad_with_tabs.lst',
  11,
"Summary for: brief_sc_1seg.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);


#&run_test (
#  $reporttype,
#  'Summarizing list file: one name, one line, no EOF',
#  'success',
#  $brief,
#  '-f brief_list_one_no_eof.lst',
#"Summary for: brief_sc_1seg.bsp",
#"Body: NEXT (-29)",
#"      Start of Interval (ET)              End of Interval (ET)",
#"      -----------------------------       -----------------------------",
#"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
#);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Summarizing list file: many names, same # lines',
  'success',
  $brief,
  '-f brief_list_many.lst',
  19,
"Summary for: brief_sc_1seg.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000",
"Summary for: brief_sc_3seg.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 01:01:01.010            2000 JAN 05 06:06:06.059"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Summarizing list file: many names, extra blank lines',
  'success',
  $brief,
  '-f brief_list_many_w_blank_lines.lst',
  27,
"Summary for: brief_sc_1seg.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000",
"Summary for: brief_sc_1seg_unk_id.bsp",
"Body: -111",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000",
"Summary for: brief_sc_3seg.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 01:01:01.010            2000 JAN 05 06:06:06.059"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Summarizing list file: many names on one line',
  'success',
  $brief,
  '-f brief_list_few_per_line.lst',
  27,
"Summary for: brief_sc_1seg.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000",
"Summary for: brief_sc_1seg_unk_id.bsp",
"Body: -111",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000",
"Summary for: brief_sc_3seg.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 02 01:01:01.010            2000 JAN 05 06:06:06.059"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Summarizing list file: including text kernels',
  'success',
  $brief,
  '-f brief_list_spk_lsk.lst -utc',
  11,
"Summary for: brief_sc_1seg.bsp",
"Body: NEXT (-29)",
"      Start of Interval (UTC)             End of Interval (UTC)",
"      -----------------------------       -----------------------------",
"      2000-JAN-01 11:58:55.816            2000-JAN-02 11:58:55.816"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Summarizing list file: two list files, only last used',
  'success',
  $brief,
  '-f brief_list_pck_only.lst -f brief_list_one.lst',
  11,
"Summary for: brief_sc_1seg.bsp",
"Body: NEXT (-29)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

#
# Test -<BODY> (one, many , one range, many ranges, overlapping ranges,
# single with ranges, no result for one/many/ranges/combinations)
#
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -, one body, using ID',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp -499',
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Body: MARS (499)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -, two bodies, using IDs',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp -499 -401',
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: PHOBOS (401)  MARS (499)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -, one body, using name',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp -SPIRIT',
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Body: MER-2 (-254)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -, one body, using name with underscores',
  'success',
  $brief,
  'brief_test.tf brief_sc_bc_pl_sat.bsp -MARS_SYSTEM_BARYCENTER',
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Body: MARS_SYSTEM_BARYCENTER (4)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -, one body, using name with blanks',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp -MARS_BARYCENTER',
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Body: MARS BARYCENTER (4)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -, two bodies, using names',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp -SPIRIT -PHOBOS',
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: MER-2 (-254)  PHOBOS (401)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -, two bodies, using name and ID',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp -SPIRIT -4',
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: MER-2 (-254)         MARS BARYCENTER (4)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -, one range, exact endponts',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-[401:499]".$qt."",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: PHOBOS (401)  MARS (499)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -, one range, wrapping endpoints',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-[400:500]".$qt."",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: PHOBOS (401)  MARS (499)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -, two ranges',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-[0:5]".$qt." ".$qt."-[401:402]".$qt."",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: MARS BARYCENTER (4)  PHOBOS (401)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -, one body, one range',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-[0:5]".$qt." -401",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: MARS BARYCENTER (4)  PHOBOS (401)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -, one body, two ranges',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp -499 ".$qt."-[0:5]".$qt." ".$qt."-[401:402]".$qt."",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: MARS BARYCENTER (4)  PHOBOS (401)         MARS (499)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -, unrecognized body ID',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp --255',
  9,
"Summary for: brief_sc_bc_pl_sat.bsp",
"There is no data:",
"  for body '-255'"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -, unrecognized body ID, with -a',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp --255 -a',
  9,
"Summary for all files.",
"There is no data:",
"  for body '-255'"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -, unrecognized body name',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp -SPIR',
  13,
"'-SPIR' is not recognized.",
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: MER-2 (-254)         PHOBOS (401)",
"        MARS BARYCENTER (4)  MARS (499)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -, negative range',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-[-300:0]".$qt."",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Body: MER-2 (-254)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -, reversed range boundaries',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-[5:0]".$qt."",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Body: MARS BARYCENTER (4)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -, range open right',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-[5:]".$qt."",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: PHOBOS (401)  MARS (499)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -, range open left',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-[:5]".$qt."",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: MER-2 (-254)         MARS BARYCENTER (4)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -, empty range',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-[:]".$qt."",
  13,
"Summary for: brief_sc_bc_pl_sat.bsp",
"'-[:]' is not recognized.",
"Bodies: MER-2 (-254)         PHOBOS (401)",
"        MARS BARYCENTER (4)  MARS (499)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -, badly formatted range',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-[5:1000:]".$qt."",
  13,
"Summary for: brief_sc_bc_pl_sat.bsp",
"'-[5:1000:]' is not recognized.",
"Bodies: MER-2 (-254)         PHOBOS (401)",
"        MARS BARYCENTER (4)  MARS (499)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -, no data two bodies',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp --255 --256',
  10,
"Summary for: brief_sc_bc_pl_sat.bsp",
"There is no data:",
"  for body '-255'",
"  for body '-256'"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -, no data two bodies, with -a',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp --255 --256 -a',
  10,
"Summary for all files.",
"There is no data:",
"  for body '-255'",
"  for body '-256'"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -, no data for range',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-[600:700]".$qt."",
  9,
"Summary for: brief_sc_bc_pl_sat.bsp",
"There is no data:",
"  for bodies in '[600:700]' ID range"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -, no data for range, with -a',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-[600:700]".$qt." -a",
  9,
"Summary for all files.",
"There is no data:",
"  for bodies in '[600:700]' ID range"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -, no data two bodies and range',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp --255 --256 ".$qt."-[600:700]".$qt."",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"There is no data:",
"  for body '-255'",
"  for body '-256'",
"  for bodies in '[600:700]' ID range"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -, no data two bodies and range, with -a',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp --255 --256 ".$qt."-[600:700]".$qt." -a",
  11,
"Summary for all files.",
"There is no data:",
"  for body '-255'",
"  for body '-256'",
"  for bodies in '[600:700]' ID range"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -, double filter',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp --254 -MER-2",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Body: MER-2 (-254)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

#
# Test -sb<BODY> (one, many , one range, many ranges, overlapping ranges,
# single with ranges, no result for one/many/ranges/combinations)
#
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sb, one body, using ID',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp -sb499',
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Body: MARS (499)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sb, two bodies, using IDs',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp -sb499 -sb401',
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: PHOBOS (401)  MARS (499)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sb, one body, using name',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp -sbSPIRIT',
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Body: MER-2 (-254)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sb, one body, using name with underscores',
  'success',
  $brief,
  'brief_test.tf brief_sc_bc_pl_sat.bsp -sbMARS_SYSTEM_BARYCENTER',
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Body: MARS_SYSTEM_BARYCENTER (4)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sb, one body, using name with blanks',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp -sbMARS_BARYCENTER',
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Body: MARS BARYCENTER (4)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sb, two bodies, using names',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp -sbSPIRIT -sbPHOBOS',
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: MER-2 (-254)  PHOBOS (401)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sb, two bodies, using name and ID',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp -sbSPIRIT -sb4',
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: MER-2 (-254)         MARS BARYCENTER (4)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sb, one range, exact endponts',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-sb[401:499]".$qt."",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: PHOBOS (401)  MARS (499)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sb, one range, wrapping endpoints',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-sb[400:500]".$qt."",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: PHOBOS (401)  MARS (499)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sb, two ranges',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-sb[0:5]".$qt." ".$qt."-sb[401:402]".$qt."",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: MARS BARYCENTER (4)  PHOBOS (401)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sb, one body, one range',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-sb[0:5]".$qt." -sb401",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: MARS BARYCENTER (4)  PHOBOS (401)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sb, one body, two ranges',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp -sb499 ".$qt."-sb[0:5]".$qt." ".$qt."-sb[401:402]".$qt."",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: MARS BARYCENTER (4)  PHOBOS (401)         MARS (499)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sb, unrecognized body ID',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp -sb-255',
  9,
"Summary for: brief_sc_bc_pl_sat.bsp",
"There is no data:",
"  for body '-255'"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sb, unrecognized body ID, with -a',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp -sb-255 -a',
  9,
"Summary for all files.",
"There is no data:",
"  for body '-255'"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sb, unrecognized body name',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp -sbSPIR',
  13,
"'-sbSPIR' is not recognized.",
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: MER-2 (-254)         PHOBOS (401)",
"        MARS BARYCENTER (4)  MARS (499)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sb, negative range',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-sb[-300:0]".$qt."",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Body: MER-2 (-254)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sb, reversed range boundaries',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-sb[5:0]".$qt."",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Body: MARS BARYCENTER (4)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sb, range open right',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-sb[5:]".$qt."",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: PHOBOS (401)  MARS (499)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sb, range open left',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-sb[:5]".$qt."",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: MER-2 (-254)         MARS BARYCENTER (4)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sb, empty range',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-sb[:]".$qt."",
  13,
"Summary for: brief_sc_bc_pl_sat.bsp",
"'-sb[:]' is not recognized.",
"Bodies: MER-2 (-254)         PHOBOS (401)",
"        MARS BARYCENTER (4)  MARS (499)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sb, badly formatted range',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-sb[5:1000:]".$qt."",
  13,
"Summary for: brief_sc_bc_pl_sat.bsp",
"'-sb[5:1000:]' is not recognized.",
"Bodies: MER-2 (-254)         PHOBOS (401)",
"        MARS BARYCENTER (4)  MARS (499)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sb, no data two bodies',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp -sb-255 -sb-256',
  10,
"Summary for: brief_sc_bc_pl_sat.bsp",
"There is no data:",
"  for body '-255'",
"  for body '-256'"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sb, no data two bodies, with -a',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp -sb-255 -sb-256 -a',
  10,
"Summary for all files.",
"There is no data:",
"  for body '-255'",
"  for body '-256'"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sb, no data for range',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-sb[600:700]".$qt."",
  9,
"Summary for: brief_sc_bc_pl_sat.bsp",
"There is no data:",
"  for bodies in '[600:700]' ID range"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sb, no data for range, with -a',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-sb[600:700]".$qt." -a",
  9,
"Summary for all files.",
"There is no data:",
"  for bodies in '[600:700]' ID range"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sb, no data two bodies and range',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp -sb-255 -sb-256 ".$qt."-sb[600:700]".$qt."",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"There is no data:",
"  for body '-255'",
"  for body '-256'",
"  for bodies in '[600:700]' ID range"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sb, no data two bodies and range, with -a',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp -sb-255 -sb-256 ".$qt."-sb[600:700]".$qt." -a",
  11,
"Summary for all files.",
"There is no data:",
"  for body '-255'",
"  for body '-256'",
"  for bodies in '[600:700]' ID range"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sb, double filter',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp -sb-254 -sbMER-2",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Body: MER-2 (-254)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

#
# Test a few -<BODY> and -sb<BODY> together
#
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: - and -sb, two bodies, using IDs',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp -sb499 -401',
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: PHOBOS (401)  MARS (499)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: - and -sb, two bodies, using names',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp -SPIRIT -sbPHOBOS',
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: MER-2 (-254)  PHOBOS (401)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: - and -sb, two bodies, using name and ID',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp -sbSPIRIT -4',
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: MER-2 (-254)         MARS BARYCENTER (4)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: - and -sb, two ranges',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-sb[0:5]".$qt." ".$qt."-[401:402]".$qt."",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: MARS BARYCENTER (4)  PHOBOS (401)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: - and -sb, one body, one range',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-[0:5]".$qt." -sb401",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: MARS BARYCENTER (4)  PHOBOS (401)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: - and -sb, one body, two ranges',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp -499 ".$qt."-sb[0:5]".$qt." ".$qt."-[401:402]".$qt."",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: MARS BARYCENTER (4)  PHOBOS (401)         MARS (499)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: - and -sb, no data two bodies',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp -sb-255 --256',
  10,
"Summary for: brief_sc_bc_pl_sat.bsp",
"There is no data:",
"  for body '-255'",
"  for body '-256'"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: - and -sb, no data two bodies and range',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp --255 -sb-256 ".$qt."-sb[600:700]".$qt."",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"There is no data:",
"  for body '-255'",
"  for body '-256'",
"  for bodies in '[600:700]' ID range"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: - and -sb, double filter',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp --254 -sbMER-2",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Body: MER-2 (-254)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

#
# Test -sc<BODY> (one, many, one range, many ranges, overlapping ranges,
# single with ranges, no result for one/many/ranges/combinations)
#
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sc, one center, using ID',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp -sc4',
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: PHOBOS (401)  MARS (499)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sc, two centers, using IDs',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp -sc499 -sc0',
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: MER-2 (-254)         MARS BARYCENTER (4)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sc, one center, using name',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp -scMARS',
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Body: MER-2 (-254)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sc, one center, using name with underscores',
  'success',
  $brief,
  'brief_test.tf brief_sc_bc_pl_sat.bsp -scMARS_SYSTEM_BARYCENTER',
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: PHOBOS (401)  MARS (499)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sc, one center, using name with blanks',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp -scMARS_BARYCENTER',
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: PHOBOS (401)  MARS (499)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sc, two centers, using names',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp -scMARS -scSSB',
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: MER-2 (-254)         MARS BARYCENTER (4)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sc, two centers, using name and ID',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp -scMARS -sc0',
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: MER-2 (-254)         MARS BARYCENTER (4)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sc, one range, exact endponts',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-sc[4:4]".$qt."",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: PHOBOS (401)  MARS (499)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sc, one range, wrapping endpoints',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-sc[3:5]".$qt."",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: PHOBOS (401)  MARS (499)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sc, two ranges',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-sc[0:0]".$qt." ".$qt."-sc[3:5]".$qt."",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: MARS BARYCENTER (4)  PHOBOS (401)         MARS (499)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sc, one center, one range',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-sc[3:5]".$qt." -sc499",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: MER-2 (-254)  PHOBOS (401)  MARS (499)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sc, one center, two ranges',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp -sc499 ".$qt."-sc[0:0]".$qt." ".$qt."-sc[4:10]".$qt."",
  12,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: MER-2 (-254)         PHOBOS (401)",
"        MARS BARYCENTER (4)  MARS (499)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sc, unrecognized center ID',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp -sc-255',
  9,
"Summary for: brief_sc_bc_pl_sat.bsp",
"There is no data:",
"  w.r.t. center '-255'"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sc, unrecognized center ID, with -a',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp -sc-255 -a',
  9,
"Summary for all files.",
"There is no data:",
"  w.r.t. center '-255'"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sc, unrecognized center name',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp -scSPIR',
  13,
"'-scSPIR' is not recognized.",
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: MER-2 (-254)         PHOBOS (401)",
"        MARS BARYCENTER (4)  MARS (499)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sc, negative range',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-sc[-300:0]".$qt."",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Body: MARS BARYCENTER (4)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sc, reversed range boundaries',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-sc[5:0]".$qt."",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: MARS BARYCENTER (4)  PHOBOS (401)         MARS (499)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sc, range open right',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-sc[5:]".$qt."",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Body: MER-2 (-254)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sc, range open left',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-sc[:5]".$qt."",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: MARS BARYCENTER (4)  PHOBOS (401)         MARS (499)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sc, empty range',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-sc[:]".$qt."",
  13,
"Summary for: brief_sc_bc_pl_sat.bsp",
"'-sc[:]' is not recognized.",
"Bodies: MER-2 (-254)         PHOBOS (401)",
"        MARS BARYCENTER (4)  MARS (499)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sc, badly formatted range',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-sc[5:1000:]".$qt."",
  13,
"Summary for: brief_sc_bc_pl_sat.bsp",
"'-sc[5:1000:]' is not recognized.",
"Bodies: MER-2 (-254)         PHOBOS (401)",
"        MARS BARYCENTER (4)  MARS (499)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sc, no data two centers',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp -sc-255 -sc-256',
  10,
"Summary for: brief_sc_bc_pl_sat.bsp",
"There is no data:",
"  w.r.t. center '-255'",
"  w.r.t. center '-256'"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sc, no data two centers, with -a',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp -sc-255 -sc-256 -a',
  10,
"Summary for all files.",
"There is no data:",
"  w.r.t. center '-255'",
"  w.r.t. center '-256'"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sc, no data for range',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-sc[600:700]".$qt."",
  9,
"Summary for: brief_sc_bc_pl_sat.bsp",
"There is no data:",
"  w.r.t. centers in '[600:700]' ID range"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sc, no data for range, with -a',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-sc[600:700]".$qt." -a",
  9,
"Summary for all files.",
"There is no data:",
"  w.r.t. centers in '[600:700]'"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sc, no data two centers and range',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp -sc-255 -sc-256 ".$qt."-sc[600:700]".$qt."",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"There is no data:",
"  w.r.t. center '-255'",
"  w.r.t. center '-256'",
"  w.r.t. centers in '[600:700]' ID range"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sc, no data two centers and range, with -a',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp -sc-255 -sc-256 ".$qt."-sc[600:700]".$qt." -a",
  11,
"Summary for all files.",
"There is no data:",
"  w.r.t. center '-255'",
"  w.r.t. center '-256'",
"  w.r.t. centers in '[600:700]' ID range"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sc, for double filter',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp -scMARS -sc499",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Body: MER-2 (-254)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

#
# Test combined -sb and -sc OR - and -sc.
#
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sb and -sc, one each, using ID',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp -sc4 -sb-254',
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: MER-2 (-254)  PHOBOS (401)  MARS (499)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sb and -sc, one each, using names',
  'success',
  $brief,
  'brief_sc_bc_pl_sat.bsp -scSSB -sbMER-2',
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: MER-2 (-254)         MARS BARYCENTER (4)",
"        Start of Interval (ET)              End of Interval (ET)",
"        -----------------------------       -----------------------------",
"        2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sb and -sc, one each, using ranges',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-sc[3:5]".$qt." ".$qt."-sb[3:5]".$qt."",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: MARS BARYCENTER (4)  PHOBOS (401)         MARS (499)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sb and -sc, two each, using IDs and ranges',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp ".$qt."-sc[0:0]".$qt." -sc499 ".$qt."-sb[402:500]".$qt." -sbPHOBOS",
  12,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Bodies: MER-2 (-254)         PHOBOS (401)",
"        MARS BARYCENTER (4)  MARS (499)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sb and -sc, double filter, body first',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp -sbMER-2 -sc499",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Body: MER-2 (-254)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -sb and -sc, double filter, center first',
  'success',
  $brief,
  "brief_sc_bc_pl_sat.bsp  -scMARS -sb-254",
  11,
"Summary for: brief_sc_bc_pl_sat.bsp",
"Body: MER-2 (-254)",
"      Start of Interval (ET)              End of Interval (ET)",
"      -----------------------------       -----------------------------",
"      2000 JAN 01 12:00:00.000            2000 JAN 02 12:00:00.000"
);

#
# Test time filters -at and -from/-to.
#
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -at and -from/-to, -at only',
  'success',
  $brief,
  "brief_sc_bc_pl_sat_dcov2.bsp -t -at 2000-01-04-01:00",
  10,
"Summary for: brief_sc_bc_pl_sat_dcov2.bsp",
"Bodies      Start of Interval (ET)          End of Interval (ET)",
"-------     -----------------------------   -----------------------------",
"401 PHOBOS  2000 JAN 01 12:00:00.000        2000 JAN 05 12:00:00.000",
"499 MARS    2000 JAN 01 12:00:00.000        2000 JAN 04 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -at and -from/-to, two -ats',
  'success',
  $brief,
  "brief_sc_bc_pl_sat_dcov2.bsp -t -at 2000-01-03-02:00 -at 2000-01-04-01:00",
  10,
"Summary for: brief_sc_bc_pl_sat_dcov2.bsp",
"Bodies      Start of Interval (ET)          End of Interval (ET)",
"-------     -----------------------------   -----------------------------",
"401 PHOBOS  2000 JAN 01 12:00:00.000        2000 JAN 05 12:00:00.000",
"499 MARS    2000 JAN 01 12:00:00.000        2000 JAN 04 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -at and -from/-to, -from and -to',
  'success',
  $brief,
  "brief_sc_bc_pl_sat_dcov2.bsp -t -from 2000-01-04-01:00 -to 2000-01-04-02:00",
  10,
"Summary for: brief_sc_bc_pl_sat_dcov2.bsp",
"Bodies      Start of Interval (ET)          End of Interval (ET)",
"-------     -----------------------------   -----------------------------",
"401 PHOBOS  2000 JAN 01 12:00:00.000        2000 JAN 05 12:00:00.000",
"499 MARS    2000 JAN 01 12:00:00.000        2000 JAN 04 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -at and -from/-to, -from only',
  'success',
  $brief,
  "brief_sc_bc_pl_sat_dcov2.bsp -t -from 2000-01-04-01:00",
  10,
"Summary for: brief_sc_bc_pl_sat_dcov2.bsp",
"Bodies      Start of Interval (ET)          End of Interval (ET)",
"-------     -----------------------------   -----------------------------",
"401 PHOBOS  2000 JAN 01 12:00:00.000        2000 JAN 05 12:00:00.000",
"499 MARS    2000 JAN 01 12:00:00.000        2000 JAN 04 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -at and -from/-to, -to only',
  'success',
  $brief,
  "brief_sc_bc_pl_sat_dcov2.bsp -t -to 2000-01-04-02:00",
  10,
"Summary for: brief_sc_bc_pl_sat_dcov2.bsp",
"Bodies      Start of Interval (ET)          End of Interval (ET)",
"-------     -----------------------------   -----------------------------",
"401 PHOBOS  2000 JAN 01 12:00:00.000        2000 JAN 05 12:00:00.000",
"499 MARS    2000 JAN 01 12:00:00.000        2000 JAN 04 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -at and -from/-to, -at and -from/-to (1)',
  'success',
  $brief,
  "brief_sc_bc_pl_sat_dcov2.bsp -t -at 2000-01-04-01:00 -from 2000-01-05-01:00 -to 2000-01-05-02:00",
  10,
"Summary for: brief_sc_bc_pl_sat_dcov2.bsp",
"Bodies      Start of Interval (ET)          End of Interval (ET)",
"-------     -----------------------------   -----------------------------",
"401 PHOBOS  2000 JAN 01 12:00:00.000        2000 JAN 05 12:00:00.000",
"499 MARS    2000 JAN 01 12:00:00.000        2000 JAN 04 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -at and -from/-to, -at and -from/-to (2)',
  'success',
  $brief,
  "brief_sc_bc_pl_sat_dcov2.bsp -t -from 2000-01-05-01:00 -to 2000-01-05-02:00 -at 2000-01-04-01:00",
  10,
"Summary for: brief_sc_bc_pl_sat_dcov2.bsp",
"Bodies      Start of Interval (ET)          End of Interval (ET)",
"-------     -----------------------------   -----------------------------",
"401 PHOBOS  2000 JAN 01 12:00:00.000        2000 JAN 05 12:00:00.000",
"499 MARS    2000 JAN 01 12:00:00.000        2000 JAN 04 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -at and -from/-to, -at and -from',
  'success',
  $brief,
  "brief_sc_bc_pl_sat_dcov2.bsp -t -from 2000-01-05-01:00 -at 2000-01-04-01:00",
  10,
"Summary for: brief_sc_bc_pl_sat_dcov2.bsp",
"Bodies      Start of Interval (ET)          End of Interval (ET)",
"-------     -----------------------------   -----------------------------",
"401 PHOBOS  2000 JAN 01 12:00:00.000        2000 JAN 05 12:00:00.000",
"499 MARS    2000 JAN 01 12:00:00.000        2000 JAN 04 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -at and -from/-to, -at and -to',
  'success',
  $brief,
  "brief_sc_bc_pl_sat_dcov2.bsp -t -to 2000-01-05-02:00 -at 2000-01-04-01:00",
  10,
"Summary for: brief_sc_bc_pl_sat_dcov2.bsp",
"Bodies      Start of Interval (ET)          End of Interval (ET)",
"-------     -----------------------------   -----------------------------",
"401 PHOBOS  2000 JAN 01 12:00:00.000        2000 JAN 05 12:00:00.000",
"499 MARS    2000 JAN 01 12:00:00.000        2000 JAN 04 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -at and -from/-to, two -from/-tos (1)',
  'success',
  $brief,
  "brief_sc_bc_pl_sat_dcov2.bsp -t -from 2000-01-05-01:00 -to 2000-01-05-02:00 -from 2000-01-03-01:00 -to 2000-01-03-02:00",
  11,
"Summary for: brief_sc_bc_pl_sat_dcov2.bsp",
"Bodies             Start of Interval (ET)          End of Interval (ET)",
"-------            -----------------------------   -----------------------------",
"4 MARS BARYCENTER  2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"401 PHOBOS         2000 JAN 01 12:00:00.000        2000 JAN 05 12:00:00.000",
"499 MARS           2000 JAN 01 12:00:00.000        2000 JAN 04 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -at and -from/-to, two -from/-tos (2)',
  'success',
  $brief,
  "brief_sc_bc_pl_sat_dcov2.bsp -t -from 2000-01-05-01:00 -from 2000-01-03-01:00 -to 2000-01-05-02:00 -to 2000-01-03-02:00",
  11,
"Summary for: brief_sc_bc_pl_sat_dcov2.bsp",
"Bodies             Start of Interval (ET)          End of Interval (ET)",
"-------            -----------------------------   -----------------------------",
"4 MARS BARYCENTER  2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"401 PHOBOS         2000 JAN 01 12:00:00.000        2000 JAN 05 12:00:00.000",
"499 MARS           2000 JAN 01 12:00:00.000        2000 JAN 04 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -at and -from/-to, two -from/-tos (3)',
  'success',
  $brief,
  "brief_sc_bc_pl_sat_dcov2.bsp -t -to 2000-01-05-02:00 -to 2000-01-03-02:00 -from 2000-01-05-01:00 -from 2000-01-03-01:00",
  11,
"Summary for: brief_sc_bc_pl_sat_dcov2.bsp",
"Bodies             Start of Interval (ET)          End of Interval (ET)",
"-------            -----------------------------   -----------------------------",
"4 MARS BARYCENTER  2000 JAN 01 12:00:00.000        2000 JAN 03 12:00:00.000",
"401 PHOBOS         2000 JAN 01 12:00:00.000        2000 JAN 05 12:00:00.000",
"499 MARS           2000 JAN 01 12:00:00.000        2000 JAN 04 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -at and -from/-to, sigleton -from/to',
  'success',
  $brief,
  "brief_sc_bc_pl_sat_dcov2.bsp -t -from 2000-01-05-02:00 -to 2000-01-05-02:00",
  9,
"Summary for: brief_sc_bc_pl_sat_dcov2.bsp",
"Bodies      Start of Interval (ET)          End of Interval (ET)",
"-------     -----------------------------   -----------------------------",
"401 PHOBOS  2000 JAN 01 12:00:00.000        2000 JAN 05 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -at and -from/-to, -to before -from',
  'success',
  $brief,
  "brief_sc_bc_pl_sat_dcov2.bsp -t -from 2000-01-05-03:00 -to 2000-01-05-02:00",
  9,
"Summary for: brief_sc_bc_pl_sat_dcov2.bsp",
"Bodies      Start of Interval (ET)          End of Interval (ET)",
"-------     -----------------------------   -----------------------------",
"401 PHOBOS  2000 JAN 01 12:00:00.000        2000 JAN 05 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -at and -from/-to, exact -from/-to',
  'success',
  $brief,
  "brief_sc_bc_pl_sat_dcov2.bsp -t -from 2000-01-01-12:00 -to 2000-01-05-12:00",
  9,
"Summary for: brief_sc_bc_pl_sat_dcov2.bsp",
"Bodies      Start of Interval (ET)          End of Interval (ET)",
"-------     -----------------------------   -----------------------------",
"401 PHOBOS  2000 JAN 01 12:00:00.000        2000 JAN 05 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -at and -from/-to, no data for -at',
  'success',
  $brief,
  "brief_sc_bc_pl_sat_dcov2.bsp -at 2001-01-01-12:00",
  9,
"Summary for: brief_sc_bc_pl_sat_dcov2.bsp",
"There is no data:",
"  covering ET '2001 JAN 01 12:00:00.000'"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -at and -from/-to, no data for -from',
  'success',
  $brief,
  "brief_sc_bc_pl_sat_dcov2.bsp -from 2001-01-01-12:00",
  9,
"Summary for: brief_sc_bc_pl_sat_dcov2.bsp",
"There is no data:",
"  covering from ET '2001 JAN 01 12:00:00.000' to ET '2001 JAN 01 12:00:00.000'"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -at and -from/-to, no data for -to',
  'success',
  $brief,
  "brief_sc_bc_pl_sat_dcov2.bsp -to 2001-01-01-13:00",
  9,
"Summary for: brief_sc_bc_pl_sat_dcov2.bsp",
"There is no data:",
"  covering from ET '2001 JAN 01 13:00:00.000' to ET '2001 JAN 01 13:00:00.000'"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -at and -from/-to, no data for -from and -to',
  'success',
  $brief,
  "brief_sc_bc_pl_sat_dcov2.bsp -from 2001-01-01-12:00 -to 2001-01-01-13:00",
  9,
"Summary for: brief_sc_bc_pl_sat_dcov2.bsp",
"There is no data:",
"  covering from ET '2001 JAN 01 12:00:00.000' to ET '2001 JAN 01 13:00:00.000'"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -at and -from/-to, no data for -at, -a',
  'success',
  $brief,
  "brief_sc_bc_pl_sat_dcov2.bsp -at 2001-01-01-12:00 -a",
  9,
"Summary for all files.",
"There is no data:",
"  covering ET '2001 JAN 01 12:00:00.000'"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -at and -from/-to, no data for -from, -a',
  'success',
  $brief,
  "brief_sc_bc_pl_sat_dcov2.bsp -from 2001-01-01-12:00 -a",
  9,
"Summary for all files.",
"There is no data:",
"  covering from ET '2001 JAN 01 12:00:00.000' to ET '2001 JAN 01 12:00:00.000'"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -at and -from/-to, no data for -to, -a',
  'success',
  $brief,
  "brief_sc_bc_pl_sat_dcov2.bsp -to 2001-01-01-13:00 -a",
  9,
"Summary for all files.",
"There is no data:",
"  covering from ET '2001 JAN 01 13:00:00.000' to ET '2001 JAN 01 13:00:00.000'"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -at and -from/-to, no data for -from and -to, -a',
  'success',
  $brief,
  "brief_sc_bc_pl_sat_dcov2.bsp -from 2001-01-01-12:00 -to 2001-01-01-13:00 -a",
  9,
"Summary for all files.",
"There is no data:",
"  covering from ET '2001 JAN 01 12:00:00.000' to ET '2001 JAN 01 13:00:00.000'"
);

#
# Test complex filters (time and body/center)
#
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: time and body/center, -at and -sb',
  'success',
  $brief,
  "brief_sc_bc_pl_sat_dcov2.bsp -t -at 2000-01-03-03:00 ".$qt."-sb[400:500]".$qt."",
  10,
"Summary for: brief_sc_bc_pl_sat_dcov2.bsp",
"Bodies      Start of Interval (ET)          End of Interval (ET)",
"-------     -----------------------------   -----------------------------",
"401 PHOBOS  2000 JAN 01 12:00:00.000        2000 JAN 05 12:00:00.000",
"499 MARS    2000 JAN 01 12:00:00.000        2000 JAN 04 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: time and body/center, -from/-to and -sb',
  'success',
  $brief,
  "brief_sc_bc_pl_sat_dcov2.bsp -t -from 2000-01-03-02:00 -to 2000-01-03-03:00 ".$qt."-sb[400:500]".$qt."",
  10,
"Summary for: brief_sc_bc_pl_sat_dcov2.bsp",
"Bodies      Start of Interval (ET)          End of Interval (ET)",
"-------     -----------------------------   -----------------------------",
"401 PHOBOS  2000 JAN 01 12:00:00.000        2000 JAN 05 12:00:00.000",
"499 MARS    2000 JAN 01 12:00:00.000        2000 JAN 04 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: time and body/center, -at and -sc',
  'success',
  $brief,
  "brief_sc_bc_pl_sat_dcov2.bsp -t -at 2000-01-03-03:00 -sc4",
  10,
"Summary for: brief_sc_bc_pl_sat_dcov2.bsp",
"Bodies      Start of Interval (ET)          End of Interval (ET)",
"-------     -----------------------------   -----------------------------",
"401 PHOBOS  2000 JAN 01 12:00:00.000        2000 JAN 05 12:00:00.000",
"499 MARS    2000 JAN 01 12:00:00.000        2000 JAN 04 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: time and body/center, -from/-to and -sc',
  'success',
  $brief,
  "brief_sc_bc_pl_sat_dcov2.bsp -t -from 2000-01-03-02:00 -to 2000-01-03-03:00 -sc4 ",
  10,
"Summary for: brief_sc_bc_pl_sat_dcov2.bsp",
"Bodies      Start of Interval (ET)          End of Interval (ET)",
"-------     -----------------------------   -----------------------------",
"401 PHOBOS  2000 JAN 01 12:00:00.000        2000 JAN 05 12:00:00.000",
"499 MARS    2000 JAN 01 12:00:00.000        2000 JAN 04 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: time and body/center, -at, -sb and -sc',
  'success',
  $brief,
  "brief_sc_bc_pl_sat_dcov2.bsp -t -at 2000-01-03-03:00 -sc4 -sb-254",
  13,
"Summary for: brief_sc_bc_pl_sat_dcov2.bsp",
"There is no data:",
"  for body '-254' covering ET '2000 JAN 03 03:00:00.000'",
"Bodies      Start of Interval (ET)          End of Interval (ET)",
"-------     -----------------------------   -----------------------------",
"401 PHOBOS  2000 JAN 01 12:00:00.000        2000 JAN 05 12:00:00.000",
"499 MARS    2000 JAN 01 12:00:00.000        2000 JAN 04 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: time and body/center, -from/-to, -sb and -sc',
  'success',
  $brief,
  "brief_sc_bc_pl_sat_dcov2.bsp -t -from 2000-01-03-02:00 -to 2000-01-03-03:00 -sc4 -sb-254",
  13,
"Summary for: brief_sc_bc_pl_sat_dcov2.bsp",
"There is no data:",
"  for body '-254' covering from ET '2000 JAN 03 02:00:00.000' to ET '2000 JAN 03 03:00:00.000'",
"Bodies      Start of Interval (ET)          End of Interval (ET)",
"-------     -----------------------------   -----------------------------",
"401 PHOBOS  2000 JAN 01 12:00:00.000        2000 JAN 05 12:00:00.000",
"499 MARS    2000 JAN 01 12:00:00.000        2000 JAN 04 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: time and body/center, -at, -sb and -sc, -a',
  'success',
  $brief,
  "brief_sc_bc_pl_sat_dcov2.bsp -t -at 2000-01-03-03:00 -sc4 -sb-254 -a",
  13,
"Summary for all files.",
"There is no data:",
"  for body '-254' covering ET '2000 JAN 03 03:00:00.000'",
"Bodies      Start of Interval (ET)          End of Interval (ET)",
"-------     -----------------------------   -----------------------------",
"401 PHOBOS  2000 JAN 01 12:00:00.000        2000 JAN 05 12:00:00.000",
"499 MARS    2000 JAN 01 12:00:00.000        2000 JAN 04 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: time and body/center, -from/-to, -sb and -sc, -a',
  'success',
  $brief,
  "brief_sc_bc_pl_sat_dcov2.bsp -t -from 2000-01-03-02:00 -to 2000-01-03-03:00 -sc4 -sb-254 -a",
  13,
"Summary for all files.",
"There is no data:",
"  for body '-254' covering from ET '2000 JAN 03 02:00:00.000' to ET '2000 JAN 03 03:00:00.000'",
"Bodies      Start of Interval (ET)          End of Interval (ET)",
"-------     -----------------------------   -----------------------------",
"401 PHOBOS  2000 JAN 01 12:00:00.000        2000 JAN 05 12:00:00.000",
"499 MARS    2000 JAN 01 12:00:00.000        2000 JAN 04 12:00:00.000"
);

#
# Filtering on -a display
#
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -a display, using -sb',
  'success',
  $brief,
  "brief_sc_bc_pl_sat_dcov2.bsp brief_sc_3seg_gaps.bsp -a -t -sb401",
  9,
"Summary for all files.",
"Bodies      Start of Interval (ET)          End of Interval (ET)",
"-------     -----------------------------   -----------------------------",
"401 PHOBOS  2000 JAN 01 12:00:00.000        2000 JAN 05 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -a display, using -sc',
  'success',
  $brief,
  "brief_sc_bc_pl_sat_dcov2.bsp brief_sc_3seg_gaps.bsp -a -t -sc499",
  9,
"Summary for all files.",
"Bodies      Start of Interval (ET)          End of Interval (ET)",
"-------     -----------------------------   -----------------------------",
"-254 MER-2  2000 JAN 01 12:00:00.000        2000 JAN 02 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -a display, using -at',
  'success',
  $brief,
  "brief_sc_bc_pl_sat_dcov2.bsp brief_sc_3seg_gaps.bsp -a -t -at 2000-JAN-04-05:00",
  10,
"Summary for all files.",
"Bodies      Start of Interval (ET)          End of Interval (ET)",
"-------     -----------------------------   -----------------------------",
"401 PHOBOS  2000 JAN 01 12:00:00.000        2000 JAN 05 12:00:00.000",
"499 MARS    2000 JAN 01 12:00:00.000        2000 JAN 04 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -a display, using -from/-to',
  'success',
  $brief,
  "brief_sc_bc_pl_sat_dcov2.bsp brief_sc_3seg_gaps.bsp -a -t -from 2000-JAN-04-05:00 -to 2000-JAN-04-05:01",
  10,
"Summary for all files.",
"Bodies      Start of Interval (ET)          End of Interval (ET)",
"-------     -----------------------------   -----------------------------",
"401 PHOBOS  2000 JAN 01 12:00:00.000        2000 JAN 05 12:00:00.000",
"499 MARS    2000 JAN 01 12:00:00.000        2000 JAN 04 12:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering SPK: -a display, using -sc, -sb, and -at',
  'success',
  $brief,
  "brief_sc_bc_pl_sat_dcov2.bsp brief_sc_3seg_gaps.bsp -a -t -sc0 -sb-29 -at 2000-JAN-04-05:10",
  11,
"Summary for all files.",
"Bodies    Start of Interval (ET)          End of Interval (ET)",
"-------   -----------------------------   -----------------------------",
"-29 NEXT  2000 JAN 04 05:05:05.049        2000 JAN 06 05:05:05.049",
"          2000 JAN 06 07:07:07.070        2000 JAN 07 06:06:06.060",
"          2000 JAN 07 08:08:08.080        2000 JAN 08 07:07:07.069"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Pushing limits: 100 restrictions using -',
  'success',
  $brief,
  'brief_sc_1seg.bsp -1 -2 -3 -4 -5 -6 -7 -8 -9 -10 -11 -12 -13 -14 -15 -16 -17 -18 -19 -20 -21 -22 -23 -24 -25 -26 -27 -28 -29 -30 -31 -32 -33 -34 -35 -36 -37 -38 -39 -40 -41 -42 -43 -44 -45 -46 -47 -48 -49 -50 -51 -52 -53 -54 -55 -56 -57 -58 -59 -60 -61 -62 -63 -64 -65 -66 -67 -68 -69 -70 -71 -72 -73 -74 -75 -76 -77 -78 -79 -80 -81 -82 -83 -84 -85 -86 -87 -88 -89 -90 -91 -92 -93 -94 -95 -96 -97 -98 -99 -100',
  108,
"There is no data:",
"  for body '1'",
"  for body '100'"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Pushing limits: 100 restrictions using -sc',
  'success',
  $brief,
  'brief_sc_1seg.bsp -sc1 -sc2 -sc3 -sc4 -sc5 -sc6 -sc7 -sc8 -sc9 -sc10 -sc11 -sc12 -sc13 -sc14 -sc15 -sc16 -sc17 -sc18 -sc19 -sc20 -sc21 -sc22 -sc23 -sc24 -sc25 -sc26 -sc27 -sc28 -sc29 -sc30 -sc31 -sc32 -sc33 -sc34 -sc35 -sc36 -sc37 -sc38 -sc39 -sc40 -sc41 -sc42 -sc43 -sc44 -sc45 -sc46 -sc47 -sc48 -sc49 -sc50 -sc51 -sc52 -sc53 -sc54 -sc55 -sc56 -sc57 -sc58 -sc59 -sc60 -sc61 -sc62 -sc63 -sc64 -sc65 -sc66 -sc67 -sc68 -sc69 -sc70 -sc71 -sc72 -sc73 -sc74 -sc75 -sc76 -sc77 -sc78 -sc79 -sc80 -sc81 -sc82 -sc83 -sc84 -sc85 -sc86 -sc87 -sc88 -sc89 -sc90 -sc91 -sc92 -sc93 -sc94 -sc95 -sc96 -sc97 -sc98 -sc99 -sc100',
  108,
"There is no data:",
"  w.r.t. center '1'",
"  w.r.t. center '100'"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Pushing limits: 100 restrictions using -sb',
  'success',
  $brief,
  'brief_sc_1seg.bsp -sb1 -sb2 -sb3 -sb4 -sb5 -sb6 -sb7 -sb8 -sb9 -sb10 -sb11 -sb12 -sb13 -sb14 -sb15 -sb16 -sb17 -sb18 -sb19 -sb20 -sb21 -sb22 -sb23 -sb24 -sb25 -sb26 -sb27 -sb28 -sb29 -sb30 -sb31 -sb32 -sb33 -sb34 -sb35 -sb36 -sb37 -sb38 -sb39 -sb40 -sb41 -sb42 -sb43 -sb44 -sb45 -sb46 -sb47 -sb48 -sb49 -sb50 -sb51 -sb52 -sb53 -sb54 -sb55 -sb56 -sb57 -sb58 -sb59 -sb60 -sb61 -sb62 -sb63 -sb64 -sb65 -sb66 -sb67 -sb68 -sb69 -sb70 -sb71 -sb72 -sb73 -sb74 -sb75 -sb76 -sb77 -sb78 -sb79 -sb80 -sb81 -sb82 -sb83 -sb84 -sb85 -sb86 -sb87 -sb88 -sb89 -sb90 -sb91 -sb92 -sb93 -sb94 -sb95 -sb96 -sb97 -sb98 -sb99 -sb100',
  108,
"There is no data:",
"  for body '1'",
"  for body '100'"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Pushing limits: 100 restrictions using -/-sc/-sb',
  'success',
  $brief,
  'brief_sc_1seg.bsp -1 -sc2 -sb3 -sb4 -sb5 -sb6 -sb7 -sb8 -sb9 -sb10 -sb11 -sb12 -sb13 -sb14 -sb15 -sb16 -sb17 -sb18 -sb19 -sb20 -sb21 -sb22 -sb23 -sb24 -sb25 -sb26 -sb27 -sb28 -sb29 -sb30 -sb31 -sb32 -sb33 -sb34 -sb35 -sb36 -sb37 -sb38 -sb39 -sb40 -sb41 -sb42 -sb43 -sb44 -sb45 -sb46 -sb47 -sb48 -sb49 -sb50 -sb51 -sb52 -sb53 -sb54 -sb55 -sb56 -sb57 -sb58 -sb59 -sb60 -sb61 -sb62 -sb63 -sb64 -sb65 -sb66 -sb67 -sb68 -sb69 -sb70 -sb71 -sb72 -sb73 -sb74 -sb75 -sb76 -sb77 -sb78 -sb79 -sb80 -sb81 -sb82 -sb83 -sb84 -sb85 -sb86 -sb87 -sb88 -sb89 -sb90 -sb91 -sb92 -sb93 -sb94 -sb95 -sb96 -sb97 -sb98 -sb99 -sb100',
  108,
"There is no data:",
"  for body '1'",
"  w.r.t. center '2'",
"  for body '100'"
);

#
# Test summarizing binary PCKs.
#
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Summarizing binary PCK, alone, -t -c',
  'success',
  $brief,
  "brief_pck.bpc -t -c",
  9,
"Summary for: brief_pck.bpc",
"Frames                     Start of Interval (ET)          End of Interval (ET)",
"-------                    -----------------------------   -----------------------------",
"2999 w.r.t. 17 ECLIPJ2000  2007 OCT 28 00:01:05.182        2007 OCT 28 00:02:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Summarizing binary PCK, two files as one, -a -t -c',
  'success',
  $brief,
  "brief_pck.bpc brief_pck_2.bpc brief_test.tf -a -t -c",
  13,
"Summary for all files.",
"Frames                              Start of Interval (ET)          End of Interval (ET)",
"-------                             -----------------------------   -----------------------------",
"2999 ITRF99 w.r.t. 17 ECLIPJ2000    2007 OCT 28 00:01:05.182        2007 OCT 28 00:02:05.182",
"3000 ITRF93 w.r.t. 1 J2000          2007 OCT 28 00:04:05.182        2007 OCT 28 00:06:05.182",
"3000 ITRF93 w.r.t. 17 ECLIPJ2000    2007 OCT 28 00:01:05.182        2007 OCT 28 00:02:05.182",
"31002 MOON_PA_DE403 w.r.t. 1 J2000  2007 OCT 28 00:01:05.182        2007 OCT 28 00:03:05.182",
"31004 MOON_PA_DE418 w.r.t. 1 J2000  2007 OCT 28 00:01:05.182        2007 OCT 28 00:05:05.182"
);

#
# Tests comprehensively covering all displays formats for PCKs.
#
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting PCK: -t',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -t',
  12,
"Summary for: brief_pck_2.bpc",
"Frames               Start of Interval (ET)          End of Interval (ET)",
"-------              -----------------------------   -----------------------------",
"3000 ITRF93          2007 OCT 28 00:01:05.182        2007 OCT 28 00:02:05.182",
"                     2007 OCT 28 00:04:05.182        2007 OCT 28 00:06:05.182",
"31002 MOON_PA_DE403  2007 OCT 28 00:01:05.182        2007 OCT 28 00:03:05.182",
"31004 MOON_PA_DE418  2007 OCT 28 00:01:05.182        2007 OCT 28 00:05:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting PCK: -t -n',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -t -n',
  12,
"Summary for: brief_pck_2.bpc",
"Frames Start of Interval (ET)          End of Interval (ET)",
"------------------------------------   -----------------------------",
"3000   2007 OCT 28 00:01:05.182        2007 OCT 28 00:02:05.182",
"       2007 OCT 28 00:04:05.182        2007 OCT 28 00:06:05.182",
"31002  2007 OCT 28 00:01:05.182        2007 OCT 28 00:03:05.182",
"31004  2007 OCT 28 00:01:05.182        2007 OCT 28 00:05:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting PCK: -t -n -c',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -t -n -c',
  12,
"Summary for: brief_pck_2.bpc",
"Frames          Start of Interval (ET)          End of Interval (ET)",
"-------         -----------------------------   -----------------------------",
"3000 w.r.t. 1   2007 OCT 28 00:04:05.182        2007 OCT 28 00:06:05.182",
"3000 w.r.t. 17  2007 OCT 28 00:01:05.182        2007 OCT 28 00:02:05.182",
"31002 w.r.t. 1  2007 OCT 28 00:01:05.182        2007 OCT 28 00:03:05.182",
"31004 w.r.t. 1  2007 OCT 28 00:01:05.182        2007 OCT 28 00:05:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting PCK: -t -n -c -o',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -t -n -c -o',
  12,
"Summary for: brief_pck_2.bpc",
"Frames          Start of Interval (ET)          End of Interval (ET)",
"-------         -----------------------------   -----------------------------",
"3000 w.r.t. 1   2007 OCT 28 00:04:05.182        2007 OCT 28 00:06:05.182",
"3000 w.r.t. 17  2007 OCT 28 00:01:05.182        2007 OCT 28 00:02:05.182",
"31002 w.r.t. 1  2007 OCT 28 00:01:05.182        2007 OCT 28 00:03:05.182",
"31004 w.r.t. 1  2007 OCT 28 00:01:05.182        2007 OCT 28 00:05:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting PCK: -t -n -o',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -t -n -o',
  12,
"Summary for: brief_pck_2.bpc",
"Frames Start of Interval (ET)          End of Interval (ET)",
"------------------------------------   -----------------------------",
"3000   2007 OCT 28 00:01:05.182        2007 OCT 28 00:02:05.182",
"       2007 OCT 28 00:04:05.182        2007 OCT 28 00:06:05.182",
"31002  2007 OCT 28 00:01:05.182        2007 OCT 28 00:03:05.182",
"31004  2007 OCT 28 00:01:05.182        2007 OCT 28 00:05:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting PCK: -t -c',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -t -c',
  12,
"Summary for: brief_pck_2.bpc",
"Frames                              Start of Interval (ET)          End of Interval (ET)",
"-------                             -----------------------------   -----------------------------",
"3000 ITRF93 w.r.t. 1 J2000          2007 OCT 28 00:04:05.182        2007 OCT 28 00:06:05.182",
"3000 ITRF93 w.r.t. 17 ECLIPJ2000    2007 OCT 28 00:01:05.182        2007 OCT 28 00:02:05.182",
"31002 MOON_PA_DE403 w.r.t. 1 J2000  2007 OCT 28 00:01:05.182        2007 OCT 28 00:03:05.182",
"31004 MOON_PA_DE418 w.r.t. 1 J2000  2007 OCT 28 00:01:05.182        2007 OCT 28 00:05:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting PCK: -t -c -o',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -t -c -o',
  12,
"Summary for: brief_pck_2.bpc",
"Frames                                  Start of Interval (ET)          End of Interval (ET)",
"-------                                 -----------------------------   -----------------------------",
"ITRF93 (3000) w.r.t. ECLIPJ2000 (17)    2007 OCT 28 00:01:05.182        2007 OCT 28 00:02:05.182",
"ITRF93 (3000) w.r.t. J2000 (1)          2007 OCT 28 00:04:05.182        2007 OCT 28 00:06:05.182",
"MOON_PA_DE403 (31002) w.r.t. J2000 (1)  2007 OCT 28 00:01:05.182        2007 OCT 28 00:03:05.182",
"MOON_PA_DE418 (31004) w.r.t. J2000 (1)  2007 OCT 28 00:01:05.182        2007 OCT 28 00:05:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting PCK: -t -o',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -t -o',
  12,
"Summary for: brief_pck_2.bpc",
"Frames                 Start of Interval (ET)          End of Interval (ET)",
"-------                -----------------------------   -----------------------------",
"ITRF93 (3000)          2007 OCT 28 00:01:05.182        2007 OCT 28 00:02:05.182",
"                       2007 OCT 28 00:04:05.182        2007 OCT 28 00:06:05.182",
"MOON_PA_DE403 (31002)  2007 OCT 28 00:01:05.182        2007 OCT 28 00:03:05.182",
"MOON_PA_DE418 (31004)  2007 OCT 28 00:01:05.182        2007 OCT 28 00:05:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting PCK: -n',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -n',
  22,
"Summary for: brief_pck_2.bpc",
"Frame: 3000",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:02:05.182",
"       2007 OCT 28 00:04:05.182            2007 OCT 28 00:06:05.182",
"Frame: 31002",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:03:05.182",
"Frame: 31004",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:05:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting PCK: -n -c',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -n -c',
  26,
"Summary for: brief_pck_2.bpc",
"Frame: 3000 w.r.t. 1",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:04:05.182            2007 OCT 28 00:06:05.182",
"Frame: 3000 w.r.t. 17",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:02:05.182",
"Frame: 31002 w.r.t. 1",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:03:05.182",
"Frame: 31004 w.r.t. 1",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:05:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting PCK: -n -c -o',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -n -c -o',
  26,
"Summary for: brief_pck_2.bpc",
"Frame: 3000 w.r.t. 1",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:04:05.182            2007 OCT 28 00:06:05.182",
"Frame: 3000 w.r.t. 17",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:02:05.182",
"Frame: 31002 w.r.t. 1",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:03:05.182",
"Frame: 31004 w.r.t. 1",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:05:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting PCK: -n -o',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -n -o',
  22,
"Summary for: brief_pck_2.bpc",
"Frame: 3000",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:02:05.182",
"       2007 OCT 28 00:04:05.182            2007 OCT 28 00:06:05.182",
"Frame: 31002",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:03:05.182",
"Frame: 31004",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:05:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting PCK: -c',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -c',
  26,
"Summary for: brief_pck_2.bpc",
"Frame: ITRF93 (3000) w.r.t. J2000 (1)",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:04:05.182            2007 OCT 28 00:06:05.182",
"Frame: ITRF93 (3000) w.r.t. ECLIPJ2000 (17)",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:02:05.182",
"Frame: MOON_PA_DE403 (31002) w.r.t. J2000 (1)",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:03:05.182",
"Frame: MOON_PA_DE418 (31004) w.r.t. J2000 (1)",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:05:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting PCK: -c -o',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -c -o',
  26,
"Summary for: brief_pck_2.bpc",
"Frame: ITRF93 (3000) w.r.t. ECLIPJ2000 (17)",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:02:05.182",
"Frame: ITRF93 (3000) w.r.t. J2000 (1)",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:04:05.182            2007 OCT 28 00:06:05.182",
"Frame: MOON_PA_DE403 (31002) w.r.t. J2000 (1)",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:03:05.182",
"Frame: MOON_PA_DE418 (31004) w.r.t. J2000 (1)",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:05:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting PCK: -o',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -o',
  22,
"Summary for: brief_pck_2.bpc",
"Frame: ITRF93 (3000)",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:02:05.182",
"       2007 OCT 28 00:04:05.182            2007 OCT 28 00:06:05.182",
"Frame: MOON_PA_DE403 (31002)",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:03:05.182",
"Frame: MOON_PA_DE418 (31004)",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:05:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting PCK: <NONE>',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf',
  22,
"Summary for: brief_pck_2.bpc",
"Frame: ITRF93 (3000)",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:02:05.182",
"       2007 OCT 28 00:04:05.182            2007 OCT 28 00:06:05.182",
"Frame: MOON_PA_DE403 (31002)",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:03:05.182",
"Frame: MOON_PA_DE418 (31004)",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:05:05.182"
);

#
# Tests comprehensively covering all displays formats with grouping for PCKs.
#
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting PCK: -g -t',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -g -t',
  12,
"Summary for: brief_pck_2.bpc",
"Frames               Start of Interval (ET)          End of Interval (ET)",
"-------              -----------------------------   -----------------------------",
"3000 ITRF93          2007 OCT 28 00:01:05.182        2007 OCT 28 00:02:05.182",
"                     2007 OCT 28 00:04:05.182        2007 OCT 28 00:06:05.182",
"31002 MOON_PA_DE403  2007 OCT 28 00:01:05.182        2007 OCT 28 00:03:05.182",
"31004 MOON_PA_DE418  2007 OCT 28 00:01:05.182        2007 OCT 28 00:05:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting PCK: -g -t -n',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -g -t -n',
  12,
"Summary for: brief_pck_2.bpc",
"Frames Start of Interval (ET)          End of Interval (ET)",
"------------------------------------   -----------------------------",
"3000   2007 OCT 28 00:01:05.182        2007 OCT 28 00:02:05.182",
"       2007 OCT 28 00:04:05.182        2007 OCT 28 00:06:05.182",
"31002  2007 OCT 28 00:01:05.182        2007 OCT 28 00:03:05.182",
"31004  2007 OCT 28 00:01:05.182        2007 OCT 28 00:05:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting PCK: -g -t -n -c',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -g -t -n -c',
  12,
"Summary for: brief_pck_2.bpc",
"Frames          Start of Interval (ET)          End of Interval (ET)",
"-------         -----------------------------   -----------------------------",
"3000 w.r.t. 1   2007 OCT 28 00:04:05.182        2007 OCT 28 00:06:05.182",
"3000 w.r.t. 17  2007 OCT 28 00:01:05.182        2007 OCT 28 00:02:05.182",
"31002 w.r.t. 1  2007 OCT 28 00:01:05.182        2007 OCT 28 00:03:05.182",
"31004 w.r.t. 1  2007 OCT 28 00:01:05.182        2007 OCT 28 00:05:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting PCK: -g -t -n -c -o',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -g -t -n -c -o',
  12,
"Summary for: brief_pck_2.bpc",
"Frames          Start of Interval (ET)          End of Interval (ET)",
"-------         -----------------------------   -----------------------------",
"3000 w.r.t. 1   2007 OCT 28 00:04:05.182        2007 OCT 28 00:06:05.182",
"3000 w.r.t. 17  2007 OCT 28 00:01:05.182        2007 OCT 28 00:02:05.182",
"31002 w.r.t. 1  2007 OCT 28 00:01:05.182        2007 OCT 28 00:03:05.182",
"31004 w.r.t. 1  2007 OCT 28 00:01:05.182        2007 OCT 28 00:05:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting PCK: -g -t -n -o',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -g -t -n -o',
  12,
"Summary for: brief_pck_2.bpc",
"Frames Start of Interval (ET)          End of Interval (ET)",
"------------------------------------   -----------------------------",
"3000   2007 OCT 28 00:01:05.182        2007 OCT 28 00:02:05.182",
"       2007 OCT 28 00:04:05.182        2007 OCT 28 00:06:05.182",
"31002  2007 OCT 28 00:01:05.182        2007 OCT 28 00:03:05.182",
"31004  2007 OCT 28 00:01:05.182        2007 OCT 28 00:05:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting PCK: -g -t -c',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -g -t -c',
  12,
"Summary for: brief_pck_2.bpc",
"Frames                              Start of Interval (ET)          End of Interval (ET)",
"-------                             -----------------------------   -----------------------------",
"3000 ITRF93 w.r.t. 1 J2000          2007 OCT 28 00:04:05.182        2007 OCT 28 00:06:05.182",
"3000 ITRF93 w.r.t. 17 ECLIPJ2000    2007 OCT 28 00:01:05.182        2007 OCT 28 00:02:05.182",
"31002 MOON_PA_DE403 w.r.t. 1 J2000  2007 OCT 28 00:01:05.182        2007 OCT 28 00:03:05.182",
"31004 MOON_PA_DE418 w.r.t. 1 J2000  2007 OCT 28 00:01:05.182        2007 OCT 28 00:05:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting PCK: -g -t -c -o',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -g -t -c -o',
  12,
"Summary for: brief_pck_2.bpc",
"Frames                                  Start of Interval (ET)          End of Interval (ET)",
"-------                                 -----------------------------   -----------------------------",
"ITRF93 (3000) w.r.t. ECLIPJ2000 (17)    2007 OCT 28 00:01:05.182        2007 OCT 28 00:02:05.182",
"ITRF93 (3000) w.r.t. J2000 (1)          2007 OCT 28 00:04:05.182        2007 OCT 28 00:06:05.182",
"MOON_PA_DE403 (31002) w.r.t. J2000 (1)  2007 OCT 28 00:01:05.182        2007 OCT 28 00:03:05.182",
"MOON_PA_DE418 (31004) w.r.t. J2000 (1)  2007 OCT 28 00:01:05.182        2007 OCT 28 00:05:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting PCK: -g -t -o',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -g -t -o',
  12,
"Summary for: brief_pck_2.bpc",
"Frames                 Start of Interval (ET)          End of Interval (ET)",
"-------                -----------------------------   -----------------------------",
"ITRF93 (3000)          2007 OCT 28 00:01:05.182        2007 OCT 28 00:02:05.182",
"                       2007 OCT 28 00:04:05.182        2007 OCT 28 00:06:05.182",
"MOON_PA_DE403 (31002)  2007 OCT 28 00:01:05.182        2007 OCT 28 00:03:05.182",
"MOON_PA_DE418 (31004)  2007 OCT 28 00:01:05.182        2007 OCT 28 00:05:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting PCK: -g -n',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -g -n',
  22,
"Summary for: brief_pck_2.bpc",
"Frame: 3000",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:02:05.182",
"       2007 OCT 28 00:04:05.182            2007 OCT 28 00:06:05.182",
"Frame: 31002",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:03:05.182",
"Frame: 31004",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:05:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting PCK: -g -n -c',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -g -n -c',
  26,
"Summary for: brief_pck_2.bpc",
"Frame: 3000 w.r.t. 1",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:04:05.182            2007 OCT 28 00:06:05.182",
"Frame: 3000 w.r.t. 17",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:02:05.182",
"Frame: 31002 w.r.t. 1",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:03:05.182",
"Frame: 31004 w.r.t. 1",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:05:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting PCK: -g -n -c -o',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -g -n -c -o',
  26,
"Summary for: brief_pck_2.bpc",
"Frame: 3000 w.r.t. 1",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:04:05.182            2007 OCT 28 00:06:05.182",
"Frame: 3000 w.r.t. 17",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:02:05.182",
"Frame: 31002 w.r.t. 1",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:03:05.182",
"Frame: 31004 w.r.t. 1",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:05:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting PCK: -g -n -o',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -g -n -o',
  22,
"Summary for: brief_pck_2.bpc",
"Frame: 3000",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:02:05.182",
"       2007 OCT 28 00:04:05.182            2007 OCT 28 00:06:05.182",
"Frame: 31002",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:03:05.182",
"Frame: 31004",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:05:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting PCK: -g -c',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -g -c',
  26,
"Summary for: brief_pck_2.bpc",
"Frame: ITRF93 (3000) w.r.t. J2000 (1)",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:04:05.182            2007 OCT 28 00:06:05.182",
"Frame: ITRF93 (3000) w.r.t. ECLIPJ2000 (17)",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:02:05.182",
"Frame: MOON_PA_DE403 (31002) w.r.t. J2000 (1)",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:03:05.182",
"Frame: MOON_PA_DE418 (31004) w.r.t. J2000 (1)",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:05:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting PCK: -g -c -o',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -g -c -o',
  26,
"Summary for: brief_pck_2.bpc",
"Frame: ITRF93 (3000) w.r.t. ECLIPJ2000 (17)",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:02:05.182",
"Frame: ITRF93 (3000) w.r.t. J2000 (1)",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:04:05.182            2007 OCT 28 00:06:05.182",
"Frame: MOON_PA_DE403 (31002) w.r.t. J2000 (1)",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:03:05.182",
"Frame: MOON_PA_DE418 (31004) w.r.t. J2000 (1)",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:05:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting PCK: -g -o',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -g -o',
  22,
"Summary for: brief_pck_2.bpc",
"Frame: ITRF93 (3000)",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:02:05.182",
"       2007 OCT 28 00:04:05.182            2007 OCT 28 00:06:05.182",
"Frame: MOON_PA_DE403 (31002)",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:03:05.182",
"Frame: MOON_PA_DE418 (31004)",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:05:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Formatting/sorting PCK: -g <NONE>',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -g',
  22,
"Summary for: brief_pck_2.bpc",
"Frame: ITRF93 (3000)",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:02:05.182",
"       2007 OCT 28 00:04:05.182            2007 OCT 28 00:06:05.182",
"Frame: MOON_PA_DE403 (31002)",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:03:05.182",
"Frame: MOON_PA_DE418 (31004)",
"       Start of Interval (ET)              End of Interval (ET)",
"       -----------------------------       -----------------------------",
"       2007 OCT 28 00:01:05.182            2007 OCT 28 00:05:05.182"
);

#
# Tests of PCK filtering.
#
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering PCK: -, one frame, using ID',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -t -c -3000',
  10,
"Summary for: brief_pck_2.bpc",
"Frames                            Start of Interval (ET)          End of Interval (ET)",
"-------                           -----------------------------   -----------------------------",
"3000 ITRF93 w.r.t. 1 J2000        2007 OCT 28 00:04:05.182        2007 OCT 28 00:06:05.182",
"3000 ITRF93 w.r.t. 17 ECLIPJ2000  2007 OCT 28 00:01:05.182        2007 OCT 28 00:02:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering PCK: -sb, one frame, using ID',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -t -c -sb3000',
  10,
"Summary for: brief_pck_2.bpc",
"Frames                            Start of Interval (ET)          End of Interval (ET)",
"-------                           -----------------------------   -----------------------------",
"3000 ITRF93 w.r.t. 1 J2000        2007 OCT 28 00:04:05.182        2007 OCT 28 00:06:05.182",
"3000 ITRF93 w.r.t. 17 ECLIPJ2000  2007 OCT 28 00:01:05.182        2007 OCT 28 00:02:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering PCK: -sc, one frame, using ID',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -t -c -sc17',
  9,
"Summary for: brief_pck_2.bpc",
"Frames                            Start of Interval (ET)          End of Interval (ET)",
"-------                           -----------------------------   -----------------------------",
"3000 ITRF93 w.r.t. 17 ECLIPJ2000  2007 OCT 28 00:01:05.182        2007 OCT 28 00:02:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering PCK: -, one frame, using name',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -t -c -ITRF93',
  10,
"Summary for: brief_pck_2.bpc",
"Frames                            Start of Interval (ET)          End of Interval (ET)",
"-------                           -----------------------------   -----------------------------",
"3000 ITRF93 w.r.t. 1 J2000        2007 OCT 28 00:04:05.182        2007 OCT 28 00:06:05.182",
"3000 ITRF93 w.r.t. 17 ECLIPJ2000  2007 OCT 28 00:01:05.182        2007 OCT 28 00:02:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering PCK: -sb, one frame, using name',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -t -c -sbITRF93',
  10,
"Summary for: brief_pck_2.bpc",
"Frames                            Start of Interval (ET)          End of Interval (ET)",
"-------                           -----------------------------   -----------------------------",
"3000 ITRF93 w.r.t. 1 J2000        2007 OCT 28 00:04:05.182        2007 OCT 28 00:06:05.182",
"3000 ITRF93 w.r.t. 17 ECLIPJ2000  2007 OCT 28 00:01:05.182        2007 OCT 28 00:02:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering PCK: -sc, one frame, using name',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -t -c -scECLIPJ2000',
  9,
"Summary for: brief_pck_2.bpc",
"Frames                            Start of Interval (ET)          End of Interval (ET)",
"-------                           -----------------------------   -----------------------------",
"3000 ITRF93 w.r.t. 17 ECLIPJ2000  2007 OCT 28 00:01:05.182        2007 OCT 28 00:02:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering PCK: -, using range',
  'success',
  $brief,
  "brief_pck_2.bpc brief_test.tf -t -c ".$qt."-[2000:4000]".$qt."",
  10,
"Summary for: brief_pck_2.bpc",
"Frames                            Start of Interval (ET)          End of Interval (ET)",
"-------                           -----------------------------   -----------------------------",
"3000 ITRF93 w.r.t. 1 J2000        2007 OCT 28 00:04:05.182        2007 OCT 28 00:06:05.182",
"3000 ITRF93 w.r.t. 17 ECLIPJ2000  2007 OCT 28 00:01:05.182        2007 OCT 28 00:02:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering PCK: -sb, using range',
  'success',
  $brief,
  "brief_pck_2.bpc brief_test.tf -t -c ".$qt."-sb[2000:4000]".$qt."",
  10,
"Summary for: brief_pck_2.bpc",
"Frames                            Start of Interval (ET)          End of Interval (ET)",
"-------                           -----------------------------   -----------------------------",
"3000 ITRF93 w.r.t. 1 J2000        2007 OCT 28 00:04:05.182        2007 OCT 28 00:06:05.182",
"3000 ITRF93 w.r.t. 17 ECLIPJ2000  2007 OCT 28 00:01:05.182        2007 OCT 28 00:02:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering PCK: -sc, using range',
  'success',
  $brief,
  "brief_pck_2.bpc brief_test.tf -t -c ".$qt."-sc[16:18]".$qt."",
  9,
"Summary for: brief_pck_2.bpc",
"Frames                            Start of Interval (ET)          End of Interval (ET)",
"-------                           -----------------------------   -----------------------------",
"3000 ITRF93 w.r.t. 17 ECLIPJ2000  2007 OCT 28 00:01:05.182        2007 OCT 28 00:02:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering PCK: -/ID and -sc/name',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -t -c -3000 -scECLIPJ2000',
  10,
"Summary for: brief_pck_2.bpc",
"Frames                            Start of Interval (ET)          End of Interval (ET)",
"-------                           -----------------------------   -----------------------------",
"3000 ITRF93 w.r.t. 1 J2000        2007 OCT 28 00:04:05.182        2007 OCT 28 00:06:05.182",
"3000 ITRF93 w.r.t. 17 ECLIPJ2000  2007 OCT 28 00:01:05.182        2007 OCT 28 00:02:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering PCK: -, unrecognized name',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -t -c -ITRF77',
  13,
"'-ITRF77' is not recognized.",
"Summary for: brief_pck_2.bpc",
"Frames                              Start of Interval (ET)          End of Interval (ET)",
"-------                             -----------------------------   -----------------------------",
"3000 ITRF93 w.r.t. 1 J2000          2007 OCT 28 00:04:05.182        2007 OCT 28 00:06:05.182",
"3000 ITRF93 w.r.t. 17 ECLIPJ2000    2007 OCT 28 00:01:05.182        2007 OCT 28 00:02:05.182",
"31002 MOON_PA_DE403 w.r.t. 1 J2000  2007 OCT 28 00:01:05.182        2007 OCT 28 00:03:05.182",
"31004 MOON_PA_DE418 w.r.t. 1 J2000  2007 OCT 28 00:01:05.182        2007 OCT 28 00:05:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering PCK: -, unrecognized ID',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -t -c --1',
  9,
"Summary for: brief_pck_2.bpc",
"There is no data:",
"  for frame '-1'"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering PCK: -, unrecognized ID, with -a',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -t -c --1 -a',
  9,
"Summary for all files.",
"There is no data:",
"  for frame '-1'"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering PCK: -, unrecognized ID range',
  'success',
  $brief,
  "brief_pck_2.bpc brief_test.tf -t -c ".$qt."-[-3:-1]".$qt."",
  9,
"Summary for: brief_pck_2.bpc",
"There is no data:",
"  for frames in '[-3:-1]' ID range"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering PCK: -, unrecognized ID range, with -a',
  'success',
  $brief,
  "brief_pck_2.bpc brief_test.tf -t -c ".$qt."-[-3:-1]".$qt." -a",
  9,
"Summary for all files.",
"There is no data:",
"  for frames in '[-3:-1]' ID range"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering PCK: -sc, unrecognized name',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -t -c -scJ2001',
  13,
"'-scJ2001' is not recognized.",
"Summary for: brief_pck_2.bpc",
"Frames                              Start of Interval (ET)          End of Interval (ET)",
"-------                             -----------------------------   -----------------------------",
"3000 ITRF93 w.r.t. 1 J2000          2007 OCT 28 00:04:05.182        2007 OCT 28 00:06:05.182",
"3000 ITRF93 w.r.t. 17 ECLIPJ2000    2007 OCT 28 00:01:05.182        2007 OCT 28 00:02:05.182",
"31002 MOON_PA_DE403 w.r.t. 1 J2000  2007 OCT 28 00:01:05.182        2007 OCT 28 00:03:05.182",
"31004 MOON_PA_DE418 w.r.t. 1 J2000  2007 OCT 28 00:01:05.182        2007 OCT 28 00:05:05.182"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering PCK: -sc, unrecognized ID',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -t -c -sc-1',
  9,
"Summary for: brief_pck_2.bpc",
"There is no data:",
"  w.r.t. frame '-1"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering PCK: -sc, unrecognized ID, with -a',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -t -c -sc-1 -a',
  9,
"Summary for all files.",
"There is no data:",
"  w.r.t. frame '-1'"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering PCK: -sc, unrecognized ID range',
  'success',
  $brief,
  "brief_pck_2.bpc brief_test.tf -t -c ".$qt."-sc[-3:-1]".$qt."",
  9,
"Summary for: brief_pck_2.bpc",
"There is no data:",
"  w.r.t. frames in '[-3:-1]' ID range"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering PCK: -sc, unrecognized ID range, with -a',
  'success',
  $brief,
  "brief_pck_2.bpc brief_test.tf -t -c ".$qt."-sc[-3:-1]".$qt." -a",
  9,
"Summary for all files.",
"There is no data:",
"  w.r.t. frames in '[-3:-1]' ID range"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Filtering PCK: - and -sc, unrecognized names',
  'success',
  $brief,
  'brief_pck_2.bpc brief_test.tf -t -c -ITRF77 -scJ2001',
  14,
"'-ITRF77' is not recognized.",
"'-scJ2001' is not recognized.",
"Summary for: brief_pck_2.bpc",
"Frames                              Start of Interval (ET)          End of Interval (ET)",
"-------                             -----------------------------   -----------------------------",
"3000 ITRF93 w.r.t. 1 J2000          2007 OCT 28 00:04:05.182        2007 OCT 28 00:06:05.182",
"3000 ITRF93 w.r.t. 17 ECLIPJ2000    2007 OCT 28 00:01:05.182        2007 OCT 28 00:02:05.182",
"31002 MOON_PA_DE403 w.r.t. 1 J2000  2007 OCT 28 00:01:05.182        2007 OCT 28 00:03:05.182",
"31004 MOON_PA_DE418 w.r.t. 1 J2000  2007 OCT 28 00:01:05.182        2007 OCT 28 00:05:05.182"
);

#
# Misc tests.
#
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Reporting - by itself',
  'success',
  $brief,
  'brief_pck_2.bpc -',
  23,
"'-' by itself is not a recognized option.",
"Summary for: brief_pck_2.bpc"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Reporting unrecognized option',
  'success',
  $brief,
  'brief_pck_2.bpc -x',
  23,
"'-x' is not recognized.",
"Summary for: brief_pck_2.bpc"
);

#
# Test usage and help displays.
#
@usage = (
"BRIEF -- Version 3.0.0, January 14, 2008 -- Toolkit Version N00",
"   BRIEF is a command-line utility program that displays a summary for",
"   one or more binary SPK or binary PCK files. The program usage is:",
"      % brief [-options] file [file ...]",
"   The most useful options are shown below. For the complete set of",
"   options, run BRIEF with the -h option. The order of options is not",
"   significant. The case of option keys is significant: they must be",
"   lowercase as shown below.",
"      -c           display centers of motion/relative-to frames",
"      -t           display summary in a tabular format",
"      -a           treat all files as a single file",
"      -utc         display times in UTC calendar date format (needs LSK)",
"      -utcdoy      display times in UTC day-of-year format (needs LSK)",
"      -etsec       display times as ET seconds past J2000",
"   An LSK file must be provided on the command line to display times in",
"   UTC formats. FK file(s) must be provided on the command line to",
"   display names of any frames that are not built into the Toolkit."
);

@help = (
"BRIEF -- Version 3.0.0, January 14, 2008 -- Toolkit Version N00",
"   BRIEF is a command-line utility program that displays a summary for",
"   one or more binary SPK or binary PCK files. The program usage is:",
"      % brief [-options] file [file ...]",
"   File names and options can be specified in any order. Text kernels",
"   needed for time conversions and/or body/frame ID-to-name conversions can",
"   be specified in addition to the SPK or PCK file(s) to be summarized.",
"   SPK files and PCK files cannot be summarized at the same time.",
"   Options are shown below. The order of options is not significant.",
"   The case of option keys is significant: they must be lowercase as",
"   shown below.",
"      -t           display summary in a tabular format",
"      -a           treat all files as a single file",
"      -c           display centers of motion/relative-to frames",
"      -utc         display times in UTC calendar date format (needs LSK)",
"      -utcdoy      display times in UTC day-of-year format (needs LSK)",
"      -etsec       display times as ET seconds past J2000",
"      -sec         display times \"rounded inward\" to second",
"      -min         display times \"rounded inward\" to minute",
"      -hour        display times \"rounded inward\" to hour",
"      -day         display times \"rounded inward\" to day",
"      -g           display summary grouped by coverage",
"      -n           display bodies/frames using only numeric id-codes",
"      -o           display summary ordered by body/frame name",
"      -[bod]       display summary for body [bod]",
"      -sb[bod]     display summary for body [bod]",
"      -sc[cen]     display summary for center of motion/relative-to frame [cen]",
"      -at [time]   display summary if coverage contains epoch [time]",
"      -from [beg]  display summary if coverage contains interval [beg]:[end]",
"      -to [end]    display summary if coverage contains interval [beg]:[end]",
"      -f [list]    summarize kernels listed in the [list] file",
"      -h           display help",
"      -v           display version",
"   An LSK file must be provided on the command line to display times in",
"   UTC formats. FK file(s) must be provided on the command line to",
"   display names of any frames that are not built into the Toolkit.",
"   See the BRIEF User's Guide for more information."
);

@version = (
"BRIEF -- Version 3.0.0, January 14, 2008 -- Toolkit Version N00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Displaying help: -h argument, without files',
  'success',
  $brief,
  '-h',
  52,
  @help
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Displaying help: -h argument, with files',
  'success',
  $brief,
  '-h brief_sc_1seg.bsp',
  52,
  @help
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Displaying usage: no command line arguments',
  'success',
  $brief,
  ' ',
  24,
  @usage
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'Displaying version: no command line arguments',
  'success',
  $brief,
  '-v',
  3,
  @version
);

#
# Delete test data
#
print "\n";
print "Deleting test data ...\n";
print "\n";
&test_data( $mkspk, $tobin, "delete" );

#
# All done.
#
print "\n";
print "Total: $counttotal --- Passed: $countpass  --- Failed: $countfail\n";
print "\n";

exit;

#
# This routine runs the specified test and prints results to the screen.
#
sub run_test {

  #
  # All argument are inputs. Output is via displaying report message to
  # the screen. Arguments are:
  #
  #    $reporttype  -- lists all types of info to be included into the report
  #                    (possible values are "command", "output", "expvalues")
  #    $maxtocompare - maximum number of characters from each @expvalue line
  #                    to check in inputs; if "", check complete lines
  #    $shortonly   -- flag indicating whether only 'SPICE(...)' line from
  #                    @expvalue should be checked in the output for 
  #                    failure-type cases; "yes" or "no"
  #    $checkcount  -- flag indicating whether the count of output lines
  #                    should be checked; "yes" or "no"
  #    $logname     -- the name of a log file, the contents of which should be
  #                    checked instead of captured STDOUT output; if "",
  #                    STDOUT is checked
  #    $testdesc    -- text line describing test
  #    $testtype    -- "success" or "failure" for expected status 0 or non 0
  #    $progname    -- name of program to run
  #    $commandline -- complete command line
  #    $expcount    -- expected count of output lines
  #    @expvalue    -- an array of strings to look for in the output.
  #                    "?" in these string stands for "any one character".
  #
  ( $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
    $testdesc,
    $testtype,
    $progname,
    $commandline,
    $expcount,
    @expvalue ) = @_;
  $infotypes = $reporttype;
  $report = "";

  $counttotal++;

  #
  # Run the test and save screen output.
  #
  $result = `$progname $commandline 2>&1`;

  #
  # Check exit status vs expected status and reflect then in the report.
  #
  $status = ( $? >> 8 );
  if (    ( ( ! $status ) && $testtype eq "success" ) ||
          ( (   $status ) && $testtype eq "failure" )    ) {
    #
    # Expected status matches returned status. Good.
    #
    $report = "";
  } elsif ( ( ! $status ) && $testtype eq "failure" ) {
    #
    # Expected failure, got success. Bad.
    #
    $report = "\n   ERROR: expected failure but returned with success.\n ";
  } elsif ( (   $status ) && $testtype eq "success" ) {
    #
    # Expected success, got failure. Bad.
    #
    $report = "\n   ERROR: expected success but returned with failure.\n ";
  }

  #
  # Check that output has expected number of lines.
  #
  if ( $checkcount eq "yes" ) {
    $rescount = 0;
    while( $result =~ m/\n/g ) {
      $rescount++;
    }
    if ( $rescount != $expcount ) {
      $report = $report.
      "\n   ERROR: expected $expcount output lines but got $rescount.\n";
    }
  }

  #
  # Check that each of expected lines is present in the output.
  #
  $checkedcount = 0;

  for ($i = 0; $i <= $#expvalue; $i++ ) {

    #
    # Take all or a part of expected value based on $maxtocompare.
    #
    if ( $maxtocompare eq "" ) {
      $shortexpvalue = $expvalue[$i];
    } else {
      $shortexpvalue = substr( $expvalue[$i], 0, $maxtocompare );
    }

    #
    # Pre-process expected value to escape all special regex characters
    # except "?" which, from this routine's point of view, stands for
    # "any one character" and, therefore, get replaced with ".".
    #
    $modexpvalue = $shortexpvalue;
    $modexpvalue =~ s/\\/\\\\/g;
    $modexpvalue =~ s/\n/\\n/g;
    $modexpvalue =~ s/\./\\./g;
    $modexpvalue =~ s/\^/\\^/g;
    $modexpvalue =~ s/\$/\\\$/g;
    $modexpvalue =~ s/\*/\\*/g;
    $modexpvalue =~ s/\+/\\+/g;
    $modexpvalue =~ s/\{/\\{/g;
    $modexpvalue =~ s/\}/\\}/g;
    $modexpvalue =~ s/\[/\\[/g;
    $modexpvalue =~ s/\]/\\]/g;
    $modexpvalue =~ s/\(/\\(/g;
    $modexpvalue =~ s/\)/\\)/g;
    $modexpvalue =~ s/\|/\\|/g;

    $modexpvalue =~ s/\?/\./g;

    #
    # Check if the output contained expected string. First, make an exception
    # for failure-type runs checking only short error messages.
    #
    if ( $testtype  eq "failure" &&
         $shortonly eq "yes"     &&
         ! ( $shortexpvalue =~ /^SPICE\(.+\)$/ ) ) {

      #
      # Don't check this line because it is not a short error message.
      #

    } else {

      if ( $result =~ /$modexpvalue/ ) {

	#
	# Expected string is present in the output. Good.
	#

      } else {

	#
	# Expected string is NOT present in the output. Bad.
	#
	$report = $report.
	 "\n   ERROR: expected string '$shortexpvalue' was not in the output.\n";

      }

      $checkedcount++;

    }

  }

  #
  # Safety belt against poor test setups: verify that we checked at
  # least one line.
  #
  if ( $checkedcount == "0" ) {
    $report = $report.
      "\n   ERROR: bad test case setup: no lines from expected values were checked.\n";
  }

  #
  # Finalize report.
  #
  if ( $report eq "" ) {

    $countpass++;
    $report = "--- passed --- ($testtype) $testdesc\n";

  } else {

    $countfail++;
    $report = "\n".
              "--- FAILED --- ($testtype) $testdesc\n".
              "$report";

    $infotypes = "command output expvalues";

  }

  #
  # Add additonal information to the report as needed.
  #
  if ( $infotypes =~ /command/ ) {
    $report = "$report".
              "\n".
              "   COMMAND --- \n".
              "\n".
              "$progname $commandline\n".
              "\n";
  }

  if ( $infotypes =~ /output/ ) {
    $report = "$report".
              "\n".
              "   OUTPUT --- \n".
              "\n".
              "$result\n".
              "\n";
  }

  if ( $infotypes =~ /expvalues/ ) {
    $report = "$report".
              "\n".
              "   EXPECTED VALUES --- \n".
              "\n";

    for ($i = 0; $i <= $#expvalue; $i++ ) {
      if ( $maxtocompare eq "" ) {
	$report = "$report".
	          "$expvalue[$i]\n";
      } else {
	$report = "$report".
	          substr( $expvalue[$i], 0, $maxtocompare )."\n";
      }
    }
    $report = "$report\n";
  }

  #
  # Display report.
  #
  print $report;

}

#
# This routine generates all necessary kernels.
#
sub test_data {

  #
  # The only inputs are MKSPK exe location and action ("make" or "delete"). 
  # Outputs are files needed for the test.
  #
  ( $mkspk, $tobin, $action ) = @_;
  $myaction = $action;

  #
  # The following files will be made
  #
  # 1)  naif0008.tls --- LSK
  #
  # 2)  brief_test.tf --- FK with name/ID mappings
  #
  #  )  brief_list_one.lst --- list only sc_1seg SPK
  #
  #  )  brief_list_one_no_eof.lst --- list with sc_1seg SPK and no EOF
  #
  #  )  brief_list_many.lst --- list with sc_1seg & sc_3seg on 2 lines
  #
  #  )  brief_list_many_w_blank_lines.lst --- w sc_1seg, sc_3seg, unk_id with banks lines
  #
  #  )  brief_list_few_per_line.lst --- same on one line
  #
  #  )  brief_list_bad_nonexisting.lst --- lists non-existing file ghost2_spk.bsp
  #
  #  )  brief_list_bad_with_tabs.lst --- has TABs in front of sc_1seg SPK
  #
  #  )  brief_list_spk_pck.lst --- with an SPK and a PCK
  #
  #  )  brief_list_spk_pck.lst --- with an SPK and an LSK
  #
  #  )  brief_list_pck_only.lst --- with a PCK only
  #
  #  )  brief_list_mk_only.lst --- with a MK only
  #
  #  )  brief_list_mk_spk.lst --- with a MK and SPK
  #
  #  )  brief_list_mk_pck.lst --- with a MK and PCK
  #
  #  )  brief_list_no_spk_pck.lst --- without SPKs or PCKs
  #
  #  )  brief_sc_1seg.bsp --- s/c only, 1 segment
  #
  #  )  brief_sc_1seg_niframe.bsp --- s/c only, 1 segment, non-inertial frame
  #
  #  )  brief_sc_1seg_unk_id.bsp --- s/c only, 1 segment, unknown ID
  #
  #  )  brief_sc_1seg_times.bsp --- s/c only, 1 segment, obscure times
  #
  #  )  brief_sc_1seg_short1.bsp --- s/c only, 1 segment, shorter than 1 second
  #
  #  )  brief_sc_1seg_short2.bsp --- s/c only, 1 segment, shorter than 1 minute
  #
  #  )  brief_sc_1seg_short3.bsp --- s/c only, 1 segment, shorter than 1 hour
  #
  #  )  brief_sc_1seg_short4.bsp --- s/c only, 1 segment, shorter than 1 day
  #
  #  )  brief_sc_1seg_bnd_short1.bsp --- s/c only, 1 seg, shorter than 1 second, bndry
  #
  #  )  brief_sc_1seg_bnd_short2.bsp --- s/c only, 1 seg, shorter than 1 minute, bndry
  #
  #  )  brief_sc_1seg_bnd_short3.bsp --- s/c only, 1 seg, shorter than 1 hour, bndry
  #
  #  )  brief_sc_1seg_bnd_short4.bsp --- s/c only, 1 seg, shorter than 1 day, bndry
  #
  #  )  brief_sc_3seg.bsp --- s/c only, 3 segs, same center, no gaps
  #
  #  )  brief_sc_3seg_gaps.bsp --- s/c only, 3 segs, same center, gaps
  #
  #  )  brief_sc_bc_pl_sat.bsp --- s/c+planet+satellite, same coverage
  #
  #  )  brief_sc_bc_pl_sat_dcov1.bsp --- s/c+bc+planet+satellite, diff. cov. 2&2
  #
  #  )  brief_sc_bc_pl_sat_dcov2.bsp --- s/c+bc+planet+satellite, diff. cov. all
  #
  #  )  brief_sc_bc_pl_sat_dcov3.bsp --- 2s/c+bc+planet+2satellite, diff. cov. all
  #
  #  )  brief_ek.xes --- transfer format EK
  #
  #  )  brief_ek.bes --- binary format EK
  #
  #  )  brief_ck.xc --- transfer format CK
  #
  #  )  brief_ck.bc --- binary format CK
  #
  #  )  brief_dsk.xds --- transfer format DSK
  #
  #  )  brief_dsk.bds --- binary format DSK
  #
  #  )  brief_uk.xu --- transfer format U(nknown) DAF kernel
  #
  #  )  brief_uk.bu --- binary format U(nknown) DAF kernel
  #
  #  )  brief_pck.xpc --- transfer format PCK
  #
  #  )  brief_pck.bpc --- binary format PCK
  #
  #  )  brief_pck_2.xpc --- transfer format PCK with a few segments
  #
  #  )  brief_pck_2.bpc --- binary format PCK with a few segments
  #
  #  )  brief_dec.xdc --- a one-line old SPICE decimal text file
  #
  #  )  brief_te1.xt1 --- a one-line Text E-Kernel type 1
  #
  #  )  brief_mk_spk.tm --- meta-kernel with one SPK
  #
  #  )  brief_mk_2spks.tm --- meta-kernel with two SPKs
  #
  #  )  brief_mk_spk_lsk.tm --- meta-kernel with one SPK and one LSK
  #
  #  )  brief_mk_spk_pck.tm --- meta-kernel with one SPK and one PCK
  #
  #  )  brief_mk_pck_lsk.tm --- meta-kernel with no SPK
  #
  # LSK and any other text kernels that are needed should be at the
  # top of the list to be made first):
  #
  @files = (
            "naif0008.tls",
            "brief_test.tf",
            "brief_list_one.lst",
            "brief_list_one_no_eof.lst",
            "brief_list_many.lst",
            "brief_list_many_w_blank_lines.lst",
            "brief_list_few_per_line.lst",
            "brief_list_bad_nonexisting.lst",
            "brief_list_bad_with_tabs.lst",
	    "brief_list_spk_pck.lst",
	    "brief_list_spk_lsk.lst",
	    "brief_list_pck_only.lst",
            "brief_list_mk_only.lst",
            "brief_list_mk_spk.lst",
            "brief_list_mk_pck.lst",
            "brief_list_no_spk_pck.lst",
            "brief_sc_1seg.bsp",
            "brief_sc_1seg_niframe.bsp",
            "brief_sc_1seg_unk_id.bsp",
            "brief_sc_1seg_times.bsp",
            "brief_sc_1seg_short1.bsp",
            "brief_sc_1seg_short2.bsp",
            "brief_sc_1seg_short3.bsp",
            "brief_sc_1seg_short4.bsp",
            "brief_sc_1seg_bnd_short1.bsp",
            "brief_sc_1seg_bnd_short2.bsp",
            "brief_sc_1seg_bnd_short3.bsp",
            "brief_sc_1seg_bnd_short4.bsp",
            "brief_sc_3seg.bsp",
            "brief_sc_3seg_gaps.bsp",
            "brief_sc_bc_pl_sat.bsp",
            "brief_sc_bc_pl_sat_dcov1.bsp",
            "brief_sc_bc_pl_sat_dcov2.bsp",
            "brief_sc_bc_pl_sat_dcov3.bsp",
            "brief_pck.xpc",
            "brief_pck.bpc",
            "brief_pck_2.xpc",
            "brief_pck_2.bpc",
            "brief_ck.xc",
            "brief_ck.bc",
            "brief_dsk.xds",
            "brief_dsk.bds",
            "brief_uk.xu",
            "brief_uk.bu",
            "brief_dec.xdc",
            "brief_te1.xt1",
            "brief_ek.xes",
            "brief_ek.bes",
            "brief_mk_spk.tm",
            "brief_mk_2spks.tm",
            "brief_mk_spk_lsk.tm",
            "brief_mk_spk_pck.tm",
            "brief_mk_pck_lsk.tm"
           );

  #
  # Loop through the file list.
  #
  foreach $file ( @files ) {

    #
    # Check if there is anything to be done for this file. Report if
    # there is.
    #
    $myaction = $action;
    if (      (   -e $file && $myaction eq "make"   ) ) {
      print "--- no need to make existing $file ... \n";
      $myaction = "do nothing";
    } elsif ( ( ! -e $file && $myaction eq "delete" )   ) {
      print "--- no need to delete non-existing $file ... \n";
      $myaction = "do nothing";
    } elsif ( ( ! -e $file && $myaction eq "make"   ) ) {
      print "--- creating $file ...\n";
    } elsif ( (   -e $file && $myaction eq "delete" ) ) {
      print "--- deleting $file ...\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_sc_1seg.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of BRIEF.
One segment.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -29
   CENTER_ID         = 0
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for BRIEF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB, 0, 0, 0, 0, 0, 0
2000-01-02 12:00:00 TDB, 0, 0, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "brief_sc_1seg.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_sc_1seg_niframe.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of BRIEF.
One segment. Non-inertial frame.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -29
   CENTER_ID         = 0
   REF_FRAME_NAME    = 'IAU_EARTH'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for BRIEF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB, 0, 0, 0, 0, 0, 0
2000-01-02 12:00:00 TDB, 0, 0, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "brief_sc_1seg_niframe.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_sc_1seg_unk_id.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of BRIEF.
One segment. ID not built into SPICE.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -111
   CENTER_ID         = 0
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for BRIEF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB, 0, 0, 0, 0, 0, 0
2000-01-02 12:00:00 TDB, 0, 0, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "brief_sc_1seg_unk_id.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_sc_1seg_times.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of BRIEF.
One segment.Obscure times to check rounding.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -29
   CENTER_ID         = 0
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for BRIEF test'
\\begintext

MKSPK input data:

2000-01-01 15:15:15.150 TDB, 0, 0, 0, 0, 0, 0
2000-01-03 08:08:08.080 TDB, 0, 0, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "brief_sc_1seg_times.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_sc_1seg_short1.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of BRIEF.
One segment. Shorter than 1 second to check rounding..

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -29
   CENTER_ID         = 0
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for BRIEF test'
\\begintext

MKSPK input data:

2000-01-02 12:00:00.100 TDB, 0, 0, 0, 0, 0, 0
2000-01-02 12:00:00.900 TDB, 0, 0, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "brief_sc_1seg_short1.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_sc_1seg_short2.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of BRIEF.
One segment. Shorter than 1 minute to check rounding..

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -29
   CENTER_ID         = 0
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for BRIEF test'
\\begintext

MKSPK input data:

2000-01-02 12:00:01.000 TDB, 0, 0, 0, 0, 0, 0
2000-01-02 12:00:59.000 TDB, 0, 0, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "brief_sc_1seg_short2.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_sc_1seg_short3.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of BRIEF.
One segment. Shorter than 1 hour to check rounding..

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -29
   CENTER_ID         = 0
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for BRIEF test'
\\begintext

MKSPK input data:

2000-01-02 12:01:00.000 TDB, 0, 0, 0, 0, 0, 0
2000-01-02 12:59:00.000 TDB, 0, 0, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "brief_sc_1seg_short3.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_sc_1seg_short4.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of BRIEF.
One segment. Shorter than 1 day to check rounding..

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -29
   CENTER_ID         = 0
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for BRIEF test'
\\begintext

MKSPK input data:

2000-01-02 01:00:00.000 TDB, 0, 0, 0, 0, 0, 0
2000-01-02 23:00:00.000 TDB, 0, 0, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "brief_sc_1seg_short4.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_sc_1seg_bnd_short1.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of BRIEF.
One segment. Shorter than 1 second to check rounding. Over second boundary.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -29
   CENTER_ID         = 0
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for BRIEF test'
\\begintext

MKSPK input data:

2000-01-01 23:59:59.580 TDB, 0, 0, 0, 0, 0, 0
2000-01-02 00:00:00.010 TDB, 0, 0, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "brief_sc_1seg_bnd_short1.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_sc_1seg_bnd_short2.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of BRIEF.
One segment. Shorter than 1 minute to check rounding. Over minute boundary.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -29
   CENTER_ID         = 0
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for BRIEF test'
\\begintext

MKSPK input data:

2000-01-01 23:59:58.580 TDB, 0, 0, 0, 0, 0, 0
2000-01-02 00:00:01.010 TDB, 0, 0, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "brief_sc_1seg_bnd_short2.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_sc_1seg_bnd_short3.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of BRIEF.
One segment. Shorter than 1 hour to check rounding. Over hour boundary.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -29
   CENTER_ID         = 0
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for BRIEF test'
\\begintext

MKSPK input data:

2000-01-01 23:58:58.580 TDB, 0, 0, 0, 0, 0, 0
2000-01-02 00:01:01.010 TDB, 0, 0, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "brief_sc_1seg_bnd_short3.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_sc_1seg_bnd_short4.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of BRIEF.
One segment. Shorter than 1 day to check rounding. Over day boundary.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -29
   CENTER_ID         = 0
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for BRIEF test'
\\begintext

MKSPK input data:

2000-01-01 22:58:58.580 TDB, 0, 0, 0, 0, 0, 0
2000-01-02 01:01:01.010 TDB, 0, 0, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "brief_sc_1seg_bnd_short4.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_sc_3seg.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of BRIEF.
3 overlapping segments for s/c; segment 1

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -29
   CENTER_ID         = 0
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for BRIEF test'
\\begintext

MKSPK input data:

2000-01-02 01:01:01.01 TDB, 0, 0, 0, 0, 0, 0
2000-01-03 04:04:04.04 TDB, 0, 0, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of BRIEF.
3 overlapping segments for s/c; segment 2

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -29
   CENTER_ID         = 0
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for BRIEF test'
\\begintext

MKSPK input data:

2000-01-03 02:02:02.02 TDB, 0, 0, 0, 0, 0, 0
2000-01-04 05:05:05.05 TDB, 0, 0, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file -append 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of BRIEF.
s/c+bc+planet+satellite, same coverage; planet segment.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -29
   CENTER_ID         = 0
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for BRIEF test'
\\begintext

MKSPK input data:

2000-01-04 03:03:03.03 TDB, 0, 0, 0, 0, 0, 0
2000-01-05 06:06:06.06 TDB, 0, 0, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file -append 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "brief_sc_3seg.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_sc_3seg_gaps.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of BRIEF.
3 non-overlapping segments for s/c; segment 1

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -29
   CENTER_ID         = 0
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for BRIEF test'
\\begintext

MKSPK input data:

2000-01-04 05:05:05.05 TDB, 0, 0, 0, 0, 0, 0
2000-01-06 05:05:05.05 TDB, 0, 0, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of BRIEF.
3 non-overlapping segments for s/c; segment 2

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -29
   CENTER_ID         = 0
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for BRIEF test'
\\begintext

MKSPK input data:

2000-01-06 07:07:07.07 TDB, 0, 0, 0, 0, 0, 0
2000-01-07 06:06:06.06 TDB, 0, 0, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file -append 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of BRIEF.
3 non-overlapping segments for s/c; segment 3

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -29
   CENTER_ID         = 0
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for BRIEF test'
\\begintext

MKSPK input data:

2000-01-07 08:08:08.08 TDB, 0, 0, 0, 0, 0, 0
2000-01-08 07:07:07.07 TDB, 0, 0, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file -append 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "brief_sc_3seg_gaps.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_sc_bc_pl_sat.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of BRIEF.
s/c+bc+planet+satellite, same coverage; s/c segment.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -254
   CENTER_ID         = 499
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for BRIEF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB, 0, 0, 0, 0, 0, 0
2000-01-02 12:00:00 TDB, 0, 0, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of BRIEF.
s/c+bc+planet+satellite, same coverage; barycenter segment.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = 4
   CENTER_ID         = 0
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for BRIEF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB, 0, 0, 0, 0, 0, 0
2000-01-02 12:00:00 TDB, 0, 0, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file -append 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of BRIEF.
s/c+bc+planet+satellite, same coverage; planet segment.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = 499
   CENTER_ID         = 4
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for BRIEF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB, 0, 0, 0, 0, 0, 0
2000-01-02 12:00:00 TDB, 0, 0, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file -append 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of BRIEF.
s/c+bc+planet+satellite, same coverage; satellite segment.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = 401
   CENTER_ID         = 4
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for BRIEF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB, 0, 0, 0, 0, 0, 0
2000-01-02 12:00:00 TDB, 0, 0, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file -append 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "brief_sc_bc_pl_sat.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_sc_bc_pl_sat_dcov1.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of BRIEF.
s/c+bc+planet+satellite, different coverage (2&2); s/c segment.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -254
   CENTER_ID         = 0
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for BRIEF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB, 0, 0, 0, 0, 0, 0
2000-01-02 12:00:00 TDB, 0, 0, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of BRIEF.
s/c+bc+planet+satellite, different coverage (2&2); barycenter segment.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = 4
   CENTER_ID         = 0
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for BRIEF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB, 0, 0, 0, 0, 0, 0
2000-01-03 12:00:00 TDB, 0, 0, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file -append 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of BRIEF.
s/c+bc+planet+satellite, different coverage (2&2); planet segment.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = 499
   CENTER_ID         = 4
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for BRIEF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB, 0, 0, 0, 0, 0, 0
2000-01-03 12:00:00 TDB, 0, 0, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file -append 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of BRIEF.
s/c+bc+planet+satellite, different coverage (2&2); satellite segment.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = 401
   CENTER_ID         = 4
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for BRIEF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB, 0, 0, 0, 0, 0, 0
2000-01-02 12:00:00 TDB, 0, 0, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file -append 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "brief_sc_bc_pl_sat_dcov1.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_sc_bc_pl_sat_dcov2.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of BRIEF.
s/c+bc+planet+satellite, different coverage (all); s/c segment.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -254
   CENTER_ID         = 499
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for BRIEF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB, 0, 0, 0, 0, 0, 0
2000-01-02 12:00:00 TDB, 0, 0, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of BRIEF.
s/c+bc+planet+satellite, different coverage (all); barycenter segment.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = 4
   CENTER_ID         = 0
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for BRIEF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB, 0, 0, 0, 0, 0, 0
2000-01-03 12:00:00 TDB, 0, 0, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file -append 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of BRIEF.
s/c+bc+planet+satellite, different coverage (all); planet segment.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = 499
   CENTER_ID         = 4
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for BRIEF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB, 0, 0, 0, 0, 0, 0
2000-01-04 12:00:00 TDB, 0, 0, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file -append 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of BRIEF.
s/c+bc+planet+satellite, different coverage (all); satellite segment.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = 401
   CENTER_ID         = 4
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for BRIEF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB, 0, 0, 0, 0, 0, 0
2000-01-05 12:00:00 TDB, 0, 0, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file -append 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "brief_sc_bc_pl_sat_dcov2.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_sc_bc_pl_sat_dcov3.bsp" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bsp$/.mkspk/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of BRIEF.
2s/c+bc+planet+2satellite, different coverage (2&3); 1st s/c segment.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -254
   CENTER_ID         = 0
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for BRIEF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB, 0, 0, 0, 0, 0, 0
2000-01-02 12:00:00 TDB, 0, 0, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of BRIEF.
2s/c+bc+planet+2satellite, different coverage (2&3); 2nd s/c segment.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = -253
   CENTER_ID         = 0
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for BRIEF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB, 0, 0, 0, 0, 0, 0
2000-01-03 12:00:00 TDB, 0, 0, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file -append 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of BRIEF.
2s/c+bc+planet+2satellite, different coverage (2&3); barycenter segment.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = 4
   CENTER_ID         = 0
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for BRIEF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB, 0, 0, 0, 0, 0, 0
2000-01-03 12:00:00 TDB, 0, 0, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file -append 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of BRIEF.
2s/c+bc+planet+2satellite, different coverage (2&3); planet segment.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = 499
   CENTER_ID         = 4
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for BRIEF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB, 0, 0, 0, 0, 0, 0
2000-01-03 12:00:00 TDB, 0, 0, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file -append 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of BRIEF.
2s/c+bc+planet+2satellite, different coverage (2&3); 1st satellite segment.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = 401
   CENTER_ID         = 4
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for BRIEF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB, 0, 0, 0, 0, 0, 0
2000-01-02 12:00:00 TDB, 0, 0, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file -append 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;

This is a special SPK. It is intended ONLY for testing of BRIEF.
2s/c+bc+planet+2satellite, different coverage (2&3); 2nd satellite segment.

MKSPK setup parameters:

\\begindata
   INPUT_DATA_TYPE   = 'STATES'
   OUTPUT_SPK_TYPE   = 9
   OBJECT_ID         = 402
   CENTER_ID         = 4
   REF_FRAME_NAME    = 'J2000'
   PRODUCER_ID       = 'BVS/NAIF'
   DATA_ORDER        = 'EPOCH X Y Z VX VY VZ'
   DATA_DELIMITER    = ','
   LEAPSECONDS_FILE  = 'naif0008.tls'
   LINES_PER_RECORD  = 1
   IGNORE_FIRST_LINE = 25
   TIME_WRAPPER      = '#'
   POLYNOM_DEGREE    = 1
   SEGMENT_ID        = 'for BRIEF test'
\\begintext

MKSPK input data:

2000-01-01 12:00:00 TDB, 0, 0, 0, 0, 0, 0
2000-01-02 12:00:00 TDB, 0, 0, 0, 0, 0, 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $result = `$mkspk -setup $setfile -input $setfile -output $file -append 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MKSPK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";

    }

    if ( $file eq "brief_sc_bc_pl_sat_dcov3.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "naif0008.tls" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
KPL/LSK

\\begindata

DELTET/DELTA_T_A       =   32.184
DELTET/K               =    1.657D-3
DELTET/EB              =    1.671D-2
DELTET/M               = (  6.239996D0   1.99096871D-7 )

DELTET/DELTA_AT        = ( 10,   \@1972-JAN-1
                           11,   \@1972-JUL-1
                           12,   \@1973-JAN-1
                           13,   \@1974-JAN-1
                           14,   \@1975-JAN-1
                           15,   \@1976-JAN-1
                           16,   \@1977-JAN-1
                           17,   \@1978-JAN-1
                           18,   \@1979-JAN-1
                           19,   \@1980-JAN-1
                           20,   \@1981-JUL-1
                           21,   \@1982-JUL-1
                           22,   \@1983-JUL-1
                           23,   \@1985-JUL-1
                           24,   \@1988-JAN-1
                           25,   \@1990-JAN-1
                           26,   \@1991-JAN-1
                           27,   \@1992-JUL-1
                           28,   \@1993-JUL-1
                           29,   \@1994-JUL-1
                           30,   \@1996-JAN-1
                           31,   \@1997-JUL-1
                           32,   \@1999-JAN-1
                           33,   \@2006-JAN-1 )

\\begintext
EndBlock

      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }

    if ( $file eq "naif0008.tls" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_test.tf" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
KPL/FK

This is a special FK for testing of BRIEF. It defines a different name-ID
mapping for selected bodies and s/c in BRIEF test SPKs.

\\begindata

   NAIF_BODY_NAME += ( 'MARS_SYSTEM_BARYCENTER' )
   NAIF_BODY_CODE += ( 4 )

   NAIF_BODY_NAME += ( 'SDU' )
   NAIF_BODY_CODE += ( -29 )

   NAIF_BODY_NAME += ( 'MER2' )
   NAIF_BODY_CODE += ( -254)

   FRAME_ITRF99                  = 2999
   FRAME_2999_NAME               = 'ITRF99'
   FRAME_2999_CLASS              = 2
   FRAME_2999_CLASS_ID           = 2999
   FRAME_2999_CENTER             = 399

   FRAME_MOON_PA_DE403           = 31002
   FRAME_31002_NAME              = 'MOON_PA_DE403'
   FRAME_31002_CLASS             = 2
   FRAME_31002_CLASS_ID          = 31002
   FRAME_31002_CENTER            = 301

   FRAME_MOON_PA_DE418           = 31004
   FRAME_31004_NAME              = 'MOON_PA_DE418'
   FRAME_31004_CLASS             = 2
   FRAME_31004_CLASS_ID          = 31004
   FRAME_31004_CENTER            = 301

\\begintext
EndBlock

      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }

    if ( $file eq "brief_test.tf" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_list_one.lst" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
brief_sc_1seg.bsp
EndBlock

      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }

    if ( $file eq "brief_list_one.lst" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_list_one_no_eof.lst" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";

      print OUTPUT "brief_sc_1seg.bsp";

      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }

    if ( $file eq "brief_list_one_no_eof.lst" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_list_many.lst" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
brief_sc_1seg.bsp
brief_sc_3seg.bsp
EndBlock

      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }

    if ( $file eq "brief_list_many.lst" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_list_many_w_blank_lines.lst" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;



  brief_sc_1seg.bsp


   brief_sc_3seg.bsp
 brief_sc_1seg_unk_id.bsp

EndBlock

      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }

    if ( $file eq "brief_list_many_w_blank_lines.lst" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_list_bad_nonexisting.lst" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
ghost2_spk.bsp
EndBlock

      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }

    if ( $file eq "brief_list_bad_nonexisting.lst" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_list_bad_with_tabs.lst" && $myaction eq "make" ) {

      $tmpname = "\t\tbrief_sc_1seg.bsp";

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
$tmpname
EndBlock

      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }

    if ( $file eq "brief_list_bad_with_tabs.lst" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_list_few_per_line.lst" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
brief_sc_1seg.bsp brief_sc_3seg.bsp brief_sc_1seg_unk_id.bsp
EndBlock

      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }

    if ( $file eq "brief_list_few_per_line.lst" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_list_spk_pck.lst" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
brief_sc_1seg.bsp
brief_pck.bpc
EndBlock

      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }

    if ( $file eq "brief_list_spk_pck.lst" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_list_spk_lsk.lst" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
brief_sc_1seg.bsp
naif0008.tls
EndBlock

      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }

    if ( $file eq "brief_list_spk_lsk.lst" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_list_pck_only.lst" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
brief_pck.bpc
EndBlock

      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }

    if ( $file eq "brief_list_pck_only.lst" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_list_mk_only.lst" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
brief_mk_spk.tm
EndBlock

      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }

    if ( $file eq "brief_list_mk_only.lst" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_list_mk_spk.lst" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
brief_mk_spk.tm
brief_sc_bc_pl_sat_dcov3.bsp
EndBlock

      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }

    if ( $file eq "brief_list_mk_spk.lst" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_list_mk_pck.lst" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
brief_mk_spk.tm
brief_pck_2.bpc
EndBlock

      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }

    if ( $file eq "brief_list_mk_pck.lst" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_list_no_spk_pck.lst" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
naif0008.tls
EndBlock

      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }

    if ( $file eq "brief_list_no_spk_pck.lst" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_ek.bes" && $myaction eq "make" ) {

      $xfrfile = $file;
      $xfrfile =~ s/\.bes$/.xes/;


      $result = `$tobin $xfrfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: TOBIN failed. Error was: $result\n";
      }

    }

    if ( $file eq "brief_ek.bes" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_ck.bc" && $myaction eq "make" ) {

      $xfrfile = $file;
      $xfrfile =~ s/\.bc$/.xc/;


      $result = `$tobin $xfrfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: TOBIN failed. Error was: $result\n";
      }

    }

    if ( $file eq "brief_ck.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_dsk.bds" && $myaction eq "make" ) {

      $xfrfile = $file;
      $xfrfile =~ s/\.bds$/.xds/;


      $result = `$tobin $xfrfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: TOBIN failed. Error was: $result\n";
      }

    }

    if ( $file eq "brief_dsk.bds" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_uk.bu" && $myaction eq "make" ) {

      $xfrfile = $file;
      $xfrfile =~ s/\.bu$/.xu/;


      $result = `$tobin $xfrfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: TOBIN failed. Error was: $result\n";
      }

    }

    if ( $file eq "brief_uk.bu" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_pck.bpc" && $myaction eq "make" ) {

      $xfrfile = $file;
      $xfrfile =~ s/\.bpc$/.xpc/;


      $result = `$tobin $xfrfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: TOBIN failed. Error was: $result\n";
      }

    }

    if ( $file eq "brief_pck.bpc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_pck_2.bpc" && $myaction eq "make" ) {

      $xfrfile = $file;
      $xfrfile =~ s/\.bpc$/.xpc/;


      $result = `$tobin $xfrfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: TOBIN failed. Error was: $result\n";
      }

    }

    if ( $file eq "brief_pck_2.bpc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_ck.xc" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
DAFETF NAIF DAF ENCODED TRANSFER FILE
'DAF/CK  '
'2'
'6'
'test                                                        '
BEGIN_ARRAY 1 6
'test                                    '
'0^0'
'0^0'
'-3E8'
'1'
'1'
'0'
6
'1^1'
'0^0'
'0^0'
'0^0'
'0^0'
'1^1'
END_ARRAY 1 6
TOTAL_ARRAYS 1
 ~NAIF/SPC BEGIN COMMENTS~
   In the SPICE system, pointing data for science instruments are stored in
   the C-kernel, the ``C'' in SPICE. The pointing of an instrument is often
   expressed in terms of a transformation matrix from some standard base
   reference frame to a local, instrument-fixed frame. In the past, the
   instrument was often a camera, and the transformation was thus dubbed
   the ``C-matrix''; hence the choice of C as the name for the pointing
   kernel.

   The data contained in C-kernel files can be accessed and manipulated by
   a collection of FORTRAN 77 subroutines which are part of the SPICELIB
   library. These subroutines can be integrated into user application
   programs. The purpose of this document is to describe both the C-kernel
   file structure and the associated SPICELIB software to the level of
   detail necessary for the user to program almost any application.

   With few exceptions, all subroutines and functions appearing in this
   document are part of SPICELIB. The exceptions are placeholders for
   user-supplied routines which appear in some of the code examples. Each
   SPICELIB routine is prefaced with a complete SPICELIB header which
   describes inputs, outputs, restrictions and context, and provides
   examples of usage. The authoritative documentation for any subroutine is
   its header, which should be consulted before using the routine in any
   program. A summary of the CK subroutines presented in this document is
   included as Appendix A.

 ~NAIF/SPC END COMMENTS~
EndBlock

      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }

    if ( $file eq "brief_ck.xc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_dec.xdc" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
'NAIF/DAF'                       
test
EndBlock

      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }

    if ( $file eq "brief_dec.xdc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_te1.xt1" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
TE1/EK        
EndBlock

      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }

    if ( $file eq "brief_te1.xt1" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_dsk.xds" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
DASETF NAIF DAS ENCODED TRANSFER FILE
'DAS/DSK '
'DSK type 3 test kernel                                      '
'0'
'0'
'0'
'0'
'0'
'D3'
'E'
BEGIN_DP_BLOCK 1 211
'270F^4'
'1^1'
'0^0'
'1^1'
'3^1'
'-3243F6A8885A3^1'
'3243F6A8885A3^1'
'-1921FB54442D18^1'
'1921FB54442D18^1'
'F4391FE8EF202^0'
'11D8C7E110394F^1'
'11D8C7E110394F^1'
'10787CBE7AAFCD^1'
'FA637FD3B151E8^0'
'F43929306B6B7^0'
'F4392A2EBCCD3^0'
'FA6382EF125AA^0'
'10787D18BFABFB^1'
'FFD06592B414B8^0'
'FB2A532519DC8^0'
'FCCBCF7AF7C888^0'
'FCCBCEC080AAD8^0'
'FB2A4A5280EBB^0'
'FFD0543D629DA^0'
'10787C1D7EC0B8^1'
'FA63764A8AA74^0'
'F4391FE8EF2038^0'
'F43920ECABE3F^0'
'FA637976DEB9E^0'
'10787C79B02F8C^1'
'11D8C7C5EB1E6C^1'
'11D8C7DDE25211^1'
'10787CB66C1561^1'
'FA637F14EB541^0'
'F43928389DA22^0'
'F43928FAB9C4F^0'
'FA638173FF72A^0'
'10787CFB522D64^1'
'FFD068B59BA028^0'
'FB2A5C9CBB54D^0'
'FCCBDF5CDA8C68^0'
'FCCBE049D1FB58^0'
'FB2A5B34F62F28^0'
'FFD064E1B7EE2^0'
'10787CBEABBCCB^1'
'FA637E66BB327^0'
'F439267FEABE1^0'
'F4392639E51D3^0'
'FA637D8BBCCEA8^0'
'10787CA5D11521^1'
'11D8C7D754E01B^1'
'11D8C7DC7D51AA^1'
'10787CB2E35DAE^1'
'FA637EC13D92^0'
'F43927CBEBFBA^0'
'F43928739F6C7^0'
'FA6380CDB99EE^0'
'10787CEE69C4C8^1'
'FFD067606A9D68^0'
'FB2A5B4290AA68^0'
'FCCBDDF552F738^0'
'FCCBDDF552F738^0'
'FB2A5B4290AA78^0'
'FFD067606A9D78^0'
'10787CEE69C4C8^1'
'FA6380CDB99EE^0'
'F43928739F6C88^0'
'F43927CBEBFBA8^0'
'FA637EC13D92^0'
'10787CB2E35DAD^1'
'11D8C7DC7D51A9^1'
'11D8C7D754E01B^1'
'10787CA5D1152^1'
'FA637D8BBCCEA8^0'
'F4392639E51D2^0'
'F439267FEABE08^0'
'FA637E66BB328^0'
'10787CBEABBCC9^1'
'FFD064E1B7EE2^0'
'FB2A5B34F62F38^0'
'FCCBE049D1FB48^0'
'FCCBDF5CDA8C78^0'
'FB2A5C9CBB54B8^0'
'FFD068B59BA028^0'
'10787CFB522D65^1'
'FA638173FF72A8^0'
'F43928FAB9C4E^0'
'F43928389DA22^0'
'FA637F14EB541^0'
'10787CB66C156^1'
'11D8C7DDE25212^1'
'11D8C7C5EB1E6C^1'
'10787C79B02F8D^1'
'FA637976DEB9E^0'
'F43920ECABE3E^0'
'F4391FE8EF202^0'
'FA63764A8AA75^0'
'10787C1D7EC0B8^1'
'FFD0543D629DA8^0'
'FB2A4A5280EBC^0'
'FCCBCEC080AAE8^0'
'FCCBCF7AF7C88^0'
'FB2A532519DC8^0'
'FFD06592B414B^0'
'10787D18BFABFB^1'
'FA6382EF125AA^0'
'F4392A2EBCCD3^0'
'F43929306B6B7^0'
'FA637FD3B151D^0'
'10787CBE7AAFCC^1'
'11D8C7E110394F^1'
'11D8C7C5EB1E6C^1'
'10787C79B02F8C^1'
'FA637976DEB9E^0'
'F43920ECABE3E^0'
'F4391FE8EF202^0'
'FA63764A8AA75^0'
'10787C1D7EC0B8^1'
'FFD0543D629DA8^0'
'FB2A4A5280EBC^0'
'FCCBCEC080AAE8^0'
'FCCBCF7AF7C88^0'
'FB2A532519DC8^0'
'FFD06592B414B^0'
'10787D18BFABFB^1'
'FA6382EF125AB^0'
'F4392A2EBCCD3^0'
'F43929306B6B7^0'
'FA637FD3B151D^0'
'10787CBE7AAFCC^1'
'11D8C7E110394F^1'
'11D8C7D754E01B^1'
'10787CA5D1152^1'
'FA637D8BBCCEA8^0'
'F4392639E51D2^0'
'F439267FEABE08^0'
'FA637E66BB328^0'
'10787CBEABBCC9^1'
'FFD064E1B7EE2^0'
'FB2A5B34F62F38^0'
'FCCBE049D1FB58^0'
'FCCBDF5CDA8C78^0'
'FB2A5C9CBB54B8^0'
'FFD068B59BA028^0'
'10787CFB522D65^1'
'FA638173FF72A8^0'
'F43928FAB9C4D^0'
'F43928389DA22^0'
'FA637F14EB541^0'
'10787CB66C156^1'
'11D8C7DDE25212^1'
'11D8C7DC7D51A9^1'
'10787CB2E35DAE^1'
'FA637EC13D92^0'
'F43927CBEBFBA8^0'
'F43928739F6C7^0'
'FA6380CDB99EE^0'
'10787CEE69C4C8^1'
'FFD067606A9D68^0'
'FB2A5B4290AA68^0'
'FCCBDDF552F738^0'
'FCCBDDF552F738^0'
'FB2A5B4290AA78^0'
'FFD067606A9D78^0'
'10787CEE69C4C8^1'
'FA6380CDB99EE^0'
'F43928739F6C7^0'
'F43927CBEBFBA^0'
'FA637EC13D92^0'
'10787CB2E35DAE^1'
'11D8C7DC7D51AA^1'
'11D8C7DDE25212^1'
'10787CB66C156^1'
'FA637F14EB541^0'
'F43928389DA21^0'
'F43928FAB9C4F^0'
'FA638173FF72A^0'
'10787CFB522D64^1'
'FFD068B59BA028^0'
'FB2A5C9CBB54D^0'
'FCCBDF5CDA8C78^0'
'FCCBE049D1FB58^0'
'FB2A5B34F62F28^0'
'FFD064E1B7EE2^0'
'10787CBEABBCCA^1'
'FA637E66BB327^0'
'F439267FEABE1^0'
'F4392639E51D2^0'
'FA637D8BBCCEA8^0'
'10787CA5D1152^1'
'11D8C7D754E01B^1'
'11D8C7E110394F^1'
'10787CBE7AAFCD^1'
'FA637FD3B151E8^0'
'F43929306B6B7^0'
'F4392A2EBCCD3^0'
'FA6382EF125AA^0'
'10787D18BFABFA^1'
'FFD06592B414B8^0'
'FB2A532519DC7^0'
'FCCBCF7AF7C888^0'
'FCCBCEC080AAD8^0'
'FB2A4A5280EBB^0'
'FFD0543D629DA^0'
'10787C1D7EC0B7^1'
'FA63764A8AA75^0'
'F4391FE8EF2038^0'
'F43920ECABE3E^0'
'FA637976DEB9F^0'
'10787C79B02F8D^1'
'11D8C7C5EB1E6C^1'
END_DP_BLOCK 1 211
TOTAL_DP_BLOCKS 1 211
BEGIN_INTEGER_BLOCK 1 14
'F4240'
'4'
'4'
'-1'
'-1'
'B'
'3'
'0'
'D3'
'0'
'0'
'14'
'A'
'1'
END_INTEGER_BLOCK 1 14
TOTAL_INTEGER_BLOCKS 1 14
EndBlock

      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }

    if ( $file eq "brief_dsk.xds" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_uk.xu" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
DAFETF NAIF DAF ENCODED TRANSFER FILE
'DAF/UK  '
'2'
'6'
'test                                                        '
BEGIN_ARRAY 1 6
'test                                    '
'0^0'
'0^0'
'-3E8'
'1'
'1'
'0'
6
'1^1'
'0^0'
'0^0'
'0^0'
'0^0'
'1^1'
END_ARRAY 1 6
TOTAL_ARRAYS 1
 ~NAIF/SPC BEGIN COMMENTS~
   In the SPICE system, pointing data for science instruments are stored in
   the C-kernel, the ``C'' in SPICE. The pointing of an instrument is often
   expressed in terms of a transformation matrix from some standard base
   reference frame to a local, instrument-fixed frame. In the past, the
   instrument was often a camera, and the transformation was thus dubbed
   the ``C-matrix''; hence the choice of C as the name for the pointing
   kernel.

   The data contained in C-kernel files can be accessed and manipulated by
   a collection of FORTRAN 77 subroutines which are part of the SPICELIB
   library. These subroutines can be integrated into user application
   programs. The purpose of this document is to describe both the C-kernel
   file structure and the associated SPICELIB software to the level of
   detail necessary for the user to program almost any application.

   With few exceptions, all subroutines and functions appearing in this
   document are part of SPICELIB. The exceptions are placeholders for
   user-supplied routines which appear in some of the code examples. Each
   SPICELIB routine is prefaced with a complete SPICELIB header which
   describes inputs, outputs, restrictions and context, and provides
   examples of usage. The authoritative documentation for any subroutine is
   its header, which should be consulted before using the routine in any
   program. A summary of the CK subroutines presented in this document is
   included as Appendix A.

 ~NAIF/SPC END COMMENTS~
EndBlock

      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }

    if ( $file eq "brief_uk.xu" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_pck.xpc" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
DAFETF NAIF DAF ENCODED TRANSFER FILE
'DAF/PCK '
'2'
'5'
'/home/bsemenov/tmp/pem_short.bpc                            '
BEGIN_ARRAY 1 69
'Earth PCK, ITRF93 Frame                 '
'EB5E5012EB5F2^7'
'EB5E53D2EB5F2^7'
'BB7'
'11'
'2'
69
'EB5E51F2EB5F2^7'
'1E^2'
'323C07E0111288^1'
'BEF130A85C28F8^-7'
'-2789D52B851EB8^-9'
'-1C9BD70A3D70A4^-C'
'-179B0A3D70A3D7^-C'
'1092B851EB851F^-C'
'-CE2B851EB851E8^-D'
'7C7AE147AE147C^-D'
'-DEEE147AE147B^-D'
'548547AE147AE^-C'
'-73F8F5C28F5C28^-C'
'1514A3D70A3D71^-C'
'12A07AE147AE14^-C'
'3AFC28F5C28F5C^-C'
'-29023D70A3D70A^-C'
'9C4^-D'
'-172F0A3D70A3D7^-C'
'D791EB851EB85^-D'
'-FA87AE147AE148^-D'
'-CF83851EB851E8^-C'
'1E853851EB851F^-B'
'68BCFE2AD87148^0'
'-790DB8BC528F5C^-7'
'-C1D542428F5C28^-A'
'19E823D70A3D71^-C'
'-2E29EB851EB852^-D'
'1A2D1EB851EB85^-D'
'-2C87AE147AE148^-D'
'1D723D70A3D70A^-D'
'-35D33333333334^-D'
'ADBCCCCCCCCCD^-D'
'-9E770A3D70A3D8^-D'
'392E147AE147AE^-D'
'91666666666668^-D'
'6DE147AE147AE^-D'
'-751CCCCCCCCCCC^-D'
'2DEC28F5C28F5C^-D'
'-10D147AE147AE1^-D'
'37866666666666^-D'
'2ADF0A3D70A3D8^-D'
'-1BA3F0A3D70A3D^-C'
'3D32051EB851EC^-C'
'3C57DFFAAE6B5^1'
'8F5E5FCBB499B^-2'
'20F3CBEB851EB8^-9'
'39DFB9C28F5C28^-A'
'-18EC3A3D70A3D7^-A'
'-67307599999998^-A'
'-3192123D70A3D8^-A'
'-4B20B35C28F5C4^-A'
'8C39B5C28F5C28^-B'
'-46DAA170A3D70C^-A'
'-37C5FE3D70A3D8^-A'
'4650547AE147B^-B'
'B10A35C28F5C28^-B'
'-2182B9EB851EB8^-A'
'5CF6BD70A3D70C^-B'
'4B77A8F5C28F5C^-A'
'21866428F5C29^-A'
'-D172911EB851E8^-A'
'-19BB6DC28F5C29^-A'
'-D80F66147AE148^-A'
'5D6F9A147AE148^-A'
'EB5E5012EB5F2^7'
'3C^2'
'41^2'
'1^1'
END_ARRAY 1 69
TOTAL_ARRAYS 1
 ~NAIF/SPC BEGIN COMMENTS~
 ~NAIF/SPC END COMMENTS~
EndBlock

      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }

    if ( $file eq "brief_pck.xpc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_pck_2.xpc" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
DAFETF NAIF DAF ENCODED TRANSFER FILE
'DAF/PCK '
'2'
'5'
' < DAFCAT: PCK CONCATENATION >                              '
BEGIN_ARRAY 1 69
'Earth PCK, ITRF93 Frame                 '
'EB5E5012EB5F2^7'
'EB5E53D2EB5F2^7'
'BB8'
'11'
'2'
69
'EB5E51F2EB5F2^7'
'1E^2'
'323C07E0111288^1'
'BEF130A85C28F8^-7'
'-2789D52B851EB8^-9'
'-1C9BD70A3D70A4^-C'
'-179B0A3D70A3D7^-C'
'1092B851EB851F^-C'
'-CE2B851EB851E8^-D'
'7C7AE147AE147C^-D'
'-DEEE147AE147B^-D'
'548547AE147AE^-C'
'-73F8F5C28F5C28^-C'
'1514A3D70A3D71^-C'
'12A07AE147AE14^-C'
'3AFC28F5C28F5C^-C'
'-29023D70A3D70A^-C'
'9C4^-D'
'-172F0A3D70A3D7^-C'
'D791EB851EB85^-D'
'-FA87AE147AE148^-D'
'-CF83851EB851E8^-C'
'1E853851EB851F^-B'
'68BCFE2AD87148^0'
'-790DB8BC528F5C^-7'
'-C1D542428F5C28^-A'
'19E823D70A3D71^-C'
'-2E29EB851EB852^-D'
'1A2D1EB851EB85^-D'
'-2C87AE147AE148^-D'
'1D723D70A3D70A^-D'
'-35D33333333334^-D'
'ADBCCCCCCCCCD^-D'
'-9E770A3D70A3D8^-D'
'392E147AE147AE^-D'
'91666666666668^-D'
'6DE147AE147AE^-D'
'-751CCCCCCCCCCC^-D'
'2DEC28F5C28F5C^-D'
'-10D147AE147AE1^-D'
'37866666666666^-D'
'2ADF0A3D70A3D8^-D'
'-1BA3F0A3D70A3D^-C'
'3D32051EB851EC^-C'
'3C57DFFAAE6B5^1'
'8F5E5FCBB499B^-2'
'20F3CBEB851EB8^-9'
'39DFB9C28F5C28^-A'
'-18EC3A3D70A3D7^-A'
'-67307599999998^-A'
'-3192123D70A3D8^-A'
'-4B20B35C28F5C4^-A'
'8C39B5C28F5C28^-B'
'-46DAA170A3D70C^-A'
'-37C5FE3D70A3D8^-A'
'4650547AE147B^-B'
'B10A35C28F5C28^-B'
'-2182B9EB851EB8^-A'
'5CF6BD70A3D70C^-B'
'4B77A8F5C28F5C^-A'
'21866428F5C29^-A'
'-D172911EB851E8^-A'
'-19BB6DC28F5C29^-A'
'-D80F66147AE148^-A'
'5D6F9A147AE148^-A'
'EB5E5012EB5F2^7'
'3C^2'
'41^2'
'1^1'
END_ARRAY 1 69
BEGIN_ARRAY 2 69
'Earth PCK, ITRF93 Frame                 '
'EB5E5012EB5F2^7'
'EB5E5792EB5F2^7'
'791A'
'1'
'2'
69
'EB5E53D2EB5F2^7'
'3C^2'
'323C07E0E4CBD^1'
'17CAB4CB691EB8^-6'
'-9E6A1B68F5C29^-9'
'-150DDEB851EB85^-B'
'-1405C28F5C28F6^-C'
'F6C^-D'
'-1447D70A3D70A4^-C'
'100A6666666666^-C'
'-13EA6666666666^-C'
'5113851EB851EC^-C'
'-6BBB3333333334^-C'
'986147AE147AE^-D'
'15ED70A3D70A3D^-C'
'42D9EB851EB85^-C'
'-29F35C28F5C29^-C'
'105BAE147AE148^-C'
'-144547AE147AE1^-C'
'B235C28F5C28F8^-D'
'-A0D1EB851EB85^-D'
'-D29DC28F5C28F8^-C'
'1E85947AE147AE^-B'
'68BCFE23A5666^0'
'-F284CD5BEE6668^-7'
'-305141CCCCCCCC^-9'
'C19F51EB851EB8^-C'
'-2E033333333334^-D'
'2353D70A3D70A4^-D'
'-15EBD70A3D70A4^-D'
'C20F5C28F5C29^-E'
'-13F1999999999A^-D'
'D9DBD70A3D70A^-D'
'-E7BA8F5C28F5C^-D'
'25BB3333333334^-D'
'14FCCCCCCCCCCD^-D'
'A593333333333^-D'
'-28470A3D70A3D8^-D'
'211^-D'
'-4699EB851EB85^-D'
'2592E147AE147A^-D'
'-E9CCCCCCCCCCD^-E'
'-1D4D2E147AE148^-C'
'435FFAE147AE14^-C'
'3C60D5DFC5A7^1'
'11EBCBFAA4E11A^-1'
'9300ED8^-9'
'146E8666666666^-A'
'-1A99C91EB851EC^-A'
'8AA95D1EB851E8^-A'
'3AB80333333334^-A'
'-67D4D2147AE148^-A'
'8CEEC451EB852^-A'
'4712E6147AE148^-A'
'-9578C7AE147AE^-B'
'2128D3D70A3D7^-A'
'5CF45C7AE147B^-A'
'-74706828F5C29^-A'
'3EC1DD70A3D70A^-A'
'63C1DA147AE148^-A'
'-14867947AE147B^-A'
'-1C6B49EB851EB8^-A'
'-17D85A66666666^-A'
'-229C03851EB852^-A'
'3F4692147AE148^-A'
'EB5E5012EB5F2^7'
'78^2'
'41^2'
'1^1'
END_ARRAY 2 69
BEGIN_ARRAY 3 69
'Earth PCK, ITRF93 Frame                 '
'EB5E5012EB5F2^7'
'EB5E5F12EB5F28^7'
'791C'
'1'
'2'
69
'EB5E5792EB5F2^7'
'780000004^2'
'323C07E25E5CDC^1'
'2F45F991E2147A^-6'
'-27BC1A52147AE2^-8'
'-B341333333333^-B'
'-18F33333333333^-C'
'6CEE147AE147B^-D'
'-D891EB851EB85^-D'
'C735C28F5C28F8^-D'
'-7EB33333333334^-D'
'5254F5C28F5C28^-C'
'-7264CCCCCCCCCC^-C'
'9D5EB851EB852^-D'
'F7BAE147AE1478^-D'
'3A8B3333333334^-C'
'-28275C28F5C29^-C'
'B835C28F5C28F8^-D'
'-135947AE147AE1^-C'
'C09C28F5C28F6^-D'
'-FAB3333333333^-D'
'-D4DFD70A3D70A^-C'
'1E6E3D70A3D70A^-B'
'68BCFE146E126C^0'
'-1E68A379F9851F^-6'
'-C02AD1E8^-9'
'5E12D333333334^-B'
'-36BEB851EB851E^-D'
'9B3851EB851EB8^-E'
'-2580F5C28F5C28^-D'
'4BCB3333333334^-D'
'-3E447AE147AE14^-D'
'795B851EB851EC^-D'
'-1027428F5C28F6^-C'
'CB428F5C28F5C^-E'
'5280F5C28F5C28^-D'
'65A23D70A3D70C^-D'
'-5D66B851EB852^-D'
'15AF5C28F5C28F^-D'
'-24F851EB851EB8^-D'
'2873D70A3D70A4^-D'
'-2F7051EB851EB8^-D'
'-1BC98A3D70A3D7^-C'
'415CBD70A3D70C^-C'
'3C72C1ABC31548^1'
'23D797F9CD356E^-1'
'2462C21C51EB86^-8'
'87D0DF3333333^-A'
'3DAE7266666666^-A'
'-D21506B851EB88^-A'
'-324C9970A3D70A^-A'
'B08870A3D70A4^-A'
'-18AA13D70A3D71^-A'
'-A9D62947AE1478^-A'
'1A17B5C28F5C29^-A'
'66118F851EB85^-A'
'3B5BECF5C28F5C^-A'
'10CD06B851EB85^-A'
'BB91FE66666668^-A'
'57A2ED1EB851EC^-A'
'43B270A3D70A3C^-B'
'-BB87B3AE147AE^-A'
'-1704C6B851EB85^-A'
'-18FEF570A3D70A^-A'
'-4F961051EB852^-A'
'EB5E5012EB5F2^7'
'F00000008^2'
'41^2'
'1^1'
END_ARRAY 3 69
BEGIN_ARRAY 4 69
'Earth PCK, ITRF93 Frame                 '
'EB5E5B52EB5F28^7'
'EB5E62D2EB5F28^7'
'BB8'
'1'
'2'
69
'EB5E5F12EB5F28^7'
'3C^2'
'323C07E54FA002^1'
'17534E12F970A4^-6'
'-9FFDFC2B851EB8^-9'
'-166575C28F5C29^-B'
'-B9C28F5C28F5C^-D'
'2DEE147AE147AE^-D'
'-13C1999999999A^-C'
'1777851EB851EC^-C'
'-1080A3D70A3D71^-C'
'52A87AE147AE14^-C'
'-6D7DC28F5C28F4^-C'
'D0547AE147AE18^-D'
'14FAE147AE147B^-C'
'3AB9EB851EB852^-C'
'-260AE147AE147A^-C'
'717AE147AE147C^-D'
'-BC6B851EB851E8^-D'
'AB30A3D70A3D7^-D'
'-AF599999999998^-D'
'-D23547AE147AE^-C'
'1E3B8A3D70A3D7^-B'
'68BCFDF5F67A4C^0'
'-F4C3A6078B852^-7'
'-2F7D98851EB852^-9'
'BF03CCCCCCCCD^-C'
'16E^-D'
'1B61999999999A^-D'
'-5C728F5C28F5C4^-D'
'50B33333333334^-E'
'DD1EB851EB852^-F'
'8CF1EB851EB85^-D'
'-FA128F5C28F5C^-D'
'136570A3D70A3D^-D'
'212947AE147AE2^-D'
'5053D70A3D70A4^-D'
'-3B7570A3D70A3E^-D'
'2A69EB851EB852^-D'
'-19EA8F5C28F5C3^-D'
'5C16B851EB852^-D'
'3E0851EB851EB8^-D'
'-18F5F0A3D70A3D^-C'
'3D27C7AE147AE2^-C'
'3C969943BFDE66^1'
'11EBCC0187C2DF^-1'
'8DFB8AB851EB88^-9'
'53142E3D70A3D8^-A'
'-2ECB6AB851EB86^-A'
'7A2747851EB85^-A'
'-63379^-A'
'16F92D1EB851EC^-A'
'20A112B851EB86^-A'
'8844547AE147B^-B'
'4FBF75C28F5C28^-B'
'60DF163D70A3D8^-A'
'-705470A3D70A3C^-B'
'3886CE147AE148^-A'
'2CCF607AE147AE^-A'
'-D8520CCCCCCCD^-B'
'7A32CD1EB851EC^-A'
'-6A67A6B851EB84^-A'
'-124114^-A'
'9A73A75C28F5C^-A'
'-260D2B851EB852^-B'
'EB5E5B52EB5F28^7'
'78^2'
'41^2'
'1^1'
END_ARRAY 4 69
TOTAL_ARRAYS 4
 ~NAIF/SPC BEGIN COMMENTS~
 ~NAIF/SPC END COMMENTS~
EndBlock

      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }

    if ( $file eq "brief_pck_2.xpc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_ek.xes" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";

      print OUTPUT <<EndBlock;
DASETF NAIF DAS ENCODED TRANSFER FILE
'DAS/EK  '
'DSK type 3 test kernel                                      '
'0'
'0'
'0'
'0'
'0'
'D3'
'E'
BEGIN_DP_BLOCK 1 211
'270F^4'
'1^1'
'0^0'
'1^1'
'3^1'
'-3243F6A8885A3^1'
'3243F6A8885A3^1'
'-1921FB54442D18^1'
'1921FB54442D18^1'
'F4391FE8EF202^0'
'11D8C7E110394F^1'
'11D8C7E110394F^1'
'10787CBE7AAFCD^1'
'FA637FD3B151E8^0'
'F43929306B6B7^0'
'F4392A2EBCCD3^0'
'FA6382EF125AA^0'
'10787D18BFABFB^1'
'FFD06592B414B8^0'
'FB2A532519DC8^0'
'FCCBCF7AF7C888^0'
'FCCBCEC080AAD8^0'
'FB2A4A5280EBB^0'
'FFD0543D629DA^0'
'10787C1D7EC0B8^1'
'FA63764A8AA74^0'
'F4391FE8EF2038^0'
'F43920ECABE3F^0'
'FA637976DEB9E^0'
'10787C79B02F8C^1'
'11D8C7C5EB1E6C^1'
'11D8C7DDE25211^1'
'10787CB66C1561^1'
'FA637F14EB541^0'
'F43928389DA22^0'
'F43928FAB9C4F^0'
'FA638173FF72A^0'
'10787CFB522D64^1'
'FFD068B59BA028^0'
'FB2A5C9CBB54D^0'
'FCCBDF5CDA8C68^0'
'FCCBE049D1FB58^0'
'FB2A5B34F62F28^0'
'FFD064E1B7EE2^0'
'10787CBEABBCCB^1'
'FA637E66BB327^0'
'F439267FEABE1^0'
'F4392639E51D3^0'
'FA637D8BBCCEA8^0'
'10787CA5D11521^1'
'11D8C7D754E01B^1'
'11D8C7DC7D51AA^1'
'10787CB2E35DAE^1'
'FA637EC13D92^0'
'F43927CBEBFBA^0'
'F43928739F6C7^0'
'FA6380CDB99EE^0'
'10787CEE69C4C8^1'
'FFD067606A9D68^0'
'FB2A5B4290AA68^0'
'FCCBDDF552F738^0'
'FCCBDDF552F738^0'
'FB2A5B4290AA78^0'
'FFD067606A9D78^0'
'10787CEE69C4C8^1'
'FA6380CDB99EE^0'
'F43928739F6C88^0'
'F43927CBEBFBA8^0'
'FA637EC13D92^0'
'10787CB2E35DAD^1'
'11D8C7DC7D51A9^1'
'11D8C7D754E01B^1'
'10787CA5D1152^1'
'FA637D8BBCCEA8^0'
'F4392639E51D2^0'
'F439267FEABE08^0'
'FA637E66BB328^0'
'10787CBEABBCC9^1'
'FFD064E1B7EE2^0'
'FB2A5B34F62F38^0'
'FCCBE049D1FB48^0'
'FCCBDF5CDA8C78^0'
'FB2A5C9CBB54B8^0'
'FFD068B59BA028^0'
'10787CFB522D65^1'
'FA638173FF72A8^0'
'F43928FAB9C4E^0'
'F43928389DA22^0'
'FA637F14EB541^0'
'10787CB66C156^1'
'11D8C7DDE25212^1'
'11D8C7C5EB1E6C^1'
'10787C79B02F8D^1'
'FA637976DEB9E^0'
'F43920ECABE3E^0'
'F4391FE8EF202^0'
'FA63764A8AA75^0'
'10787C1D7EC0B8^1'
'FFD0543D629DA8^0'
'FB2A4A5280EBC^0'
'FCCBCEC080AAE8^0'
'FCCBCF7AF7C88^0'
'FB2A532519DC8^0'
'FFD06592B414B^0'
'10787D18BFABFB^1'
'FA6382EF125AA^0'
'F4392A2EBCCD3^0'
'F43929306B6B7^0'
'FA637FD3B151D^0'
'10787CBE7AAFCC^1'
'11D8C7E110394F^1'
'11D8C7C5EB1E6C^1'
'10787C79B02F8C^1'
'FA637976DEB9E^0'
'F43920ECABE3E^0'
'F4391FE8EF202^0'
'FA63764A8AA75^0'
'10787C1D7EC0B8^1'
'FFD0543D629DA8^0'
'FB2A4A5280EBC^0'
'FCCBCEC080AAE8^0'
'FCCBCF7AF7C88^0'
'FB2A532519DC8^0'
'FFD06592B414B^0'
'10787D18BFABFB^1'
'FA6382EF125AB^0'
'F4392A2EBCCD3^0'
'F43929306B6B7^0'
'FA637FD3B151D^0'
'10787CBE7AAFCC^1'
'11D8C7E110394F^1'
'11D8C7D754E01B^1'
'10787CA5D1152^1'
'FA637D8BBCCEA8^0'
'F4392639E51D2^0'
'F439267FEABE08^0'
'FA637E66BB328^0'
'10787CBEABBCC9^1'
'FFD064E1B7EE2^0'
'FB2A5B34F62F38^0'
'FCCBE049D1FB58^0'
'FCCBDF5CDA8C78^0'
'FB2A5C9CBB54B8^0'
'FFD068B59BA028^0'
'10787CFB522D65^1'
'FA638173FF72A8^0'
'F43928FAB9C4D^0'
'F43928389DA22^0'
'FA637F14EB541^0'
'10787CB66C156^1'
'11D8C7DDE25212^1'
'11D8C7DC7D51A9^1'
'10787CB2E35DAE^1'
'FA637EC13D92^0'
'F43927CBEBFBA8^0'
'F43928739F6C7^0'
'FA6380CDB99EE^0'
'10787CEE69C4C8^1'
'FFD067606A9D68^0'
'FB2A5B4290AA68^0'
'FCCBDDF552F738^0'
'FCCBDDF552F738^0'
'FB2A5B4290AA78^0'
'FFD067606A9D78^0'
'10787CEE69C4C8^1'
'FA6380CDB99EE^0'
'F43928739F6C7^0'
'F43927CBEBFBA^0'
'FA637EC13D92^0'
'10787CB2E35DAE^1'
'11D8C7DC7D51AA^1'
'11D8C7DDE25212^1'
'10787CB66C156^1'
'FA637F14EB541^0'
'F43928389DA21^0'
'F43928FAB9C4F^0'
'FA638173FF72A^0'
'10787CFB522D64^1'
'FFD068B59BA028^0'
'FB2A5C9CBB54D^0'
'FCCBDF5CDA8C78^0'
'FCCBE049D1FB58^0'
'FB2A5B34F62F28^0'
'FFD064E1B7EE2^0'
'10787CBEABBCCA^1'
'FA637E66BB327^0'
'F439267FEABE1^0'
'F4392639E51D2^0'
'FA637D8BBCCEA8^0'
'10787CA5D1152^1'
'11D8C7D754E01B^1'
'11D8C7E110394F^1'
'10787CBE7AAFCD^1'
'FA637FD3B151E8^0'
'F43929306B6B7^0'
'F4392A2EBCCD3^0'
'FA6382EF125AA^0'
'10787D18BFABFA^1'
'FFD06592B414B8^0'
'FB2A532519DC7^0'
'FCCBCF7AF7C888^0'
'FCCBCEC080AAD8^0'
'FB2A4A5280EBB^0'
'FFD0543D629DA^0'
'10787C1D7EC0B7^1'
'FA63764A8AA75^0'
'F4391FE8EF2038^0'
'F43920ECABE3E^0'
'FA637976DEB9F^0'
'10787C79B02F8D^1'
'11D8C7C5EB1E6C^1'
END_DP_BLOCK 1 211
TOTAL_DP_BLOCKS 1 211
BEGIN_INTEGER_BLOCK 1 14
'F4240'
'4'
'4'
'-1'
'-1'
'B'
'3'
'0'
'D3'
'0'
'0'
'14'
'A'
'1'
END_INTEGER_BLOCK 1 14
TOTAL_INTEGER_BLOCKS 1 14
EndBlock

      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }

    if ( $file eq "brief_ek.xes" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_mk_spk.tm" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";

      print OUTPUT <<EndBlock;
KPL/MK
\\begindata
KERNELS_TO_LOAD = (
'brief_sc_1seg.bsp'
)
\\begintext
EndBlock

      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }

    if ( $file eq "brief_mk_spk.tm" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_mk_2spks.tm" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";

      print OUTPUT <<EndBlock;
KPL/MK
\\begindata
KERNELS_TO_LOAD = (
'brief_sc_3seg_gaps.bsp'
'brief_sc_bc_pl_sat_dcov1.bsp'
)
\\begintext
EndBlock

      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }

    if ( $file eq "brief_mk_2spks.tm" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_mk_spk_lsk.tm" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";

      print OUTPUT <<EndBlock;
KPL/MK
\\begindata
KERNELS_TO_LOAD = (
'brief_sc_1seg.bsp'
'naif0008.tls'
)
\\begintext
EndBlock

      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }

    if ( $file eq "brief_mk_spk_lsk.tm" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_mk_spk_pck.tm" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";

      print OUTPUT <<EndBlock;
KPL/MK
\\begindata
KERNELS_TO_LOAD = (
'brief_sc_1seg.bsp'
'brief_pck.bpc'
)
\\begintext
EndBlock

      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }

    if ( $file eq "brief_mk_spk_pck.tm" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "brief_mk_pck_lsk.tm" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";

      print OUTPUT <<EndBlock;
KPL/MK
\\begindata
KERNELS_TO_LOAD = (
'brief_pck.bpc'
'naif0008.tls'
)
\\begintext
EndBlock

      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";
    }

    if ( $file eq "brief_mk_pck_lsk.tm" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

  }

}
