#!/usr/bin/perl
# /bin/perl
# /usr/contrib/bin/perl
#
# This script tests FRMDIFF. It includes two routines: test_data and run_test.
# test_data is called once to generate all needed kernels; run_test is
# called once for each test case and reports to the screen.
#
$version = "1.1.0 -- March 30, 2009 -- BVS/NAIF";

#
# Version 1.1.0 -- March 30, 2009 -- BVS/NAIF
#
#    Updated for improved N0063 PXFORM/SXFORM error messages.
#
# Version 1.0.0 -- February 10, 2009 -- BVS/NAIF
#
#    Initial version.
#
#---------------------------------------------------------------------------
# Begin of configuration parameter section. See descriptions below.
#---------------------------------------------------------------------------

#
# For UNIX
#
$frmdiff       = "./frmdiff";
$msopck        = "./msopck";
$tobin         = "./tobin";
$maxtocompare  = "";
$shortonly     = "no";
$checkcount    = "yes";
$qt            = "'";

#
# For Windows
#
#$frmdiff       = ".\\frmdiff";
#$msopck        = ".\\msopck";
#$tobin         = ".\\tobin";
#$maxtocompare  = "77";
#$shortonly     = "yes";
#$checkcount    = "no";
#$qt            = "";

#
# For CYGWIN
#
#$frmdiff       = "frmdiff";
#$msopck        = "msopck";
#$tobin         = "tobin";
#$maxtocompare  = "";
#$shortonly     = "no";
#$checkcount    = "yes";
#$qt            = "'";

#
# Configurable parameters:
#
# $frmdiff              Executables invoked by and other files used by
# $msopck               the script.
# $tobin
#
# $reporttype           Information types that test cases should report
#                       (space delimited list including any combination
#                       of these words "command output expvalues")
#
# $maxtocompare         The number of characters of each expected value
#                       to be used in comparison. To use all characters
#                       it must be set to "".
#
# $shortonly            Flag indicating whether for failure-type cases
#                       only short error message should be checked
#                       ("yes" or "no").
#
# $checkcount           Flag indicating whether the output line count
#                       should be checked ("yes" or "no").
#
# $logname              Log file name and log file option.
# $logopt
#
# $qt                   Quote used to quote command line keys and
#                       values that cannot be specified unquoted (for
#                       example [] must be passed as '[]' to Unix
#                       shells)
#
$reporttype = " ";

$logname = "";
$logopt  = "";
#$logname = "tmp.log";
#$logopt  = "-l tmp.log ";

#---------------------------------------------------------------------------
# End of configuration parameter section.
#---------------------------------------------------------------------------

#
# These counters are global variables incremented by run_test routine. (Yuck!)
#
$counttotal = 0;
$countpass  = 0;
$countfail  = 0;

#
# Generate test report banner. Include OS name and date.
#
$seconds = time;
($sec,$min,$hours,$mday,$mon,$year,$wday,$yday) = gmtime($seconds);

print  "\n";
print  "FRMDIFF Test Suite, Version -- $version\n";
print  "\n";
printf "--- DATE: %4d-%02d-%02d %02d:%02d:%02d GMT\n",
       $year+1900, $mon+1, $mday, $hours, $min, $sec;
print  "--- OS:   $^O\n";

#
# Run FRMDIFF without command line arguments and dump its output to
# the screen to remove any ambiguity of what version is tested.
#

$result = `$frmdiff 2>&1`;
print "\n";
print "Testing the following FRMDIFF:\n";
print "\n";
print "--- $frmdiff\n";
print "\n";
print "$result";

#
# Prepare test data
#
print "\n";
print "Preparing test data ...\n";
print "\n";
&test_data( $msopck, $tobin, "make" );

#
# Run tests.
#
print "\n";
print "Executing tests ...\n";
print "\n";

#
# Tests in this block test exceptions.
#

#
# The following exceptions can be caused only by bugs in FRMDIFF and
# for this reason are not exersized. They are (module/error):
#
#    ?/?

#
# The following exceptions can be caused only by buffer overflows and
# are not covered due to impracticality of pushing the large limits set
# for buffers:
#
#    ?/?

#
# The following exceptions in conversion to decimal SCLK cannot
# be caused by FRMDIFF because it obtains SCLK string that are
# input to SC01S2D using SCE2S:
#
#    ?/?

#
# Exceptions yet to cover: command line syntax, other?
#

#
# Test exceptions first.
#
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'not a kernel as last argument',
  'failure',
  $frmdiff,
  'frmdiff_t.txt',
  14,
"SPICE(NOTAKERNELFILE2)",
"File 'frmdiff_t.txt' specified as the last argument on the command line is not",
"a SPICE kernel file.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'kernel of non-applicable type (EK) as last argument',
  'failure',
  $frmdiff,
  'frmdiff_ek.bes',
  15,
"SPICE(NONAPPLICABLETYPE2)",
"File 'frmdiff_ek.bes' specified as the last argument on the command line is not",
"one of the kernel types that can be given as the last or second to last",
"argument to this program. This file's architecture/type were 'DAS/EK'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'transfer file as last argument',
  'failure',
  $frmdiff,
  'frmdiff_pck_cov1_id1.xpc',
  15,
"SPICE(NONAPPLICABLETYPE2)",
"File 'frmdiff_pck_cov1_id1.xpc' specified as the last argument on the command",
"line is not one of the kernel types that can be given as the last or second to",
"last argument to this program. This file's architecture/type were 'XFR/DAF'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'text kernel without KPL as last argument',
  'failure',
  $frmdiff,
  'frmdiff_fk_no_kpl.tf',
  14,
"SPICE(NOTAKERNELFILE2)",
"File 'frmdiff_fk_no_kpl.tf' specified as the last argument on the command line",
"is not a SPICE kernel file.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'not a kernel as second to last argument',
  'failure',
  $frmdiff,
  'frmdiff_t.txt frmdiff_ck_cov1_id1.bc',
  14,
"SPICE(NOTAKERNELFILE1)",
"File 'frmdiff_t.txt' specified as the second to last argument on the command",
"line is not a SPICE kernel file.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'kernel of non-applicable type (EK) as second to last argument',
  'failure',
  $frmdiff,
  'frmdiff_ek.bes frmdiff_ck_cov1_id1.bc',
  15,
"SPICE(NONAPPLICABLETYPE1)",
"File 'frmdiff_ek.bes' specified as the second to last argument on the command",
"line is not one of the kernel types that can be given as the last or second to",
"last argument to this program. This file's architecture/type were 'DAS/EK'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'transfer file as second to last argument',
  'failure',
  $frmdiff,
  'frmdiff_pck_cov1_id1.xpc frmdiff_ck_cov1_id1.bc',
  16,
"SPICE(NONAPPLICABLETYPE1)",
"File 'frmdiff_pck_cov1_id1.xpc' specified as the second to last argument on the",
"command line is not one of the kernel types that can be given as the last or",
"second to last argument to this program. This file's architecture/type were",
"'XFR/DAF'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'text kernel without KPL as second to last argument',
  'failure',
  $frmdiff,
  'frmdiff_fk_no_kpl.tf frmdiff_ck_cov1_id1.bc',
  14,
"SPICE(NOTAKERNELFILE1)",
"File 'frmdiff_fk_no_kpl.tf' specified as the second to last argument on the",
"command line is not a SPICE kernel file.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'no kernels following -k',
  'failure',
  $frmdiff,
  '-k',
  14,
"SPICE(MISSINGFILENAMES3)",
"Although '-k' key was provided on the command line no kernel file names were",
"following it.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'no kernels following -k1',
  'failure',
  $frmdiff,
  '-k1',
  14,
"SPICE(MISSINGFILENAMES1)",
"Although '-k1' key was provided on the command line no kernel file names were",
"following it.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'no kernels following -k2',
  'failure',
  $frmdiff,
  '-k2',
  14,
"SPICE(MISSINGFILENAMES2)",
"Although '-k2' key was provided on the command line no kernel file names were",
"following it.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'non existing kernels following -k',
  'failure',
  $frmdiff,
  '-k boo',
  13,
"SPICE(FILEDOESNTEXIST3)",
"File 'boo' listed after '-k' key does not exist.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'non existing kernels following -k1',
  'failure',
  $frmdiff,
  '-k1 boo',
  13,
"SPICE(FILEDOESNTEXIST1)",
"File 'boo' listed after '-k1' key does not exist.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'non existing kernels following -k2',
  'failure',
  $frmdiff,
  '-k2 boo',
  13,
"SPICE(FILEDOESNTEXIST2)",
"File 'boo' listed after '-k2' key does not exist.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"from" name given with -f1, cannot be resolved',
  'failure',
  $frmdiff,
  '-f1 JJ2000',
  14,
"SPICE(BADFROMFRAME1SP1)",
"'JJ2000' specified after '-f1' key is neither an integer number representing a",
"legitimate frame ID nor a frame name recognized in SPICE.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"from" id given with -f1, cannot be resolved',
  'failure',
  $frmdiff,
  '-f1 2000',
  14,
"SPICE(BADFROMFRAME1SP2)",
"'2000' specified after '-f1' key is neither an integer number representing a",
"legitimate frame ID nor a frame name recognized in SPICE.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" name given with -t1, cannot be resolved',
  'failure',
  $frmdiff,
  '-t1 JJ2000',
  14,
"SPICE(BADTOFRAME1SPEC1)",
"'JJ2000' specified after '-t1' key is neither an integer number representing a",
"legitimate frame ID nor a frame name recognized in SPICE.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t1, present in first file CK, cannot be resolved as class id or id',
  'failure',
  $frmdiff,
  '-t1 -84100 frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  14,
"SPICE(BADTOFRAME1SPEC2)",
"'-84100' specified after '-t1' key is neither an integer number representing a",
"legitimate frame ID nor a frame name recognized in SPICE.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t1, present in only file CK, cannot be resolved as class id or id',
  'failure',
  $frmdiff,
  '-t1 -84100 frmdiff_ck_cov1_id1.bc',
  14,
"SPICE(BADTOFRAME1SPEC2)",
"'-84100' specified after '-t1' key is neither an integer number representing a",
"legitimate frame ID nor a frame name recognized in SPICE.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t1, present in first file PCK, cannot be resolved as class id or id',
  'failure',
  $frmdiff,
  '-t1 3001 frmdiff_pck_unk_obj.bpc frmdiff_pck_cov1_id1.bpc',
  14,
"SPICE(BADTOFRAME1SPEC2)",
"'3001' specified after '-t1' key is neither an integer number representing a",
"legitimate frame ID nor a frame name recognized in SPICE.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t1, present in only file PCK, cannot be resolved as class id or id',
  'failure',
  $frmdiff,
  '-t1 3001 frmdiff_pck_unk_obj.bpc',
  14,
"SPICE(BADTOFRAME1SPEC2)",
"'3001' specified after '-t1' key is neither an integer number representing a",
"legitimate frame ID nor a frame name recognized in SPICE.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t1, not present in first file CK, cannot be resolved as id',
  'failure',
  $frmdiff,
  '-t1 2000 frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  14,
"SPICE(BADTOFRAME1SPEC2)",
"'2000' specified after '-t1' key is neither an integer number representing a",
"legitimate frame ID nor a frame name recognized in SPICE.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t1, not present in only file CK, cannot be resolved as id',
  'failure',
  $frmdiff,
  '-t1 2000 frmdiff_ck_cov1_id1.bc',
  14,
"SPICE(BADTOFRAME1SPEC2)",
"'2000' specified after '-t1' key is neither an integer number representing a",
"legitimate frame ID nor a frame name recognized in SPICE.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t1, not present in first file PCK, cannot be resolved as id',
  'failure',
  $frmdiff,
  '-t1 2000 frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id1.bpc',
  14,
"SPICE(BADTOFRAME1SPEC2)",
"'2000' specified after '-t1' key is neither an integer number representing a",
"legitimate frame ID nor a frame name recognized in SPICE.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t1, not present in only file PCK, cannot be resolved as id',
  'failure',
  $frmdiff,
  '-t1 2000 frmdiff_pck_cov1_id1.bpc',
  14,
"SPICE(BADTOFRAME1SPEC2)",
"'2000' specified after '-t1' key is neither an integer number representing a",
"legitimate frame ID nor a frame name recognized in SPICE.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c1, first file is not CK or PCK',
  'failure',
  $frmdiff,
  '-c1 J2000 frmdiff_lsk.tls frmdiff_lsk.tls',
  14,
"SPICE(BADCOVFRAME1SPEC1)",
"'-c1' option cannot be used in this run because the file 'frmdiff_lsk.tls' is",
"not a CK or binary PCK.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c1, only file is not CK or PCK',
  'failure',
  $frmdiff,
  '-c1 J2000 frmdiff_lsk.tls',
  14,
"SPICE(BADCOVFRAME1SPEC1)",
"'-c1' option cannot be used in this run because the file 'frmdiff_lsk.tls' is",
"not a CK or binary PCK.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c1, no files',
  'failure',
  $frmdiff,
  '-c1 J2000',
  14,
"SPICE(BADCOVFRAME1SPEC2)",
"'-c1' option cannot be used in this run because no files were specified on the",
"command line.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c1, cannot be resolved',
  'failure',
  $frmdiff,
  '-c1 JJ2000 frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  14,
"SPICE(BADCOVFRAME1SPEC4)",
"'JJ2000' specified after '-c1' key is neither an integer number representing a",
"legitimate frame ID nor a frame name recognized in SPICE.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c1, not a PCK or CK class frame',
  'failure',
  $frmdiff,
  '-c1 J2000 frmdiff_ck_cov1_id1.bc',
  15,
"SPICE(COVFRAME1MISMATCH)",
"The class of the frame 'J2000' provided after '-c1' key does not match the",
"kernel type of the file 'frmdiff_ck_cov1_id1.bc', to which the frame applies.",
"The class was '1'; the kernel architecture/type were 'DAF/CK'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c1, PCK class frame for first CK file',
  'failure',
  $frmdiff,
  '-c1 IAU_EARTH frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  15,
"SPICE(COVFRAME1MISMATCH)",
"The class of the frame 'IAU_EARTH' provided after '-c1' key does not match the",
"kernel type of the file 'frmdiff_ck_cov1_id1.bc', to which the frame applies.",
"The class was '2'; the kernel architecture/type were 'DAF/CK'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c1, PCK class frame for only CK file',
  'failure',
  $frmdiff,
  '-c1 IAU_EARTH frmdiff_ck_cov1_id1.bc',
  15,
"SPICE(COVFRAME1MISMATCH)",
"The class of the frame 'IAU_EARTH' provided after '-c1' key does not match the",
"kernel type of the file 'frmdiff_ck_cov1_id1.bc', to which the frame applies.",
"The class was '2'; the kernel architecture/type were 'DAF/CK'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c1, CK class frame for first PCK file',
  'failure',
  $frmdiff,
  '-k frmdiff_fk.tf -c1 PHX_PAYLOAD frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id1.bpc',
  15,
"SPICE(COVFRAME1MISMATCH)",
"The class of the frame 'PHX_PAYLOAD' provided after '-c1' key does not match",
"the kernel type of the file 'frmdiff_pck_cov1_id1.bpc', to which the frame",
"applies. The class was '3'; the kernel architecture/type were 'DAF/PCK'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c1, CK class frame for only PCK file',
  'failure',
  $frmdiff,
  '-k frmdiff_fk.tf -c1 PHX_PAYLOAD frmdiff_pck_cov1_id1.bpc',
  15,
"SPICE(COVFRAME1MISMATCH)",
"The class of the frame 'PHX_PAYLOAD' provided after '-c1' key does not match",
"the kernel type of the file 'frmdiff_pck_cov1_id1.bpc', to which the frame",
"applies. The class was '3'; the kernel architecture/type were 'DAF/PCK'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c1, CK class frame, not present in first CK file',
  'failure',
  $frmdiff,
  '-k frmdiff_fk.tf -c1 PHX_LANDER frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  14,
"SPICE(COVFRAME1NODATA1)",
"The file 'frmdiff_ck_cov1_id1.bc' does not contain any data for the frame",
"'PHX_LANDER' (frame class ID '-84001') specified after '-c1' key.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c1, CK class frame, not present in only CK file',
  'failure',
  $frmdiff,
  '-k frmdiff_fk.tf -c1 PHX_LANDER frmdiff_ck_cov1_id1.bc',
  14,
"SPICE(COVFRAME1NODATA1)",
"The file 'frmdiff_ck_cov1_id1.bc' does not contain any data for the frame",
"'PHX_LANDER' (frame class ID '-84001') specified after '-c1' key.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c1, PCK class frame, not present in first PCK file',
  'failure',
  $frmdiff,
  '-c1 IAU_EARTH frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id1.bpc',
  14,
"SPICE(COVFRAME1NODATA1)",
"The file 'frmdiff_pck_cov1_id1.bpc' does not contain any data for the frame",
"'IAU_EARTH' (frame class ID '399') specified after '-c1' key.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c1, PCK class frame, not present in only PCK file',
  'failure',
  $frmdiff,
  '-c1 IAU_EARTH frmdiff_pck_cov1_id1.bpc',
  14,
"SPICE(COVFRAME1NODATA1)",
"The file 'frmdiff_pck_cov1_id1.bpc' does not contain any data for the frame",
"'IAU_EARTH' (frame class ID '399') specified after '-c1' key.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" frame id given with -c1, first file is not CK or PCK',
  'failure',
  $frmdiff,
  '-c1 1 frmdiff_lsk.tls frmdiff_lsk.tls',
  14,
"SPICE(BADCOVFRAME1SPEC1)",
"'-c1' option cannot be used in this run because the file 'frmdiff_lsk.tls' is",
"not a CK or binary PCK.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" frame id given with -c1, only file is not CK or PCK',
  'failure',
  $frmdiff,
  '-c1 1 frmdiff_lsk.tls',
  14,
"SPICE(BADCOVFRAME1SPEC1)",
"'-c1' option cannot be used in this run because the file 'frmdiff_lsk.tls' is",
"not a CK or binary PCK.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" frame id given with -c1, no files',
  'failure',
  $frmdiff,
  '-c1 1',
  14,
"SPICE(BADCOVFRAME1SPEC2)",
"'-c1' option cannot be used in this run because no files were specified on the",
"command line.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" is given with -c1, id not present in first CK file',
  'failure',
  $frmdiff,
  '-c1 -84101 frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  14,
"SPICE(COVFRAME1NODATA2)",
"The file 'frmdiff_ck_cov1_id1.bc' does not contain any data for the ID '-84101'",
"specified after '-c1' key.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" is given with -c1, id not present in only CK file',
  'failure',
  $frmdiff,
  '-c1 -84101 frmdiff_ck_cov1_id1.bc',
  14,
"SPICE(COVFRAME1NODATA2)",
"The file 'frmdiff_ck_cov1_id1.bc' does not contain any data for the ID '-84101'",
"specified after '-c1' key.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" is given with -c1, id not present in first PCK file',
  'failure',
  $frmdiff,
  '-c1 31005 frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id1.bpc',
  14,
"SPICE(COVFRAME1NODATA2)",
"The file 'frmdiff_pck_cov1_id1.bpc' does not contain any data for the ID",
"'31005' specified after '-c1' key.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" is given with -c1, id not present in only PCK file',
  'failure',
  $frmdiff,
  '-c1 31005 frmdiff_pck_cov1_id1.bpc',
  14,
"SPICE(COVFRAME1NODATA2)",
"The file 'frmdiff_pck_cov1_id1.bpc' does not contain any data for the ID",
"'31005' specified after '-c1' key.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"from" name given with -f1, cannot be resolved using kernels from -k2',
  'failure',
  $frmdiff,
  '-k2 frmdiff_fk.tf -f1 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  14,
"SPICE(BADFROMFRAME1SP1)",
"'PHX_PAYLOAD' specified after '-f1' key is neither an integer number",
"representing a legitimate frame ID nor a frame name recognized in SPICE.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" name given with -t1, cannot be resolved using kernels from -k2',
  'failure',
  $frmdiff,
  '-k2 frmdiff_fk.tf -t1 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  14,
"SPICE(BADTOFRAME1SPEC1)",
"'PHX_PAYLOAD' specified after '-t1' key is neither an integer number",
"representing a legitimate frame ID nor a frame name recognized in SPICE.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c1, cannot be resolved using kernels from -k2',
  'failure',
  $frmdiff,
  '-k2 frmdiff_fk.tf -c1 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  14,
"SPICE(BADCOVFRAME1SPEC4)",
"'PHX_PAYLOAD' specified after '-c1' key is neither an integer number",
"representing a legitimate frame ID nor a frame name recognized in SPICE.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"from" name given with -f1, cannot be resolved using second file',
  'failure',
  $frmdiff,
  '-f1 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc frmdiff_fk.tf',
  14,
"SPICE(BADFROMFRAME1SP1)",
"'PHX_PAYLOAD' specified after '-f1' key is neither an integer number",
"representing a legitimate frame ID nor a frame name recognized in SPICE.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" name given with -t1, cannot be resolved using second file',
  'failure',
  $frmdiff,
  '-t1 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc frmdiff_fk.tf',
  14,
"SPICE(BADTOFRAME1SPEC1)",
"'PHX_PAYLOAD' specified after '-t1' key is neither an integer number",
"representing a legitimate frame ID nor a frame name recognized in SPICE.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c1, cannot be resolved using second file',
  'failure',
  $frmdiff,
  '-c1 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc frmdiff_fk.tf',
  14,
"SPICE(BADCOVFRAME1SPEC4)",
"'PHX_PAYLOAD' specified after '-c1' key is neither an integer number",
"representing a legitimate frame ID nor a frame name recognized in SPICE.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"from" name given with -f2, cannot be resolved',
  'failure',
  $frmdiff,
  '-f2 JJ2000',
  14,
"SPICE(BADFROMFRAME2SP1)",
"'JJ2000' specified after '-f2' key is neither an integer number representing a",
"legitimate frame ID nor a frame name recognized in SPICE.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"from" id given with -f2, cannot be resolved',
  'failure',
  $frmdiff,
  '-f2 2000',
  14,
"SPICE(BADFROMFRAME2SP2)",
"'2000' specified after '-f2' key is neither an integer number representing a",
"legitimate frame ID nor a frame name recognized in SPICE.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" name given with -t2, cannot be resolved',
  'failure',
  $frmdiff,
  '-t2 JJ2000',
  14,
"SPICE(BADTOFRAME2SPEC1)",
"'JJ2000' specified after '-t2' key is neither an integer number representing a",
"legitimate frame ID nor a frame name recognized in SPICE.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t2, present in second file CK, cannot be resolved as class id or id',
  'failure',
  $frmdiff,
  '-t2 -84100 frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  14,
"SPICE(BADTOFRAME2SPEC2)",
"'-84100' specified after '-t2' key is neither an integer number representing a",
"legitimate frame ID nor a frame name recognized in SPICE.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t2, present in only file CK, cannot be resolved as class id or id',
  'failure',
  $frmdiff,
  '-t2 -84100 frmdiff_ck_cov1_id1.bc',
  14,
"SPICE(BADTOFRAME2SPEC2)",
"'-84100' specified after '-t2' key is neither an integer number representing a",
"legitimate frame ID nor a frame name recognized in SPICE.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t2, present in second file PCK, cannot be resolved as class id or id',
  'failure',
  $frmdiff,
  '-t2 3001 frmdiff_pck_cov1_id1.bpc frmdiff_pck_unk_obj.bpc',
  14,
"SPICE(BADTOFRAME2SPEC2)",
"'3001' specified after '-t2' key is neither an integer number representing a",
"legitimate frame ID nor a frame name recognized in SPICE.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t2, present in only file PCK, cannot be resolved as class id or id',
  'failure',
  $frmdiff,
  '-t2 3001 frmdiff_pck_unk_obj.bpc',
  14,
"SPICE(BADTOFRAME2SPEC2)",
"'3001' specified after '-t2' key is neither an integer number representing a",
"legitimate frame ID nor a frame name recognized in SPICE.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t2, not present in second file CK, cannot be resolved as id',
  'failure',
  $frmdiff,
  '-t2 2000 frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  14,
"SPICE(BADTOFRAME2SPEC2)",
"'2000' specified after '-t2' key is neither an integer number representing a",
"legitimate frame ID nor a frame name recognized in SPICE.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t2, not present in only file CK, cannot be resolved as id',
  'failure',
  $frmdiff,
  '-t2 2000 frmdiff_ck_cov1_id1.bc',
  14,
"SPICE(BADTOFRAME2SPEC2)",
"'2000' specified after '-t2' key is neither an integer number representing a",
"legitimate frame ID nor a frame name recognized in SPICE.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t2, not present in second file PCK, cannot be resolved as id',
  'failure',
  $frmdiff,
  '-t2 2000 frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id1.bpc',
  14,
"SPICE(BADTOFRAME2SPEC2)",
"'2000' specified after '-t2' key is neither an integer number representing a",
"legitimate frame ID nor a frame name recognized in SPICE.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t2, not present in only file PCK, cannot be resolved as id',
  'failure',
  $frmdiff,
  '-t2 2000 frmdiff_pck_cov1_id1.bpc',
  14,
"SPICE(BADTOFRAME2SPEC2)",
"'2000' specified after '-t2' key is neither an integer number representing a",
"legitimate frame ID nor a frame name recognized in SPICE.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c2, second file is not CK or PCK',
  'failure',
  $frmdiff,
  '-c2 J2000 frmdiff_lsk.tls frmdiff_lsk.tls',
  14,
"SPICE(BADCOVFRAME2SPEC1)",
"'-c2' option cannot be used in this run because the file 'frmdiff_lsk.tls' is",
"not a CK or binary PCK.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c2, only file is not CK or PCK',
  'failure',
  $frmdiff,
  '-c2 J2000 frmdiff_lsk.tls',
  14,
"SPICE(BADCOVFRAME2SPEC1)",
"'-c2' option cannot be used in this run because the file 'frmdiff_lsk.tls' is",
"not a CK or binary PCK.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c2, no files',
  'failure',
  $frmdiff,
  '-c2 J2000',
  14,
"SPICE(BADCOVFRAME2SPEC2)",
"'-c2' option cannot be used in this run because no files were specified on the",
"command line.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c2, cannot be resolved',
  'failure',
  $frmdiff,
  '-c2 JJ2000 frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  14,
"SPICE(BADCOVFRAME2SPEC4)",
"'JJ2000' specified after '-c2' key is neither an integer number representing a",
"legitimate frame ID nor a frame name recognized in SPICE.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c2, not a PCK or CK class frame',
  'failure',
  $frmdiff,
  '-c2 J2000 frmdiff_ck_cov1_id1.bc',
  15,
"SPICE(COVFRAME2MISMATCH)",
"The class of the frame 'J2000' provided after '-c2' key does not match the",
"kernel type of the file 'frmdiff_ck_cov1_id1.bc', to which the frame applies.",
"The class was '1'; the kernel architecture/type were 'DAF/CK'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c2, PCK class frame for second CK file',
  'failure',
  $frmdiff,
  '-c2 IAU_EARTH frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  15,
"SPICE(COVFRAME2MISMATCH)",
"The class of the frame 'IAU_EARTH' provided after '-c2' key does not match the",
"kernel type of the file 'frmdiff_ck_cov1_id1.bc', to which the frame applies.",
"The class was '2'; the kernel architecture/type were 'DAF/CK'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c2, PCK class frame for only CK file',
  'failure',
  $frmdiff,
  '-c2 IAU_EARTH frmdiff_ck_cov1_id1.bc',
  15,
"SPICE(COVFRAME2MISMATCH)",
"The class of the frame 'IAU_EARTH' provided after '-c2' key does not match the",
"kernel type of the file 'frmdiff_ck_cov1_id1.bc', to which the frame applies.",
"The class was '2'; the kernel architecture/type were 'DAF/CK'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c2, CK class frame for second PCK file',
  'failure',
  $frmdiff,
  '-k frmdiff_fk.tf -c2 PHX_PAYLOAD frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id1.bpc',
  15,
"SPICE(COVFRAME2MISMATCH)",
"The class of the frame 'PHX_PAYLOAD' provided after '-c2' key does not match",
"the kernel type of the file 'frmdiff_pck_cov1_id1.bpc', to which the frame",
"applies. The class was '3'; the kernel architecture/type were 'DAF/PCK'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c2, CK class frame for only PCK file',
  'failure',
  $frmdiff,
  '-k frmdiff_fk.tf -c2 PHX_PAYLOAD frmdiff_pck_cov1_id1.bpc',
  15,
"SPICE(COVFRAME2MISMATCH)",
"The class of the frame 'PHX_PAYLOAD' provided after '-c2' key does not match",
"the kernel type of the file 'frmdiff_pck_cov1_id1.bpc', to which the frame",
"applies. The class was '3'; the kernel architecture/type were 'DAF/PCK'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c2, CK class frame, not present in second CK file',
  'failure',
  $frmdiff,
  '-k frmdiff_fk.tf -c2 PHX_LANDER frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  14,
"SPICE(COVFRAME2NODATA1)",
"The file 'frmdiff_ck_cov1_id1.bc' does not contain any data for the frame",
"'PHX_LANDER' (frame class ID '-84001') specified after '-c2' key.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c2, CK class frame, not present in only CK file',
  'failure',
  $frmdiff,
  '-k frmdiff_fk.tf -c2 PHX_LANDER frmdiff_ck_cov1_id1.bc',
  14,
"SPICE(COVFRAME2NODATA1)",
"The file 'frmdiff_ck_cov1_id1.bc' does not contain any data for the frame",
"'PHX_LANDER' (frame class ID '-84001') specified after '-c2' key.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c2, PCK class frame, not present in second PCK file',
  'failure',
  $frmdiff,
  '-c2 IAU_EARTH frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id1.bpc',
  14,
"SPICE(COVFRAME2NODATA1)",
"The file 'frmdiff_pck_cov1_id1.bpc' does not contain any data for the frame",
"'IAU_EARTH' (frame class ID '399') specified after '-c2' key.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c2, PCK class frame, not present in only PCK file',
  'failure',
  $frmdiff,
  '-c2 IAU_EARTH frmdiff_pck_cov1_id1.bpc',
  14,
"SPICE(COVFRAME2NODATA1)",
"The file 'frmdiff_pck_cov1_id1.bpc' does not contain any data for the frame",
"'IAU_EARTH' (frame class ID '399') specified after '-c2' key.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" frame id given with -c2, second file is not CK or PCK',
  'failure',
  $frmdiff,
  '-c2 1 frmdiff_lsk.tls frmdiff_lsk.tls',
  14,
"SPICE(BADCOVFRAME2SPEC1)",
"'-c2' option cannot be used in this run because the file 'frmdiff_lsk.tls' is",
"not a CK or binary PCK.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" frame id given with -c2, only file is not CK or PCK',
  'failure',
  $frmdiff,
  '-c2 1 frmdiff_lsk.tls',
  14,
"SPICE(BADCOVFRAME2SPEC1)",
"'-c2' option cannot be used in this run because the file 'frmdiff_lsk.tls' is",
"not a CK or binary PCK.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" frame id given with -c2, no files',
  'failure',
  $frmdiff,
  '-c2 1',
  14,
"SPICE(BADCOVFRAME2SPEC2)",
"'-c2' option cannot be used in this run because no files were specified on the",
"command line.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" is given with -c2, id not present in second CK file',
  'failure',
  $frmdiff,
  '-c2 -84101 frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  14,
"SPICE(COVFRAME2NODATA2)",
"The file 'frmdiff_ck_cov1_id1.bc' does not contain any data for the ID '-84101'",
"specified after '-c2' key.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" is given with -c2, id not present in only CK file',
  'failure',
  $frmdiff,
  '-c2 -84101 frmdiff_ck_cov1_id1.bc',
  14,
"SPICE(COVFRAME2NODATA2)",
"The file 'frmdiff_ck_cov1_id1.bc' does not contain any data for the ID '-84101'",
"specified after '-c2' key.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" is given with -c2, id not present in second PCK file',
  'failure',
  $frmdiff,
  '-c2 31005 frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id1.bpc',
  14,
"SPICE(COVFRAME2NODATA2)",
"The file 'frmdiff_pck_cov1_id1.bpc' does not contain any data for the ID",
"'31005' specified after '-c2' key.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" is given with -c2, id not present in only PCK file',
  'failure',
  $frmdiff,
  '-c2 31005 frmdiff_pck_cov1_id1.bpc',
  14,
"SPICE(COVFRAME2NODATA2)",
"The file 'frmdiff_pck_cov1_id1.bpc' does not contain any data for the ID",
"'31005' specified after '-c2' key.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"from" name given with -f2, cannot be resolved using kernels from -k1',
  'failure',
  $frmdiff,
  '-k1 frmdiff_fk.tf -f2 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  14,
"SPICE(BADFROMFRAME2SP1)",
"'PHX_PAYLOAD' specified after '-f2' key is neither an integer number",
"representing a legitimate frame ID nor a frame name recognized in SPICE.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" name given with -t2, cannot be resolved using kernels from -k1',
  'failure',
  $frmdiff,
  '-k1 frmdiff_fk.tf -t2 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  14,
"SPICE(BADTOFRAME2SPEC1)",
"'PHX_PAYLOAD' specified after '-t2' key is neither an integer number",
"representing a legitimate frame ID nor a frame name recognized in SPICE.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c2, cannot be resolved using kernels from -k1',
  'failure',
  $frmdiff,
  '-k1 frmdiff_fk.tf -c2 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  14,
"SPICE(BADCOVFRAME2SPEC4)",
"'PHX_PAYLOAD' specified after '-c2' key is neither an integer number",
"representing a legitimate frame ID nor a frame name recognized in SPICE.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"from" name given with -f2, cannot be resolved using first file',
  'failure',
  $frmdiff,
  '-f2 PHX_PAYLOAD frmdiff_fk.tf frmdiff_ck_cov1_id1.bc',
  14,
"SPICE(BADFROMFRAME2SP1)",
"'PHX_PAYLOAD' specified after '-f2' key is neither an integer number",
"representing a legitimate frame ID nor a frame name recognized in SPICE.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" name given with -t2, cannot be resolved using first file',
  'failure',
  $frmdiff,
  '-t2 PHX_PAYLOAD frmdiff_fk.tf frmdiff_ck_cov1_id1.bc',
  14,
"SPICE(BADTOFRAME2SPEC1)",
"'PHX_PAYLOAD' specified after '-t2' key is neither an integer number",
"representing a legitimate frame ID nor a frame name recognized in SPICE.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c2, cannot be resolved using first file',
  'failure',
  $frmdiff,
  '-c2 PHX_PAYLOAD frmdiff_fk.tf frmdiff_ck_cov1_id1.bc',
  14,
"SPICE(BADCOVFRAME2SPEC4)",
"'PHX_PAYLOAD' specified after '-c2' key is neither an integer number",
"representing a legitimate frame ID nor a frame name recognized in SPICE.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-a with unrecognized value',
  'failure',
  $frmdiff,
  '-a boo',
  14,
"SPICE(BADAVFLAG)",
"Angular velocity comparison flag 'boo' specified after '-a' key is not",
"recognized. Recognized values are 'yes' and 'no'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-a with no value',
  'failure',
  $frmdiff,
  '-a frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  14,
"SPICE(BADAVFLAG)",
"Angular velocity comparison flag ' ' specified after '-a' key is not",
"recognized. Recognized values are 'yes' and 'no'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-m with unrecognized value',
  'failure',
  $frmdiff,
  '-m boo',
  14,
"SPICE(BADAVFRAMEFLAG)",
"Angular velocity frame flag 'boo' specified after '-m' key is not recognized.",
"Recognized values are 'from' and 'to'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-m with no value',
  'failure',
  $frmdiff,
  '-m frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  14,
"SPICE(BADAVFRAMEFLAG)",
"Angular velocity frame flag ' ' specified after '-m' key is not recognized.",
"Recognized values are 'from' and 'to'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-a with "yes", first CK without AVs',
  'failure',
  $frmdiff,
  '-n 1 -k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_pck.tpc frmdiff_fk.tf -a yes frmdiff_ck_cov1_id1_no_av.bc frmdiff_ck_cov1_id1.bc',
  15,
"SPICE(NOTIMEBOUNDS4)",
"Cannot determine time range for comparison because CK file",
"'frmdiff_ck_cov1_id1_no_av.bc' does not provide any roundoff-adjusted coverage",
"for the CK frame with class ID '-84100'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-a with "yes", second CK without AVs',
  'failure',
  $frmdiff,
  '-n 1 -k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_pck.tpc frmdiff_fk.tf -a yes frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1_no_av.bc',
  15,
"SPICE(NOTIMEBOUNDS6)",
"Cannot determine time range for comparison because CK file",
"'frmdiff_ck_cov1_id1_no_av.bc' does not provide any roundoff-adjusted coverage",
"for the CK frame with class ID '-84100'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-a with "yes", only CK without AVs',
  'failure',
  $frmdiff,
  '-n 1 -k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_pck.tpc frmdiff_fk.tf -a yes frmdiff_ck_cov1_id1_no_av.bc',
  15,
"SPICE(NOTIMEBOUNDS4)",
"Cannot determine time range for comparison because CK file",
"'frmdiff_ck_cov1_id1_no_av.bc' does not provide any roundoff-adjusted coverage",
"for the CK frame with class ID '-84100'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-a with "yes", CK provided with -k without AVs',
  'failure',
  $frmdiff,
  '-n 1 -k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_pck.tpc frmdiff_fk.tf frmdiff_ck_cov1_id1_no_av.bc -a yes -f1 J2000 frmdiff_ck_cov1_id2.bc frmdiff_ck_cov1_id2.bc',
  27,
"SPICE(NOTENOUGHDATA0)",
"The attitude must be computable using the first kernel 'frmdiff_ck_cov1_id2.bc'",
"and supporting kernels 'frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_pck.tpc",
"frmdiff_fk.tf frmdiff_ck_cov1_id1_no_av.bc' provided after the keys '-k' and",
"'-k1'. State (6x6) transformation from 'J2000' frame to 'PHX_LANDER' frame",
"could not be computed at ET 2.5000000000000E+08. SXFORM error was: At epoch",
"2.5000000000000E+08 TDB (2007 DEC 04 00:26:40.000 TDB), there is insufficient",
"information available to transform from reference frame 1 (J2000) to reference",
"frame -84001 (PHX_LANDER). Frame PHX_LANDER could be transformed to frame",
"-84100 (PHX_PAYLOAD). The latter is a CK frame; a CK file containing data for",
"instrument or structure -84100 at the epoch shown above, as well as a",
"corresponding SCLK kernel, must be loaded in order to use this frame. Failure",
"to find required CK data could be due to one or more CK files not having been",
"loaded, or to the epoch shown above lying within a coverage gap or beyond the",
"coverage bounds of the loaded CK files. You can use CKBRIEF with the -dump",
"option to display coverage intervals of a CK file.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-a with "yes", CK provided with -k1 without AVs',
  'failure',
  $frmdiff,
  '-n 1 -k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_pck.tpc frmdiff_fk.tf -k2 frmdiff_ck_cov1_id1.bc -k1 frmdiff_ck_cov1_id1_no_av.bc -a yes -f1 J2000 frmdiff_ck_cov1_id2.bc frmdiff_ck_cov1_id2.bc',
  24,
"SPICE(NOTENOUGHDATA1)",
"The first attitude to be compared must be computable using the first kernel",
"'frmdiff_ck_cov1_id2.bc' and supporting kernels 'frmdiff_lsk.tls",
"frmdiff_sclk.tsc frmdiff_pck.tpc frmdiff_fk.tf frmdiff_ck_cov1_id1_no_av.bc'",
"provided after the keys '-k' and '-k1'. State (6x6) transformation from 'J2000'",
"frame to 'PHX_LANDER' frame could not be computed at ET 2.5000000000000E+08.",
"SXFORM error was: At epoch 2.5000000000000E+08 TDB (2007 DEC 04 00:26:40.000",
"TDB), there is insufficient information available to transform from reference",
"frame 1 (J2000) to reference frame -84001 (PHX_LANDER). Frame PHX_LANDER could",
"be transformed to frame -84100 (PHX_PAYLOAD). The latter is a CK frame; a CK",
"file containing data for instrument or structure -84100 at the epoch shown",
"above, as well as a corresponding SCLK kernel, must be loaded in order to use",
"this frame. Failure to find required C",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-a with "yes", CK provided with -k2 without AVs',
  'failure',
  $frmdiff,
  '-n 1 -k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_pck.tpc frmdiff_fk.tf -k1 frmdiff_ck_cov1_id1.bc -k2 frmdiff_ck_cov1_id1_no_av.bc -a yes -f1 J2000 frmdiff_ck_cov1_id2.bc frmdiff_ck_cov1_id2.bc',
  24,
"SPICE(NOTENOUGHDATA2)",
"The second attitude to be compared must be computable using the second kernel",
"'frmdiff_ck_cov1_id2.bc' and supporting kernels 'frmdiff_lsk.tls",
"frmdiff_sclk.tsc frmdiff_pck.tpc frmdiff_fk.tf frmdiff_ck_cov1_id1_no_av.bc'",
"provided after the keys '-k' and '-k2'. State (6x6) transformation from 'J2000'",
"frame to 'PHX_LANDER' frame could not be computed at ET 2.5000000000000E+08.",
"SXFORM error was: At epoch 2.5000000000000E+08 TDB (2007 DEC 04 00:26:40.000",
"TDB), there is insufficient information available to transform from reference",
"frame 1 (J2000) to reference frame -84001 (PHX_LANDER). Frame PHX_LANDER could",
"be transformed to frame -84100 (PHX_PAYLOAD). The latter is a CK frame; a CK",
"file containing data for instrument or structure -84100 at the epoch shown",
"above, as well as a corresponding SCLK kernel, must be loaded in order to use",
"this frame. Failure to find required",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-b with good time string, no LSK',
  'failure',
  $frmdiff,
  '-b 2000-01-01 12:00',
  15,
"SPICE(NOLEAPSECONDS)",
"The variable that points to the leapseconds (DELTET/DELTA_AT) could not be",
"located in the kernel pool. It is likely that the leapseconds kernel has not",
"been loaded via the routine FURNSH.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML --> STR2ET --> TTRANS"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-b with bad time string',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls -b boo frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  14,
"SPICE(UNPARSEDTIME)",
"The input string contains an unrecognizable substring beginning at the",
'character marked by <b>: "<b>oo"',
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML --> STR2ET"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-b with no value',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls -b frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  13,
"SPICE(UNPARSEDTIME)",
"The input time string is blank.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML --> STR2ET"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-e with good time string, no LSK',
  'failure',
  $frmdiff,
  '-e 2000-01-01 12:00',
  15,
"SPICE(NOLEAPSECONDS)",
"The variable that points to the leapseconds (DELTET/DELTA_AT) could not be",
"located in the kernel pool. It is likely that the leapseconds kernel has not",
"been loaded via the routine FURNSH.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML --> STR2ET --> TTRANS"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-e with bad time string',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls -e boo frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  14,
"SPICE(UNPARSEDTIME)",
"The input string contains an unrecognizable substring beginning at the",
'character marked by <b>: "<b>oo"',
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML --> STR2ET"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-e with no value',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls -e frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  13,
"SPICE(UNPARSEDTIME)",
"The input time string is blank.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML --> STR2ET"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'start time greater than stop time',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls -b 2000-01-01 12:00 -e 2000-01-01 11:00',
  14,
"SPICE(INCONSISTENTTIMES)",
"Specified start time '2000-01-01 12:00' is greater than specified stop time",
"'2000-01-01 11:00'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'getting defaults for "from" frame, no files',
  'failure',
  $frmdiff,
  '-t1 J2000',
  14,
"SPICE(CANTPICKDEFAULTS1)",
"Cannot pick default values for 'from' frames because no kernels were provided",
"as the last and/or second to last item on the command line.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'getting defaults for "from" frame, first file not CK or PCK',
  'failure',
  $frmdiff,
  '-t1 J2000 frmdiff_lsk.tls frmdiff_fk.tf',
  14,
"SPICE(CANTPICKDEFAULTS2)",
"Cannot pick default values for 'from' frames from the 'frmdiff_lsk.tls' file",
"because it is not a CK or binary PCK file.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'getting defaults for "from" frame, only file not CK or PCK',
  'failure',
  $frmdiff,
  '-t1 J2000 frmdiff_fk.tf',
  14,
"SPICE(CANTPICKDEFAULTS2)",
"Cannot pick default values for 'from' frames from the 'frmdiff_fk.tf' file",
"because it is not a CK or binary PCK file.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'getting defaults for "from" frame, first file CK without segments',
  'failure',
  $frmdiff,
  '-t1 J2000 frmdiff_ck_no_seg.bc frmdiff_fk.tf',
  14,
"SPICE(NOSEGMENTSFOUND)",
"The CK file 'frmdiff_ck_no_seg.bc' does not contain any segments. Cannot pick",
"default 'from' frame from this file.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'getting defaults for "from" frame, only file CK without segments',
  'failure',
  $frmdiff,
  '-t1 J2000 frmdiff_ck_no_seg.bc',
  14,
"SPICE(NOSEGMENTSFOUND)",
"The CK file 'frmdiff_ck_no_seg.bc' does not contain any segments. Cannot pick",
"default 'from' frame from this file.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'getting defaults for "from" frame, first file PCK without segments',
  'failure',
  $frmdiff,
  '-t1 J2000 frmdiff_pck_no_seg.bpc frmdiff_fk.tf',
  14,
"SPICE(NOSEGMENTSFOUND)",
"The PCK file 'frmdiff_pck_no_seg.bpc' does not contain any segments. Cannot",
"pick default 'from' frame from this file.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'getting defaults for "from" frame, only file PCK without segments',
  'failure',
  $frmdiff,
  '-t1 J2000 frmdiff_pck_no_seg.bpc',
  14,
"SPICE(NOSEGMENTSFOUND)",
"The PCK file 'frmdiff_pck_no_seg.bpc' does not contain any segments. Cannot",
"pick default 'from' frame from this file.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'getting defaults for "from" frame, first file CK, unrecognized frame',
  'failure',
  $frmdiff,
  '-t1 J2000 frmdiff_ck_cov1_id1.bc frmdiff_fk.tf',
  15,
"SPICE(CANTPICKDEFAULTS3)",
"Cannot pick default 'from' frame because the frame ID '-84903' from the last",
"segment of the CK file 'frmdiff_ck_cov1_id1.bc' cannot be mapped to a frame",
"name.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'getting defaults for "from" frame, only file CK, unrecognized frame',
  'failure',
  $frmdiff,
  '-t1 J2000 frmdiff_ck_cov1_id1.bc',
  15,
"SPICE(CANTPICKDEFAULTS3)",
"Cannot pick default 'from' frame because the frame ID '-84903' from the last",
"segment of the CK file 'frmdiff_ck_cov1_id1.bc' cannot be mapped to a frame",
"name.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'getting defaults for "from" frame, first file PCK, unrecognized frame',
  'failure',
  $frmdiff,
  '-t1 J2000 frmdiff_pck_unk_ref.bpc frmdiff_fk.tf',
  15,
"SPICE(CANTPICKDEFAULTS3)",
"Cannot pick default 'from' frame because the frame ID '333' from the last",
"segment of the PCK file 'frmdiff_pck_unk_ref.bpc' cannot be mapped to a frame",
"name.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'getting defaults for "from" frame, only file PCK, unrecognized frame',
  'failure',
  $frmdiff,
  '-t1 J2000 frmdiff_pck_unk_ref.bpc',
  15,
"SPICE(CANTPICKDEFAULTS3)",
"Cannot pick default 'from' frame because the frame ID '333' from the last",
"segment of the PCK file 'frmdiff_pck_unk_ref.bpc' cannot be mapped to a frame",
"name.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'getting defaults for "to" frame, no files',
  'failure',
  $frmdiff,
  '-f1 J2000',
  14,
"SPICE(CANTPICKDEFAULTS1)",
"Cannot pick default values for 'to' frames because no kernels were provided as",
"the last and/or second to last item on the command line.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'getting defaults for "to" frame, first file not CK or PCK',
  'failure',
  $frmdiff,
  '-f1 J2000 frmdiff_lsk.tls frmdiff_fk.tf',
  14,
"SPICE(CANTPICKDEFAULTS2)",
"Cannot pick default values for 'to' frames from the 'frmdiff_lsk.tls' file",
"because it is not a CK or binary PCK file.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'getting defaults for "to" frame, only file not CK or PCK',
  'failure',
  $frmdiff,
  '-f1 J2000 frmdiff_fk.tf',
  14,
"SPICE(CANTPICKDEFAULTS2)",
"Cannot pick default values for 'to' frames from the 'frmdiff_fk.tf' file",
"because it is not a CK or binary PCK file.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'getting defaults for "to" frame, first file CK without segments',
  'failure',
  $frmdiff,
  '-f1 J2000 frmdiff_ck_no_seg.bc frmdiff_fk.tf',
  14,
"SPICE(NOSEGMENTSFOUND)",
"The CK file 'frmdiff_ck_no_seg.bc' does not contain any segments. Cannot pick",
"default 'to' frame from this file.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'getting defaults for "to" frame, only file CK without segments',
  'failure',
  $frmdiff,
  '-f1 J2000 frmdiff_ck_no_seg.bc',
  14,
"SPICE(NOSEGMENTSFOUND)",
"The CK file 'frmdiff_ck_no_seg.bc' does not contain any segments. Cannot pick",
"default 'to' frame from this file.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'getting defaults for "to" frame, first file PCK without segments',
  'failure',
  $frmdiff,
  '-f1 J2000 frmdiff_pck_no_seg.bpc frmdiff_fk.tf',
  14,
"SPICE(NOSEGMENTSFOUND)",
"The PCK file 'frmdiff_pck_no_seg.bpc' does not contain any segments. Cannot",
"pick default 'to' frame from this file.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'getting defaults for "to" frame, only file PCK without segments',
  'failure',
  $frmdiff,
  '-f1 J2000 frmdiff_pck_no_seg.bpc',
  14,
"SPICE(NOSEGMENTSFOUND)",
"The PCK file 'frmdiff_pck_no_seg.bpc' does not contain any segments. Cannot",
"pick default 'to' frame from this file.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'getting defaults for "to" frame, first file CK, unrecognized frame',
  'failure',
  $frmdiff,
  '-f1 J2000 frmdiff_ck_cov1_id1.bc frmdiff_fk.tf',
  15,
"SPICE(CANTPICKDEFAULTS4)",
"Cannot pick default 'to' frame because the frame class ID '-84100' from the",
"last segment of the CK file 'frmdiff_ck_cov1_id1.bc' cannot be mapped to a",
"frame name.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'getting defaults for "to" frame, only file CK, unrecognized frame',
  'failure',
  $frmdiff,
  '-f1 J2000 frmdiff_ck_cov1_id1.bc',
  15,
"SPICE(CANTPICKDEFAULTS4)",
"Cannot pick default 'to' frame because the frame class ID '-84100' from the",
"last segment of the CK file 'frmdiff_ck_cov1_id1.bc' cannot be mapped to a",
"frame name.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'getting defaults for "to" frame, first file PCK, unrecognized frame',
  'failure',
  $frmdiff,
  '-f1 J2000 frmdiff_pck_unk_obj.bpc frmdiff_fk.tf',
  15,
"SPICE(CANTPICKDEFAULTS4)",
"Cannot pick default 'to' frame because the frame class ID '3001' from the last",
"segment of the PCKfile 'frmdiff_pck_unk_obj.bpc' cannot be mapped to a frame",
"name.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'getting defaults for "to" frame, only file PCK, unrecognized frame',
  'failure',
  $frmdiff,
  '-f1 J2000 frmdiff_pck_unk_obj.bpc',
  15,
"SPICE(CANTPICKDEFAULTS4)",
"Cannot pick default 'to' frame because the frame class ID '3001' from the last",
"segment of the PCKfile 'frmdiff_pck_unk_obj.bpc' cannot be mapped to a frame",
"name.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, no files, no -b and -e',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls -f1 J2000 -t1 ECLIPJ2000',
  15,
"SPICE(NOTIMEBOUNDS1)",
"Cannot determine time range for comparison. Both start time and stop time must",
"be provided using '-b' and '-e' keys when no files are given on the command",
"line.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, no files, no -b',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls -f1 J2000 -t1 ECLIPJ2000 -e 2001-01-01',
  15,
"SPICE(NOTIMEBOUNDS1)",
"Cannot determine time range for comparison. Both start time and stop time must",
"be provided using '-b' and '-e' keys when no files are given on the command",
"line.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, no files, no -e',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls -f1 J2000 -t1 ECLIPJ2000 -b 2001-01-01',
  15,
"SPICE(NOTIMEBOUNDS1)",
"Cannot determine time range for comparison. Both start time and stop time must",
"be provided using '-b' and '-e' keys when no files are given on the command",
"line.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, one file not CK or binary PCK, no -b and -e',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls -f1 J2000 -t1 ECLIPJ2000 frmdiff_fk.tf',
  15,
"SPICE(NOTIMEBOUNDS2)",
"Cannot determine time range for comparison. Both start time and stop time must",
"be provided using '-b' and '-e' keys when the only file given on the command",
"line -- 'frmdiff_fk.tf' -- is not a CK or binary PCK.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, one file not CK or binary PCK, no -b ',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls -f1 J2000 -t1 ECLIPJ2000 -e 2001-01-01 frmdiff_fk.tf',
  15,
"SPICE(NOTIMEBOUNDS2)",
"Cannot determine time range for comparison. Both start time and stop time must",
"be provided using '-b' and '-e' keys when the only file given on the command",
"line -- 'frmdiff_fk.tf' -- is not a CK or binary PCK.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, one file not CK or binary PCK, no -e',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls -f1 J2000 -t1 ECLIPJ2000 -b 2001-01-01 frmdiff_fk.tf',
  15,
"SPICE(NOTIMEBOUNDS2)",
"Cannot determine time range for comparison. Both start time and stop time must",
"be provided using '-b' and '-e' keys when the only file given on the command",
"line -- 'frmdiff_fk.tf' -- is not a CK or binary PCK.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, two files not CK or binary PCK, no -b and -e',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls -f1 J2000 -t1 ECLIPJ2000 frmdiff_fk.tf frmdiff_pck.tpc',
  15,
"SPICE(NOTIMEBOUNDS3)",
"Cannot determine time range for comparison. Both start time and stop time must",
"be provided using '-b' and '-e' keys when both files given on the command line",
"-- 'frmdiff_fk.tf' and 'frmdiff_pck.tpc' -- are not CKs or binary PCKs.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, two files not CK or binary PCK, no -b ',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls -f1 J2000 -t1 ECLIPJ2000 -e 2001-01-01 frmdiff_fk.tf frmdiff_pck.tpc',
  15,
"SPICE(NOTIMEBOUNDS3)",
"Cannot determine time range for comparison. Both start time and stop time must",
"be provided using '-b' and '-e' keys when both files given on the command line",
"-- 'frmdiff_fk.tf' and 'frmdiff_pck.tpc' -- are not CKs or binary PCKs.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, two files not CK or binary PCK, no -e',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls -f1 J2000 -t1 ECLIPJ2000 -b 2001-01-01 frmdiff_fk.tf frmdiff_pck.tpc',
  15,
"SPICE(NOTIMEBOUNDS3)",
"Cannot determine time range for comparison. Both start time and stop time must",
"be provided using '-b' and '-e' keys when both files given on the command line",
"-- 'frmdiff_fk.tf' and 'frmdiff_pck.tpc' -- are not CKs or binary PCKs.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, first file CK, contains data for first "cov", empty window for discrete data',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk_tdt.tsc -f1 J2000 -t1 ECLIPJ2000 -c1 -84100 frmdiff_ck_discrete.bc frmdiff_pck.tpc',
  15,
"SPICE(NOTIMEBOUNDS4)",
"Cannot determine time range for comparison because CK file",
"'frmdiff_ck_discrete.bc' does not provide any roundoff-adjusted coverage for",
"the CK frame with class ID '-84100'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only file CK, contains data for first "cov", empty window for discrete data',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk_tdt.tsc -f1 J2000 -t1 ECLIPJ2000 -c1 -84100 frmdiff_ck_discrete.bc',
  15,
"SPICE(NOTIMEBOUNDS4)",
"Cannot determine time range for comparison because CK file",
"'frmdiff_ck_discrete.bc' does not provide any roundoff-adjusted coverage for",
"the CK frame with class ID '-84100'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, first file CK, contains data for first "cov", empty window for missing SCLK data',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls -f1 J2000 -t1 ECLIPJ2000 -c1 -84100 frmdiff_ck_discrete.bc frmdiff_pck.tpc',
  13,
"SPICE(KERNELVARNOTFOUND)",
"SCLK_DATA_TYPE_84 not found. Did you load the SCLK kernel?",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML --> CKCOVR --> SCT2E --> SCTYPE --> SCLI01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only file CK, contains data for first "cov", empty window for missing SCLK data',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls -f1 J2000 -t1 ECLIPJ2000 -c1 -84100 frmdiff_ck_discrete.bc',
  13,
"SPICE(KERNELVARNOTFOUND)",
"SCLK_DATA_TYPE_84 not found. Did you load the SCLK kernel?",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML --> CKCOVR --> SCT2E --> SCTYPE --> SCLI01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, first file CK, contains data for first "cov", empty window for missing LSK data',
  'failure',
  $frmdiff,
  '-k frmdiff_sclk_tdt.tsc -f1 J2000 -t1 ECLIPJ2000 -c1 -84100 frmdiff_ck_discrete.bc frmdiff_pck.tpc',
  22,
"SPICE(MISSINGTIMEINFO)",
"The following, needed to convert between the input uniform time scales, were",
"not found in the kernel pool: DELTET/DELTA_T_A, DELTET/K, DELTET/EB, DELTET/M.",
"Your program may have failed to load a leapseconds kernel. Other possible",
"causes of this problem include loading an invalid leapseconds kernel---one that",
"lacks an initial \\begindata marker or final newline character, or is otherwise",
"corrupted---or deleting previously loaded kernel pool variables via calls to",
"UNLOAD, KCLEAR, or CLPOOL. Use the SPICE routine FURNSH (in Fortran Toolkits,",
"FURNSH is an entry point of KEEPER) to load a leapseconds kernel; make sure the",
'kernel is up to date. See the Kernel and Time Required Reading or the "Intro to',
'Kernels" and "LSK and SCLK" SPICE Tutorials for details.',
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML --> CKCOVR --> SCT2E --> SCTE01 --> UNITIM"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only file CK, contains data for first "cov", empty window for missing LSK data',
  'failure',
  $frmdiff,
  '-k frmdiff_sclk_tdt.tsc -f1 J2000 -t1 ECLIPJ2000 -c1 -84100 frmdiff_ck_discrete.bc',
  22,
"SPICE(MISSINGTIMEINFO)",
"The following, needed to convert between the input uniform time scales, were",
"not found in the kernel pool: DELTET/DELTA_T_A, DELTET/K, DELTET/EB, DELTET/M.",
"Your program may have failed to load a leapseconds kernel. Other possible",
"causes of this problem include loading an invalid leapseconds kernel---one that",
"lacks an initial \\begindata marker or final newline character, or is otherwise",
"corrupted---or deleting previously loaded kernel pool variables via calls to",
"UNLOAD, KCLEAR, or CLPOOL. Use the SPICE routine FURNSH (in Fortran Toolkits,",
"FURNSH is an entry point of KEEPER) to load a leapseconds kernel; make sure the",
'kernel is up to date. See the Kernel and Time Required Reading or the "Intro to',
'Kernels" and "LSK and SCLK" SPICE Tutorials for details.',
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML --> CKCOVR --> SCT2E --> SCTE01 --> UNITIM"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, second file CK, contains data for second "cov", empty window for discrete data',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk_tdt.tsc -f1 J2000 -t1 ECLIPJ2000 -c2 -84100 frmdiff_pck.tpc frmdiff_ck_discrete.bc',
  15,
"SPICE(NOTIMEBOUNDS6)",
"Cannot determine time range for comparison because CK file",
"'frmdiff_ck_discrete.bc' does not provide any roundoff-adjusted coverage for",
"the CK frame with class ID '-84100'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, second file CK, contains data for second "cov", empty window for missing SCLK data',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls -f1 J2000 -t1 ECLIPJ2000 -c2 -84100 frmdiff_pck.tpc frmdiff_ck_discrete.bc',
  13,
"SPICE(KERNELVARNOTFOUND)",
"SCLK_DATA_TYPE_84 not found. Did you load the SCLK kernel?",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML --> CKCOVR --> SCT2E --> SCTYPE --> SCLI01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, second file CK, contains data for second "cov", empty window for missing LSK data',
  'failure',
  $frmdiff,
  '-k frmdiff_sclk_tdt.tsc -f1 J2000 -t1 ECLIPJ2000 -c2 -84100  frmdiff_pck.tpc frmdiff_ck_discrete.bc',
  22,
"SPICE(MISSINGTIMEINFO)",
"The following, needed to convert between the input uniform time scales, were",
"not found in the kernel pool: DELTET/DELTA_T_A, DELTET/K, DELTET/EB, DELTET/M.",
"Your program may have failed to load a leapseconds kernel. Other possible",
"causes of this problem include loading an invalid leapseconds kernel---one that",
"lacks an initial \\begindata marker or final newline character, or is otherwise",
"corrupted---or deleting previously loaded kernel pool variables via calls to",
"UNLOAD, KCLEAR, or CLPOOL. Use the SPICE routine FURNSH (in Fortran Toolkits,",
"FURNSH is an entry point of KEEPER) to load a leapseconds kernel; make sure the",
'kernel is up to date. See the Kernel and Time Required Reading or the "Intro to',
'Kernels" and "LSK and SCLK" SPICE Tutorials for details.',
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML --> CKCOVR --> SCT2E --> SCTE01 --> UNITIM"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only CK, contains data for first "cov" frame, start time too late',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc -f1 J2000 -t1 ECLIPJ2000 -f2 IAU_EARTH -t2 IAU_MARS -c1 -84100 -b 2020-01-01 frmdiff_ck_cov1_id1.bc',
  18,
"SPICE(NOTIMEBOUNDS11)",
"Cannot determine time range for comparison because the coverage window obtained",
"by examining the kernel provided on the command line does not overlap the time",
"range specified in the command line using '-b' and/or '-e' keys. Coverage for",
"the CK frame with class ID '-84100' was determined from CK file",
"'frmdiff_ck_cov1_id1.bc'. Comparison window specified on the command line was",
"all times after '2020-01-01'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only CK, contains data for first "cov" frame, stop time too early',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc -f1 J2000 -t1 ECLIPJ2000 -f2 IAU_EARTH -t2 IAU_MARS -c1 -84100 -e 2000-01-01 frmdiff_ck_cov1_id1.bc',
  18,
"SPICE(NOTIMEBOUNDS11)",
"Cannot determine time range for comparison because the coverage window obtained",
"by examining the kernel provided on the command line does not overlap the time",
"range specified in the command line using '-b' and/or '-e' keys. Coverage for",
"the CK frame with class ID '-84100' was determined from CK file",
"'frmdiff_ck_cov1_id1.bc'. Comparison window specified on the command line was",
"all times before '2000-01-01'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only PCK, contains data for first "cov" frame, start time too late',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls -f1 J2000 -t1 ECLIPJ2000 -f2 IAU_EARTH -t2 IAU_MARS -c1 3000 -b 2051-01-01 frmdiff_pck_cov1_id1.bpc',
  18,
"SPICE(NOTIMEBOUNDS11)",
"Cannot determine time range for comparison because the coverage window obtained",
"by examining the kernel provided on the command line does not overlap the time",
"range specified in the command line using '-b' and/or '-e' keys. Coverage for",
"the PCK frame with class ID '3000' was determined from PCK file",
"'frmdiff_pck_cov1_id1.bpc'. Comparison window specified on the command line was",
"all times after '2051-01-01'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only PCK, contains data for first "cov" frame, stop time too early',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls -f1 J2000 -t1 ECLIPJ2000 -f2 IAU_EARTH -t2 IAU_MARS -c1 3000 -e 1949-01-01 frmdiff_pck_cov1_id1.bpc',
  18,
"SPICE(NOTIMEBOUNDS11)",
"Cannot determine time range for comparison because the coverage window obtained",
"by examining the kernel provided on the command line does not overlap the time",
"range specified in the command line using '-b' and/or '-e' keys. Coverage for",
"the PCK frame with class ID '3000' was determined from PCK file",
"'frmdiff_pck_cov1_id1.bpc'. Comparison window specified on the command line was",
"all times before '1949-01-01'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only CK, contains data for second "cov" frame, start time too late',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc -f1 J2000 -t1 ECLIPJ2000 -f2 IAU_EARTH -t2 IAU_MARS -c2 -84100 -b 2020-01-01 frmdiff_ck_cov1_id1.bc',
  18,
"SPICE(NOTIMEBOUNDS12)",
"Cannot determine time range for comparison because the coverage window obtained",
"by examining the kernel provided on the command line does not overlap the time",
"range specified in the command line using '-b' and/or '-e' keys. Coverage for",
"the CK frame with class ID '-84100' was determined from CK file",
"'frmdiff_ck_cov1_id1.bc'. Comparison window specified on the command line was",
"all times after '2020-01-01'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only CK, contains data for second "cov" frame, stop time too early',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc -f1 J2000 -t1 ECLIPJ2000 -f2 IAU_EARTH -t2 IAU_MARS -c2 -84100 -e 2000-01-01 frmdiff_ck_cov1_id1.bc',
  18,
"SPICE(NOTIMEBOUNDS12)",
"Cannot determine time range for comparison because the coverage window obtained",
"by examining the kernel provided on the command line does not overlap the time",
"range specified in the command line using '-b' and/or '-e' keys. Coverage for",
"the CK frame with class ID '-84100' was determined from CK file",
"'frmdiff_ck_cov1_id1.bc'. Comparison window specified on the command line was",
"all times before '2000-01-01'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only PCK, contains data for second "cov" frame, start time too late',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls -f1 J2000 -t1 ECLIPJ2000 -f2 IAU_EARTH -t2 IAU_MARS -c2 3000 -b 2051-01-01 frmdiff_pck_cov1_id1.bpc',
  18,
"SPICE(NOTIMEBOUNDS12)",
"Cannot determine time range for comparison because the coverage window obtained",
"by examining the kernel provided on the command line does not overlap the time",
"range specified in the command line using '-b' and/or '-e' keys. Coverage for",
"the PCK frame with class ID '3000' was determined from PCK file",
"'frmdiff_pck_cov1_id1.bpc'. Comparison window specified on the command line was",
"all times after '2051-01-01'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only PCK, contains data for second "cov" frame, stop time too early',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls -f1 J2000 -t1 ECLIPJ2000 -f2 IAU_EARTH -t2 IAU_MARS -c2 3000 -e 1949-01-01 frmdiff_pck_cov1_id1.bpc',
  18,
"SPICE(NOTIMEBOUNDS12)",
"Cannot determine time range for comparison because the coverage window obtained",
"by examining the kernel provided on the command line does not overlap the time",
"range specified in the command line using '-b' and/or '-e' keys. Coverage for",
"the PCK frame with class ID '3000' was determined from PCK file",
"'frmdiff_pck_cov1_id1.bpc'. Comparison window specified on the command line was",
"all times before '1949-01-01'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, first CK second not CK/PCK, contains data for first "cov" frame, start time too late',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc -f1 J2000 -t1 ECLIPJ2000 -c1 -84100 -b 2020-01-01 frmdiff_ck_cov1_id1.bc frmdiff_pck.tpc',
  18,
"SPICE(NOTIMEBOUNDS11)",
"Cannot determine time range for comparison because the coverage window obtained",
"by examining the kernel provided on the command line does not overlap the time",
"range specified in the command line using '-b' and/or '-e' keys. Coverage for",
"the CK frame with class ID '-84100' was determined from CK file",
"'frmdiff_ck_cov1_id1.bc'. Comparison window specified on the command line was",
"all times after '2020-01-01'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, first CK second not CK/PCK, contains data for first "cov" frame, stop time too early',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc -f1 J2000 -t1 ECLIPJ2000 -c1 -84100 -e 2000-01-01 frmdiff_ck_cov1_id1.bc frmdiff_pck.tpc',
  18,
"SPICE(NOTIMEBOUNDS11)",
"Cannot determine time range for comparison because the coverage window obtained",
"by examining the kernel provided on the command line does not overlap the time",
"range specified in the command line using '-b' and/or '-e' keys. Coverage for",
"the CK frame with class ID '-84100' was determined from CK file",
"'frmdiff_ck_cov1_id1.bc'. Comparison window specified on the command line was",
"all times before '2000-01-01'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, first PCK second not CK/PCK, contains data for first "cov" frame, start time too late',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls -f1 J2000 -t1 ECLIPJ2000 -c1 3000 -b 2051-01-01 frmdiff_pck_cov1_id1.bpc frmdiff_pck.tpc',
  18,
"SPICE(NOTIMEBOUNDS11)",
"Cannot determine time range for comparison because the coverage window obtained",
"by examining the kernel provided on the command line does not overlap the time",
"range specified in the command line using '-b' and/or '-e' keys. Coverage for",
"the PCK frame with class ID '3000' was determined from PCK file",
"'frmdiff_pck_cov1_id1.bpc'. Comparison window specified on the command line was",
"all times after '2051-01-01'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, first PCK second not CK/PCK, contains data for first "cov" frame, stop time too early',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls -f1 J2000 -t1 ECLIPJ2000 -c1 3000 -e 1949-01-01 frmdiff_pck_cov1_id1.bpc frmdiff_pck.tpc',
  18,
"SPICE(NOTIMEBOUNDS11)",
"Cannot determine time range for comparison because the coverage window obtained",
"by examining the kernel provided on the command line does not overlap the time",
"range specified in the command line using '-b' and/or '-e' keys. Coverage for",
"the PCK frame with class ID '3000' was determined from PCK file",
"'frmdiff_pck_cov1_id1.bpc'. Comparison window specified on the command line was",
"all times before '1949-01-01'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, second CK first not CK/PCK, contains data for second "cov" frame, start time too late',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc -f1 J2000 -t1 ECLIPJ2000 -f2 IAU_EARTH -t2 IAU_MARS -c2 -84100 -b 2020-01-01 frmdiff_pck.tpc frmdiff_ck_cov1_id1.bc',
  18,
"SPICE(NOTIMEBOUNDS12)",
"Cannot determine time range for comparison because the coverage window obtained",
"by examining the kernel provided on the command line does not overlap the time",
"range specified in the command line using '-b' and/or '-e' keys. Coverage for",
"the CK frame with class ID '-84100' was determined from CK file",
"'frmdiff_ck_cov1_id1.bc'. Comparison window specified on the command line was",
"all times after '2020-01-01'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, second CK first not CK/PCK, contains data for second "cov" frame, stop time too early',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc -f1 J2000 -t1 ECLIPJ2000 -f2 IAU_EARTH -t2 IAU_MARS -c2 -84100 -e 2000-01-01 frmdiff_pck.tpc frmdiff_ck_cov1_id1.bc',
  18,
"SPICE(NOTIMEBOUNDS12)",
"Cannot determine time range for comparison because the coverage window obtained",
"by examining the kernel provided on the command line does not overlap the time",
"range specified in the command line using '-b' and/or '-e' keys. Coverage for",
"the CK frame with class ID '-84100' was determined from CK file",
"'frmdiff_ck_cov1_id1.bc'. Comparison window specified on the command line was",
"all times before '2000-01-01'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, second PCK first not CK/PCK, contains data for second "cov" frame, start time too late',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls -f1 J2000 -t1 ECLIPJ2000 -f2 IAU_EARTH -t2 IAU_MARS -c2 3000 -b 2051-01-01 frmdiff_pck.tpc frmdiff_pck_cov1_id1.bpc',
  18,
"SPICE(NOTIMEBOUNDS12)",
"Cannot determine time range for comparison because the coverage window obtained",
"by examining the kernel provided on the command line does not overlap the time",
"range specified in the command line using '-b' and/or '-e' keys. Coverage for",
"the PCK frame with class ID '3000' was determined from PCK file",
"'frmdiff_pck_cov1_id1.bpc'. Comparison window specified on the command line was",
"all times after '2051-01-01'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, second PCK first not CK/PCK, contains data for second "cov" frame, stop time too early',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls -f1 J2000 -t1 ECLIPJ2000 -f2 IAU_EARTH -t2 IAU_MARS -c2 3000 -e 1949-01-01 frmdiff_pck.tpc frmdiff_pck_cov1_id1.bpc',
  18,
"SPICE(NOTIMEBOUNDS12)",
"Cannot determine time range for comparison because the coverage window obtained",
"by examining the kernel provided on the command line does not overlap the time",
"range specified in the command line using '-b' and/or '-e' keys. Coverage for",
"the PCK frame with class ID '3000' was determined from PCK file",
"'frmdiff_pck_cov1_id1.bpc'. Comparison window specified on the command line was",
"all times before '1949-01-01'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, two CKs, two "to" frames not CK frames',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf -t1 J2000 -t2 ECLIPJ2000 frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id2.bc',
  18,
"SPICE(NOTIMEBOUNDS8)",
"Insufficient information was provided on the command line to determine time",
"range for comparison. If the program is run to perform comparison for CKs",
"and/or binary PCKs, the '-c1' and/or '-c2' keys can be used to direct the",
"program to determine default coverage using data from the files. Otherwise,",
"both of the '-b' and '-e' keys must be used to specify the start and stop times",
"of the comparison window.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, two CKs, two "to" CK frames with no data in files',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf -t1 PHX_LANDER -t2 PHX_LANDER frmdiff_ck_cov1_id1.bc frmdiff_ck_cov2_id1.bc',
  18,
"SPICE(NOTIMEBOUNDS8)",
"Insufficient information was provided on the command line to determine time",
"range for comparison. If the program is run to perform comparison for CKs",
"and/or binary PCKs, the '-c1' and/or '-c2' keys can be used to direct the",
"program to determine default coverage using data from the files. Otherwise,",
"both of the '-b' and '-e' keys must be used to specify the start and stop times",
"of the comparison window.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, two PCKs, two "to" frames not PCK frames',
  'failure',
  $frmdiff,
  '-t1 J2000 -t2 ECLIPJ2000 frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id2.bpc',
  18,
"SPICE(NOTIMEBOUNDS8)",
"Insufficient information was provided on the command line to determine time",
"range for comparison. If the program is run to perform comparison for CKs",
"and/or binary PCKs, the '-c1' and/or '-c2' keys can be used to direct the",
"program to determine default coverage using data from the files. Otherwise,",
"both of the '-b' and '-e' keys must be used to specify the start and stop times",
"of the comparison window.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, two PCKs, two "to" PCk frames with no data in files',
  'failure',
  $frmdiff,
  '-t1 IAU_VENUS -t2 IAU_MARS frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id2.bpc',
  18,
"SPICE(NOTIMEBOUNDS8)",
"Insufficient information was provided on the command line to determine time",
"range for comparison. If the program is run to perform comparison for CKs",
"and/or binary PCKs, the '-c1' and/or '-c2' keys can be used to direct the",
"program to determine default coverage using data from the files. Otherwise,",
"both of the '-b' and '-e' keys must be used to specify the start and stop times",
"of the comparison window.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, first CK second not CK/PCK, first "to" frame not CK frame',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf -t1 J2000 frmdiff_ck_cov1_id1.bc frmdiff_pck.tpc',
  18,
"SPICE(NOTIMEBOUNDS8)",
"Insufficient information was provided on the command line to determine time",
"range for comparison. If the program is run to perform comparison for CKs",
"and/or binary PCKs, the '-c1' and/or '-c2' keys can be used to direct the",
"program to determine default coverage using data from the files. Otherwise,",
"both of the '-b' and '-e' keys must be used to specify the start and stop times",
"of the comparison window.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, first CK second not CK/PCK, first "to" CK frame with no data in file',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf -t1 PHX_LANDER frmdiff_ck_cov1_id1.bc frmdiff_pck.tpc',
  18,
"SPICE(NOTIMEBOUNDS8)",
"Insufficient information was provided on the command line to determine time",
"range for comparison. If the program is run to perform comparison for CKs",
"and/or binary PCKs, the '-c1' and/or '-c2' keys can be used to direct the",
"program to determine default coverage using data from the files. Otherwise,",
"both of the '-b' and '-e' keys must be used to specify the start and stop times",
"of the comparison window.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, first PCK second not CK/PCK, first "to" frame not PCK frame',
  'failure',
  $frmdiff,
  '-t1 J2000 frmdiff_pck_cov1_id1.bpc frmdiff_pck.tpc',
  18,
"SPICE(NOTIMEBOUNDS8)",
"Insufficient information was provided on the command line to determine time",
"range for comparison. If the program is run to perform comparison for CKs",
"and/or binary PCKs, the '-c1' and/or '-c2' keys can be used to direct the",
"program to determine default coverage using data from the files. Otherwise,",
"both of the '-b' and '-e' keys must be used to specify the start and stop times",
"of the comparison window.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, first PCK second not CK/PCK, first "to" PCK frame with no data in file',
  'failure',
  $frmdiff,
  '-t1 IAU_VENUS frmdiff_pck_cov1_id1.bpc frmdiff_pck.tpc',
  18,
"SPICE(NOTIMEBOUNDS8)",
"Insufficient information was provided on the command line to determine time",
"range for comparison. If the program is run to perform comparison for CKs",
"and/or binary PCKs, the '-c1' and/or '-c2' keys can be used to direct the",
"program to determine default coverage using data from the files. Otherwise,",
"both of the '-b' and '-e' keys must be used to specify the start and stop times",
"of the comparison window.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only CK, first "to" frame not CK frame',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf -t1 J2000 frmdiff_ck_cov1_id1.bc',
  18,
"SPICE(NOTIMEBOUNDS8)",
"Insufficient information was provided on the command line to determine time",
"range for comparison. If the program is run to perform comparison for CKs",
"and/or binary PCKs, the '-c1' and/or '-c2' keys can be used to direct the",
"program to determine default coverage using data from the files. Otherwise,",
"both of the '-b' and '-e' keys must be used to specify the start and stop times",
"of the comparison window.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only CK, first "to" CK frame with no data in file',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf -t1 PHX_LANDER frmdiff_ck_cov1_id1.bc',
  18,
"SPICE(NOTIMEBOUNDS8)",
"Insufficient information was provided on the command line to determine time",
"range for comparison. If the program is run to perform comparison for CKs",
"and/or binary PCKs, the '-c1' and/or '-c2' keys can be used to direct the",
"program to determine default coverage using data from the files. Otherwise,",
"both of the '-b' and '-e' keys must be used to specify the start and stop times",
"of the comparison window.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only PCK, first "to" frame not PCK frame',
  'failure',
  $frmdiff,
  '-t1 J2000 frmdiff_pck_cov1_id1.bpc',
  18,
"SPICE(NOTIMEBOUNDS8)",
"Insufficient information was provided on the command line to determine time",
"range for comparison. If the program is run to perform comparison for CKs",
"and/or binary PCKs, the '-c1' and/or '-c2' keys can be used to direct the",
"program to determine default coverage using data from the files. Otherwise,",
"both of the '-b' and '-e' keys must be used to specify the start and stop times",
"of the comparison window.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only PCK, first "to" PCK frame with no data in file',
  'failure',
  $frmdiff,
  '-t1 IAU_VENUS frmdiff_pck_cov1_id1.bpc',
  18,
"SPICE(NOTIMEBOUNDS8)",
"Insufficient information was provided on the command line to determine time",
"range for comparison. If the program is run to perform comparison for CKs",
"and/or binary PCKs, the '-c1' and/or '-c2' keys can be used to direct the",
"program to determine default coverage using data from the files. Otherwise,",
"both of the '-b' and '-e' keys must be used to specify the start and stop times",
"of the comparison window.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only CK, second "to" frame not CK frame',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf -t2 J2000 frmdiff_ck_cov1_id1.bc',
  18,
"SPICE(NOTIMEBOUNDS8)",
"Insufficient information was provided on the command line to determine time",
"range for comparison. If the program is run to perform comparison for CKs",
"and/or binary PCKs, the '-c1' and/or '-c2' keys can be used to direct the",
"program to determine default coverage using data from the files. Otherwise,",
"both of the '-b' and '-e' keys must be used to specify the start and stop times",
"of the comparison window.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only CK, second "to" CK frame with no data in file',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf -t2 PHX_LANDER frmdiff_ck_cov1_id1.bc',
  18,
"SPICE(NOTIMEBOUNDS8)",
"Insufficient information was provided on the command line to determine time",
"range for comparison. If the program is run to perform comparison for CKs",
"and/or binary PCKs, the '-c1' and/or '-c2' keys can be used to direct the",
"program to determine default coverage using data from the files. Otherwise,",
"both of the '-b' and '-e' keys must be used to specify the start and stop times",
"of the comparison window.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only PCK, second "to" frame not PCK frame',
  'failure',
  $frmdiff,
  '-t2 J2000 frmdiff_pck_cov1_id1.bpc',
  18,
"SPICE(NOTIMEBOUNDS8)",
"Insufficient information was provided on the command line to determine time",
"range for comparison. If the program is run to perform comparison for CKs",
"and/or binary PCKs, the '-c1' and/or '-c2' keys can be used to direct the",
"program to determine default coverage using data from the files. Otherwise,",
"both of the '-b' and '-e' keys must be used to specify the start and stop times",
"of the comparison window.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only PCK, second "to" PCK frame with no data in file',
  'failure',
  $frmdiff,
  '-t2 IAU_VENUS frmdiff_pck_cov1_id1.bpc',
  18,
"SPICE(NOTIMEBOUNDS8)",
"Insufficient information was provided on the command line to determine time",
"range for comparison. If the program is run to perform comparison for CKs",
"and/or binary PCKs, the '-c1' and/or '-c2' keys can be used to direct the",
"program to determine default coverage using data from the files. Otherwise,",
"both of the '-b' and '-e' keys must be used to specify the start and stop times",
"of the comparison window.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, two CKs, both contains data for corresponding "cov" frames, no overlap',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf -c1 PHX_PAYLOAD -c2 PHX_LANDER frmdiff_ck_cov1_id1.bc frmdiff_ck_cov3_id2.bc',
  17,
"SPICE(NOTIMEBOUNDS9)",
"Cannot determine time range for comparison because coverage windows obtained by",
"examining kernels provided on the command line do not overlap. Coverage for the",
"CK frame 'PHX_PAYLOAD' (class ID '-84100') was determined from CK file",
"'frmdiff_ck_cov1_id1.bc'. Coverage for the CK frame 'PHX_LANDER' (class ID",
"'-84001') was determined from CK file 'frmdiff_ck_cov3_id2.bc'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, two CKs, both contains data for corresponding "cov" frames, overlap, start time too late',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf -c1 PHX_PAYLOAD -c2 PHX_LANDER -b 2009-01-01 frmdiff_ck_cov1_id1.bc frmdiff_ck_cov2_id2.bc',
  20,
"SPICE(NOTIMEBOUNDS10)",
"Cannot determine time range for comparison because the intersection of the",
"coverage windows obtained by examining kernels provided on the command line",
"does not overlap the time range specified in the command line using '-b' and/or",
"'-e' keys. Coverage for the CK frame 'PHX_PAYLOAD' (class ID '-84100') was",
"determined from CK file 'frmdiff_ck_cov1_id1.bc'. Coverage for the CK frame",
"'PHX_LANDER' (class ID '-84001') was determined from CK file",
"'frmdiff_ck_cov2_id2.bc'. Comparison window specified on the command line was",
"all times after '2009-01-01'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, two CKs, both contains data for corresponding "cov" frames, overlap, stop time too early',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf -c1 PHX_PAYLOAD -c2 PHX_LANDER -e 2007-01-01 frmdiff_ck_cov1_id1.bc frmdiff_ck_cov2_id2.bc',
  20,
"SPICE(NOTIMEBOUNDS10)",
"Cannot determine time range for comparison because the intersection of the",
"coverage windows obtained by examining kernels provided on the command line",
"does not overlap the time range specified in the command line using '-b' and/or",
"'-e' keys. Coverage for the CK frame 'PHX_PAYLOAD' (class ID '-84100') was",
"determined from CK file 'frmdiff_ck_cov1_id1.bc'. Coverage for the CK frame",
"'PHX_LANDER' (class ID '-84001') was determined from CK file",
"'frmdiff_ck_cov2_id2.bc'. Comparison window specified on the command line was",
"all times before '2007-01-01'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, two PCKs, both contains data for corresponding "cov" frames, no overlap',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls -c1 ITRF93 -c2 IAU_EARTH frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov3_id2.bpc',
  17,
"SPICE(NOTIMEBOUNDS9)",
"Cannot determine time range for comparison because coverage windows obtained by",
"examining kernels provided on the command line do not overlap. Coverage for the",
"PCK frame 'ITRF93' (class ID '3000') was determined from PCK file",
"'frmdiff_pck_cov1_id1.bpc'. Coverage for the PCK frame 'IAU_EARTH' (class ID",
"'399') was determined from PCK file 'frmdiff_pck_cov3_id2.bpc'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, two PCKs, both contains data for corresponding "cov" frames, overlap, start time too late',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls -c1 ITRF93 -c2 IAU_EARTH -b 2009-01-01 frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov2_id2.bpc',
  20,
"SPICE(NOTIMEBOUNDS10)",
"Cannot determine time range for comparison because the intersection of the",
"coverage windows obtained by examining kernels provided on the command line",
"does not overlap the time range specified in the command line using '-b' and/or",
"'-e' keys. Coverage for the PCK frame 'ITRF93' (class ID '3000') was determined",
"from PCK file 'frmdiff_pck_cov1_id1.bpc'. Coverage for the PCK frame",
"'IAU_EARTH' (class ID '399') was determined from PCK file",
"'frmdiff_pck_cov2_id2.bpc'. Comparison window specified on the command line was",
"all times after '2009-01-01'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, two PCKs, both contains data for corresponding "cov" frames, overlap, stop time too early',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls -c1 ITRF93 -c2 IAU_EARTH  -e 2007-01-01 frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov2_id2.bpc',
  20,
"SPICE(NOTIMEBOUNDS10)",
"Cannot determine time range for comparison because the intersection of the",
"coverage windows obtained by examining kernels provided on the command line",
"does not overlap the time range specified in the command line using '-b' and/or",
"'-e' keys. Coverage for the PCK frame 'ITRF93' (class ID '3000') was determined",
"from PCK file 'frmdiff_pck_cov1_id1.bpc'. Coverage for the PCK frame",
"'IAU_EARTH' (class ID '399') was determined from PCK file",
"'frmdiff_pck_cov2_id2.bpc'. Comparison window specified on the command line was",
"all times before '2007-01-01'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, first CK second PCK, both contains data for corresponding "cov" frames, no overlap',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf -c1 PHX_PAYLOAD -c2 IAU_EARTH frmdiff_ck_cov1_id1.bc frmdiff_pck_cov3_id2.bpc',
  17,
"SPICE(NOTIMEBOUNDS9)",
"Cannot determine time range for comparison because coverage windows obtained by",
"examining kernels provided on the command line do not overlap. Coverage for the",
"CK frame 'PHX_PAYLOAD' (class ID '-84100') was determined from CK file",
"'frmdiff_ck_cov1_id1.bc'. Coverage for the PCK frame 'IAU_EARTH' (class ID",
"'399') was determined from PCK file 'frmdiff_pck_cov3_id2.bpc'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, first CK second PCK, both contains data for corresponding "cov" frames, overlap, start time too late',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf -c1 PHX_PAYLOAD -c2 IAU_EARTH -b 2009-01-01 frmdiff_ck_cov1_id1.bc frmdiff_pck_cov2_id2.bpc',
  20,
"SPICE(NOTIMEBOUNDS10)",
"Cannot determine time range for comparison because the intersection of the",
"coverage windows obtained by examining kernels provided on the command line",
"does not overlap the time range specified in the command line using '-b' and/or",
"'-e' keys. Coverage for the CK frame 'PHX_PAYLOAD' (class ID '-84100') was",
"determined from CK file 'frmdiff_ck_cov1_id1.bc'. Coverage for the PCK frame",
"'IAU_EARTH' (class ID '399') was determined from PCK file",
"'frmdiff_pck_cov2_id2.bpc'. Comparison window specified on the command line was",
"all times after '2009-01-01'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, first CK second PCK, both contains data for corresponding "cov" frames, overlap, stop time too early',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf -c1 PHX_PAYLOAD -c2 IAU_EARTH -e 2007-01-01 frmdiff_ck_cov1_id1.bc frmdiff_pck_cov2_id2.bpc',
  20,
"SPICE(NOTIMEBOUNDS10)",
"Cannot determine time range for comparison because the intersection of the",
"coverage windows obtained by examining kernels provided on the command line",
"does not overlap the time range specified in the command line using '-b' and/or",
"'-e' keys. Coverage for the CK frame 'PHX_PAYLOAD' (class ID '-84100') was",
"determined from CK file 'frmdiff_ck_cov1_id1.bc'. Coverage for the PCK frame",
"'IAU_EARTH' (class ID '399') was determined from PCK file",
"'frmdiff_pck_cov2_id2.bpc'. Comparison window specified on the command line was",
"all times before '2007-01-01'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, first PCK second CK, both contains data for corresponding "cov" frames, no overlap',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf -c2 PHX_PAYLOAD -c1 IAU_EARTH frmdiff_pck_cov3_id2.bpc frmdiff_ck_cov1_id1.bc',
  17,
"SPICE(NOTIMEBOUNDS9)",
"Cannot determine time range for comparison because coverage windows obtained by",
"examining kernels provided on the command line do not overlap. Coverage for the",
"PCK frame 'IAU_EARTH' (class ID '399') was determined from PCK file",
"'frmdiff_pck_cov3_id2.bpc'. Coverage for the CK frame 'PHX_PAYLOAD' (class ID",
"'-84100') was determined from CK file 'frmdiff_ck_cov1_id1.bc'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, first PCK second CK, both contains data for corresponding "cov" frames, overlap, start time too late',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf -c2 PHX_PAYLOAD -c1 IAU_EARTH -b 2009-01-01 frmdiff_pck_cov2_id2.bpc frmdiff_ck_cov1_id1.bc',
  20,
"SPICE(NOTIMEBOUNDS10)",
"Cannot determine time range for comparison because the intersection of the",
"coverage windows obtained by examining kernels provided on the command line",
"does not overlap the time range specified in the command line using '-b' and/or",
"'-e' keys. Coverage for the PCK frame 'IAU_EARTH' (class ID '399') was",
"determined from PCK file 'frmdiff_pck_cov2_id2.bpc'. Coverage for the CK frame",
"'PHX_PAYLOAD' (class ID '-84100') was determined from CK file",
"'frmdiff_ck_cov1_id1.bc'. Comparison window specified on the command line was",
"all times after '2009-01-01'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, first PCK second CK, both contains data for corresponding "cov" frames, overlap, stop time too early',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf -c2 PHX_PAYLOAD -c1 IAU_EARTH -e 2007-01-01 frmdiff_pck_cov2_id2.bpc frmdiff_ck_cov1_id1.bc',
  20,
"SPICE(NOTIMEBOUNDS10)",
"Cannot determine time range for comparison because the intersection of the",
"coverage windows obtained by examining kernels provided on the command line",
"does not overlap the time range specified in the command line using '-b' and/or",
"'-e' keys. Coverage for the PCK frame 'IAU_EARTH' (class ID '399') was",
"determined from PCK file 'frmdiff_pck_cov2_id2.bpc'. Coverage for the CK frame",
"'PHX_PAYLOAD' (class ID '-84100') was determined from CK file",
"'frmdiff_ck_cov1_id1.bc'. Comparison window specified on the command line was",
"all times before '2007-01-01'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only CK, contains data for two distinct "cov" frames, no overlap',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf -c1 PHX_PAYLOAD -c2 PHX_LANDER frmdiff_ck_cov13_id12.bc',
  17,
"SPICE(NOTIMEBOUNDS9)",
"Cannot determine time range for comparison because coverage windows obtained by",
"examining kernel provided on the command line do not overlap. Coverage for the",
"CK frame 'PHX_PAYLOAD' (class ID '-84100') was determined from CK file",
"'frmdiff_ck_cov13_id12.bc'. Coverage for the CK frame 'PHX_LANDER' (class ID",
"'-84001') was determined from CK file 'frmdiff_ck_cov13_id12.bc'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only CK, contains data for two distinct "cov" frames, overlap, start time too late',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf -c1 PHX_PAYLOAD -c2 PHX_LANDER -b 2009-01-01 frmdiff_ck_cov12_id12.bc',
  20,
"SPICE(NOTIMEBOUNDS10)",
"Cannot determine time range for comparison because the intersection of the",
"coverage windows obtained by examining kernel provided on the command line does",
"not overlap the time range specified in the command line using '-b' and/or '-e'",
"keys. Coverage for the CK frame 'PHX_PAYLOAD' (class ID '-84100') was",
"determined from CK file 'frmdiff_ck_cov12_id12.bc'. Coverage for the CK frame",
"'PHX_LANDER' (class ID '-84001') was determined from CK file",
"'frmdiff_ck_cov12_id12.bc'. Comparison window specified on the command line was",
"all times after '2009-01-01'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only CK, contains data for two distinct "cov" frames, overlap, stop time too early',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf -c1 PHX_PAYLOAD -c2 PHX_LANDER -e 2007-01-01 frmdiff_ck_cov12_id12.bc',
  20,
"SPICE(NOTIMEBOUNDS10)",
"Cannot determine time range for comparison because the intersection of the",
"coverage windows obtained by examining kernel provided on the command line does",
"not overlap the time range specified in the command line using '-b' and/or '-e'",
"keys. Coverage for the CK frame 'PHX_PAYLOAD' (class ID '-84100') was",
"determined from CK file 'frmdiff_ck_cov12_id12.bc'. Coverage for the CK frame",
"'PHX_LANDER' (class ID '-84001') was determined from CK file",
"'frmdiff_ck_cov12_id12.bc'. Comparison window specified on the command line was",
"all times before '2007-01-01'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only CK, contains data for two same "cov" frames, start time too late',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf -c1 PHX_PAYLOAD -c2 PHX_PAYLOAD -b 2009-01-01 frmdiff_ck_cov12_id12.bc',
  18,
"SPICE(NOTIMEBOUNDS10)",
"Cannot determine time range for comparison because the intersection of the",
"coverage windows obtained by examining kernel provided on the command line does",
"not overlap the time range specified in the command line using '-b' and/or '-e'",
"keys. Coverage for the CK frame 'PHX_PAYLOAD' (class ID '-84100') was",
"determined from CK file 'frmdiff_ck_cov12_id12.bc'. Comparison window specified",
"on the command line was all times after '2009-01-01'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only CK, contains data for two same "cov" frames, stop time too early',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf -c1 PHX_PAYLOAD -c2 PHX_PAYLOAD -e 2007-01-01 frmdiff_ck_cov12_id12.bc',
  18,
"SPICE(NOTIMEBOUNDS10)",
"Cannot determine time range for comparison because the intersection of the",
"coverage windows obtained by examining kernel provided on the command line does",
"not overlap the time range specified in the command line using '-b' and/or '-e'",
"keys. Coverage for the CK frame 'PHX_PAYLOAD' (class ID '-84100') was",
"determined from CK file 'frmdiff_ck_cov12_id12.bc'. Comparison window specified",
"on the command line was all times before '2007-01-01'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only PCK, contains data for two distinct "cov" frames, no overlap',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls -c1 ITRF93 -c2 IAU_EARTH frmdiff_pck_cov13_id12.bpc',
  17,
"SPICE(NOTIMEBOUNDS9)",
"Cannot determine time range for comparison because coverage windows obtained by",
"examining kernel provided on the command line do not overlap. Coverage for the",
"PCK frame 'ITRF93' (class ID '3000') was determined from PCK file",
"'frmdiff_pck_cov13_id12.bpc'. Coverage for the PCK frame 'IAU_EARTH' (class ID",
"'399') was determined from PCK file 'frmdiff_pck_cov13_id12.bpc'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only PCK, contains data for two distinct "cov" frames, overlap, start time too late',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls -c1 ITRF93 -c2 IAU_EARTH -b 2009-01-01 frmdiff_pck_cov12_id12.bpc',
  20,
"SPICE(NOTIMEBOUNDS10)",
"Cannot determine time range for comparison because the intersection of the",
"coverage windows obtained by examining kernel provided on the command line does",
"not overlap the time range specified in the command line using '-b' and/or '-e'",
"keys. Coverage for the PCK frame 'ITRF93' (class ID '3000') was determined from",
"PCK file 'frmdiff_pck_cov12_id12.bpc'. Coverage for the PCK frame 'IAU_EARTH'",
"(class ID '399') was determined from PCK file 'frmdiff_pck_cov12_id12.bpc'.",
"Comparison window specified on the command line was all times after",
"'2009-01-01'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only PCK, contains data for two distinct "cov" frames, overlap, stop time too early',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls -c1 ITRF93 -c2 IAU_EARTH -e 2007-01-01 frmdiff_pck_cov12_id12.bpc',
  20,
"SPICE(NOTIMEBOUNDS10)",
"Cannot determine time range for comparison because the intersection of the",
"coverage windows obtained by examining kernel provided on the command line does",
"not overlap the time range specified in the command line using '-b' and/or '-e'",
"keys. Coverage for the PCK frame 'ITRF93' (class ID '3000') was determined from",
"PCK file 'frmdiff_pck_cov12_id12.bpc'. Coverage for the PCK frame 'IAU_EARTH'",
"(class ID '399') was determined from PCK file 'frmdiff_pck_cov12_id12.bpc'.",
"Comparison window specified on the command line was all times before",
"'2007-01-01'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only PCK, contains data for two same "cov" frames, start time too late',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls -c1 ITRF93 -c2 ITRF93 -b 2009-01-01 frmdiff_pck_cov12_id12.bpc',
  18,
"SPICE(NOTIMEBOUNDS10)",
"Cannot determine time range for comparison because the intersection of the",
"coverage windows obtained by examining kernel provided on the command line does",
"not overlap the time range specified in the command line using '-b' and/or '-e'",
"keys. Coverage for the PCK frame 'ITRF93' (class ID '3000') was determined from",
"PCK file 'frmdiff_pck_cov12_id12.bpc'. Comparison window specified on the",
"command line was all times after '2009-01-01'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only PCK, contains data for two same "cov" frames, stop time too early',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls -c1 ITRF93 -c2 ITRF93 -e 2007-01-01 frmdiff_pck_cov12_id12.bpc',
  18,
"SPICE(NOTIMEBOUNDS10)",
"Cannot determine time range for comparison because the intersection of the",
"coverage windows obtained by examining kernel provided on the command line does",
"not overlap the time range specified in the command line using '-b' and/or '-e'",
"keys. Coverage for the PCK frame 'ITRF93' (class ID '3000') was determined from",
"PCK file 'frmdiff_pck_cov12_id12.bpc'. Comparison window specified on the",
"command line was all times before '2007-01-01'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-s with non-number',
  'failure',
  $frmdiff,
  '-s boo frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id1.bpc',
  13,
"SPICE(NOTANDPNUMBER)",
"Time step 'boo' specified after '-s' key is not a DP number.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-s without value',
  'failure',
  $frmdiff,
  '-s frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id1.bpc',
  13,
"SPICE(NOTANDPNUMBER)",
"Time step ' ' specified after '-s' key is not a DP number.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-s with step smaller than allowed',
  'failure',
  $frmdiff,
  '-s 0.000000001 frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id1.bpc',
  14,
"SPICE(STEPTOOSMALL1)",
"Time step '0.000000001' specified after '-s' key is smaller than",
"1.0000000000000E-08 seconds.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-s with small step resulting in too many steps, two CKs/PCKs and time range',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls -s 0.00001 -b 2007-01-01 frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov2_id1.bpc',
  23,
"SPICE(STEPTOOSMALL2)",
"The number of points within the comparison window determined using step of",
"'1.0000000000000E-05' seconds specified after the command line key '-s' is",
"greater than can fit into program's buffers (1000000 epochs maximum.) Increase",
"the step or use command line keys '-b' and '-e' to make the time window smaller",
"in order to run the program. The comparison window was determined by applying",
"constraints specified on the command line to the intersection of coverages",
"obtained from the files. Coverage for the PCK frame 'ITRF93' (class ID '3000')",
"was determined from PCK file 'frmdiff_pck_cov1_id1.bpc'. Coverage for the PCK",
"frame 'ITRF93' (class ID '3000') was determined from PCK file",
"'frmdiff_pck_cov2_id1.bpc'. Comparison window specified on the command line was",
"all times after '2007-01-01'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-s with small step resulting in too many steps, first CK/PCK and time range',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls -s 0.00001 -b 2007-01-01 frmdiff_pck_cov1_id1.bpc frmdiff_fk.tf',
  21,
"SPICE(STEPTOOSMALL2)",
"The number of points within the comparison window determined using step of",
"'1.0000000000000E-05' seconds specified after the command line key '-s' is",
"greater than can fit into program's buffers (1000000 epochs maximum.) Increase",
"the step or use command line keys '-b' and '-e' to make the time window smaller",
"in order to run the program. The comparison window was determined by applying",
"constraints specified on the command line to the coverage obtained from the",
"file. Coverage for the PCK frame 'ITRF93' (class ID '3000') was determined from",
"PCK file 'frmdiff_pck_cov1_id1.bpc'. Comparison window specified on the command",
"line was all times after '2007-01-01'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-s with small step resulting in too many steps, only CK/PCK and time range',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls -s 0.00001 -b 2007-01-01 frmdiff_pck_cov1_id1.bpc',
  21,
"SPICE(STEPTOOSMALL2)",
"The number of points within the comparison window determined using step of",
"'1.0000000000000E-05' seconds specified after the command line key '-s' is",
"greater than can fit into program's buffers (1000000 epochs maximum.) Increase",
"the step or use command line keys '-b' and '-e' to make the time window smaller",
"in order to run the program. The comparison window was determined by applying",
"constraints specified on the command line to the intersection of coverages",
"obtained from the files. Coverage for the PCK frame 'ITRF93' (class ID '3000')",
"was determined from PCK file 'frmdiff_pck_cov1_id1.bpc'. Comparison window",
"specified on the command line was all times after '2007-01-01'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-s with small step resulting in too many steps, only time range',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls -s 0.00001 -b 2007-01-01 -e 2008-01-01 -f1 J2000 -t1 ECLIPJ2000 frmdiff_fk.tf',
  19,
"SPICE(STEPTOOSMALL2)",
"The number of points within the comparison window determined using step of",
"'1.0000000000000E-05' seconds specified after the command line key '-s' is",
"greater than can fit into program's buffers (1000000 epochs maximum.) Increase",
"the step or use command line keys '-b' and '-e' to make the time window smaller",
"in order to run the program. The comparison window was specified on the command",
"line. Comparison window specified on the command line was from '2007-01-01' to",
"'2008-01-01'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-s with small step resulting in too many steps, two CKs/PCKs',
  'failure',
  $frmdiff,
  '-s 0.00001 frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov2_id1.bpc',
  21,
"SPICE(STEPTOOSMALL2)",
"The number of points within the comparison window determined using step of",
"'1.0000000000000E-05' seconds specified after the command line key '-s' is",
"greater than can fit into program's buffers (1000000 epochs maximum.) Increase",
"the step or use command line keys '-b' and '-e' to make the time window smaller",
"in order to run the program. The comparison window was determined by",
"intersecting coverages obtained from the files. Coverage for the PCK frame",
"'ITRF93' (class ID '3000') was determined from PCK file",
"'frmdiff_pck_cov1_id1.bpc'. Coverage for the PCK frame 'ITRF93' (class ID",
"'3000') was determined from PCK file 'frmdiff_pck_cov2_id1.bpc'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-s with small step resulting in too many steps, first CK/PCK second not CK/PCK',
  'failure',
  $frmdiff,
  '-s 0.00001 frmdiff_pck_cov1_id1.bpc frmdiff_fk.tf',
  19,
"SPICE(STEPTOOSMALL2)",
"The number of points within the comparison window determined using step of",
"'1.0000000000000E-05' seconds specified after the command line key '-s' is",
"greater than can fit into program's buffers (1000000 epochs maximum.) Increase",
"the step or use command line keys '-b' and '-e' to make the time window smaller",
"in order to run the program. The comparison window was determined from the",
"file. Coverage for the PCK frame 'ITRF93' (class ID '3000') was determined from",
"PCK file 'frmdiff_pck_cov1_id1.bpc'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-s with small step resulting in too many steps, only CK/PCK',
  'failure',
  $frmdiff,
  '-s 0.00001 frmdiff_pck_cov1_id1.bpc',
  20,
"SPICE(STEPTOOSMALL2)",
"The number of points within the comparison window determined using step of",
"'1.0000000000000E-05' seconds specified after the command line key '-s' is",
"greater than can fit into program's buffers (1000000 epochs maximum.) Increase",
"the step or use command line keys '-b' and '-e' to make the time window smaller",
"in order to run the program. The comparison window was determined by",
"intersecting coverages obtained from the files. Coverage for the PCK frame",
"'ITRF93' (class ID '3000') was determined from PCK file",
"'frmdiff_pck_cov1_id1.bpc'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-s with small step resulting in too many steps, coverage with more that one interval',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf -s 0.00015 frmdiff_ck_cov13_id1.bc',
  20,
"SPICE(STEPTOOSMALL2)",
"The number of points within the comparison window determined using step of",
"'1.5000000000000E-04' seconds specified after the command line key '-s' is",
"greater than can fit into program's buffers (1000000 epochs maximum.) Increase",
"the step or use command line keys '-b' and '-e' to make the time window smaller",
"in order to run the program. The comparison window was determined by",
"intersecting coverages obtained from the files. Coverage for the CK frame",
"'PHX_PAYLOAD' (class ID '-84100') was determined from CK file",
"'frmdiff_ck_cov13_id1.bc'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-n with less than 1',
  'failure',
  $frmdiff,
  '-n 0 frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id1.bpc',
  14,
"SPICE(BADNUMBEROFPOINTS)",
"Number of points must be an integer number between 1 and 1000000. The number of",
"points specified after the '-n' key was 0.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-n with more than 1000000',
  'failure',
  $frmdiff,
  '-n 2000000 frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id1.bpc',
  14,
"SPICE(BADNUMBEROFPOINTS)",
"Number of points must be an integer number between 1 and 1000000. The number of",
"points specified after the '-n' key was 2000000.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-n with non-integer value',
  'failure',
  $frmdiff,
  '-n boo frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id1.bpc',
  13,
"SPICE(NOTANINTEGERNUMBER)",
"Number of points 'boo' specified after '-n' key is not an integer number.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-n without value',
  'failure',
  $frmdiff,
  '-n frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id1.bpc',
  13,
"SPICE(NOTANINTEGERNUMBER)",
"Number of points ' ' specified after '-n' key is not an integer number.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t with unrecognized value',
  'failure',
  $frmdiff,
  '-t boo frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id1.bpc',
  15,
"SPICE(BADOUTPUTTYPE)",
"Output type 'boo' specified after '-t' key is not recognized. Recognized output",
"types are 'basic', 'stats', 'dumpaa', 'dumpm', 'dumpqs', 'dumpqo', 'dumpea',",
"'dumpc', and 'dumpg'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t without value',
  'failure',
  $frmdiff,
  '-t frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id1.bpc',
  15,
"SPICE(BADOUTPUTTYPE)",
"Output type ' ' specified after '-t' key is not recognized. Recognized output",
"types are 'basic', 'stats', 'dumpaa', 'dumpm', 'dumpqs', 'dumpqo', 'dumpea',",
"'dumpc', and 'dumpg'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-f without value',
  'failure',
  $frmdiff,
  '-f -k frmdiff_lsk.tls -t dumpm frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id1.bpc',
  13,
"SPICE(BLANKTIMEFORMAT)",
"The time format specified after the '-f' key was blank.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-f with "sclk", two "to" and two "cov" frames not CK frames',
  'failure',
  $frmdiff,
  '-f sclk -t dumpm -t1 J2000 -c1 ITRF93 -t2 ECLIPJ2000 -c2 IAU_EARTH frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id2.bpc',
  15,
"SPICE(FORMATDOESNTAPPLY)",
"The 'sclk' time format specified after the '-f' key cannot be used when neither",
"of the 'to' frames ('J2000' and 'ECLIPJ2000') and coverage look up frames (PCK",
"frames with class IDs 3000 and 399) is a CK-based (class 3) frame.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-f with "sclk", two "to" and first "cov" frames not CK frames',
  'failure',
  $frmdiff,
  '-f sclk -t dumpm -t1 J2000 -c1 ITRF93 -t2 ECLIPJ2000 -f2 IAU_MARS frmdiff_pck_cov1_id1.bpc frmdiff_fk.tf',
  15,
"SPICE(FORMATDOESNTAPPLY)",
"The 'sclk' time format specified after the '-f' key cannot be used when neither",
"of the 'to' frames ('J2000' and 'ECLIPJ2000') and coverage look up frame (PCK",
"frame with class ID 3000) is a CK-based (class 3) frame.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-f with "sclk", two "to" and second "cov" frames not CK frames',
  'failure',
  $frmdiff,
  '-f sclk -t dumpm -t1 J2000 -f1 IAU_MARS -t2 ECLIPJ2000 -c2 IAU_EARTH frmdiff_fk.tf frmdiff_pck_cov1_id2.bpc',
  15,
"SPICE(FORMATDOESNTAPPLY)",
"The 'sclk' time format specified after the '-f' key cannot be used when neither",
"of the 'to' frames ('J2000' and 'ECLIPJ2000') and coverage look up frame (PCK",
"frame with class ID 399) is a CK-based (class 3) frame.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-f with "sclk", two "to" frames not CK frames',
  'failure',
  $frmdiff,
  '-f sclk -k frmdiff_lsk.tls -b 2001-01-01 -e 2001-01-02  -t dumpm -f sclk -t1 J2000 -f1 IAU_VENUS -t2 ECLIPJ2000 -f2 IAU_MARS frmdiff_fk.tf frmdiff_pck.tpc',
  14,
"SPICE(FORMATDOESNTAPPLY)",
"The 'sclk' time format specified after the '-f' key cannot be used when neither",
"of the 'to' frames ('J2000' and 'ECLIPJ2000') is a CK-based (class 3) frame.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-f with "sclkd", two "to" and two "cov" frames not CK frames',
  'failure',
  $frmdiff,
  '-f sclkd -t dumpm -t1 J2000 -c1 ITRF93 -t2 ECLIPJ2000 -c2 IAU_EARTH frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id2.bpc',
  15,
"SPICE(FORMATDOESNTAPPLY)",
"The 'sclkd' time format specified after the '-f' key cannot be used when",
"neither of the 'to' frames ('J2000' and 'ECLIPJ2000') and coverage look up",
"frames (PCK frames with class IDs 3000 and 399) is a CK-based (class 3) frame.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-f with "sclkd", two "to" and first "cov" frames not CK frames',
  'failure',
  $frmdiff,
  '-f sclkd -t dumpm -t1 J2000 -c1 ITRF93 -t2 ECLIPJ2000 -f2 IAU_VENUS frmdiff_pck_cov1_id1.bpc frmdiff_fk.tf',
  15,
"SPICE(FORMATDOESNTAPPLY)",
"The 'sclkd' time format specified after the '-f' key cannot be used when",
"neither of the 'to' frames ('J2000' and 'ECLIPJ2000') and coverage look up",
"frame (PCK frame with class ID 3000) is a CK-based (class 3) frame.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-f with "sclkd", two "to" and second "cov" frames not CK frames',
  'failure',
  $frmdiff,
  '-f sclkd -t dumpm -t1 J2000 -f1 IAU_VENUS -t2 ECLIPJ2000 -c2 IAU_EARTH frmdiff_fk.tf frmdiff_pck_cov1_id2.bpc',
  15,
"SPICE(FORMATDOESNTAPPLY)",
"The 'sclkd' time format specified after the '-f' key cannot be used when",
"neither of the 'to' frames ('J2000' and 'ECLIPJ2000') and coverage look up",
"frame (PCK frame with class ID 399) is a CK-based (class 3) frame.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-f with "sclkd", two "to" frames not CK frames',
  'failure',
  $frmdiff,
  '-f sclkd -k frmdiff_lsk.tls -b 2001-01-01 -e 2001-01-02  -t dumpm -t1 J2000 -f1 IAU_VENUS -t2 ECLIPJ2000 -f1 IAU_MARS frmdiff_fk.tf frmdiff_pck.tpc',
  15,
"SPICE(FORMATDOESNTAPPLY)",
"The 'sclkd' time format specified after the '-f' key cannot be used when",
"neither of the 'to' frames ('J2000' and 'ECLIPJ2000') is a CK-based (class 3)",
"frame.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-f with "ticks", two "to" and two "cov" frames not CK frames',
  'failure',
  $frmdiff,
  '-t dumpm -f ticks -t1 J2000 -c1 ITRF93 -t2 ECLIPJ2000 -c2 IAU_EARTH frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id2.bpc',
  15,
"SPICE(FORMATDOESNTAPPLY)",
"The 'ticks' time format specified after the '-f' key cannot be used when",
"neither of the 'to' frames ('J2000' and 'ECLIPJ2000') and coverage look up",
"frames (PCK frames with class IDs 3000 and 399) is a CK-based (class 3) frame.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-f with "ticks", two "to" and first "cov" frames not CK frames',
  'failure',
  $frmdiff,
  '-t dumpm -f ticks -t1 J2000 -c1 ITRF93 -t2 ECLIPJ2000 -f2 IAU_VENUS frmdiff_pck_cov1_id1.bpc frmdiff_fk.tf',
  15,
"SPICE(FORMATDOESNTAPPLY)",
"The 'ticks' time format specified after the '-f' key cannot be used when",
"neither of the 'to' frames ('J2000' and 'ECLIPJ2000') and coverage look up",
"frame (PCK frame with class ID 3000) is a CK-based (class 3) frame.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-f with "ticks", two "to" and second "cov" frames not CK frames',
  'failure',
  $frmdiff,
  '-t dumpm -f ticks -t1 J2000 -f1 IAU_VENUS -t2 ECLIPJ2000 -c2 IAU_EARTH frmdiff_fk.tf frmdiff_pck_cov1_id2.bpc',
  15,
"SPICE(FORMATDOESNTAPPLY)",
"The 'ticks' time format specified after the '-f' key cannot be used when",
"neither of the 'to' frames ('J2000' and 'ECLIPJ2000') and coverage look up",
"frame (PCK frame with class ID 399) is a CK-based (class 3) frame.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-f with "ticks", two "to" frames not CK frames',
  'failure',
  $frmdiff,
  '-f ticks -k frmdiff_lsk.tls -b 2001-01-01 -e 2001-01-02 -t dumpm -t1 J2000 -f1 IAU_VENUS -t2 ECLIPJ2000 -f1 IAU_MARS frmdiff_fk.tf frmdiff_pck.tpc',
  15,
"SPICE(FORMATDOESNTAPPLY)",
"The 'ticks' time format specified after the '-f' key cannot be used when",
"neither of the 'to' frames ('J2000' and 'ECLIPJ2000') is a CK-based (class 3)",
"frame.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-o without value',
  'failure',
  $frmdiff,
  '-o -t dumpea frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id1.bpc',
  14,
"SPICE(BADROTATIONORDER3)",
"The rotation order ' ' specified after the '-o' key is not a set of three",
"space-delimited axes identifiers (x, y, z).",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-o with one axis',
  'failure',
  $frmdiff,
  '-o x -t dumpea frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id1.bpc',
  14,
"SPICE(BADROTATIONORDER3)",
"The rotation order 'x' specified after the '-o' key is not a set of three",
"space-delimited axes identifiers (x, y, z).",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-o with two axes',
  'failure',
  $frmdiff,
  '-o x y -t dumpea frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id1.bpc',
  14,
"SPICE(BADROTATIONORDER3)",
"The rotation order 'x y' specified after the '-o' key is not a set of three",
"space-delimited axes identifiers (x, y, z).",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-o with four axes',
  'failure',
  $frmdiff,
  '-o x y z x -t dumpea frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id1.bpc',
  14,
"SPICE(BADROTATIONORDER3)",
"The rotation order 'x y z x' specified after the '-o' key is not a set of three",
"space-delimited axes identifiers (x, y, z).",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-o with three axes, unrecoginized first axis',
  'failure',
  $frmdiff,
  '-o 1 y z -t dumpea frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id1.bpc',
  14,
"SPICE(BADROTATIONORDER1)",
"Token '1' in the rotation order '1 y z' specified after after the '-o' key is",
"not one of the recognized axis identifiers (x, y, z).",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-o with three axes, unrecoginized second axis',
  'failure',
  $frmdiff,
  '-o x 2 z -t dumpea frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id1.bpc',
  14,
"SPICE(BADROTATIONORDER1)",
"Token '2' in the rotation order 'x 2 z' specified after after the '-o' key is",
"not one of the recognized axis identifiers (x, y, z).",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-o with three axes, unrecoginized third axis',
  'failure',
  $frmdiff,
  '-o x y 3 -t dumpea frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id1.bpc',
  14,
"SPICE(BADROTATIONORDER1)",
"Token '3' in the rotation order 'x y 3' specified after after the '-o' key is",
"not one of the recognized axis identifiers (x, y, z).",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-o with three axes, first and second same axes',
  'failure',
  $frmdiff,
  '-o x x z -t dumpea frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id1.bpc',
  14,
"SPICE(BADROTATIONORDER2)",
"Middle axis in the rotation order 'x x z' specified after the '-o' key matches",
"one of the neighbors.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-o with three axes, second and third same axes',
  'failure',
  $frmdiff,
  '-o x z z -t dumpea frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id1.bpc',
  14,
"SPICE(BADROTATIONORDER2)",
"Middle axis in the rotation order 'x z z' specified after the '-o' key matches",
"one of the neighbors.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-o with three axes, comma delimited, -t dumpea',
  'failure',
  $frmdiff,
  '-o x, y, z -t dumpea frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id1.bpc',
  14,
"SPICE(BADROTATIONORDER1)",
"Token 'x,' in the rotation order 'x, y, z' specified after after the '-o' key",
"is not one of the recognized axis identifiers (x, y, z).",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-o with three axes, comma delimited, -t dumpaa',
  'failure',
  $frmdiff,
  '-o x, y, z -t dumpaa frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id1.bpc',
  14,
"SPICE(BADROTATIONORDER1)",
"Token 'x,' in the rotation order 'x, y, z' specified after after the '-o' key",
"is not one of the recognized axis identifiers (x, y, z).",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-x without value',
  'failure',
  $frmdiff,
  '-x -t dumpea frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id1.bpc',
  14,
"SPICE(BADANGLEUNITS)",
"The angle units ' ' specified after the '-x' key are not recognized. Refer to",
"the program's User's Guide for the list of supported units.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-x with unrecognized value, -t dumpea',
  'failure',
  $frmdiff,
  '-x km -t dumpea frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id1.bpc',
  14,
"SPICE(BADANGLEUNITS)",
"The angle units 'km' specified after the '-x' key are not recognized. Refer to",
"the program's User's Guide for the list of supported units.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-x with unrecognized value, -t dumpaa',
  'failure',
  $frmdiff,
  '-x km -t dumpaa frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id1.bpc',
  14,
"SPICE(BADANGLEUNITS)",
"The angle units 'km' specified after the '-x' key are not recognized. Refer to",
"the program's User's Guide for the list of supported units.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> CHWCML"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, sampling same files-from-to-k1-k2, jeopadized run 0, for first attitude, offending file with -k',
  'failure',
  $frmdiff,
  '-k frmdiff_ck_cov2_id1.bc frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  18,
"SPICE(JEOPARDIZEDRUN0)",
"The attitude must not be computable using only supporting kernels",
"'frmdiff_ck_cov2_id1.bc frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf",
"frmdiff_pck.tpc' provided after the keys '-k' and '-k1' without loading the",
"first kernel 'frmdiff_ck_cov1_id1.bc'. Position (3x3) transformation from",
"'PHX_LL' frame to 'PHX_PAYLOAD' frame could be computed at ET",
"2.5000010000000E+08.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, sampling same files-from-to-k1-k2, jeopadized run 0, for first attitude, offending file with -k1',
  'failure',
  $frmdiff,
  '-k1 frmdiff_ck_cov2_id1.bc -k2 frmdiff_ck_cov2_id1.bc -k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  18,
"SPICE(JEOPARDIZEDRUN0)",
"The attitude must not be computable using only supporting kernels",
"'frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc",
"frmdiff_ck_cov2_id1.bc' provided after the keys '-k' and '-k1' without loading",
"the first kernel 'frmdiff_ck_cov1_id1.bc'. Position (3x3) transformation from",
"'PHX_LL' frame to 'PHX_PAYLOAD' frame could be computed at ET",
"2.5000010000000E+08.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, sampling same files-from-to-k1-k2, not enough data 0, for first attitude, in first file',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc -n 1 -f1 PHX_LL -t1 PHX_LANDER frmdiff_ck_cov1_id2.bc frmdiff_ck_cov1_id2.bc',
  28,
"SPICE(NOTENOUGHDATA0)",
"The attitude must be computable using the first kernel 'frmdiff_ck_cov1_id2.bc'",
"and supporting kernels 'frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf",
"frmdiff_pck.tpc' provided after the keys '-k' and '-k1'. Position (3x3)",
"transformation from 'PHX_LL' frame to 'PHX_LANDER' frame could not be computed",
"at ET 2.5000000000000E+08. PXFORM error was: At epoch 2.5000000000000E+08 TDB",
"(2007 DEC 04 00:26:40.000 TDB), there is insufficient information available to",
"transform from reference frame -84903 (PHX_LL) to reference frame -84001",
"(PHX_LANDER). Frame PHX_LL could be transformed to frame 1 (J2000). Frame",
"PHX_LANDER could be transformed to frame -84100 (PHX_PAYLOAD). The latter is a",
"CK frame; a CK file containing data for instrument or structure -84100 at the",
"epoch shown above, as well as a corresponding SCLK kernel, must be loaded in",
"order to use this frame. Failure to find required CK data could be due to one",
"or more CK files not having been loaded, or to the epoch shown above lying",
"within a coverage gap or beyond the coverage bounds of the loaded CK files. You",
"can use CKBRIEF with the -dump option to display coverage intervals of a CK",
"file.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different "from" frames, jeopadized run 1, for first attitude, offending file with -k',
  'failure',
  $frmdiff,
  '-k frmdiff_ck_cov2_id1.bc frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  18,
"SPICE(JEOPARDIZEDRUN1)",
"The first attitude to be compared must not be computable using only supporting",
"kernels 'frmdiff_ck_cov2_id1.bc frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf",
"frmdiff_pck.tpc' provided after the keys '-k' and '-k1' without loading the",
"first kernel 'frmdiff_ck_cov1_id1.bc'. Position (3x3) transformation from",
"'PHX_LL' frame to 'PHX_PAYLOAD' frame could be computed at ET",
"2.5000010000000E+08.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different "from" frames, jeopadized run 1, for first attitude, offending file with -k1',
  'failure',
  $frmdiff,
  '-k1 frmdiff_ck_cov2_id1.bc -k2 frmdiff_ck_cov2_id1.bc -k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  18,
"SPICE(JEOPARDIZEDRUN1)",
"The first attitude to be compared must not be computable using only supporting",
"kernels 'frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc",
"frmdiff_ck_cov2_id1.bc' provided after the keys '-k' and '-k1' without loading",
"the first kernel 'frmdiff_ck_cov1_id1.bc'. Position (3x3) transformation from",
"'PHX_LL' frame to 'PHX_PAYLOAD' frame could be computed at ET",
"2.5000010000000E+08.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different "from" frames, not enough data 1, for first attitude, in first file',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc -n 1 -f1 PHX_LL -t1 PHX_LANDER -f2 PHX_PAYLOAD frmdiff_ck_cov1_id2.bc frmdiff_ck_cov1_id2.bc',
  28,
"SPICE(NOTENOUGHDATA1)",
"The first attitude to be compared must be computable using the first kernel",
"'frmdiff_ck_cov1_id2.bc' and supporting kernels 'frmdiff_lsk.tls",
"frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc' provided after the keys '-k'",
"and '-k1'. Position (3x3) transformation from 'PHX_LL' frame to 'PHX_LANDER'",
"frame could not be computed at ET 2.5000000000000E+08. PXFORM error was: At",
"epoch 2.5000000000000E+08 TDB (2007 DEC 04 00:26:40.000 TDB), there is",
"insufficient information available to transform from reference frame -84903",
"(PHX_LL) to reference frame -84001 (PHX_LANDER). Frame PHX_LL could be",
"transformed to frame 1 (J2000). Frame PHX_LANDER could be transformed to frame",
"-84100 (PHX_PAYLOAD). The latter is a CK frame; a CK file containing data for",
"instrument or structure -84100 at the epoch shown above, as well as a",
"corresponding SCLK kernel, must be loaded in order to use this frame. Failure",
"to find required CK data could be due to one or more CK files not having been",
"loaded, or to the epoch shown above lying within a coverage gap or beyond the",
"coverage bounds of the loaded CK files. You can use CKBRIEF with the -dump",
"option to display coverage intervals of a CK file.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different "from" frames, jeopadized run 2, for second attitude, offending file with -k',
  'failure',
  $frmdiff,
  '-k frmdiff_ck_cov2_id2.bc frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  18,
"SPICE(JEOPARDIZEDRUN2)",
"The second attitude to be compared must not be computable using only supporting",
"kernels 'frmdiff_ck_cov2_id2.bc frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf",
"frmdiff_pck.tpc' provided after the keys '-k' and '-k2' without loading the",
"second kernel 'frmdiff_ck_cov1_id1.bc'. Position (3x3) transformation from",
"'PHX_PAYLOAD' frame to 'PHX_PAYLOAD' frame could be computed at ET",
"2.5000000000000E+08.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different "from" frames, jeopadized run 2, for second attitude, offending file with -k2',
  'failure',
  $frmdiff,
  '-k1 frmdiff_ck_cov2_id2.bc -k2 frmdiff_ck_cov2_id2.bc -k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  18,
"SPICE(JEOPARDIZEDRUN2)",
"The second attitude to be compared must not be computable using only supporting",
"kernels 'frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc",
"frmdiff_ck_cov2_id2.bc' provided after the keys '-k' and '-k2' without loading",
"the second kernel 'frmdiff_ck_cov1_id1.bc'. Position (3x3) transformation from",
"'PHX_PAYLOAD' frame to 'PHX_PAYLOAD' frame could be computed at ET",
"2.5000000000000E+08.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different "from" frames, not enough data 2, for second attitude, in second file',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 PHX_LANDER frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  27,
"SPICE(NOTENOUGHDATA2)",
"The second attitude to be compared must be computable using the second kernel",
"'frmdiff_ck_cov1_id1.bc' and supporting kernels 'frmdiff_lsk.tls",
"frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc' provided after the keys '-k'",
"and '-k2'. Position (3x3) transformation from 'PHX_LANDER' frame to",
"'PHX_PAYLOAD' frame could not be computed at ET 2.5000000000000E+08. PXFORM",
"error was: At epoch 2.5000000000000E+08 TDB (2007 DEC 04 00:26:40.000 TDB),",
"there is insufficient information available to transform from reference frame",
"-84001 (PHX_LANDER) to reference frame -84100 (PHX_PAYLOAD). PHX_LANDER is a CK",
"frame; a CK file containing data for instrument or structure -84001 at the",
"epoch shown above, as well as a corresponding SCLK kernel, must be loaded in",
"order to use this frame. Frame PHX_PAYLOAD could be transformed to frame 1",
"(J2000). Failure to find required CK data could be due to one or more CK files",
"not having been loaded, or to the epoch shown above lying within a coverage gap",
"or beyond the coverage bounds of the loaded CK files. You can use CKBRIEF with",
"the -dump option to display coverage intervals of a CK file.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different "to" frames, jeopadized run 1, for first attitude, offending file with -k',
  'failure',
  $frmdiff,
  '-k frmdiff_ck_cov2_id1.bc frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD -t2 PHX_LANDER frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  18,
"SPICE(JEOPARDIZEDRUN1)",
"The first attitude to be compared must not be computable using only supporting",
"kernels 'frmdiff_ck_cov2_id1.bc frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf",
"frmdiff_pck.tpc' provided after the keys '-k' and '-k1' without loading the",
"first kernel 'frmdiff_ck_cov1_id1.bc'. Position (3x3) transformation from",
"'PHX_LL' frame to 'PHX_PAYLOAD' frame could be computed at ET",
"2.5000010000000E+08.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different "to" frames, jeopadized run 1, for first attitude, offending file with -k1',
  'failure',
  $frmdiff,
  '-k1 frmdiff_ck_cov2_id1.bc -k2 frmdiff_ck_cov2_id1.bc -k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD -t2 PHX_LANDER frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  18,
"SPICE(JEOPARDIZEDRUN1)",
"The first attitude to be compared must not be computable using only supporting",
"kernels 'frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc",
"frmdiff_ck_cov2_id1.bc' provided after the keys '-k' and '-k1' without loading",
"the first kernel 'frmdiff_ck_cov1_id1.bc'. Position (3x3) transformation from",
"'PHX_LL' frame to 'PHX_PAYLOAD' frame could be computed at ET",
"2.5000010000000E+08.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different "to" frames, not enough data 1, for first attitude, in first file',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc -n 1 -f1 PHX_LL -t1 PHX_LANDER -t2 PHX_PAYLOAD frmdiff_ck_cov1_id2.bc frmdiff_ck_cov1_id2.bc',
  28,
"SPICE(NOTENOUGHDATA1)",
"The first attitude to be compared must be computable using the first kernel",
"'frmdiff_ck_cov1_id2.bc' and supporting kernels 'frmdiff_lsk.tls",
"frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc' provided after the keys '-k'",
"and '-k1'. Position (3x3) transformation from 'PHX_LL' frame to 'PHX_LANDER'",
"frame could not be computed at ET 2.5000000000000E+08. PXFORM error was: At",
"epoch 2.5000000000000E+08 TDB (2007 DEC 04 00:26:40.000 TDB), there is",
"insufficient information available to transform from reference frame -84903",
"(PHX_LL) to reference frame -84001 (PHX_LANDER). Frame PHX_LL could be",
"transformed to frame 1 (J2000). Frame PHX_LANDER could be transformed to frame",
"-84100 (PHX_PAYLOAD). The latter is a CK frame; a CK file containing data for",
"instrument or structure -84100 at the epoch shown above, as well as a",
"corresponding SCLK kernel, must be loaded in order to use this frame. Failure",
"to find required CK data could be due to one or more CK files not having been",
"loaded, or to the epoch shown above lying within a coverage gap or beyond the",
"coverage bounds of the loaded CK files. You can use CKBRIEF with the -dump",
"option to display coverage intervals of a CK file.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different "to" frames, jeopadized run 2, for second attitude, offending file with -k',
  'failure',
  $frmdiff,
  '-k frmdiff_ck_cov2_id2.bc frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD -t2 PHX_LL frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  17,
"SPICE(JEOPARDIZEDRUN2)",
"The second attitude to be compared must not be computable using only supporting",
"kernels 'frmdiff_ck_cov2_id2.bc frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf",
"frmdiff_pck.tpc' provided after the keys '-k' and '-k2' without loading the",
"second kernel 'frmdiff_ck_cov1_id1.bc'. Position (3x3) transformation from",
"'PHX_LL' frame to 'PHX_LL' frame could be computed at ET 2.5000000000000E+08.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different "to" frames, jeopadized run 2, for second attitude, offending file with -k2',
  'failure',
  $frmdiff,
  '-k1 frmdiff_ck_cov2_id2.bc -k2 frmdiff_ck_cov2_id2.bc -k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD -t2 PHX_LL frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  17,
"SPICE(JEOPARDIZEDRUN2)",
"The second attitude to be compared must not be computable using only supporting",
"kernels 'frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc",
"frmdiff_ck_cov2_id2.bc' provided after the keys '-k' and '-k2' without loading",
"the second kernel 'frmdiff_ck_cov1_id1.bc'. Position (3x3) transformation from",
"'PHX_LL' frame to 'PHX_LL' frame could be computed at ET 2.5000000000000E+08.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different "to" frames, not enough data 2, for second attitude, in second file',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD -t2 PHX_LANDER frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  27,
"SPICE(NOTENOUGHDATA2)",
"The second attitude to be compared must be computable using the second kernel",
"'frmdiff_ck_cov1_id1.bc' and supporting kernels 'frmdiff_lsk.tls",
"frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc' provided after the keys '-k'",
"and '-k2'. Position (3x3) transformation from 'PHX_LL' frame to 'PHX_LANDER'",
"frame could not be computed at ET 2.5000000000000E+08. PXFORM error was: At",
"epoch 2.5000000000000E+08 TDB (2007 DEC 04 00:26:40.000 TDB), there is",
"insufficient information available to transform from reference frame -84903",
"(PHX_LL) to reference frame -84001 (PHX_LANDER). Frame PHX_LL could be",
"transformed to frame 1 (J2000). PHX_LANDER is a CK frame; a CK file containing",
"data for instrument or structure -84001 at the epoch shown above, as well as a",
"corresponding SCLK kernel, must be loaded in order to use this frame. Failure",
"to find required CK data could be due to one or more CK files not having been",
"loaded, or to the epoch shown above lying within a coverage gap or beyond the",
"coverage bounds of the loaded CK files. You can use CKBRIEF with the -dump",
"option to display coverage intervals of a CK file.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different -k1 and -k2, jeopadized run 1, for first attitude, offending file with -k',
  'failure',
  $frmdiff,
  '-k1 frmdiff_fk.tf -k2 frmdiff_lsk.tls -k frmdiff_ck_cov2_id1.bc frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  18,
"SPICE(JEOPARDIZEDRUN1)",
"The first attitude to be compared must not be computable using only supporting",
"kernels 'frmdiff_ck_cov2_id1.bc frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf",
"frmdiff_pck.tpc frmdiff_fk.tf' provided after the keys '-k' and '-k1' without",
"loading the first kernel 'frmdiff_ck_cov1_id1.bc'. Position (3x3)",
"transformation from 'PHX_LL' frame to 'PHX_PAYLOAD' frame could be computed at",
"ET 2.5000010000000E+08.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different -k1 and -k2, jeopadized run 1, for first attitude, offending file with -k1',
  'failure',
  $frmdiff,
  '-k1 frmdiff_ck_cov2_id1.bc -k2 frmdiff_lsk.tls -k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  18,
"SPICE(JEOPARDIZEDRUN1)",
"The first attitude to be compared must not be computable using only supporting",
"kernels 'frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc",
"frmdiff_ck_cov2_id1.bc' provided after the keys '-k' and '-k1' without loading",
"the first kernel 'frmdiff_ck_cov1_id1.bc'. Position (3x3) transformation from",
"'PHX_LL' frame to 'PHX_PAYLOAD' frame could be computed at ET",
"2.5000010000000E+08.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different -k1 and -k2, not enough data 1, for first attitude, in first file',
  'failure',
  $frmdiff,
  '-k2 frmdiff_ck_cov1_id1.bc -k1 frmdiff_sclk.tsc -k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc -n 1 -f1 PHX_LL -t1 PHX_LANDER frmdiff_ck_cov1_id2.bc frmdiff_ck_cov1_id2.bc',
  24,
"SPICE(NOTENOUGHDATA1)",
"The first attitude to be compared must be computable using the first kernel",
"'frmdiff_ck_cov1_id2.bc' and supporting kernels 'frmdiff_lsk.tls",
"frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc frmdiff_sclk.tsc' provided after",
"the keys '-k' and '-k1'. Position (3x3) transformation from 'PHX_LL' frame to",
"'PHX_LANDER' frame could not be computed at ET 2.5000000000000E+08. PXFORM",
"error was: At epoch 2.5000000000000E+08 TDB (2007 DEC 04 00:26:40.000 TDB),",
"there is insufficient information available to transform from reference frame",
"-84903 (PHX_LL) to reference frame -84001 (PHX_LANDER). Frame PHX_LL could be",
"transformed to frame 1 (J2000). Frame PHX_LANDER could be transformed to frame",
"-84100 (PHX_PAYLOAD). The latter is a CK frame; a CK file containing data for",
"instrument or structure -84100 at the epoch shown above, as well as a",
"corresponding SCLK kernel, must be loaded in",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different -k1 and -k2, jeopadized run 2, for second attitude, offending file with -k',
  'failure',
  $frmdiff,
  '-k1 frmdiff_lsk.tls -k2 frmdiff_ck_cov1_id1.bc -k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  18,
"SPICE(JEOPARDIZEDRUN2)",
"The second attitude to be compared must not be computable using only supporting",
"kernels 'frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc",
"frmdiff_ck_cov1_id1.bc' provided after the keys '-k' and '-k2' without loading",
"the second kernel 'frmdiff_ck_cov1_id1.bc'. Position (3x3) transformation from",
"'PHX_LL' frame to 'PHX_PAYLOAD' frame could be computed at ET",
"2.5000000000000E+08.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different -k1 and -k2, jeopadized run 2, for second attitude, offending file with -k2',
  'failure',
  $frmdiff,
  '-k1 frmdiff_lsk.tls -k2 frmdiff_ck_cov1_id1.bc -k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  18,
"SPICE(JEOPARDIZEDRUN2)",
"The second attitude to be compared must not be computable using only supporting",
"kernels 'frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc",
"frmdiff_ck_cov1_id1.bc' provided after the keys '-k' and '-k2' without loading",
"the second kernel 'frmdiff_ck_cov1_id1.bc'. Position (3x3) transformation from",
"'PHX_LL' frame to 'PHX_PAYLOAD' frame could be computed at ET",
"2.5000000000000E+08.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different -k1 and -k2, not enough data 2, for second attitude, in second file',
  'failure',
  $frmdiff,
  '-k1 frmdiff_ck_cov1_id1.bc -k2 frmdiff_sclk.tsc -k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc -n 1 -f1 PHX_LL -t1 PHX_LANDER frmdiff_ck_cov1_id2.bc frmdiff_ck_cov1_id2.bc',
  24,
"SPICE(NOTENOUGHDATA2)",
"The second attitude to be compared must be computable using the second kernel",
"'frmdiff_ck_cov1_id2.bc' and supporting kernels 'frmdiff_lsk.tls",
"frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc frmdiff_sclk.tsc' provided after",
"the keys '-k' and '-k2'. Position (3x3) transformation from 'PHX_LL' frame to",
"'PHX_LANDER' frame could not be computed at ET 2.5000000000000E+08. PXFORM",
"error was: At epoch 2.5000000000000E+08 TDB (2007 DEC 04 00:26:40.000 TDB),",
"there is insufficient information available to transform from reference frame",
"-84903 (PHX_LL) to reference frame -84001 (PHX_LANDER). Frame PHX_LL could be",
"transformed to frame 1 (J2000). Frame PHX_LANDER could be transformed to frame",
"-84100 (PHX_PAYLOAD). The latter is a CK frame; a CK file containing data for",
"instrument or structure -84100 at the epoch shown above, as well as a",
"corresponding SCLK kernel, must be loaded i",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different files, jeopadized run 1, for first attitude, offending file with -k',
  'failure',
  $frmdiff,
  '-k frmdiff_ck_cov2_id1.bc frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc frmdiff_ck_cov2_id1.bc',
  18,
"SPICE(JEOPARDIZEDRUN1)",
"The first attitude to be compared must not be computable using only supporting",
"kernels 'frmdiff_ck_cov2_id1.bc frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf",
"frmdiff_pck.tpc' provided after the keys '-k' and '-k1' without loading the",
"first kernel 'frmdiff_ck_cov1_id1.bc'. Position (3x3) transformation from",
"'PHX_LL' frame to 'PHX_PAYLOAD' frame could be computed at ET",
"2.5000007500000E+08.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different files, jeopadized run 1, for first attitude, offending file with -k1',
  'failure',
  $frmdiff,
  '-k1 frmdiff_ck_cov2_id1.bc -k2 frmdiff_ck_cov2_id1.bc -k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc frmdiff_ck_cov2_id1.bc',
  18,
"SPICE(JEOPARDIZEDRUN1)",
"The first attitude to be compared must not be computable using only supporting",
"kernels 'frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc",
"frmdiff_ck_cov2_id1.bc' provided after the keys '-k' and '-k1' without loading",
"the first kernel 'frmdiff_ck_cov1_id1.bc'. Position (3x3) transformation from",
"'PHX_LL' frame to 'PHX_PAYLOAD' frame could be computed at ET",
"2.5000007500000E+08.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different files, not enough data 1, for first attitude, in first file',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc frmdiff_ck_cov2_id1.bc',
  24,
"SPICE(NOTENOUGHDATA1)",
"The first attitude to be compared must be computable using the first kernel",
"'frmdiff_ck_cov1_id1.bc' and supporting kernels 'frmdiff_lsk.tls",
"frmdiff_sclk.tsc frmdiff_fk.tf' provided after the keys '-k' and '-k1'.",
"Position (3x3) transformation from 'PHX_LL' frame to 'PHX_PAYLOAD' frame could",
"not be computed at ET 2.5000007500000E+08. PXFORM error was: PCK data required",
"to compute the orientation of the body-fixed frame IAU_MARS for epoch 2007 DEC",
"04 00:27:55.000 TDB were not found. If these data were to be provided by a",
"binary PCK file, then it is possible that the PCK file does not have coverage",
"for the specified body-fixed frame at the time of interest. If the data were to",
"be provided by a text PCK file, then possibly the file does not contain data",
"for the specified body-fixed frame. In either case it is possible that a",
"required PCK file was not loaded at all.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different files, jeopadized run 2, for second attitude, offending file with -k',
  'failure',
  $frmdiff,
  '-k frmdiff_ck_cov1_id1.bc frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc frmdiff_ck_cov13_id1.bc',
  18,
"SPICE(JEOPARDIZEDRUN1)",
"The first attitude to be compared must not be computable using only supporting",
"kernels 'frmdiff_ck_cov1_id1.bc frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf",
"frmdiff_pck.tpc' provided after the keys '-k' and '-k1' without loading the",
"first kernel 'frmdiff_ck_cov1_id1.bc'. Position (3x3) transformation from",
"'PHX_LL' frame to 'PHX_PAYLOAD' frame could be computed at ET",
"2.5000000000000E+08.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different files, jeopadized run 2, for second attitude, offending file with -k2',
  'failure',
  $frmdiff,
  '-k1 frmdiff_ck_cov2_id1.bc -k2 frmdiff_ck_cov2_id1.bc -k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc frmdiff_ck_cov13_id1.bc',
  18,
"SPICE(JEOPARDIZEDRUN1)",
"The first attitude to be compared must not be computable using only supporting",
"kernels 'frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc",
"frmdiff_ck_cov2_id1.bc' provided after the keys '-k' and '-k1' without loading",
"the first kernel 'frmdiff_ck_cov1_id1.bc'. Position (3x3) transformation from",
"'PHX_LL' frame to 'PHX_PAYLOAD' frame could be computed at ET",
"2.5000010000000E+08.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different files, not enough data 2, for second attitude, in second file',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc frmdiff_pck.tpc',
  27,
"SPICE(NOTENOUGHDATA2)",
"The second attitude to be compared must be computable using the second kernel",
"'frmdiff_pck.tpc' and supporting kernels 'frmdiff_lsk.tls frmdiff_sclk.tsc",
"frmdiff_fk.tf frmdiff_pck.tpc' provided after the keys '-k' and '-k2'. Position",
"(3x3) transformation from 'PHX_LL' frame to 'PHX_PAYLOAD' frame could not be",
"computed at ET 2.5000000000000E+08. PXFORM error was: At epoch",
"2.5000000000000E+08 TDB (2007 DEC 04 00:26:40.000 TDB), there is insufficient",
"information available to transform from reference frame -84903 (PHX_LL) to",
"reference frame -84100 (PHX_PAYLOAD). Frame PHX_LL could be transformed to",
"frame 1 (J2000). PHX_PAYLOAD is a CK frame; a CK file containing data for",
"instrument or structure -84100 at the epoch shown above, as well as a",
"corresponding SCLK kernel, must be loaded in order to use this frame. Failure",
"to find required CK data could be due to one or more CK files not having been",
"loaded, or to the epoch shown above lying within a coverage gap or beyond the",
"coverage bounds of the loaded CK files. You can use CKBRIEF with the -dump",
"option to display coverage intervals of a CK file.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, sampling same from-to-k1-k2, jeopadized run 3, for first attitude, offending file with -k',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_ck_cov2_id1.bc -k1 frmdiff_pck.tpc -k2 frmdiff_pck.tpc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 phx_ll -t2 phx_payload frmdiff_ck_cov1_id1.bc',
  17,
"SPICE(JEOPARDIZEDRUN3)",
"The attitude must not be computable using only supporting kernels",
"'frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_ck_cov2_id1.bc",
"frmdiff_pck.tpc' provided after the keys '-k' and '-k1' without loading the",
"kernel 'frmdiff_ck_cov1_id1.bc'. Position (3x3) transformation from 'PHX_LL'",
"frame to 'PHX_PAYLOAD' frame could be computed at ET 2.5000010000000E+08.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, sampling same from-to-k1-k2, jeopadized run 3, for first attitude, offending file with -k1',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc -k1 frmdiff_ck_cov2_id1.bc -k2 frmdiff_ck_cov2_id1.bc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 phx_ll -t2 phx_payload frmdiff_ck_cov1_id1.bc',
  18,
"SPICE(JEOPARDIZEDRUN3)",
"The attitude must not be computable using only supporting kernels",
"'frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc",
"frmdiff_ck_cov2_id1.bc' provided after the keys '-k' and '-k1' without loading",
"the kernel 'frmdiff_ck_cov1_id1.bc'. Position (3x3) transformation from",
"'PHX_LL' frame to 'PHX_PAYLOAD' frame could be computed at ET",
"2.5000010000000E+08.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, sampling same from-to-k1-k2, not enough data 3, for first attitude, in only file',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_fk.tf -k1 frmdiff_pck.tpc -k2 frmdiff_pck.tpc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 phx_ll -t2 phx_payload -b 2001-01-01 -e 2001-01-02 frmdiff_sclk.tsc',
  23,
"SPICE(NOTENOUGHDATA3)",
"The attitude must be computable using the kernel 'frmdiff_sclk.tsc' and",
"supporting kernels 'frmdiff_lsk.tls frmdiff_fk.tf frmdiff_pck.tpc' provided",
"after the keys '-k' and '-k1'. Position (3x3) transformation from 'PHX_LL'",
"frame to 'PHX_PAYLOAD' frame could not be computed at ET 3.1579264183934E+07.",
"PXFORM error was: At epoch 3.1579264183934E+07 TDB (2001 JAN 01 00:01:04.183",
"TDB), there is insufficient information available to transform from reference",
"frame -84903 (PHX_LL) to reference frame -84100 (PHX_PAYLOAD). Frame PHX_LL",
"could be transformed to frame 1 (J2000). PHX_PAYLOAD is a CK frame; a CK file",
"containing data for instrument or structure -84100 at the epoch shown above, as",
"well as a corresponding SCLK kernel, must be loaded in order to use this frame.",
"Failure to find required CK data could be due to one or more CK files not h",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, different "from" frames, jeopadized run 4, for first attitude, offending file with -k',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_ck_cov2_id1.bc -k1 frmdiff_pck.tpc -k2 frmdiff_pck.tpc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 phx_lander -t2 phx_payload frmdiff_ck_cov1_id1.bc',
  17,
"SPICE(JEOPARDIZEDRUN4)",
"The first attitude to be compared must not be computable using only supporting",
"kernels 'frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_ck_cov2_id1.bc",
"frmdiff_pck.tpc' provided after the keys '-k' and '-k1' without loading the",
"kernel 'frmdiff_ck_cov1_id1.bc'. Position (3x3) transformation from 'PHX_LL'",
"frame to 'PHX_PAYLOAD' frame could be computed at ET 2.5000010000000E+08.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, different "from" frames, jeopadized run 4, for first attitude, offending file with -k1',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc -k1 frmdiff_ck_cov2_id1.bc -k2 frmdiff_ck_cov2_id1.bc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 phx_lander -t2 phx_payload frmdiff_ck_cov1_id1.bc',
  18,
"SPICE(JEOPARDIZEDRUN4)",
"The first attitude to be compared must not be computable using only supporting",
"kernels 'frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc",
"frmdiff_ck_cov2_id1.bc' provided after the keys '-k' and '-k1' without loading",
"the kernel 'frmdiff_ck_cov1_id1.bc'. Position (3x3) transformation from",
"'PHX_LL' frame to 'PHX_PAYLOAD' frame could be computed at ET",
"2.5000010000000E+08.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, different "from" frames, not enough data 4, for first attitude, in only file',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc -k1 frmdiff_ck_cov2_id1.bc -k2 frmdiff_ck_cov2_id1.bc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 phx_lander -t2 phx_payload -b 2001-01-01 -e 2001-01-02 frmdiff_sclk.tsc',
  24,
"SPICE(NOTENOUGHDATA4)",
"The first attitude to be compared must be computable using the kernel",
"'frmdiff_sclk.tsc' and supporting kernels 'frmdiff_lsk.tls frmdiff_sclk.tsc",
"frmdiff_fk.tf frmdiff_pck.tpc frmdiff_ck_cov2_id1.bc' provided after the keys",
"'-k' and '-k1'. Position (3x3) transformation from 'PHX_LL' frame to",
"'PHX_PAYLOAD' frame could not be computed at ET 3.1579264183934E+07. PXFORM",
"error was: At epoch 3.1579264183934E+07 TDB (2001 JAN 01 00:01:04.183 TDB),",
"there is insufficient information available to transform from reference frame",
"-84903 (PHX_LL) to reference frame -84100 (PHX_PAYLOAD). Frame PHX_LL could be",
"transformed to frame 1 (J2000). PHX_PAYLOAD is a CK frame; a CK file containing",
"data for instrument or structure -84100 at the epoch shown above, as well as a",
"corresponding SCLK kernel, must be loaded in order to use this frame. Failure",
"to find required CK data could be due t",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, different "from" frames, jeopadized run 5, for second attitude, offending file with -k',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_ck_cov2_id2.bc -k1 frmdiff_pck.tpc -k2 frmdiff_pck.tpc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 phx_lander -t2 phx_payload frmdiff_ck_cov12_id12.bc',
  18,
"SPICE(JEOPARDIZEDRUN5)",
"The second attitude to be compared must not be computable using only supporting",
"kernels 'frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_ck_cov2_id2.bc",
"frmdiff_pck.tpc' provided after the keys '-k' and '-k2' without loading the",
"kernel 'frmdiff_ck_cov12_id12.bc'. Position (3x3) transformation from",
"'phx_lander' frame to 'phx_payload' frame could be computed at ET",
"2.5000010000000E+08.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, different "from" frames, jeopadized run 5, for second attitude, offending file with -k2',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc -k1 frmdiff_ck_cov2_id2.bc -k2 frmdiff_ck_cov2_id2.bc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 phx_lander -t2 phx_payload frmdiff_ck_cov12_id12.bc',
  18,
"SPICE(JEOPARDIZEDRUN5)",
"The second attitude to be compared must not be computable using only supporting",
"kernels 'frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc",
"frmdiff_ck_cov2_id2.bc' provided after the keys '-k' and '-k2' without loading",
"the kernel 'frmdiff_ck_cov12_id12.bc'. Position (3x3) transformation from",
"'phx_lander' frame to 'phx_payload' frame could be computed at ET",
"2.5000010000000E+08.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, different "from" frames, not enough data 5, for second attitude, in only file',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_fk.tf frmdiff_ck_cov1_id1.bc -k1 frmdiff_pck.tpc -k2 frmdiff_pck.tpc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 phx_lander -t2 phx_payload -b 2007-DEC-04 00:26 -e 2007-DEC-04 00:26 frmdiff_sclk.tsc',
  24,
"SPICE(NOTENOUGHDATA5)",
"The second attitude to be compared must be computable using the kernel",
"'frmdiff_sclk.tsc' and supporting kernels 'frmdiff_lsk.tls frmdiff_fk.tf",
"frmdiff_ck_cov1_id1.bc frmdiff_pck.tpc' provided after the keys '-k' and '-k2'.",
"Position (3x3) transformation from 'phx_lander' frame to 'phx_payload' frame",
"could not be computed at ET 2.5000002518314E+08. PXFORM error was: At epoch",
"2.5000002518314E+08 TDB (2007 DEC 04 00:27:05.183 TDB), there is insufficient",
"information available to transform from reference frame -84001 (PHX_LANDER) to",
"reference frame -84100 (PHX_PAYLOAD). PHX_LANDER is a CK frame; a CK file",
"containing data for instrument or structure -84001 at the epoch shown above, as",
"well as a corresponding SCLK kernel, must be loaded in order to use this frame.",
"Frame PHX_PAYLOAD could be transformed to frame 1 (J2000). Failure to find",
"required CK data could be",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, different "to" frames, jeopadized run 4, for first attitude, offending file with -k',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_ck_cov2_id1.bc -k1 frmdiff_pck.tpc -k2 frmdiff_pck.tpc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 phx_ll -t2 phx_lander frmdiff_ck_cov1_id1.bc',
  17,
"SPICE(JEOPARDIZEDRUN4)",
"The first attitude to be compared must not be computable using only supporting",
"kernels 'frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_ck_cov2_id1.bc",
"frmdiff_pck.tpc' provided after the keys '-k' and '-k1' without loading the",
"kernel 'frmdiff_ck_cov1_id1.bc'. Position (3x3) transformation from 'PHX_LL'",
"frame to 'PHX_PAYLOAD' frame could be computed at ET 2.5000010000000E+08.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, different "to" frames, jeopadized run 4, for first attitude, offending file with -k1',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc -k1 frmdiff_ck_cov2_id1.bc -k2 frmdiff_ck_cov2_id1.bc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 phx_ll -t2 phx_lander frmdiff_ck_cov1_id1.bc',
  18,
"SPICE(JEOPARDIZEDRUN4)",
"The first attitude to be compared must not be computable using only supporting",
"kernels 'frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc",
"frmdiff_ck_cov2_id1.bc' provided after the keys '-k' and '-k1' without loading",
"the kernel 'frmdiff_ck_cov1_id1.bc'. Position (3x3) transformation from",
"'PHX_LL' frame to 'PHX_PAYLOAD' frame could be computed at ET",
"2.5000010000000E+08.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, different "to" frames, not enough data 4, for first attitude, in only file',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc -k1 frmdiff_ck_cov2_id1.bc -k2 frmdiff_ck_cov2_id1.bc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 phx_ll -t2 phx_lander -b 2001-01-01 -e 2001-01-02 frmdiff_sclk.tsc',
  24,
"SPICE(NOTENOUGHDATA4)",
"The first attitude to be compared must be computable using the kernel",
"'frmdiff_sclk.tsc' and supporting kernels 'frmdiff_lsk.tls frmdiff_sclk.tsc",
"frmdiff_fk.tf frmdiff_pck.tpc frmdiff_ck_cov2_id1.bc' provided after the keys",
"'-k' and '-k1'. Position (3x3) transformation from 'PHX_LL' frame to",
"'PHX_PAYLOAD' frame could not be computed at ET 3.1579264183934E+07. PXFORM",
"error was: At epoch 3.1579264183934E+07 TDB (2001 JAN 01 00:01:04.183 TDB),",
"there is insufficient information available to transform from reference frame",
"-84903 (PHX_LL) to reference frame -84100 (PHX_PAYLOAD). Frame PHX_LL could be",
"transformed to frame 1 (J2000). PHX_PAYLOAD is a CK frame; a CK file containing",
"data for instrument or structure -84100 at the epoch shown above, as well as a",
"corresponding SCLK kernel, must be loaded in order to use this frame. Failure",
"to find required CK data could be due t",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, different "to" frames, jeopadized run 5, for second attitude, offending file with -k',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc -k1 frmdiff_ck_cov2_id2.bc -k2 frmdiff_ck_cov2_id2.bc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 phx_ll -t2 iau_mars frmdiff_ck_cov13_id12.bc',
  17,
"SPICE(JEOPARDIZEDRUN5)",
"The second attitude to be compared must not be computable using only supporting",
"kernels 'frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc",
"frmdiff_ck_cov2_id2.bc' provided after the keys '-k' and '-k2' without loading",
"the kernel 'frmdiff_ck_cov13_id12.bc'. Position (3x3) transformation from",
"'phx_ll' frame to 'iau_mars' frame could be computed at ET 2.5000000000000E+08.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, different "to" frames, jeopadized run 5, for second attitude, offending file with -k2',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_ck_cov2_id2.bc -k1 frmdiff_pck.tpc -k2 frmdiff_pck.tpc  -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 phx_ll -t2 iau_mars frmdiff_ck_cov13_id12.bc',
  17,
"SPICE(JEOPARDIZEDRUN5)",
"The second attitude to be compared must not be computable using only supporting",
"kernels 'frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_ck_cov2_id2.bc",
"frmdiff_pck.tpc' provided after the keys '-k' and '-k2' without loading the",
"kernel 'frmdiff_ck_cov13_id12.bc'. Position (3x3) transformation from 'phx_ll'",
"frame to 'iau_mars' frame could be computed at ET 2.5000000000000E+08.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, different "to" frames, not enough data 5, for second attitude, in only file',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc -k1 frmdiff_ck_cov2_id2.bc -k2 frmdiff_ck_cov2_id2.bc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 phx_ll -t2 phx_lander frmdiff_ck_cov1_id1.bc',
  24,
"SPICE(NOTENOUGHDATA5)",
"The second attitude to be compared must be computable using the kernel",
"'frmdiff_ck_cov1_id1.bc' and supporting kernels 'frmdiff_lsk.tls",
"frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc frmdiff_ck_cov2_id2.bc' provided",
"after the keys '-k' and '-k2'. Position (3x3) transformation from 'phx_ll'",
"frame to 'phx_lander' frame could not be computed at ET 2.5000000000000E+08.",
"PXFORM error was: At epoch 2.5000000000000E+08 TDB (2007 DEC 04 00:26:40.000",
"TDB), there is insufficient information available to transform from reference",
"frame -84903 (PHX_LL) to reference frame -84001 (PHX_LANDER). Frame PHX_LL",
"could be transformed to frame 1 (J2000). PHX_LANDER is a CK frame; a CK file",
"containing data for instrument or structure -84001 at the epoch shown above, as",
"well as a corresponding SCLK kernel, must be loaded in order to use this frame.",
"Failure to find required CK data could be d",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, different -k1 and -k2, jeopadized run 4, for first attitude, offending file with -k',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_ck_cov1_id1.bc -k1 frmdiff_pck.tpc -k2 frmdiff_ck_cov2_id2.bc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 phx_ll -t2 phx_payload frmdiff_ck_cov1_id1.bc',
  17,
"SPICE(JEOPARDIZEDRUN4)",
"The first attitude to be compared must not be computable using only supporting",
"kernels 'frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_ck_cov1_id1.bc",
"frmdiff_pck.tpc' provided after the keys '-k' and '-k1' without loading the",
"kernel 'frmdiff_ck_cov1_id1.bc'. Position (3x3) transformation from 'PHX_LL'",
"frame to 'PHX_PAYLOAD' frame could be computed at ET 2.5000000000000E+08.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, different -k1 and -k2, jeopadized run 4, for first attitude, offending file with -k1',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc -k1 frmdiff_ck_cov1_id1.bc -k2 frmdiff_ck_cov2_id2.bc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 phx_ll -t2 phx_payload frmdiff_ck_cov1_id1.bc',
  18,
"SPICE(JEOPARDIZEDRUN4)",
"The first attitude to be compared must not be computable using only supporting",
"kernels 'frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc",
"frmdiff_ck_cov1_id1.bc' provided after the keys '-k' and '-k1' without loading",
"the kernel 'frmdiff_ck_cov1_id1.bc'. Position (3x3) transformation from",
"'PHX_LL' frame to 'PHX_PAYLOAD' frame could be computed at ET",
"2.5000000000000E+08.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, different -k1 and -k2, not enough data 4, for first attitude, in only file',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc -k1 frmdiff_ck_cov1_id2.bc -k2 frmdiff_ck_cov2_id2.bc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 phx_ll -t2 phx_payload -b 2001-01-01 -e 2001-01-02 frmdiff_sclk.tsc',
  24,
"SPICE(NOTENOUGHDATA4)",
"The first attitude to be compared must be computable using the kernel",
"'frmdiff_sclk.tsc' and supporting kernels 'frmdiff_lsk.tls frmdiff_sclk.tsc",
"frmdiff_fk.tf frmdiff_pck.tpc frmdiff_ck_cov1_id2.bc' provided after the keys",
"'-k' and '-k1'. Position (3x3) transformation from 'PHX_LL' frame to",
"'PHX_PAYLOAD' frame could not be computed at ET 3.1579264183934E+07. PXFORM",
"error was: At epoch 3.1579264183934E+07 TDB (2001 JAN 01 00:01:04.183 TDB),",
"there is insufficient information available to transform from reference frame",
"-84903 (PHX_LL) to reference frame -84100 (PHX_PAYLOAD). Frame PHX_LL could be",
"transformed to frame 1 (J2000). PHX_PAYLOAD is a CK frame; a CK file containing",
"data for instrument or structure -84100 at the epoch shown above, as well as a",
"corresponding SCLK kernel, must be loaded in order to use this frame. Failure",
"to find required CK data could be due t",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, different -k1 and -k2, jeopadized run 5, for second attitude, offending file with -k',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc -k1 frmdiff_ck_cov2_id2.bc -k2 frmdiff_ck_cov2_id1.bc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 phx_ll -t2 phx_payload frmdiff_ck_cov1_id1.bc',
  18,
"SPICE(JEOPARDIZEDRUN5)",
"The second attitude to be compared must not be computable using only supporting",
"kernels 'frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc",
"frmdiff_ck_cov2_id1.bc' provided after the keys '-k' and '-k2' without loading",
"the kernel 'frmdiff_ck_cov1_id1.bc'. Position (3x3) transformation from",
"'phx_ll' frame to 'phx_payload' frame could be computed at ET",
"2.5000010000000E+08.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, different -k1 and -k2, jeopadized run 5, for second attitude, offending file with -k2',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf -k1 frmdiff_pck.tpc -k2 frmdiff_pck.tpc frmdiff_ck_cov2_id1.bc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 phx_ll -t2 phx_payload frmdiff_ck_cov1_id1.bc',
  18,
"SPICE(JEOPARDIZEDRUN5)",
"The second attitude to be compared must not be computable using only supporting",
"kernels 'frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_pck.tpc",
"frmdiff_ck_cov2_id1.bc' provided after the keys '-k' and '-k2' without loading",
"the kernel 'frmdiff_ck_cov1_id1.bc'. Position (3x3) transformation from",
"'phx_ll' frame to 'phx_payload' frame could be computed at ET",
"2.5000010000000E+08.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, different -k1 and -k2, not enough data 5, for second attitude, in only file',
  'failure',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_fk.tf -k1 frmdiff_pck.tpc -k2 frmdiff_ck_cov1_id1.bc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 phx_ll -t2 phx_payload frmdiff_ck_cov1_id1.bc',
  24,
"SPICE(NOTENOUGHDATA5)",
"The second attitude to be compared must be computable using the kernel",
"'frmdiff_ck_cov1_id1.bc' and supporting kernels 'frmdiff_lsk.tls",
"frmdiff_sclk.tsc frmdiff_fk.tf frmdiff_ck_cov1_id1.bc' provided after the keys",
"'-k' and '-k2'. Position (3x3) transformation from 'phx_ll' frame to",
"'phx_payload' frame could not be computed at ET 2.5000000000000E+08. PXFORM",
"error was: PCK data required to compute the orientation of the body-fixed frame",
"IAU_MARS for epoch 2007 DEC 04 00:26:40.000 TDB were not found. If these data",
"were to be provided by a binary PCK file, then it is possible that the PCK file",
"does not have coverage for the specified body-fixed frame at the time of",
"interest. If the data were to be provided by a text PCK file, then possibly the",
"file does not contain data for the specified body-fixed frame. In either case",
"it is possible that a required PC",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'no files, sampling same from-to-k1-k2, not enough data 6, for first attitude',
  'failure',
  $frmdiff,
  '-k frmdiff_fk.tf -k1 frmdiff_lsk.tls -k2 frmdiff_lsk.tls -n 1 -f1 J2000 -t1 PHX_LL -f2 j2000 -t2 phx_ll -b 2001-01-01 -e 2001-01-02',
  23,
"SPICE(NOTENOUGHDATA6)",
"The attitude must be computable using the supporting kernels 'frmdiff_fk.tf",
"frmdiff_lsk.tls' provided after the keys '-k' and '-k1'. Position (3x3)",
"transformation from 'J2000' frame to 'PHX_LL' frame could not be computed at ET",
"3.1579264183934E+07. PXFORM error was: PCK data required to compute the",
"orientation of the body-fixed frame IAU_MARS for epoch 2001 JAN 01 00:01:04.183",
"TDB were not found. If these data were to be provided by a binary PCK file,",
"then it is possible that the PCK file does not have coverage for the specified",
"body-fixed frame at the time of interest. If the data were to be provided by a",
"text PCK file, then possibly the file does not contain data for the specified",
"body-fixed frame. In either case it is possible that a required PCK file was",
"not loaded at all.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'different "from" frames, not enough data 7, for first attitude',
  'failure',
  $frmdiff,
  '-k frmdiff_fk.tf -k1 frmdiff_lsk.tls -k2 frmdiff_lsk.tls -n 1 -f1 J2000 -t1 PHX_LL -f2 phx_topo -t2 phx_ll -b 2001-01-01 -e 2001-01-02',
  23,
"SPICE(NOTENOUGHDATA7)",
"The first attitude to be compared must be computable using the supporting",
"kernels 'frmdiff_fk.tf frmdiff_lsk.tls' provided after the keys '-k' and '-k1'.",
"Position (3x3) transformation from 'J2000' frame to 'PHX_LL' frame could not be",
"computed at ET 3.1579264183934E+07. PXFORM error was: PCK data required to",
"compute the orientation of the body-fixed frame IAU_MARS for epoch 2001 JAN 01",
"00:01:04.183 TDB were not found. If these data were to be provided by a binary",
"PCK file, then it is possible that the PCK file does not have coverage for the",
"specified body-fixed frame at the time of interest. If the data were to be",
"provided by a text PCK file, then possibly the file does not contain data for",
"the specified body-fixed frame. In either case it is possible that a required",
"PCK file was not loaded at all.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'no files, different "from" frames, not enough data 8, for second attitude',
  'failure',
  $frmdiff,
  '-k frmdiff_fk.tf -k1 frmdiff_lsk.tls -k2 frmdiff_lsk.tls -n 1 -f1 B1950 -t1 J2000 -f2 phx_ll -t2 j2000 -b 2001-01-01 -e 2001-01-02',
  23,
"SPICE(NOTENOUGHDATA8)",
"The second attitude to be compared must be computable using the supporting",
"kernels 'frmdiff_fk.tf frmdiff_lsk.tls' provided after the keys '-k' and '-k2'.",
"Position (3x3) transformation from 'phx_ll' frame to 'j2000' frame could not be",
"computed at ET 3.1579264183934E+07. PXFORM error was: PCK data required to",
"compute the orientation of the body-fixed frame IAU_MARS for epoch 2001 JAN 01",
"00:01:04.183 TDB were not found. If these data were to be provided by a binary",
"PCK file, then it is possible that the PCK file does not have coverage for the",
"specified body-fixed frame at the time of interest. If the data were to be",
"provided by a text PCK file, then possibly the file does not contain data for",
"the specified body-fixed frame. In either case it is possible that a required",
"PCK file was not loaded at all.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'no files, different "to" frames, not enough data 7, for first attitude',
  'failure',
  $frmdiff,
  '-k frmdiff_fk.tf -k1 frmdiff_lsk.tls -k2 frmdiff_lsk.tls -n 1 -f1 J2000 -t1 PHX_TOPO -f2 j2000 -t2 phx_ll -b 2001-01-01 -e 2001-01-02',
  23,
"SPICE(NOTENOUGHDATA7)",
"The first attitude to be compared must be computable using the supporting",
"kernels 'frmdiff_fk.tf frmdiff_lsk.tls' provided after the keys '-k' and '-k1'.",
"Position (3x3) transformation from 'J2000' frame to 'PHX_TOPO' frame could not",
"be computed at ET 3.1579264183934E+07. PXFORM error was: PCK data required to",
"compute the orientation of the body-fixed frame IAU_MARS for epoch 2001 JAN 01",
"00:01:04.183 TDB were not found. If these data were to be provided by a binary",
"PCK file, then it is possible that the PCK file does not have coverage for the",
"specified body-fixed frame at the time of interest. If the data were to be",
"provided by a text PCK file, then possibly the file does not contain data for",
"the specified body-fixed frame. In either case it is possible that a required",
"PCK file was not loaded at all.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'no files, different "to" frames, not enough data 8, for second attitude',
  'failure',
  $frmdiff,
  '-k frmdiff_fk.tf -k1 frmdiff_lsk.tls -k2 frmdiff_lsk.tls -n 1 -f1 J2000 -t1 B1950 -f2 j2000 -t2 phx_ll -b 2001-01-01 -e 2001-01-02',
  23,
"SPICE(NOTENOUGHDATA8)",
"The second attitude to be compared must be computable using the supporting",
"kernels 'frmdiff_fk.tf frmdiff_lsk.tls' provided after the keys '-k' and '-k2'.",
"Position (3x3) transformation from 'j2000' frame to 'phx_ll' frame could not be",
"computed at ET 3.1579264183934E+07. PXFORM error was: PCK data required to",
"compute the orientation of the body-fixed frame IAU_MARS for epoch 2001 JAN 01",
"00:01:04.183 TDB were not found. If these data were to be provided by a binary",
"PCK file, then it is possible that the PCK file does not have coverage for the",
"specified body-fixed frame at the time of interest. If the data were to be",
"provided by a text PCK file, then possibly the file does not contain data for",
"the specified body-fixed frame. In either case it is possible that a required",
"PCK file was not loaded at all.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'no files, different -k1 and -k2, not enough data 7, for first attitude',
  'failure',
  $frmdiff,
  '-k frmdiff_fk.tf -k1 frmdiff_lsk.tls -k2 frmdiff_lsk.tls frmdiff_pck.tpc -n 1 -f1 J2000 -t1 PHX_TOPO -f2 j2000 -t2 phx_topo -b 2001-01-01 -e 2001-01-02',
  23,
"SPICE(NOTENOUGHDATA7)",
"The first attitude to be compared must be computable using the supporting",
"kernels 'frmdiff_fk.tf frmdiff_lsk.tls' provided after the keys '-k' and '-k1'.",
"Position (3x3) transformation from 'J2000' frame to 'PHX_TOPO' frame could not",
"be computed at ET 3.1579264183934E+07. PXFORM error was: PCK data required to",
"compute the orientation of the body-fixed frame IAU_MARS for epoch 2001 JAN 01",
"00:01:04.183 TDB were not found. If these data were to be provided by a binary",
"PCK file, then it is possible that the PCK file does not have coverage for the",
"specified body-fixed frame at the time of interest. If the data were to be",
"provided by a text PCK file, then possibly the file does not contain data for",
"the specified body-fixed frame. In either case it is possible that a required",
"PCK file was not loaded at all.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'no files, different -k1 and -k2, not enough data 8, for second attitude',
  'failure',
  $frmdiff,
  '-k frmdiff_fk.tf -k1 frmdiff_lsk.tls frmdiff_pck.tpc -k2 frmdiff_lsk.tls -n 1 -f1 J2000 -t1 PHX_TOPO -f2 j2000 -t2 phx_topo -b 2001-01-01 -e 2001-01-02',
  23,
"SPICE(NOTENOUGHDATA8)",
"The second attitude to be compared must be computable using the supporting",
"kernels 'frmdiff_fk.tf frmdiff_lsk.tls' provided after the keys '-k' and '-k2'.",
"Position (3x3) transformation from 'j2000' frame to 'phx_topo' frame could not",
"be computed at ET 3.1579264183934E+07. PXFORM error was: PCK data required to",
"compute the orientation of the body-fixed frame IAU_MARS for epoch 2001 JAN 01",
"00:01:04.183 TDB were not found. If these data were to be provided by a binary",
"PCK file, then it is possible that the PCK file does not have coverage for the",
"specified body-fixed frame at the time of interest. If the data were to be",
"provided by a text PCK file, then possibly the file does not contain data for",
"the specified body-fixed frame. In either case it is possible that a required",
"PCK file was not loaded at all.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-f sclkd, too few OFFSETS',
  'failure',
  $frmdiff,
  '-f sclkd -t dumpc -k frmdiff_lsk.tls frmdiff_sclk_too_few_offsets.tsc frmdiff_fk.tf frmdiff_pck.tpc -n 1 -f1 PHX_LL -t1 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc',
  33,
"# Coverage for rotation",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_sclk_too_few_offsets.tsc frmdiff_fk.tf frmdiff_pck.tpc",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"SPICE(BADSCLKDATA1)",
"Invalid SCLK parameters for ID -84. The number of fields (2) provided by",
"keyword 'SCLK01_N_FIELDS_84' does not match the count of field offsets (1)",
"provided in the keyword 'SCLK01_OFFSETS_84'.",
"A traceback follows.  The name of the highest level module is first.",
"frmdiff --> RTDIFF --> ET2STR --> SC01S2D"
);

#
# Test good cases.
#

#
# Test usage, help, and version displays.
#
@toolversion = (
"frmdiff -- Version 1.0.0, February 10, 2009 -- Toolkit Version N0"
);

@toolusage = (
"   frmdiff provides a simple way of sampling orientation of a frame or",
"   comparing orientations of two frames known to SPICE and supported by",
"   data from SPICE kernels. The program usage is:",
"   where kernel can be a CK, an FK, or a PCK. Options are shown below.",
"   Order and case of keys are not significant. Values must be",
"   space-separated from keys, i.e. '-n 10', not '-n10'.",
"      -k  <supporting kernel(s) name(s)>",
"      -f1 <first ``from'' frame, name or ID>",
"      -t1 <first ``to'' frame, name or ID>",
"      -c1 <first frame for coverage look up, name or ID>",
"      -k1 <additional supporting kernel(s) for first file>",
"      -f2 <second ``from'' frame, name or ID>",
"      -t2 <second ``to'' frame, name or ID>",
"      -c2 <second frame for coverage look up, name or ID>",
"      -k2 <additional supporting kernel(s) for second file>",
"      -a  <compare angular velocities: yes|no>",
"      -m  <frame for angular velocities: from|to>",
"      -b  <interval start time>",
"      -e  <interval stop time>",
"      -n  <number of points: 1 to 1000000 (default: 1000)>",
"      -s  <time step in seconds>",
"      -f  <time format: et|sclk|sclkd|ticks|picture_for_TIMOUT>",
"      -t  <report: basic|stats|dumpaa|dumpm|dumpqs|dumpqo|dumpea|dumpc|dumpg>",
"      -o  <rotation axes order (default: z y x)>",
"      -x  <units for output angles> (only for -t dumpaa and -t dumpea)"
);

@toolhelp = (
"   frmdiff provides means for sampling orientation of a single reference",
"   frame, or for comparing orientations of two reference frames known to",
"   SPICE and supported by data from SPICE kernels.",
"   To sample orientation of a single frame the program computes a set of",
"   transformations from one frame (the ``from'' frame) to another frame",
"   (the ``to'' frame) over an interval of time with fixed or variable time",
"   step, using a given set of kernel files. Then, depending on the",
"   requested type of output report, it prints to the screen a table",
"   containing these transformations expressed as total rotation angles and",
"   axes, quaternions, matrices or Euler angles and angular velocities, or",
"   only magnitude of the maximum rotation and angular velocity, or results",
"   of a simple statistical analysis of rotations.",
"   To compare orientations of two frames the program computes a set of",
"   transformations from one frame (the ``from'' frame) to another frame",
"   (the ``to'' frame) over an interval of time with a fixed or variable",
"   time step using one set of kernels, computes a set of transformations",
"   for the same or a different ``from''-``to'' frame combination at the",
"   same times using the same or a different set of kernels, and then",
"   computes the difference in rotation and angular velocity between the",
"   corresponding transformations. Depending on the requested type of",
"   output report the program prints to the screen only maximum differences",
"   in rotation and angular velocity, or a complete table of rotation and",
"   angular velocity differences expressed as total rotation angles and",
"   axes, matrices, quaternions, or Euler angles, or results of a simple",
"   statistical analysis of the rotation differences."
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'usage display, no command line arguments',
  'success',
  $frmdiff,
  '',
  35,
  @toolversion,
  @toolusage
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'help display, -h',
  'success',
  $frmdiff,
  '-h',
  31,
  @toolversion,
  @toolhelp
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'help display, -help ',
  'success',
  $frmdiff,
  '-help',
  31,
  @toolversion,
  @toolhelp
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'usage display, -u',
  'success',
  $frmdiff,
  '-u',
  35,
  @toolversion,
  @toolusage
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'usage display, -usage',
  'success',
  $frmdiff,
  '-usage',
  35,
  @toolversion,
  @toolusage
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'version display, -v',
  'success',
  $frmdiff,
  '-v',
  3,
  @toolversion
);

#
# Test more good cases.
#
&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'SPK as last argument',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_lsk.tls frmdiff_pck.tpc frmdiff_fk.tf -f1 J2000 -t1 PHX_TOPO_R frmdiff_spk.bsp',
  22,
"# Sampling of 1 rotations",
"#    from 'J2000' (1) to 'PHX_TOPO_R' (-84905)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc frmdiff_fk.tf",
"#       frmdiff_spk.bsp",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +7.5888481569???E-01      +7.5888481569???E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'CK as last argument',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_lsk.tls frmdiff_pck.tpc frmdiff_fk.tf frmdiff_sclk.tsc -f1 J2000 -t1 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc',
  22,
"# Sampling of 1 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc frmdiff_fk.tf frmdiff_sclk.tsc",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.506448241827?E+00      +2.506448241827?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'binary PCK as last argument',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_lsk.tls -f1 J2000 -t1 ITRF93 frmdiff_pck_cov1_id1.bpc',
  22,
"# Sampling of 1 rotations",
"#    from 'J2000' (1) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.3757536773195E+00      +1.3757536773195E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'text PCK as last argument',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_lsk.tls -f1 J2000 -t1 IAU_MARS frmdiff_pck.tpc',
  22,
"# Sampling of 1 rotations",
"#    from 'J2000' (1) to 'IAU_MARS' (10014)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +7.5987585256???E-01      +7.5987585256???E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'LSK kernel as last argument',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_ck_cov1_id1.bc frmdiff_pck.tpc frmdiff_fk.tf frmdiff_sclk_tdt.tsc -f1 J2000 -t1 PHX_PAYLOAD frmdiff_lsk.tls',
  22,
"# Sampling of 1 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc frmdiff_pck.tpc frmdiff_fk.tf frmdiff_sclk_tdt.tsc",
"#       frmdiff_lsk.tls",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.506448241827?E+00      +2.506448241827?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'SCLK kernel as last argument',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_ck_cov1_id1.bc frmdiff_pck.tpc frmdiff_fk.tf frmdiff_lsk.tls -f1 J2000 -t1 PHX_PAYLOAD frmdiff_sclk.tsc',
  22,
"# Sampling of 1 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc frmdiff_pck.tpc frmdiff_fk.tf frmdiff_lsk.tls",
"#       frmdiff_sclk.tsc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.506448241827?E+00      +2.506448241827?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'FK kernel as last argument',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_ck_cov1_id1.bc frmdiff_pck.tpc frmdiff_sclk.tsc frmdiff_lsk.tls -f1 J2000 -t1 PHX_PAYLOAD frmdiff_fk.tf',
  22,
"# Sampling of 1 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc frmdiff_pck.tpc frmdiff_sclk.tsc frmdiff_lsk.tls",
"#       frmdiff_fk.tf",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.506448241827?E+00      +2.506448241827?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'IK kernel as last argument',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_ck_cov1_id1.bc frmdiff_pck.tpc frmdiff_sclk.tsc frmdiff_lsk.tls -f1 J2000 -t1 PHX_PAYLOAD frmdiff_ik.ti',
  22,
"# Sampling of 1 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc frmdiff_pck.tpc frmdiff_sclk.tsc frmdiff_lsk.tls",
"#       frmdiff_ik.ti",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.506448241827?E+00      +2.506448241827?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'MK kernel as last argument',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_ck_cov1_id1.bc -f1 J2000 -t1 PHX_PAYLOAD frmdiff_mk.tm',
  22,
"# Sampling of 1 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc",
"#       frmdiff_mk.tm",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.506448241827?E+00      +2.506448241827?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'SPK as second to last argument',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_lsk.tls frmdiff_pck.tpc frmdiff_fk.tf -f1 J2000 -t1 PHX_TOPO_R -t2 ITRF93 frmdiff_spk.bsp frmdiff_pck_cov1_id1.bpc',
  30,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'PHX_TOPO_R' (-84905)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc frmdiff_fk.tf",
"#       frmdiff_spk.bsp",
"# with 1 rotations",
"#    from 'J2000' (1) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc frmdiff_fk.tf",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.1331819634???E+00      +1.1331819634???E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'CK as second to last argument',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_lsk.tls frmdiff_pck.tpc frmdiff_fk.tf frmdiff_sclk.tsc -f1 J2000 -t1 PHX_PAYLOAD -t2 ITRF93 frmdiff_ck_cov1_id1.bc frmdiff_pck_cov1_id1.bpc',
  30,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc frmdiff_fk.tf frmdiff_sclk.tsc",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc frmdiff_fk.tf frmdiff_sclk.tsc",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.660669742196?E+00      +2.660669742196?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'binary PCK as second to last argument',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_lsk.tls -f1 J2000 -t1 ITRF93 -t2 ITRF93 frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov1_id1.bpc',
  22,
"# Sampling of 1 rotations",
"#    from 'J2000' (1) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.3757536773195E+00      +1.3757536773195E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'text PCK as second to last argument',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_lsk.tls -f1 J2000 -t1 IAU_MARS -t2 ITRF93 frmdiff_pck.tpc frmdiff_pck_cov1_id1.bpc',
  30,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'IAU_MARS' (10014)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck.tpc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.86265679443??E+00      +1.86265679443??E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'LSK kernel as second to last argument',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_ck_cov1_id1.bc frmdiff_pck.tpc frmdiff_fk.tf frmdiff_sclk_tdt.tsc -f1 J2000 -t1 PHX_PAYLOAD -t2 ITRF93 frmdiff_lsk.tls frmdiff_pck_cov1_id1.bpc',
  30,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc frmdiff_pck.tpc frmdiff_fk.tf frmdiff_sclk_tdt.tsc",
"#       frmdiff_lsk.tls",
"# with 1 rotations",
"#    from 'J2000' (1) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc frmdiff_pck.tpc frmdiff_fk.tf frmdiff_sclk_tdt.tsc",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.660669742196?E+00      +2.660669742196?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'SCLK kernel as second to last argument',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_ck_cov1_id1.bc frmdiff_pck.tpc frmdiff_fk.tf frmdiff_lsk.tls -f1 J2000 -t1 PHX_PAYLOAD -t2 ITRF93 frmdiff_sclk.tsc frmdiff_pck_cov1_id1.bpc',
  30,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc frmdiff_pck.tpc frmdiff_fk.tf frmdiff_lsk.tls",
"#       frmdiff_sclk.tsc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc frmdiff_pck.tpc frmdiff_fk.tf frmdiff_lsk.tls",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.660669742196?E+00      +2.660669742196?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'FK kernel as second to last argument',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_ck_cov1_id1.bc frmdiff_pck.tpc frmdiff_sclk.tsc frmdiff_lsk.tls -f1 J2000 -t1 PHX_PAYLOAD -t2 ITRF93 frmdiff_fk.tf frmdiff_pck_cov1_id1.bpc',
  30,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc frmdiff_pck.tpc frmdiff_sclk.tsc frmdiff_lsk.tls",
"#       frmdiff_fk.tf",
"# with 1 rotations",
"#    from 'J2000' (1) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc frmdiff_pck.tpc frmdiff_sclk.tsc frmdiff_lsk.tls",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.660669742196?E+00      +2.660669742196?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'IK kernel as second to last argument',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_ck_cov1_id1.bc frmdiff_pck.tpc frmdiff_sclk.tsc frmdiff_lsk.tls -f1 J2000 -t1 PHX_PAYLOAD -t2 ITRF93 frmdiff_ik.ti frmdiff_pck_cov1_id1.bpc',
  30,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc frmdiff_pck.tpc frmdiff_sclk.tsc frmdiff_lsk.tls",
"#       frmdiff_ik.ti",
"# with 1 rotations",
"#    from 'J2000' (1) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc frmdiff_pck.tpc frmdiff_sclk.tsc frmdiff_lsk.tls",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.660669742196?E+00      +2.660669742196?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'MK kernel as second to last argument',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_ck_cov1_id1.bc -f1 J2000 -t1 PHX_PAYLOAD -t2 ITRF93 frmdiff_mk.tm frmdiff_pck_cov1_id1.bpc',
  30,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc",
"#       frmdiff_mk.tm",
"# with 1 rotations",
"#    from 'J2000' (1) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.660669742196?E+00      +2.660669742196?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'one kernel following -k',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_lsk.tls -f1 J2000 -t1 B1950',
  21,
"# Sampling of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056036E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'one kernel following -k1',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k1 frmdiff_lsk.tls -f1 J2000 -t1 B1950',
  25,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +0.0000000000000E+00      +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'one kernel following -k2',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k2 frmdiff_lsk.tls -f1 J2000 -t1 B1950',
  25,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +0.0000000000000E+00      +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'more than one kernel following -k',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_lsk.tls frmdiff_pck.tpc -f1 J2000 -t1 IAU_MARS',
  21,
"# Sampling of 1 rotations",
"#    from 'J2000' (1) to 'IAU_MARS' (10014)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +7.5987585256???E-01      +7.5987585256???E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'more than one kernel following -k1',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k1 frmdiff_lsk.tls frmdiff_pck.tpc -f1 J2000 -t1 IAU_MARS -t2 B1950',
  25,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'IAU_MARS' (10014)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +7.6923615532???E-01      +7.6923615532???E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'more than one kernel following -k2',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k2 frmdiff_lsk.tls frmdiff_pck.tpc -f1 J2000 -t1 B1950 -t2 IAU_MARS',
  25,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"# with 1 rotations",
"#    from 'J2000' (1) to 'IAU_MARS' (10014)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +7.6923615532???E-01      +7.6923615532???E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"from" name given with -f1, resolved because it is built in',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_lsk.tls -f1 J2000 -t1 B1950',
  21,
"# Sampling of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056036E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"from" name given with -f1, resolved using kernels from -k',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm -f1 PHX_PAYLOAD -t1 B1950 frmdiff_ck_cov1_id1.bc',
  22,
"# Sampling of 1 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.505494162164?E+00      +2.505494162164?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"from" name given with -f1, resolved using kernels from -k1',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k1 frmdiff_mk.tm -f1 PHX_PAYLOAD -f2 J2000 -t1 B1950 frmdiff_ck_cov1_id1.bc',
  29,
"# Comparison of 1 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.506448241827?E+00      +2.506448241827?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"from" name given with -f1, resolved using first file',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k1 frmdiff_ck_cov1_id1.bc -f1 PHX_PAYLOAD -f2 J2000 -t1 B1950 frmdiff_mk.tm frmdiff_ck_cov1_id1.bc',
  29,
"# Comparison of 1 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc",
"#       frmdiff_mk.tm",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.506448241827?E+00      +2.506448241827?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"from" name given with -f1, resolved using only file',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k1 frmdiff_ck_cov1_id1.bc -f1 PHX_PAYLOAD -f2 J2000 -t1 B1950 frmdiff_mk.tm',
  29,
"# Comparison of 1 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc",
"#       frmdiff_mk.tm",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.506448241827?E+00      +2.506448241827?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"from" id given with -f1, resolved because it is built in',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_lsk.tls -f1 1 -t1 B1950',
  21,
"# Sampling of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056036E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"from" id given with -f1, resolved using kernels from -k',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm -f1 -84100 -t1 B1950 frmdiff_ck_cov1_id1.bc',
  22,
"# Sampling of 1 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.505494162164?E+00      +2.505494162164?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"from" id given with -f1, resolved using kernels from -k1',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k1 frmdiff_mk.tm -f1 -84100 -f2 J2000 -t1 B1950 frmdiff_ck_cov1_id1.bc',
  29,
"# Comparison of 1 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.506448241827?E+00      +2.506448241827?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"from" id given with -f1, resolved using first file (not CK or PCK)',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k1 frmdiff_ck_cov1_id1.bc -f1 -84100 -f2 J2000 -t1 B1950 frmdiff_mk.tm frmdiff_ck_cov1_id1.bc',
  29,
"# Comparison of 1 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc",
"#       frmdiff_mk.tm",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.506448241827?E+00      +2.506448241827?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"from" id given with -f1, resolved using only file (not CK or PCK)',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k1 frmdiff_ck_cov1_id1.bc -f1 -84100 -f2 J2000 -t1 B1950 frmdiff_mk.tm',
  29,
"# Comparison of 1 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc",
"#       frmdiff_mk.tm",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.506448241827?E+00      +2.506448241827?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" name given with -t1, resolved because it is built in',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_lsk.tls -t1 J2000 -f1 B1950',
  21,
"# Sampling of 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_lsk.tls",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056036E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" name given with -t1, resolved using kernels from -k',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm -t1 PHX_PAYLOAD -f1 B1950 frmdiff_ck_cov1_id1.bc',
  22,
"# Sampling of 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.505494162164?E+00      +2.505494162164?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" name given with -t1, resolved using kernels from -k1',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k1 frmdiff_mk.tm -t1 PHX_PAYLOAD -t2 J2000 -f1 B1950 frmdiff_ck_cov1_id1.bc',
  29,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.506448241827?E+00      +2.506448241827?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" name given with -t1, resolved using first file',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k1 frmdiff_ck_cov1_id1.bc -t1 PHX_PAYLOAD -t2 J2000 -f1 B1950 frmdiff_mk.tm frmdiff_ck_cov1_id1.bc',
  29,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc",
"#       frmdiff_mk.tm",
"# with 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.506448241827?E+00      +2.506448241827?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" name given with -t1, resolved using only file',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k1 frmdiff_ck_cov1_id1.bc -t1 PHX_PAYLOAD -t2 J2000 -f1 B1950 frmdiff_mk.tm',
  29,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc",
"#       frmdiff_mk.tm",
"# with 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_mk.tm",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.506448241827?E+00      +2.506448241827?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t1, present in first file CK, resolved as class id using kernels from -k',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm -t1 -84100 -f1 B1950 -t2 B1950 -f2 J2000 frmdiff_ck_cov1_id1.bc frmdiff_pck_cov1_id1.bpc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.5045643955???E+00      +2.5045643955???E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t1, present in first file CK, resolved as class id using kernels from -k1',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k1 frmdiff_mk.tm -t1 -84100 -f1 B1950 -t2 B1950 -f2 J2000 frmdiff_ck_cov1_id1.bc frmdiff_pck_cov1_id1.bpc',
  29,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.5045643955???E+00      +2.5045643955???E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t1, present in first file PCK, resolved as class id because it is built in',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_lsk.tls -t1 3000 -f1 B1950 -t2 B1950 -f2 J2000 frmdiff_pck_cov1_id1.bpc frmdiff_ck_cov1_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck_cov1_id1.bpc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.3534293422891E+00      +1.3534293422891E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t1, present in first file PCK, resolved as class id using kernels from -k ',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm -t1 3001 -f1 B1950 -t2 B1950 -f2 J2000 frmdiff_pck_unk_obj.bpc frmdiff_ck_cov1_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'PCK3001' (3001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_unk_obj.bpc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.3534293422891E+00      +1.3534293422891E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t1, present in first file PCK, resolved as class id using kernels from -k1',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k1 frmdiff_mk.tm -t1 3001 -f1 B1950 -t2 B1950 -f2 J2000 frmdiff_pck_unk_obj.bpc frmdiff_ck_cov1_id1.bc',
  29,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'PCK3001' (3001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_unk_obj.bpc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.3534293422891E+00      +1.3534293422891E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t1, present in only file CK, resolved as class id using kernels from -k',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm -t1 -84100 -f1 B1950 -t2 B1950 -f2 J2000 frmdiff_ck_cov1_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.5045643955???E+00      +2.5045643955???E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t1, present in only file CK, resolved as class id using kernels from -k1',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k1 frmdiff_mk.tm -t1 -84100 -f1 B1950 -t2 B1950 -f2 J2000 frmdiff_ck_cov1_id1.bc',
  29,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.5045643955???E+00      +2.5045643955???E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t1, present in only file PCK, resolved as class id because it is built in',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_lsk.tls -t1 3000 -f1 B1950 -t2 B1950 -f2 J2000 frmdiff_pck_cov1_id1.bpc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck_cov1_id1.bpc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.3534293422891E+00      +1.3534293422891E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t1, present in only file PCK, resolved as class id using kernels from -k',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm -t1 3001 -f1 B1950 -t2 B1950 -f2 J2000 frmdiff_pck_unk_obj.bpc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'PCK3001' (3001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_unk_obj.bpc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_unk_obj.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.3534293422891E+00      +1.3534293422891E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t1, present in only file PCK, resolved as class id using kernels from -k1',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k1 frmdiff_mk.tm -t1 3001 -f1 B1950 -t2 B1950 -f2 J2000 frmdiff_pck_unk_obj.bpc',
  29,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'PCK3001' (3001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_unk_obj.bpc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_pck_unk_obj.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.3534293422891E+00      +1.3534293422891E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t1, not present in first file CK, resolved as id using kernels from -k',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm frmdiff_ck_cov1_id2.bc -t1 -84001 -f1 B1950 -t2 B1950 -f2 J2000 frmdiff_ck_cov1_id1.bc frmdiff_pck_cov1_id1.bpc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm frmdiff_ck_cov1_id2.bc",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm frmdiff_ck_cov1_id2.bc",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.5045643955???E+00      +2.5045643955???E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t1, not present in first file CK, resolved as id using kernels from -k1',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k1 frmdiff_mk.tm frmdiff_ck_cov1_id2.bc -t1 -84001 -f1 B1950 -t2 B1950 -f2 J2000 frmdiff_ck_cov1_id1.bc frmdiff_pck_cov1_id1.bpc',
  29,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm frmdiff_ck_cov1_id2.bc",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.5045643955???E+00      +2.5045643955???E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t1, not present in first file PCK, resolved as id because it is built in',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_lsk.tls -t1 1 -f1 B1950 -t2 B1950 -f2 J2000 frmdiff_pck_cov1_id1.bpc frmdiff_ck_cov1_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck_cov1_id1.bpc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.4379166112073E-02      +2.4379166112073E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t1, not present in first file PCK, resolved as id using kernels from -k',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm -t1 3002 -f1 B1950 -t2 B1950 -f2 J2000 frmdiff_pck_cov1_id1.bpc frmdiff_ck_cov1_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'FIXED3002' (3002)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov1_id1.bpc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.3534293422891E+00      +1.3534293422891E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t1, not present in first file PCK, resolved as id using kernels from -k1',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k1 frmdiff_mk.tm -t1 3002 -f1 B1950 -t2 B1950 -f2 J2000 frmdiff_pck_cov1_id1.bpc frmdiff_ck_cov1_id1.bc',
  29,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'FIXED3002' (3002)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov1_id1.bpc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.3534293422891E+00      +1.3534293422891E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t1, not present in only file CK, resolved as id using kernels from -k',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm frmdiff_ck_cov1_id2.bc -t1 -84001 -f1 B1950 -t2 B1950 -f2 J2000 frmdiff_ck_cov1_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm frmdiff_ck_cov1_id2.bc",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm frmdiff_ck_cov1_id2.bc",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.5045643955???E+00      +2.5045643955???E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t1, not present in only file CK, resolved as id using kernels from -k1',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k1 frmdiff_mk.tm frmdiff_ck_cov1_id2.bc -t1 -84001 -f1 B1950 -t2 B1950 -f2 J2000 frmdiff_ck_cov1_id1.bc',
  29,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm frmdiff_ck_cov1_id2.bc",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.5045643955???E+00      +2.5045643955???E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t1, not present in only file PCK, resolved as id because it is built in',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_lsk.tls -t1 1 -f1 B1950 -t2 B1950 -f2 J2000 frmdiff_pck_cov1_id1.bpc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck_cov1_id1.bpc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.4379166112073E-02      +2.4379166112073E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t1, not present in only file PCK, resolved as id using kernels from -k',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm -t1 3002 -f1 B1950 -t2 B1950 -f2 J2000 frmdiff_pck_cov1_id1.bpc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'FIXED3002' (3002)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov1_id1.bpc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.3534293422891E+00      +1.3534293422891E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t1, not present in only file PCK, resolved as id using kernels from -k1',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k1 frmdiff_mk.tm -t1 3002 -f1 B1950 -t2 B1950 -f2 J2000 frmdiff_pck_cov1_id1.bpc',
  29,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'FIXED3002' (3002)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov1_id1.bpc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.3534293422891E+00      +1.3534293422891E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c1, resolved using kernels from -k',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm -c1 PHX_PAYLOAD -f1 J2000 -t1 B1950 frmdiff_ck_cov1_id1.bc',
  22,
"# Sampling of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056036E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c1, resolved using kernels from -k1',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k1 frmdiff_mk.tm -c1 PHX_PAYLOAD -f1 ECLIPJ2000 -f2 J2000 -t1 B1950 frmdiff_ck_cov1_id1.bc',
  29,
"# Comparison of 1 rotations",
"#    from 'ECLIPJ2000' (17) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +4.0909280422233E-01      +4.0909280422233E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c1, CK class frame, present in first CK file',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm -c1 PHX_PAYLOAD -t1 ECLIPJ2000 -f1 B1950 -t2 B1950 -f2 J2000 frmdiff_ck_cov1_id1.bc frmdiff_pck_cov1_id1.bpc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +4.0980843101531E-01      +4.0980843101531E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c1, CK class frame, present in only CK file',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm -c1 PHX_PAYLOAD -t1 ECLIPJ2000 -f1 B1950 -t2 B1950 -f2 J2000 frmdiff_ck_cov1_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +4.0980843101531E-01      +4.0980843101531E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c1, PCK class frame, present in first PCK file',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_lsk.tls -c1 ITRF93 -t1 ECLIPJ2000 -f1 B1950 -t2 B1950 -f2 J2000 frmdiff_pck_cov1_id1.bpc frmdiff_ck_cov1_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck_cov1_id1.bpc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +4.0980843101531E-01      +4.0980843101531E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c1, PCK class frame, present in only PCK file',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_lsk.tls -c1 ITRF93 -t1 ECLIPJ2000 -f1 B1950 -t2 B1950 -f2 J2000 frmdiff_pck_cov1_id1.bpc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck_cov1_id1.bpc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +4.0980843101531E-01      +4.0980843101531E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" id given with -c1, id present in first CK file',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm -c1 -84100 -t1 ECLIPJ2000 -f1 B1950 -t2 B1950 -f2 J2000 frmdiff_ck_cov1_id1.bc frmdiff_pck_cov1_id1.bpc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +4.0980843101531E-01      +4.0980843101531E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" id given with -c1, id present in only CK file',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm -c1 -84100 -t1 ECLIPJ2000 -f1 B1950 -t2 B1950 -f2 J2000 frmdiff_ck_cov1_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +4.0980843101531E-01      +4.0980843101531E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" id given with -c1, id present in first PCK file',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_lsk.tls -c1 3000 -t1 ECLIPJ2000 -f1 B1950 -t2 B1950 -f2 J2000 frmdiff_pck_cov1_id1.bpc frmdiff_ck_cov1_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck_cov1_id1.bpc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +4.0980843101531E-01      +4.0980843101531E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" id given with -c1, id present in only PCK file',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_lsk.tls -c1 3000 -t1 ECLIPJ2000 -f1 B1950 -t2 B1950 -f2 J2000 frmdiff_pck_cov1_id1.bpc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck_cov1_id1.bpc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +4.0980843101531E-01      +4.0980843101531E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"from" name given with -f2, resolved because it is built in',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_lsk.tls -f2 J2000 -t2 B1950',
  21,
"# Sampling of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056036E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"from" name given with -f2, resolved using kernels from -k',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm -f2 PHX_PAYLOAD -t2 B1950 frmdiff_ck_cov1_id1.bc',
  22,
"# Sampling of 1 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.505494162164?E+00      +2.505494162164?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"from" name given with -f2, resolved using kernels from -k2',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k2 frmdiff_mk.tm -f2 PHX_PAYLOAD -f1 J2000 -t2 B1950 frmdiff_ck_cov1_id1.bc',
  29,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.506448241827?E+00      +2.506448241827?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"from" name given with -f2, resolved using second file',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k2 frmdiff_ck_cov1_id1.bc -f2 PHX_PAYLOAD -f1 J2000 -t2 B1950 frmdiff_ck_cov1_id1.bc frmdiff_mk.tm',
  29,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc",
"#       frmdiff_mk.tm",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.506448241827?E+00      +2.506448241827?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"from" name given with -f2, resolved using only file',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k2 frmdiff_ck_cov1_id1.bc -f2 PHX_PAYLOAD -f1 J2000 -t2 B1950 frmdiff_mk.tm',
  29,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"# with 1 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc",
"#       frmdiff_mk.tm",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.506448241827?E+00      +2.506448241827?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"from" id given with -f2, resolved because it is built in',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_lsk.tls -f2 1 -t2 B1950',
  21,
"# Sampling of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056036E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"from" id given with -f2, resolved using kernels from -k',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm -f2 -84100 -t2 B1950 frmdiff_ck_cov1_id1.bc',
  22,
"# Sampling of 1 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.505494162164?E+00      +2.505494162164?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"from" id given with -f2, resolved using kernels from -k2',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k2 frmdiff_mk.tm -f2 -84100 -f1 J2000 -t2 B1950 frmdiff_ck_cov1_id1.bc',
  29,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.506448241827?E+00      +2.506448241827?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"from" id given with -f2, resolved using second file (not CK or PCK)',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k2 frmdiff_ck_cov1_id1.bc -f2 -84100 -f1 J2000 -t2 B1950 frmdiff_ck_cov1_id1.bc frmdiff_mk.tm',
  29,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc",
"#       frmdiff_mk.tm",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.506448241827?E+00      +2.506448241827?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"from" id given with -f2, resolved using only file (not CK or PCK)',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k2 frmdiff_ck_cov1_id1.bc -f2 -84100 -f1 J2000 -t2 B1950 frmdiff_mk.tm',
  29,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"# with 1 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc",
"#       frmdiff_mk.tm",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.506448241827?E+00      +2.506448241827?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" name given with -t2, resolved because it is built in',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_lsk.tls -t2 J2000 -f2 B1950',
  21,
"# Sampling of 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_lsk.tls",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056036E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" name given with -t2, resolved using kernels from -k',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm -t2 PHX_PAYLOAD -f2 B1950 frmdiff_ck_cov1_id1.bc',
  22,
"# Sampling of 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.505494162164?E+00      +2.505494162164?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" name given with -t2, resolved using kernels from -k2',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k2 frmdiff_mk.tm -t2 PHX_PAYLOAD -t1 J2000 -f2 B1950 frmdiff_ck_cov1_id1.bc',
  29,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.506448241827?E+00      +2.506448241827?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" name given with -t2, resolved using second file',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k2 frmdiff_ck_cov1_id1.bc -t2 PHX_PAYLOAD -t1 J2000 -f2 B1950 frmdiff_ck_cov1_id1.bc frmdiff_mk.tm',
  29,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc",
"#       frmdiff_mk.tm",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.506448241827?E+00      +2.506448241827?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" name given with -t2, resolved using only file',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k2 frmdiff_ck_cov1_id1.bc -t2 PHX_PAYLOAD -t1 J2000 -f2 B1950 frmdiff_mk.tm',
  29,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_mk.tm",
"# with 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc",
"#       frmdiff_mk.tm",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.506448241827?E+00      +2.506448241827?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t2, present in second file CK, resolved as class id using kernels from -k ',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm -t2 -84100 -f2 B1950 -t1 B1950 -f1 J2000 frmdiff_pck_cov1_id1.bpc frmdiff_ck_cov1_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov1_id1.bpc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.5045643955???E+00      +2.5045643955???E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t2, present in second file CK, resolved as class id using kernels from -k2',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k2 frmdiff_mk.tm -t2 -84100 -f2 B1950 -t1 B1950 -f1 J2000 frmdiff_pck_cov1_id1.bpc frmdiff_ck_cov1_id1.bc',
  29,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_pck_cov1_id1.bpc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.5045643955???E+00      +2.5045643955???E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t2, present in second file PCK, resolved as class id because it is built in',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_lsk.tls -t2 3000 -f2 B1950 -t1 B1950 -f1 J2000 frmdiff_ck_cov1_id1.bc frmdiff_pck_cov1_id1.bpc',
  30,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.3534293422891E+00      +1.3534293422891E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t2, present in second file PCK, resolved as class id using kernels from -k ',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm -t2 3001 -f2 B1950 -t1 B1950 -f1 J2000 frmdiff_ck_cov1_id1.bc frmdiff_pck_unk_obj.bpc',
  30,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'PCK3001' (3001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_unk_obj.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.3534293422891E+00      +1.3534293422891E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t2, present in second file PCK, resolved as class id using kernels from -k2',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k2 frmdiff_mk.tm -t2 3001 -f2 B1950 -t1 B1950 -f1 J2000 frmdiff_ck_cov1_id1.bc frmdiff_pck_unk_obj.bpc',
  29,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'PCK3001' (3001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_unk_obj.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.3534293422891E+00      +1.3534293422891E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t2, present in only file CK, resolved as class id using kernels from -k',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm -t2 -84100 -f2 B1950 -t1 B1950 -f1 J2000 frmdiff_ck_cov1_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.5045643955???E+00      +2.5045643955???E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t2, present in only file CK, resolved as class id using kernels from -k2',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k2 frmdiff_mk.tm -t2 -84100 -f2 B1950 -t1 B1950 -f1 J2000 frmdiff_ck_cov1_id1.bc',
  29,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.5045643955???E+00      +2.5045643955???E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t2, present in only file PCK, resolved as class id because it is built in',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_lsk.tls -t2 3000 -f2 B1950 -t1 B1950 -f1 J2000 frmdiff_pck_cov1_id1.bpc',
  30,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck_cov1_id1.bpc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.3534293422891E+00      +1.3534293422891E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t2, present in only file PCK, resolved as class id using kernels from -k ',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm -t2 3001 -f2 B1950 -t1 B1950 -f1 J2000 frmdiff_pck_unk_obj.bpc',
  30,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_unk_obj.bpc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'PCK3001' (3001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_unk_obj.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.3534293422891E+00      +1.3534293422891E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t2, present in only file PCK, resolved as class id using kernels from -k2',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k2 frmdiff_mk.tm -t2 3001 -f2 B1950 -t1 B1950 -f1 J2000 frmdiff_pck_unk_obj.bpc',
  29,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_pck_unk_obj.bpc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'PCK3001' (3001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_unk_obj.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.3534293422891E+00      +1.3534293422891E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t2, not present in second file CK, resolved as id using kernels from -k',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm frmdiff_ck_cov1_id2.bc -t2 -84001 -f2 B1950 -t1 B1950 -f1 J2000 frmdiff_pck_cov1_id1.bpc frmdiff_ck_cov1_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm frmdiff_ck_cov1_id2.bc",
"#       frmdiff_pck_cov1_id1.bpc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm frmdiff_ck_cov1_id2.bc",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.5045643955???E+00      +2.5045643955???E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t2, not present in second file CK, resolved as id using kernels from -k2',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k2 frmdiff_mk.tm frmdiff_ck_cov1_id2.bc -t2 -84001 -f2 B1950 -t1 B1950 -f1 J2000 frmdiff_pck_cov1_id1.bpc frmdiff_ck_cov1_id1.bc',
  29,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_pck_cov1_id1.bpc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm frmdiff_ck_cov1_id2.bc",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.5045643955???E+00      +2.5045643955???E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t2, not present in second file PCK, resolved as id because it is built in',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_lsk.tls -t2 1 -f2 B1950 -t1 B1950 -f1 J2000 frmdiff_ck_cov1_id1.bc frmdiff_pck_cov1_id1.bpc',
  30,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.4379166112073E-02      +2.4379166112073E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t2, not present in second file PCK, resolved as id using kernels from -k',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm -t2 3002 -f2 B1950 -t1 B1950 -f1 J2000 frmdiff_ck_cov1_id1.bc frmdiff_pck_cov1_id1.bpc',
  30,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'FIXED3002' (3002)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.3534293422891E+00      +1.3534293422891E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t2, not present in second file PCK, resolved as id using kernels from -k2',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k2 frmdiff_mk.tm -t2 3002 -f2 B1950 -t1 B1950 -f1 J2000 frmdiff_ck_cov1_id1.bc frmdiff_pck_cov1_id1.bpc',
  29,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'FIXED3002' (3002)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.3534293422891E+00      +1.3534293422891E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t2, not present in only file CK, resolved as id using kernels from -k ',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm frmdiff_ck_cov1_id2.bc -t2 -84001 -f2 B1950 -t1 B1950 -f1 J2000 frmdiff_ck_cov1_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm frmdiff_ck_cov1_id2.bc",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm frmdiff_ck_cov1_id2.bc",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.5045643955???E+00      +2.5045643955???E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t2, not present in only file CK, resolved as id using kernels from -k2',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k2 frmdiff_mk.tm frmdiff_ck_cov1_id2.bc -t2 -84001 -f2 B1950 -t1 B1950 -f1 J2000 frmdiff_ck_cov1_id1.bc',
  29,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm frmdiff_ck_cov1_id2.bc",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.5045643955???E+00      +2.5045643955???E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t2, not present in only file PCK, resolved as id because it is built in',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_lsk.tls -t2 1 -f2 B1950 -t1 B1950 -f1 J2000 frmdiff_pck_cov1_id1.bpc',
  30,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck_cov1_id1.bpc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.4379166112073E-02      +2.4379166112073E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t2, not present in only file PCK, resolved as id using kernels from -k',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm -t2 3002 -f2 B1950 -t1 B1950 -f1 J2000 frmdiff_pck_cov1_id1.bpc',
  30,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov1_id1.bpc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'FIXED3002' (3002)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.3534293422891E+00      +1.3534293422891E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"to" id given with -t2, not present in only file PCK, resolved as id using kernels from -k2',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k2 frmdiff_mk.tm -t2 3002 -f2 B1950 -t1 B1950 -f1 J2000 frmdiff_pck_cov1_id1.bpc',
  29,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_pck_cov1_id1.bpc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'FIXED3002' (3002)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.3534293422891E+00      +1.3534293422891E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c2, resolved using kernels from -k',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm -c2 PHX_PAYLOAD -f2 J2000 -t2 B1950 frmdiff_ck_cov1_id1.bc',
  22,
"# Sampling of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056036E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c2, resolved using kernels from -k2',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k2 frmdiff_mk.tm -c2 PHX_PAYLOAD -f2 ECLIPJ2000 -f1 J2000 -t2 B1950 frmdiff_ck_cov1_id1.bc',
  29,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'ECLIPJ2000' (17) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +4.0909280422233E-01      +4.0909280422233E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c2, CK class frame, present in second CK file',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm -c2 PHX_PAYLOAD -t2 ECLIPJ2000 -f2 B1950 -t1 B1950 -f1 J2000 frmdiff_pck_cov1_id1.bpc frmdiff_ck_cov1_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov1_id1.bpc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +4.0980843101531E-01      +4.0980843101531E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c2, CK class frame, present in only CK file',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm -c2 PHX_PAYLOAD -t2 ECLIPJ2000 -f2 B1950 -t1 B1950 -f1 J2000 frmdiff_ck_cov1_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +4.0980843101531E-01      +4.0980843101531E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c2, PCK class frame, present in second PCK file',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_lsk.tls -c2 ITRF93 -t2 ECLIPJ2000 -f2 B1950 -t1 B1950 -f1 J2000 frmdiff_ck_cov1_id1.bc frmdiff_pck_cov1_id1.bpc',
  30,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +4.0980843101531E-01      +4.0980843101531E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" name given with -c2, PCK class frame, present in only PCK file',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_lsk.tls -c2 ITRF93 -t2 ECLIPJ2000 -f2 B1950 -t1 B1950 -f1 J2000 frmdiff_pck_cov1_id1.bpc',
  30,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck_cov1_id1.bpc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +4.0980843101531E-01      +4.0980843101531E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" is given with -c2, id present in second CK file',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm -c2 -84100 -t2 ECLIPJ2000 -f2 B1950 -t1 B1950 -f1 J2000 frmdiff_pck_cov1_id1.bpc frmdiff_ck_cov1_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov1_id1.bpc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +4.0980843101531E-01      +4.0980843101531E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" is given with -c2, id present in only CK file',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm -c2 -84100 -t2 ECLIPJ2000 -f2 B1950 -t1 B1950 -f1 J2000 frmdiff_ck_cov1_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +4.0980843101531E-01      +4.0980843101531E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" is given with -c2, id present in second PCK file',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_lsk.tls -c2 3000 -t2 ECLIPJ2000 -f2 B1950 -t1 B1950 -f1 J2000 frmdiff_ck_cov1_id1.bc frmdiff_pck_cov1_id1.bpc',
  30,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_ck_cov1_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +4.0980843101531E-01      +4.0980843101531E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '"cov" is given with -c2, id present in only PCK file',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_lsk.tls -c2 3000 -t2 ECLIPJ2000 -f2 B1950 -t1 B1950 -f1 J2000 frmdiff_pck_cov1_id1.bpc',
  30,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck_cov1_id1.bpc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +4.0980843101531E-01      +4.0980843101531E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'output for -a with "yes", -m with "from"',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -t dumpea -k frmdiff_lsk.tls frmdiff_pck.tpc -a yes -m from -f1 J2000 -t1 IAU_MARS',
  22,
"# Sampling of 1 rotations",
"#    from 'J2000' (1) to 'IAU_MARS' (10014)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"# including angular velocities relative to 'from' frame.",
"# angles are shown in radians.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X, av_x, av_y, av_z",
"+2.5000002000000E+08 -5.17284038749??E-01 +4.6245745034552E-01 +4.712959277803?E-01 +3.1623997856238E-05 -2.8802851535811E-05 +5.6520810080975E-05"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'output for -a with "yes", -m with "to"',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -t dumpea -k frmdiff_lsk.tls frmdiff_pck.tpc -a yes -m to -f1 J2000 -t1 IAU_MARS',
  22,
"# Sampling of 1 rotations",
"#    from 'J2000' (1) to 'IAU_MARS' (10014)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"# including angular velocities relative to 'to' frame.",
"# angles are shown in radians.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X, av_x, av_y, av_z",
"+2.5000002000000E+08 -5.17284038749??E-01 +4.6245745034552E-01 +4.712959277803?E-01 +4.45039????????E-13 +2.01935????????E-13 +7.0882180195131E-05"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'output for -a with "yes", no -m',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -t dumpea -k frmdiff_lsk.tls frmdiff_pck.tpc -a yes -f1 J2000 -t1 IAU_MARS',
  22,
"# Sampling of 1 rotations",
"#    from 'J2000' (1) to 'IAU_MARS' (10014)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"# including angular velocities relative to 'from' frame.",
"# angles are shown in radians.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X, av_x, av_y, av_z",
"+2.5000002000000E+08 -5.17284038749??E-01 +4.6245745034552E-01 +4.712959277803?E-01 +3.1623997856238E-05 -2.8802851535811E-05 +5.6520810080975E-05"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'output for -a with "no", -m with "from" (ignored)',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -t dumpea -k frmdiff_lsk.tls frmdiff_pck.tpc -a no -m from -f1 J2000 -t1 IAU_MARS',
  20,
"# Sampling of 1 rotations",
"#    from 'J2000' (1) to 'IAU_MARS' (10014)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"# angles are shown in radians.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X",
"+2.5000002000000E+08 -5.17284038749??E-01 +4.6245745034552E-01 +4.712959277803?E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'output for -a with "no", -m with "to" (ignored)',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -t dumpea -k frmdiff_lsk.tls frmdiff_pck.tpc -a no -m to -f1 J2000 -t1 IAU_MARS',
  20,
"# Sampling of 1 rotations",
"#    from 'J2000' (1) to 'IAU_MARS' (10014)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"# angles are shown in radians.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X",
"+2.5000002000000E+08 -5.17284038749??E-01 +4.6245745034552E-01 +4.712959277803?E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'output for -a with "no", no -m (ignored)',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -t dumpea -k frmdiff_lsk.tls frmdiff_pck.tpc -a no -f1 J2000 -t1 IAU_MARS',
  20,
"# Sampling of 1 rotations",
"#    from 'J2000' (1) to 'IAU_MARS' (10014)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"# angles are shown in radians.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X",
"+2.5000002000000E+08 -5.17284038749??E-01 +4.6245745034552E-01 +4.712959277803?E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'output for no -a, -m with "from" (ignored)',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -t dumpea -k frmdiff_lsk.tls frmdiff_pck.tpc -m from -f1 J2000 -t1 IAU_MARS',
  20,
"# Sampling of 1 rotations",
"#    from 'J2000' (1) to 'IAU_MARS' (10014)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"# angles are shown in radians.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X",
"+2.5000002000000E+08 -5.17284038749??E-01 +4.6245745034552E-01 +4.712959277803?E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'output for no -a, -m with "to" (ignored)',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -t dumpea -k frmdiff_lsk.tls frmdiff_pck.tpc -m to -f1 J2000 -t1 IAU_MARS',
  20,
"# Sampling of 1 rotations",
"#    from 'J2000' (1) to 'IAU_MARS' (10014)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"# angles are shown in radians.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X",
"+2.5000002000000E+08 -5.17284038749??E-01 +4.6245745034552E-01 +4.712959277803?E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'output for no -a, no -m (ignored)',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -t dumpea -k frmdiff_lsk.tls frmdiff_pck.tpc -f1 J2000 -t1 IAU_MARS',
  20,
"# Sampling of 1 rotations",
"#    from 'J2000' (1) to 'IAU_MARS' (10014)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"# angles are shown in radians.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X",
"+2.5000002000000E+08 -5.17284038749??E-01 +4.6245745034552E-01 +4.712959277803?E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'pick default "from" frame from first CK, "to" given with -t1',
  'success',
  $frmdiff,
  '-n 1 -k frmdiff_mk.tm -t1 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc frmdiff_ck_cov2_id1.bc',
  30,
"# Comparison of 2 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with 2 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov2_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +0.0000000000000E+00      +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'pick default "from" frame from first PCK, "to" given with -t1',
  'success',
  $frmdiff,
  '-n 1 -k frmdiff_mk.tm -t1 ITRF93 frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov2_id1.bpc',
  30,
"# Comparison of 2 rotations",
"#    from 'ECLIPJ2000' (17) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov1_id1.bpc",
"# with 2 rotations",
"#    from 'ECLIPJ2000' (17) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov2_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.74???????????E-12      +1.60???????????E-12"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'pick default "from" frame from only CK, "to" given with -t1',
  'success',
  $frmdiff,
  '-n 1 -k frmdiff_mk.tm -t1 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc',
  22,
"# Sampling of 2 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +0.0000000000000E+00      +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'pick default "from" frame from only PCK, "to" given with -t1',
  'success',
  $frmdiff,
  '-n 1 -k frmdiff_mk.tm -t1 ITRF93 frmdiff_pck_cov1_id1.bpc',
  22,
"# Sampling of 2 rotations",
"#    from 'ECLIPJ2000' (17) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.4311356762341E+00      +1.4276695519708E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'pick default "to" frame from first CK, "from" given with -f1',
  'success',
  $frmdiff,
  '-n 1 -k frmdiff_mk.tm -f1 J2000 frmdiff_ck_cov1_id1.bc frmdiff_ck_cov2_id1.bc',
  30,
"# Comparison of 2 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with 2 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov2_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +0.0000000000000E+00      +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'pick default "to" frame from first PCK, "from" given with -f1',
  'success',
  $frmdiff,
  '-n 1 -k frmdiff_mk.tm -f1 J2000 frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov2_id1.bpc',
  30,
"# Comparison of 2 rotations",
"#    from 'J2000' (1) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov1_id1.bpc",
"# with 2 rotations",
"#    from 'J2000' (1) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov2_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.74???????????E-12      +1.60???????????E-12"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'pick default "to" frame from only CK, "from" given with -f1',
  'success',
  $frmdiff,
  '-n 1 -k frmdiff_mk.tm -f1 J2000 frmdiff_ck_cov1_id1.bc',
  22,
"# Sampling of 2 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.50695135014??E+00      +2.505695024401?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'pick default "to" frame from only PCK, "from" given with -f1',
  'success',
  $frmdiff,
  '-n 1 -k frmdiff_mk.tm -f1 J2000 frmdiff_pck_cov1_id1.bpc',
  22,
"# Sampling of 2 rotations",
"#    from 'J2000' (1) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.3815873682281E+00      +1.3779413114101E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'pick default "from" frame from first CK, "to" given with -t2',
  'success',
  $frmdiff,
  '-n 1 -k frmdiff_mk.tm -t2 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc frmdiff_ck_cov2_id1.bc',
  30,
"# Comparison of 2 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with 2 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov2_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +0.0000000000000E+00      +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'pick default "from" frame from first PCK, "to" given with -t2',
  'success',
  $frmdiff,
  '-n 1 -k frmdiff_mk.tm -t2 ITRF93 frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov2_id1.bpc',
  30,
"# Comparison of 2 rotations",
"#    from 'ECLIPJ2000' (17) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov1_id1.bpc",
"# with 2 rotations",
"#    from 'ECLIPJ2000' (17) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov2_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.74???????????E-12      +1.60???????????E-12"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'pick default "from" frame from only CK, "to" given with -t2',
  'success',
  $frmdiff,
  '-n 1 -k frmdiff_mk.tm -t2 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc',
  22,
"# Sampling of 2 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +0.0000000000000E+00      +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'pick default "from" frame from only PCK, "to" given with -t2',
  'success',
  $frmdiff,
  '-n 1 -k frmdiff_mk.tm -t2 ITRF93 frmdiff_pck_cov1_id1.bpc',
  22,
"# Sampling of 2 rotations",
"#    from 'ECLIPJ2000' (17) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.4311356762341E+00      +1.4276695519708E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'pick default "to" frame from first CK, "from" given with -f2',
  'success',
  $frmdiff,
  '-n 1 -k frmdiff_mk.tm -f2 J2000 frmdiff_ck_cov1_id1.bc frmdiff_ck_cov2_id1.bc',
  30,
"# Comparison of 2 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with 2 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov2_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +0.0000000000000E+00      +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'pick default "to" frame from first PCK, "from" given with -f2',
  'success',
  $frmdiff,
  '-n 1 -k frmdiff_mk.tm -f2 J2000 frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov2_id1.bpc',
  30,
"# Comparison of 2 rotations",
"#    from 'J2000' (1) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov1_id1.bpc",
"# with 2 rotations",
"#    from 'J2000' (1) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov2_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.74???????????E-12      +1.60???????????E-12"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'pick default "to" frame from only CK, "from" given with -f2',
  'success',
  $frmdiff,
  '-n 1 -k frmdiff_mk.tm -f2 J2000 frmdiff_ck_cov1_id1.bc',
  22,
"# Sampling of 2 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.50695135014??E+00      +2.505695024401?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'pick default "to" frame from only PCK, "from" given with -f2',
  'success',
  $frmdiff,
  '-n 1 -k frmdiff_mk.tm -f2 J2000 frmdiff_pck_cov1_id1.bpc',
  22,
"# Sampling of 2 rotations",
"#    from 'J2000' (1) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.3815873682281E+00      +1.3779413114101E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default second "from" frame to -f1, -t1 and -t2 specified, first file CK',
  'success',
  $frmdiff,
  '-n 1 -k frmdiff_mk.tm -t1 B1950 -t2 J2000 -f1 ECLIPJ2000 -c1 -84100 frmdiff_ck_cov1_id1.bc frmdiff_pck_cov2_id1.bpc',
  30,
"# Comparison of 2 rotations",
"#    from 'ECLIPJ2000' (17) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with 2 rotations",
"#    from 'ECLIPJ2000' (17) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov2_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056036E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default second "from" frame to -f1, -t1 and -t2 specified, only file CK',
  'success',
  $frmdiff,
  '-n 1 -k frmdiff_mk.tm -t1 B1950 -t2 J2000 -f1 ECLIPJ2000 -c1 -84100 frmdiff_ck_cov1_id1.bc',
  30,
"# Comparison of 2 rotations",
"#    from 'ECLIPJ2000' (17) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with 2 rotations",
"#    from 'ECLIPJ2000' (17) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056036E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default second "from" frame to -f1, -t1 and -t2 specified, first file PCK',
  'success',
  $frmdiff,
  '-n 1 -k frmdiff_mk.tm -t1 B1950 -t2 J2000 -f1 ECLIPJ2000 -c1 3000 frmdiff_pck_cov2_id1.bpc frmdiff_ck_cov1_id1.bc',
  30,
"# Comparison of 2 rotations",
"#    from 'ECLIPJ2000' (17) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov2_id1.bpc",
"# with 2 rotations",
"#    from 'ECLIPJ2000' (17) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:29:35.000' TDB (250000175.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056036E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default second "from" frame to -f1, -t1 and -t2 specified, only file PCK',
  'success',
  $frmdiff,
  '-n 1 -k frmdiff_mk.tm -t1 B1950 -t2 J2000 -f1 ECLIPJ2000 -c1 3000 frmdiff_pck_cov2_id1.bpc',
  30,
"# Comparison of 2 rotations",
"#    from 'ECLIPJ2000' (17) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov2_id1.bpc",
"# with 2 rotations",
"#    from 'ECLIPJ2000' (17) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov2_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:29:35.000' TDB (250000175.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056036E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default second "from" frame to -f1, -t1 and -t2 specified, no files',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm -t1 B1950 -t2 J2000 -f1 ECLIPJ2000',
  28,
"# Comparison of 1 rotations",
"#    from 'ECLIPJ2000' (17) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"# with 1 rotations",
"#    from 'ECLIPJ2000' (17) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_mk.tm",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056036E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default first "from" frame to -f2, -t1 and -t2 specified, first file CK',
  'success',
  $frmdiff,
  '-n 1 -k frmdiff_mk.tm -t1 B1950 -t2 J2000 -f2 ECLIPJ2000 -c1 -84100 frmdiff_ck_cov1_id1.bc frmdiff_pck_cov2_id1.bpc',
  30,
"# Comparison of 2 rotations",
"#    from 'ECLIPJ2000' (17) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with 2 rotations",
"#    from 'ECLIPJ2000' (17) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov2_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056036E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default first "from" frame to -f2, -t1 and -t2 specified, only file CK',
  'success',
  $frmdiff,
  '-n 1 -k frmdiff_mk.tm -t1 B1950 -t2 J2000 -f2 ECLIPJ2000 -c1 -84100 frmdiff_ck_cov1_id1.bc',
  30,
"# Comparison of 2 rotations",
"#    from 'ECLIPJ2000' (17) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with 2 rotations",
"#    from 'ECLIPJ2000' (17) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056036E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default first "from" frame to -f2, -t1 and -t2 specified, first file PCK',
  'success',
  $frmdiff,
  '-n 1 -k frmdiff_mk.tm -t1 B1950 -t2 J2000 -f2 ECLIPJ2000 -c1 3000 frmdiff_pck_cov2_id1.bpc frmdiff_ck_cov1_id1.bc',
  30,
"# Comparison of 2 rotations",
"#    from 'ECLIPJ2000' (17) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov2_id1.bpc",
"# with 2 rotations",
"#    from 'ECLIPJ2000' (17) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:29:35.000' TDB (250000175.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056036E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default first "from" frame to -f2, -t1 and -t2 specified, only file PCK',
  'success',
  $frmdiff,
  '-n 1 -k frmdiff_mk.tm -t1 B1950 -t2 J2000 -f2 ECLIPJ2000 -c1 3000 frmdiff_pck_cov2_id1.bpc',
  30,
"# Comparison of 2 rotations",
"#    from 'ECLIPJ2000' (17) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov2_id1.bpc",
"# with 2 rotations",
"#    from 'ECLIPJ2000' (17) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov2_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:29:35.000' TDB (250000175.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056036E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default first "from" frame to -f2, -t1 and -t2 specified, no files',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm -t1 B1950 -t2 J2000 -f2 ECLIPJ2000',
  28,
"# Comparison of 1 rotations",
"#    from 'ECLIPJ2000' (17) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"# with 1 rotations",
"#    from 'ECLIPJ2000' (17) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_mk.tm",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056036E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default second "to" frame to -t1, -f1 and -f2 specified, first file CK',
  'success',
  $frmdiff,
  '-n 1 -k frmdiff_mk.tm -f1 B1950 -f2 J2000 -t1 ECLIPJ2000 -c1 -84100 frmdiff_ck_cov1_id1.bc frmdiff_pck_cov2_id1.bpc',
  30,
"# Comparison of 2 rotations",
"#    from 'B1950' (2) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with 2 rotations",
"#    from 'J2000' (1) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov2_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056036E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default second "to" frame to -t1, -f1 and -f2 specified, only file CK',
  'success',
  $frmdiff,
  '-n 1 -k frmdiff_mk.tm -f1 B1950 -f2 J2000 -t1 ECLIPJ2000 -c1 -84100 frmdiff_ck_cov1_id1.bc',
  30,
"# Comparison of 2 rotations",
"#    from 'B1950' (2) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with 2 rotations",
"#    from 'J2000' (1) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056036E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default second "to" frame to -t1, -f1 and -f2 specified, first file PCK',
  'success',
  $frmdiff,
  '-n 1 -k frmdiff_mk.tm -f1 B1950 -f2 J2000 -t1 ECLIPJ2000 -c1 3000 frmdiff_pck_cov2_id1.bpc frmdiff_ck_cov1_id1.bc',
  30,
"# Comparison of 2 rotations",
"#    from 'B1950' (2) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov2_id1.bpc",
"# with 2 rotations",
"#    from 'J2000' (1) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:29:35.000' TDB (250000175.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056036E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default second "to" frame to -t1, -f1 and -f2 specified, only file PCK',
  'success',
  $frmdiff,
  '-n 1 -k frmdiff_mk.tm -f1 B1950 -f2 J2000 -t1 ECLIPJ2000 -c1 3000 frmdiff_pck_cov2_id1.bpc',
  30,
"# Comparison of 2 rotations",
"#    from 'B1950' (2) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov2_id1.bpc",
"# with 2 rotations",
"#    from 'J2000' (1) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov2_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:29:35.000' TDB (250000175.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056036E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default second "to" frame to -t1, -f1 and -f2 specified, no files',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm -f1 B1950 -f2 J2000 -t1 ECLIPJ2000',
  28,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm",
"# with 1 rotations",
"#    from 'J2000' (1) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056036E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default first "to" frame to -t2, -f1 and -f2 specified, first file CK',
  'success',
  $frmdiff,
  '-n 1 -k frmdiff_mk.tm -f1 B1950 -f2 J2000 -t2 ECLIPJ2000 -c1 -84100 frmdiff_ck_cov1_id1.bc frmdiff_pck_cov2_id1.bpc',
  30,
"# Comparison of 2 rotations",
"#    from 'B1950' (2) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with 2 rotations",
"#    from 'J2000' (1) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov2_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056036E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default first "to" frame to -t2, -f1 and -f2 specified, only file CK',
  'success',
  $frmdiff,
  '-n 1 -k frmdiff_mk.tm -f1 B1950 -f2 J2000 -t2 ECLIPJ2000 -c1 -84100 frmdiff_ck_cov1_id1.bc',
  30,
"# Comparison of 2 rotations",
"#    from 'B1950' (2) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with 2 rotations",
"#    from 'J2000' (1) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056036E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default first "to" frame to -t2, -f1 and -f2 specified, first file PCK',
  'success',
  $frmdiff,
  '-n 1 -k frmdiff_mk.tm -f1 B1950 -f2 J2000 -t2 ECLIPJ2000 -c1 3000 frmdiff_pck_cov2_id1.bpc frmdiff_ck_cov1_id1.bc',
  30,
"# Comparison of 2 rotations",
"#    from 'B1950' (2) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov2_id1.bpc",
"# with 2 rotations",
"#    from 'J2000' (1) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:29:35.000' TDB (250000175.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056036E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default first "to" frame to -t2, -f1 and -f2 specified, only file PCK',
  'success',
  $frmdiff,
  '-n 1 -k frmdiff_mk.tm -f1 B1950 -f2 J2000 -t2 ECLIPJ2000 -c1 3000 frmdiff_pck_cov2_id1.bpc',
  30,
"# Comparison of 2 rotations",
"#    from 'B1950' (2) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov2_id1.bpc",
"# with 2 rotations",
"#    from 'J2000' (1) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov2_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:29:35.000' TDB (250000175.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056036E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default first "to" frame to -t2, -f1 and -f2 specified, no files',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm -f1 B1950 -f2 J2000 -t2 ECLIPJ2000',
  28,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm",
"# with 1 rotations",
"#    from 'J2000' (1) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056036E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default first "cov" frame to first "to" frame, both files CKs, data present',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -f1 J2000 -t1 PHX_PAYLOAD frmdiff_ck_cov12_id12.bc frmdiff_ck_cov2_id1.bc',
  30,
"# Comparison of 2 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov12_id12.bc",
"# with 2 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov2_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +0.0000000000000E+00      +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default first "cov" frame to first "to" frame, both files PCKs, data present',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -f1 J2000 -t1 ITRF93 frmdiff_pck_cov12_id12.bpc frmdiff_pck_cov2_id1.bpc',
  30,
"# Comparison of 2 rotations",
"#    from 'J2000' (1) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov12_id12.bpc",
"# with 2 rotations",
"#    from 'J2000' (1) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov2_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.74???????????E-12      +1.60???????????E-12"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default first "cov" frame to first "to" frame, first file CK, data present',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -f1 J2000 -t1 PHX_PAYLOAD -t2 B1950 frmdiff_ck_cov12_id12.bc frmdiff_lsk.tls',
  30,
"# Comparison of 2 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov12_id12.bc",
"# with 2 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_lsk.tls",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.50599866611??E+00      +2.50473885245??E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default first "cov" frame to first "to" frame, first file PCK, data present',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -f1 J2000 -t1 ITRF93 -t2 B1950 frmdiff_pck_cov12_id12.bpc frmdiff_lsk.tls',
  30,
"# Comparison of 2 rotations",
"#    from 'J2000' (1) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov12_id12.bpc",
"# with 2 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_lsk.tls",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.3704177610696E+00      +1.3667717399579E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default first "cov" frame to first "to" frame, only file CK, data present',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -f1 J2000 -t1 PHX_PAYLOAD frmdiff_ck_cov12_id12.bc',
  22,
"# Sampling of 2 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov12_id12.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.50695135014??E+00      +2.505695024401?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default first "cov" frame to first "to" frame, only file PCK, data present',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -f1 J2000 -t1 ITRF93 frmdiff_pck_cov12_id12.bpc',
  22,
"# Sampling of 2 rotations",
"#    from 'J2000' (1) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov12_id12.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.3815873682281E+00      +1.3779413114101E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default first "cov" frame to first "to" frame, both files CKs, no data',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -k1 frmdiff_ck_cov2_id2.bc -k2 frmdiff_ck_cov2_id1.bc -n 1 -f1 J2000 -t1 PHX_LANDER frmdiff_ck_cov2_id1.bc frmdiff_ck_cov2_id2.bc',
  32,
"# Comparison of 2 rotations",
"#    from 'J2000' (1) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov2_id2.bc",
"#       frmdiff_ck_cov2_id1.bc",
"# with 2 rotations",
"#    from 'J2000' (1) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov2_id1.bc",
"#       frmdiff_ck_cov2_id2.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:29:35.000' TDB (250000175.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +0.0000000000000E+00      +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default first "cov" frame to first "to" frame, only file CK, no data',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm frmdiff_ck_cov1_id2.bc -n 1 -f1 J2000 -t1 PHX_LANDER frmdiff_ck_cov1_id1.bc',
  22,
"# Sampling of 1 rotations",
"#    from 'J2000' (1) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm frmdiff_ck_cov1_id2.bc",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.506448241827?E+00      +2.506448241827?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default second "cov" frame to second "to" frame, second file CK, data present',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -f2 J2000 -t2 PHX_PAYLOAD -t1 B1950 frmdiff_lsk.tls frmdiff_ck_cov2_id1.bc',
  30,
"# Comparison of 2 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_lsk.tls",
"# with 2 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov2_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:29:35.000' TDB (250000175.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.504108267072?E+00      +2.502851171598?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default second "cov" frame to second "to" frame, second file PCK, data present',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -f2 J2000 -t2 ITRF93 -t1 B1950 frmdiff_lsk.tls frmdiff_pck_cov2_id1.bpc',
  30,
"# Comparison of 2 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_lsk.tls",
"# with 2 rotations",
"#    from 'J2000' (1) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov2_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:29:35.000' TDB (250000175.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.375886793163?E+00      +1.372240771807?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'default second "cov" frame to second "to" frame, second file CK, no data',
  'success',
  $frmdiff,
  '-b 2007-12-04 00:27 TDB -e 2007-12-04 00:27 TDB -k frmdiff_mk.tm -k2 frmdiff_ck_cov1_id2.bc -n 1 -f2 J2000 -t2 PHX_LANDER -t1 B1950 frmdiff_lsk.tls frmdiff_ck_cov1_id1.bc',
  31,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_lsk.tls",
"# with 1 rotations",
"#    from 'J2000' (1) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id2.bc",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:00.000' TDB (250000020.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.505494162164?E+00      +2.505494162164?E+00"
);


&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, no files, -b and -e specified',
  'success',
  $frmdiff,
  '-k frmdiff_lsk.tls -n 1 -t dumpc -b 2007-12-04 00:26:40 TDB -e 2007-12-04 00:28:20 TDB -f1 J2000 -t1 B1950',
  18,
"# Coverage for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000000000E+08 +2.5000010000000E+08         100.000000     0:00:01:40.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only file not CK/PCK, -b and -e specified',
  'success',
  $frmdiff,
  '-k frmdiff_lsk.tls -n 1 -t dumpc -b 2007-12-04 00:26:40 TDB -e 2007-12-04 00:28:20 TDB -f1 J2000 -t1 B1950 frmdiff_pck.tpc',
  19,
"# Coverage for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000000000E+08 +2.5000010000000E+08         100.000000     0:00:01:40.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, two files not CK/PCK, -b and -e specified',
  'success',
  $frmdiff,
  '-k frmdiff_lsk.tls -n 1 -t dumpc -b 2007-12-04 00:26:40 TDB -e 2007-12-04 00:28:20 TDB -f1 J2000 -t1 B1950 frmdiff_pck.tpc frmdiff_fk.tf',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck.tpc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_fk.tf",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000000000E+08 +2.5000010000000E+08         100.000000     0:00:01:40.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only file CK, first "cov" frame, no -b and -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 PHX_PAYLOAD -f1 PHX_LL -t1 PHX_PAYLOAD frmdiff_ck_cov12_id12.bc',
  19,
"# Coverage for rotation",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov12_id12.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000000000E+08 +2.5000010000000E+08         100.000000     0:00:01:40.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only file CK, first "cov" frame, only -b',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 PHX_PAYLOAD -f1 PHX_LL -t1 PHX_PAYLOAD -b 2007-12-04 00:26:41 TDB frmdiff_ck_cov12_id12.bc',
  19,
"# Coverage for rotation",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov12_id12.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:41.000' TDB (250000001.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000100000E+08 +2.5000010000000E+08          99.000000     0:00:01:39.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only file CK, first "cov" frame, only -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 PHX_PAYLOAD -f1 PHX_LL -t1 PHX_PAYLOAD -e 2007-12-04 00:28:19 TDB frmdiff_ck_cov12_id12.bc',
  19,
"# Coverage for rotation",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov12_id12.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:19.000' TDB (250000099.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000000000E+08 +2.5000009900000E+08          99.000000     0:00:01:39.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only file CK, first "cov" frame, -b and -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 PHX_PAYLOAD -f1 PHX_LL -t1 PHX_PAYLOAD -b 2007-12-04 00:26:41 TDB -e 2007-12-04 00:28:19 TDB frmdiff_ck_cov12_id12.bc',
  19,
"# Coverage for rotation",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov12_id12.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:41.000' TDB (250000001.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:19.000' TDB (250000099.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000100000E+08 +2.5000009900000E+08          98.000000     0:00:01:38.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only file CK, second "cov" frame, no -b and -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c2 PHX_LANDER -t2 PHX_LANDER frmdiff_ck_cov12_id12.bc',
  19,
"# Coverage for rotation",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov12_id12.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:29:35.000' TDB (250000175.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007500000E+08 +2.5000017500000E+08         100.000000     0:00:01:40.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only file CK, second "cov" frame, only -b',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c2 PHX_LANDER -t2 PHX_LANDER -b 2007-12-04 00:27:56 TDB frmdiff_ck_cov12_id12.bc',
  19,
"# Coverage for rotation",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov12_id12.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:56.000' TDB (250000076.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:29:35.000' TDB (250000175.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007600000E+08 +2.5000017500000E+08          99.000000     0:00:01:39.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only file CK, second "cov" frame, only -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c2 PHX_LANDER -t2 PHX_LANDER -e 2007-12-04 00:29:34 TDB frmdiff_ck_cov12_id12.bc',
  19,
"# Coverage for rotation",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov12_id12.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:29:34.000' TDB (250000174.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007500000E+08 +2.5000017400000E+08          99.000000     0:00:01:39.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only file CK, second "cov" frame, -b and -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c2 PHX_LANDER -t2 PHX_LANDER -b 2007-12-04 00:27:56 TDB -e 2007-12-04 00:29:34 TDB frmdiff_ck_cov12_id12.bc',
  19,
"# Coverage for rotation",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov12_id12.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:56.000' TDB (250000076.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:29:34.000' TDB (250000174.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007600000E+08 +2.5000017400000E+08          98.000000     0:00:01:38.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only file CK, two same "cov" frames, no -b and -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 PHX_LANDER -t2 PHX_LANDER frmdiff_ck_cov12_id12.bc',
  19,
"# Coverage for rotation",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov12_id12.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:29:35.000' TDB (250000175.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007500000E+08 +2.5000017500000E+08         100.000000     0:00:01:40.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only file CK, two same "cov" frames, only -b',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 PHX_LANDER -t2 PHX_LANDER -b 2007-12-04 00:27:56 TDB frmdiff_ck_cov12_id12.bc',
  19,
"# Coverage for rotation",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov12_id12.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:56.000' TDB (250000076.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:29:35.000' TDB (250000175.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007600000E+08 +2.5000017500000E+08          99.000000     0:00:01:39.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only file CK, two same "cov" frames, only -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 PHX_LANDER -t2 PHX_LANDER -e 2007-12-04 00:29:34 TDB frmdiff_ck_cov12_id12.bc',
  19,
"# Coverage for rotation",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov12_id12.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:29:34.000' TDB (250000174.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007500000E+08 +2.5000017400000E+08          99.000000     0:00:01:39.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only file CK, two same "cov" frames, -b and -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 PHX_LANDER -t2 PHX_LANDER -b 2007-12-04 00:27:56 TDB -e 2007-12-04 00:29:34 TDB frmdiff_ck_cov12_id12.bc',
  19,
"# Coverage for rotation",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov12_id12.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:56.000' TDB (250000076.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:29:34.000' TDB (250000174.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007600000E+08 +2.5000017400000E+08          98.000000     0:00:01:38.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only file CK, two distinct "cov" frames, overlap, no -b and -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 PHX_PAYLOAD -c2 PHX_LANDER frmdiff_ck_cov12_id12.bc',
  19,
"# Coverage for rotation",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov12_id12.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007500000E+08 +2.5000010000000E+08          25.000000     0:00:00:25.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only file CK, two distinct "cov" frames, overlap, only -b',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 PHX_PAYLOAD -c2 PHX_LANDER -b 2007-12-04 00:27:56 TDB frmdiff_ck_cov12_id12.bc',
  19,
"# Coverage for rotation",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov12_id12.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:56.000' TDB (250000076.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007600000E+08 +2.5000010000000E+08          24.000000     0:00:00:24.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only file CK, two distinct "cov" frames, overlap, only -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 PHX_PAYLOAD -c2 PHX_LANDER -e 2007-12-04 00:28:19 TDB frmdiff_ck_cov12_id12.bc',
  19,
"# Coverage for rotation",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov12_id12.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:19.000' TDB (250000099.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007500000E+08 +2.5000009900000E+08          24.000000     0:00:00:24.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only file CK, two distinct "cov" frames, overlap, -b and -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 PHX_PAYLOAD -c2 PHX_LANDER -b 2007-12-04 00:27:56 TDB -e 2007-12-04 00:28:19 TDB frmdiff_ck_cov12_id12.bc',
  19,
"# Coverage for rotation",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov12_id12.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:56.000' TDB (250000076.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:19.000' TDB (250000099.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007600000E+08 +2.5000009900000E+08          23.000000     0:00:00:23.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only file PCK, first "cov" frame, no -b and -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 ITRF93 -t1 ITRF93 frmdiff_pck_cov12_id12.bpc',
  19,
"# Coverage for rotation",
"#    from 'ECLIPJ2000' (17) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov12_id12.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000000000E+08 +2.5000010000000E+08         100.000000     0:00:01:40.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only file PCK, first "cov" frame, only -b',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 ITRF93 -t1 ITRF93 -b 2007-12-04 00:26:41 TDB frmdiff_pck_cov12_id12.bpc',
  19,
"# Coverage for rotation",
"#    from 'ECLIPJ2000' (17) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov12_id12.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:41.000' TDB (250000001.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000100000E+08 +2.5000010000000E+08          99.000000     0:00:01:39.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only file PCK, first "cov" frame, only -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 ITRF93 -t1 ITRF93 -e 2007-12-04 00:28:19 TDB frmdiff_pck_cov12_id12.bpc',
  19,
"# Coverage for rotation",
"#    from 'ECLIPJ2000' (17) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov12_id12.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:19.000' TDB (250000099.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000000000E+08 +2.5000009900000E+08          99.000000     0:00:01:39.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only file PCK, first "cov" frame, -b and -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 ITRF93 -t1 ITRF93 -b 2007-12-04 00:26:41 TDB -e 2007-12-04 00:28:19 TDB frmdiff_pck_cov12_id12.bpc',
  19,
"# Coverage for rotation",
"#    from 'ECLIPJ2000' (17) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov12_id12.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:41.000' TDB (250000001.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:19.000' TDB (250000099.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000100000E+08 +2.5000009900000E+08          98.000000     0:00:01:38.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only file PCK, second "cov" frame, no -b and -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c2 IAU_EARTH -t2 IAU_EARTH frmdiff_pck_cov12_id12.bpc',
  19,
"# Coverage for rotation",
"#    from 'ECLIPJ2000' (17) to 'IAU_EARTH' (10013)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov12_id12.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:29:35.000' TDB (250000175.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007500000E+08 +2.5000017500000E+08         100.000000     0:00:01:40.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only file PCK, second "cov" frame, only -b',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c2 IAU_EARTH -t2 IAU_EARTH -b 2007-12-04 00:27:56 TDB frmdiff_pck_cov12_id12.bpc',
  19,
"# Coverage for rotation",
"#    from 'ECLIPJ2000' (17) to 'IAU_EARTH' (10013)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov12_id12.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:56.000' TDB (250000076.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:29:35.000' TDB (250000175.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007600000E+08 +2.5000017500000E+08          99.000000     0:00:01:39.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only file PCK, second "cov" frame, only -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c2 IAU_EARTH -t2 IAU_EARTH -e 2007-12-04 00:29:34 TDB frmdiff_pck_cov12_id12.bpc',
  19,
"# Coverage for rotation",
"#    from 'ECLIPJ2000' (17) to 'IAU_EARTH' (10013)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov12_id12.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:29:34.000' TDB (250000174.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007500000E+08 +2.5000017400000E+08          99.000000     0:00:01:39.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only file PCK, second "cov" frame, -b and -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c2 IAU_EARTH -t2 IAU_EARTH -b 2007-12-04 00:27:56 TDB -e 2007-12-04 00:29:34 TDB frmdiff_pck_cov12_id12.bpc',
  19,
"# Coverage for rotation",
"#    from 'ECLIPJ2000' (17) to 'IAU_EARTH' (10013)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov12_id12.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:56.000' TDB (250000076.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:29:34.000' TDB (250000174.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007600000E+08 +2.5000017400000E+08          98.000000     0:00:01:38.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only file PCK, two same "cov" frames, no -b and -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 IAU_EARTH -t2 IAU_EARTH frmdiff_pck_cov12_id12.bpc',
  19,
"# Coverage for rotation",
"#    from 'ECLIPJ2000' (17) to 'IAU_EARTH' (10013)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov12_id12.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:29:35.000' TDB (250000175.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007500000E+08 +2.5000017500000E+08         100.000000     0:00:01:40.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only file PCK, two same "cov" frames, only -b',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 IAU_EARTH -t2 IAU_EARTH -b 2007-12-04 00:27:56 TDB frmdiff_pck_cov12_id12.bpc',
  19,
"# Coverage for rotation",
"#    from 'ECLIPJ2000' (17) to 'IAU_EARTH' (10013)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov12_id12.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:56.000' TDB (250000076.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:29:35.000' TDB (250000175.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007600000E+08 +2.5000017500000E+08          99.000000     0:00:01:39.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only file PCK, two same "cov" frames, only -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 IAU_EARTH -t2 IAU_EARTH -e 2007-12-04 00:29:34 TDB frmdiff_pck_cov12_id12.bpc',
  19,
"# Coverage for rotation",
"#    from 'ECLIPJ2000' (17) to 'IAU_EARTH' (10013)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov12_id12.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:29:34.000' TDB (250000174.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007500000E+08 +2.5000017400000E+08          99.000000     0:00:01:39.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only file PCK, two same "cov" frames, -b and -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 IAU_EARTH -t2 IAU_EARTH -b 2007-12-04 00:27:56 TDB -e 2007-12-04 00:29:34 TDB frmdiff_pck_cov12_id12.bpc',
  19,
"# Coverage for rotation",
"#    from 'ECLIPJ2000' (17) to 'IAU_EARTH' (10013)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov12_id12.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:56.000' TDB (250000076.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:29:34.000' TDB (250000174.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007600000E+08 +2.5000017400000E+08          98.000000     0:00:01:38.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only file PCK, two distinct "cov" frames, overlap, no -b and -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 ITRF93 -c2 IAU_EARTH frmdiff_pck_cov12_id12.bpc',
  19,
"# Coverage for rotation",
"#    from 'ECLIPJ2000' (17) to 'IAU_EARTH' (10013)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov12_id12.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007500000E+08 +2.5000010000000E+08          25.000000     0:00:00:25.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only file PCK, two distinct "cov" frames, overlap, only -b',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 ITRF93 -c2 IAU_EARTH -b 2007-12-04 00:27:56 TDB frmdiff_pck_cov12_id12.bpc',
  19,
"# Coverage for rotation",
"#    from 'ECLIPJ2000' (17) to 'IAU_EARTH' (10013)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov12_id12.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:56.000' TDB (250000076.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007600000E+08 +2.5000010000000E+08          24.000000     0:00:00:24.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only file PCK, two distinct "cov" frames, overlap, only -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 ITRF93 -c2 IAU_EARTH -e 2007-12-04 00:28:19 TDB frmdiff_pck_cov12_id12.bpc',
  19,
"# Coverage for rotation",
"#    from 'ECLIPJ2000' (17) to 'IAU_EARTH' (10013)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov12_id12.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:19.000' TDB (250000099.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007500000E+08 +2.5000009900000E+08          24.000000     0:00:00:24.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only file PCK, two distinct "cov" frames, overlap, -b and -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 ITRF93 -c2 IAU_EARTH -b 2007-12-04 00:27:56 TDB -e 2007-12-04 00:28:19 TDB frmdiff_pck_cov12_id12.bpc',
  19,
"# Coverage for rotation",
"#    from 'ECLIPJ2000' (17) to 'IAU_EARTH' (10013)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov12_id12.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:56.000' TDB (250000076.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:19.000' TDB (250000099.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007600000E+08 +2.5000009900000E+08          23.000000     0:00:00:23.000000"
);


&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, first file CK second not CK/PCK, first "cov" frame, no -b and -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 PHX_PAYLOAD -f1 J2000 -t1 PHX_PAYLOAD -t2 B1950 frmdiff_ck_cov12_id12.bc frmdiff_pck.tpc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov12_id12.bc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000000000E+08 +2.5000010000000E+08         100.000000     0:00:01:40.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, first file CK second not CK/PCK, first "cov" frame, only -b',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 PHX_PAYLOAD -f1 J2000 -t1 PHX_PAYLOAD -t2 B1950 -b 2007-12-04 00:26:41 TDB frmdiff_ck_cov12_id12.bc frmdiff_pck.tpc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov12_id12.bc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:41.000' TDB (250000001.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000100000E+08 +2.5000010000000E+08          99.000000     0:00:01:39.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, first file CK second not CK/PCK, first "cov" frame, only -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 PHX_PAYLOAD -f1 J2000 -t1 PHX_PAYLOAD -t2 B1950 -e 2007-12-04 00:28:19 TDB frmdiff_ck_cov12_id12.bc frmdiff_pck.tpc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov12_id12.bc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:19.000' TDB (250000099.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000000000E+08 +2.5000009900000E+08          99.000000     0:00:01:39.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, first file CK second not CK/PCK, first "cov" frame, -b and -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 PHX_PAYLOAD -f1 J2000 -t1 PHX_PAYLOAD -t2 B1950 -b 2007-12-04 00:26:41 TDB -e 2007-12-04 00:28:19 TDB frmdiff_ck_cov12_id12.bc frmdiff_pck.tpc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov12_id12.bc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:41.000' TDB (250000001.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:19.000' TDB (250000099.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000100000E+08 +2.5000009900000E+08          98.000000     0:00:01:38.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, first file PCK second not CK/PCK, first "cov" frame, no -b and -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 ITRF93 -f1 J2000 -t1 ITRF93 -t2 B1950 frmdiff_pck_cov12_id12.bpc frmdiff_pck.tpc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov12_id12.bpc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000000000E+08 +2.5000010000000E+08         100.000000     0:00:01:40.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, first file PCK second not CK/PCK, first "cov" frame, only -b',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 ITRF93 -f1 J2000 -t1 ITRF93 -t2 B1950 -b 2007-12-04 00:26:41 TDB frmdiff_pck_cov12_id12.bpc frmdiff_pck.tpc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov12_id12.bpc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:41.000' TDB (250000001.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000100000E+08 +2.5000010000000E+08          99.000000     0:00:01:39.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, first file PCK second not CK/PCK, first "cov" frame, only -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 ITRF93 -f1 J2000 -t1 ITRF93 -t2 B1950 -e 2007-12-04 00:28:19 TDB frmdiff_pck_cov12_id12.bpc frmdiff_pck.tpc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov12_id12.bpc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:19.000' TDB (250000099.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000000000E+08 +2.5000009900000E+08          99.000000     0:00:01:39.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, first file PCK second not CK/PCK, first "cov" frame, -b and -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 ITRF93 -f1 J2000 -t1 ITRF93 -t2 B1950 -b 2007-12-04 00:26:41 TDB -e 2007-12-04 00:28:19 TDB frmdiff_pck_cov12_id12.bpc frmdiff_pck.tpc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov12_id12.bpc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:41.000' TDB (250000001.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:19.000' TDB (250000099.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000100000E+08 +2.5000009900000E+08          98.000000     0:00:01:38.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, second file CK first not CK/PCK, second "cov" frame, no -b and -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c2 PHX_PAYLOAD -f1 J2000 -t2 PHX_PAYLOAD -t1 B1950 frmdiff_pck.tpc frmdiff_ck_cov12_id12.bc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck.tpc",
"# and rotation",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov12_id12.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000000000E+08 +2.5000010000000E+08         100.000000     0:00:01:40.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, second file CK first not CK/PCK, second "cov" frame, only -b',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c2 PHX_PAYLOAD -f1 J2000 -t2 PHX_PAYLOAD -t1 B1950 -b 2007-12-04 00:26:41 TDB frmdiff_pck.tpc frmdiff_ck_cov12_id12.bc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck.tpc",
"# and rotation",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov12_id12.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:41.000' TDB (250000001.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000100000E+08 +2.5000010000000E+08          99.000000     0:00:01:39.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, second file CK first not CK/PCK, second "cov" frame, only -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c2 PHX_PAYLOAD -f1 J2000 -t2 PHX_PAYLOAD -t1 B1950 -e 2007-12-04 00:28:19 TDB frmdiff_pck.tpc frmdiff_ck_cov12_id12.bc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck.tpc",
"# and rotation",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov12_id12.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:19.000' TDB (250000099.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000000000E+08 +2.5000009900000E+08          99.000000     0:00:01:39.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, second file CK first not CK/PCK, second "cov" frame, -b and -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c2 PHX_PAYLOAD -f1 J2000 -t2 PHX_PAYLOAD -t1 B1950 -b 2007-12-04 00:26:41 TDB -e 2007-12-04 00:28:19 TDB frmdiff_pck.tpc frmdiff_ck_cov12_id12.bc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck.tpc",
"# and rotation",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov12_id12.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:41.000' TDB (250000001.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:19.000' TDB (250000099.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000100000E+08 +2.5000009900000E+08          98.000000     0:00:01:38.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, second file PCK first not CK/PCK, second "cov" frame, no -b and -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c2 ITRF93 -f1 J2000 -t2 ITRF93 -t1 B1950 frmdiff_pck.tpc frmdiff_pck_cov12_id12.bpc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck.tpc",
"# and rotation",
"#    from 'J2000' (1) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov12_id12.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000000000E+08 +2.5000010000000E+08         100.000000     0:00:01:40.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, second file PCK first not CK/PCK, second "cov" frame, only -b',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c2 ITRF93 -f1 J2000 -t2 ITRF93 -t1 B1950 -b 2007-12-04 00:26:41 TDB frmdiff_pck.tpc frmdiff_pck_cov12_id12.bpc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck.tpc",
"# and rotation",
"#    from 'J2000' (1) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov12_id12.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:41.000' TDB (250000001.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000100000E+08 +2.5000010000000E+08          99.000000     0:00:01:39.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, second file PCK first not CK/PCK, second "cov" frame, only -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c2 ITRF93 -f1 J2000 -t2 ITRF93 -t1 B1950 -e 2007-12-04 00:28:19 TDB frmdiff_pck.tpc frmdiff_pck_cov12_id12.bpc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck.tpc",
"# and rotation",
"#    from 'J2000' (1) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov12_id12.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:19.000' TDB (250000099.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000000000E+08 +2.5000009900000E+08          99.000000     0:00:01:39.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, second file PCK first not CK/PCK, second "cov" frame, -b and -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c2 ITRF93 -f1 J2000 -t2 ITRF93 -t1 B1950 -b 2007-12-04 00:26:41 TDB -e 2007-12-04 00:28:19 TDB frmdiff_pck.tpc frmdiff_pck_cov12_id12.bpc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck.tpc",
"# and rotation",
"#    from 'J2000' (1) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov12_id12.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:41.000' TDB (250000001.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:19.000' TDB (250000099.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000100000E+08 +2.5000009900000E+08          98.000000     0:00:01:38.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, two CKs, two "cov" frames, overlap, no -b and -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 PHX_PAYLOAD -c2 PHX_LANDER -f1 J2000 -t1 B1950 frmdiff_ck_cov1_id1.bc frmdiff_ck_cov2_id2.bc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov2_id2.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007500000E+08 +2.5000010000000E+08          25.000000     0:00:00:25.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, two CKs, two "cov" frames, overlap, only -b',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 PHX_PAYLOAD -c2 PHX_LANDER -f1 J2000 -t1 B1950 -b 2007-12-04 00:27:56 TDB frmdiff_ck_cov1_id1.bc frmdiff_ck_cov2_id2.bc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov2_id2.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:56.000' TDB (250000076.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007600000E+08 +2.5000010000000E+08          24.000000     0:00:00:24.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, two CKs, two "cov" frames, overlap, only -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 PHX_PAYLOAD -c2 PHX_LANDER -f1 J2000 -t1 B1950 -e 2007-12-04 00:28:19 TDB frmdiff_ck_cov1_id1.bc frmdiff_ck_cov2_id2.bc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov2_id2.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:19.000' TDB (250000099.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007500000E+08 +2.5000009900000E+08          24.000000     0:00:00:24.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, two CKs, two "cov" frames, overlap, -b and -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 PHX_PAYLOAD -c2 PHX_LANDER -f1 J2000 -t1 B1950 -b 2007-12-04 00:27:56 TDB -e 2007-12-04 00:28:19 TDB frmdiff_ck_cov1_id1.bc frmdiff_ck_cov2_id2.bc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov2_id2.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:56.000' TDB (250000076.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:19.000' TDB (250000099.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007600000E+08 +2.5000009900000E+08          23.000000     0:00:00:23.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, two PCKs, two "cov" frames, overlap, no -b and -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 ITRF93 -c2 IAU_EARTH -f1 J2000 -t1 B1950 frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov2_id2.bpc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov1_id1.bpc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov2_id2.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007500000E+08 +2.5000010000000E+08          25.000000     0:00:00:25.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, two PCKs, two "cov" frames, overlap, only -b',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 ITRF93 -c2 IAU_EARTH -f1 J2000 -t1 B1950 -b 2007-12-04 00:27:56 TDB frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov2_id2.bpc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov1_id1.bpc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov2_id2.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:56.000' TDB (250000076.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007600000E+08 +2.5000010000000E+08          24.000000     0:00:00:24.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, two PCKs, two "cov" frames, overlap, only -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 ITRF93 -c2 IAU_EARTH -f1 J2000 -t1 B1950 -e 2007-12-04 00:28:19 TDB frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov2_id2.bpc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov1_id1.bpc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov2_id2.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:19.000' TDB (250000099.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007500000E+08 +2.5000009900000E+08          24.000000     0:00:00:24.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, two PCKs, two "cov" frames, overlap, -b and -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 ITRF93 -c2 IAU_EARTH -f1 J2000 -t1 B1950 -b 2007-12-04 00:27:56 TDB -e 2007-12-04 00:28:19 TDB frmdiff_pck_cov1_id1.bpc frmdiff_pck_cov2_id2.bpc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov1_id1.bpc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov2_id2.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:56.000' TDB (250000076.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:19.000' TDB (250000099.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007600000E+08 +2.5000009900000E+08          23.000000     0:00:00:23.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, first CK second PCK, two "cov" frames, overlap, no -b and -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 PHX_PAYLOAD -c2 IAU_EARTH -f1 J2000 -t1 B1950 frmdiff_ck_cov1_id1.bc frmdiff_pck_cov2_id2.bpc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov2_id2.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007500000E+08 +2.5000010000000E+08          25.000000     0:00:00:25.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, first CK second PCK, two "cov" frames, overlap, only -b',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 PHX_PAYLOAD -c2 IAU_EARTH -f1 J2000 -t1 B1950 -b 2007-12-04 00:27:56 TDB frmdiff_ck_cov1_id1.bc frmdiff_pck_cov2_id2.bpc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov2_id2.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:56.000' TDB (250000076.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007600000E+08 +2.5000010000000E+08          24.000000     0:00:00:24.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, first CK second PCK, two "cov" frames, overlap, only -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 PHX_PAYLOAD -c2 IAU_EARTH -f1 J2000 -t1 B1950 -e 2007-12-04 00:28:19 TDB frmdiff_ck_cov1_id1.bc frmdiff_pck_cov2_id2.bpc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov2_id2.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:19.000' TDB (250000099.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007500000E+08 +2.5000009900000E+08          24.000000     0:00:00:24.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, first CK second PCK, two "cov" frames, overlap, -b and -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c1 PHX_PAYLOAD -c2 IAU_EARTH -f1 J2000 -t1 B1950 -b 2007-12-04 00:27:56 TDB -e 2007-12-04 00:28:19 TDB frmdiff_ck_cov1_id1.bc frmdiff_pck_cov2_id2.bpc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov2_id2.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:56.000' TDB (250000076.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:19.000' TDB (250000099.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007600000E+08 +2.5000009900000E+08          23.000000     0:00:00:23.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, first PCK second CK, two "cov" frames, overlap, no -b and -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c2 PHX_PAYLOAD -c1 IAU_EARTH -f1 J2000 -t1 B1950 frmdiff_pck_cov2_id2.bpc frmdiff_ck_cov1_id1.bc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov2_id2.bpc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007500000E+08 +2.5000010000000E+08          25.000000     0:00:00:25.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, first PCK second CK, two "cov" frames, overlap, only -b',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c2 PHX_PAYLOAD -c1 IAU_EARTH -f1 J2000 -t1 B1950 -b 2007-12-04 00:27:56 TDB frmdiff_pck_cov2_id2.bpc frmdiff_ck_cov1_id1.bc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov2_id2.bpc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:56.000' TDB (250000076.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007600000E+08 +2.5000010000000E+08          24.000000     0:00:00:24.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, first PCK second CK, two "cov" frames, overlap, only -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c2 PHX_PAYLOAD -c1 IAU_EARTH -f1 J2000 -t1 B1950 -e 2007-12-04 00:28:19 TDB frmdiff_pck_cov2_id2.bpc frmdiff_ck_cov1_id1.bc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov2_id2.bpc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:19.000' TDB (250000099.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007500000E+08 +2.5000009900000E+08          24.000000     0:00:00:24.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, first PCK second CK, two "cov" frames, overlap, -b and -e',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 -t dumpc -c2 PHX_PAYLOAD -c1 IAU_EARTH -f1 J2000 -t1 B1950 -b 2007-12-04 00:27:56 TDB -e 2007-12-04 00:28:19 TDB frmdiff_pck_cov2_id2.bpc frmdiff_ck_cov1_id1.bc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck_cov2_id2.bpc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:56.000' TDB (250000076.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:19.000' TDB (250000099.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007600000E+08 +2.5000009900000E+08          23.000000     0:00:00:23.000000"
);


&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, two CKs, two "cov" frames, overlap, both SCLKs given with -k',
  'success',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_sclk_id3.tsc -t dumpc -n 1 -c1 -84100 -c2 -85100 -f1 J2000 -t1 B1950 frmdiff_ck_cov2_id1.bc frmdiff_ck_cov1_id3.bc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_sclk_id3.tsc",
"#       frmdiff_ck_cov2_id1.bc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_sclk.tsc frmdiff_sclk_id3.tsc",
"#       frmdiff_ck_cov1_id3.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007500000E+08 +2.5000010000000E+08          25.000000     0:00:00:25.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, two CKs, two "cov" frames, overlap, first SCLK after -k1 second SCLK after -k',
  'success',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk_id3.tsc -k1 frmdiff_sclk.tsc -t dumpc -n 1 -c1 -84100 -c2 -85100 -f1 J2000 -t1 B1950 frmdiff_ck_cov2_id1.bc frmdiff_ck_cov1_id3.bc',
  28,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_sclk_id3.tsc",
"#       frmdiff_sclk.tsc",
"#       frmdiff_ck_cov2_id1.bc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_sclk_id3.tsc",
"#       frmdiff_ck_cov1_id3.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007500000E+08 +2.5000010000000E+08          25.000000     0:00:00:25.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, two CKs, two "cov" frames, overlap, first SCLK after -k second SCLK after -k2',
  'success',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_sclk.tsc -k2 frmdiff_sclk_id3.tsc -t dumpc -n 1 -c1 -84100 -c2 -85100 -f1 J2000 -t1 B1950 frmdiff_ck_cov2_id1.bc frmdiff_ck_cov1_id3.bc',
  28,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_sclk.tsc",
"#       frmdiff_ck_cov2_id1.bc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_sclk.tsc",
"#       frmdiff_sclk_id3.tsc",
"#       frmdiff_ck_cov1_id3.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007500000E+08 +2.5000010000000E+08          25.000000     0:00:00:25.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, two CKs, two "cov" frames, overlap, first SCLK after -k1 second SCLK after -k2',
  'success',
  $frmdiff,
  '-k frmdiff_lsk.tls -k1 frmdiff_sclk.tsc -k2 frmdiff_sclk_id3.tsc -t dumpc -n 1 -c1 -84100 -c2 -85100 -f1 J2000 -t1 B1950 frmdiff_ck_cov2_id1.bc frmdiff_ck_cov1_id3.bc',
  29,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_sclk.tsc",
"#       frmdiff_ck_cov2_id1.bc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_sclk_id3.tsc",
"#       frmdiff_ck_cov1_id3.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:55.000' TDB (250000075.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000007500000E+08 +2.5000010000000E+08          25.000000     0:00:00:25.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, first CK second not CK/PCK, first "cov" frame, SCLK after -k',
  'success',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_fk.tf frmdiff_sclk.tsc -n 1 -t dumpc -c1 PHX_PAYLOAD -f1 J2000 -t2 B1950 frmdiff_ck_cov12_id12.bc frmdiff_pck.tpc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_fk.tf frmdiff_sclk.tsc",
"#       frmdiff_ck_cov12_id12.bc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_fk.tf frmdiff_sclk.tsc",
"#       frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000000000E+08 +2.5000010000000E+08         100.000000     0:00:01:40.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, first CK second not CK/PCK, first "cov" frame, SCLK after -k1',
  'success',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_fk.tf -k1 frmdiff_sclk.tsc -n 1 -t dumpc -c1 PHX_PAYLOAD -f1 J2000 -t2 B1950 frmdiff_ck_cov12_id12.bc frmdiff_pck.tpc',
  28,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_fk.tf",
"#       frmdiff_sclk.tsc",
"#       frmdiff_ck_cov12_id12.bc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_fk.tf",
"#       frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000000000E+08 +2.5000010000000E+08         100.000000     0:00:01:40.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, second CK first not CK/PCK, second "cov" frame, SCLK after -k',
  'success',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_fk.tf frmdiff_sclk.tsc -n 1 -t dumpc -c2 PHX_PAYLOAD -f1 J2000 -t2 B1950 frmdiff_pck.tpc frmdiff_ck_cov12_id12.bc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_fk.tf frmdiff_sclk.tsc",
"#       frmdiff_pck.tpc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_fk.tf frmdiff_sclk.tsc",
"#       frmdiff_ck_cov12_id12.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000000000E+08 +2.5000010000000E+08         100.000000     0:00:01:40.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, second CK first not CK/PCK, second "cov" frame, SCLK after -k2',
  'success',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_fk.tf -k2 frmdiff_sclk.tsc -n 1 -t dumpc -c2 PHX_PAYLOAD -f1 J2000 -t2 B1950 frmdiff_pck.tpc frmdiff_ck_cov12_id12.bc',
  28,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_fk.tf",
"#       frmdiff_pck.tpc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_fk.tf",
"#       frmdiff_sclk.tsc",
"#       frmdiff_ck_cov12_id12.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000000000E+08 +2.5000010000000E+08         100.000000     0:00:01:40.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only CK, first "cov" frame, SCLK after -k',
  'success',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_fk.tf frmdiff_sclk.tsc -n 1 -t dumpc -c1 PHX_PAYLOAD -f1 J2000 -t2 B1950 frmdiff_ck_cov12_id12.bc',
  19,
"# Coverage for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_fk.tf frmdiff_sclk.tsc",
"#       frmdiff_ck_cov12_id12.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000000000E+08 +2.5000010000000E+08         100.000000     0:00:01:40.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only CK, first "cov" frame, SCLK after -k1',
  'success',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_fk.tf -k1 frmdiff_sclk.tsc -n 1 -t dumpc -c1 PHX_PAYLOAD -f1 J2000 -t2 B1950 frmdiff_ck_cov12_id12.bc',
  28,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_fk.tf",
"#       frmdiff_sclk.tsc",
"#       frmdiff_ck_cov12_id12.bc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_fk.tf",
"#       frmdiff_ck_cov12_id12.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000000000E+08 +2.5000010000000E+08         100.000000     0:00:01:40.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only CK, second "cov" frame, SCLK after -k',
  'success',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_fk.tf frmdiff_sclk.tsc -n 1 -t dumpc -c2 PHX_PAYLOAD -f1 J2000 -t2 B1950 frmdiff_ck_cov12_id12.bc',
  19,
"# Coverage for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_fk.tf frmdiff_sclk.tsc",
"#       frmdiff_ck_cov12_id12.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000000000E+08 +2.5000010000000E+08         100.000000     0:00:01:40.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'get coverage, only CK, second "cov" frame, SCLK after -k2',
  'success',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_fk.tf -k2 frmdiff_sclk.tsc -n 1 -t dumpc -c2 PHX_PAYLOAD -f1 J2000 -t2 B1950 frmdiff_ck_cov12_id12.bc',
  28,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_fk.tf",
"#       frmdiff_ck_cov12_id12.bc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_fk.tf",
"#       frmdiff_sclk.tsc",
"#       frmdiff_ck_cov12_id12.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000000000E+08 +2.5000010000000E+08         100.000000     0:00:01:40.000000"
);


&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-s with proper value, -n with proper value (ignored)',
  'success',
  $frmdiff,
  '-k frmdiff_lsk.tls -b 2007-12-04 00:27:56 TDB -e 2007-12-04 00:27:57 TDB -f1 J2000 -t1 B1950 -s 0.5 -n 1000',
  21,
"# Sampling of 3 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"# with a 0.50000000000000 second (0:00:00:00.500000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:56.000' TDB (250000076.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:57.000' TDB (250000077.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056036E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-s with proper value, -n with bad value (ignored)',
  'success',
  $frmdiff,
  '-k frmdiff_lsk.tls -b 2007-12-04 00:27:56 TDB -e 2007-12-04 00:27:57 TDB -f1 J2000 -t1 B1950 -s 0.5 -n BOO',
  21,
"# Sampling of 3 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"# with a 0.50000000000000 second (0:00:00:00.500000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:27:56.000' TDB (250000076.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:57.000' TDB (250000077.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056036E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-s with step resuting in 1000000 steps, one interval',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -f1 J2000 -t1 B1950 -s 1 -b 2000 JAN 01 12:00:00.000 TDB -e 2000 JAN 13 01:46:39.000 TDB',
  21,
"# Sampling of 1000000 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"# with a 1.0000000000000 second (0:00:00:01.000000) step size",
"# within the continuous time period",
"#    from '2000 JAN 01 12:00:00.000' TDB (0.00000000000000 TDB seconds)",
"#    to   '2000 JAN 13 01:46:39.000' TDB (999999.00000000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056141E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-s with step resuting in 1000000 steps, more than one interval',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -c1 PHX_PAYLOAD -f1 J2000 -t1 B1950 -s 0.0001 -b 2007-12-04 00:27:30.0002 TDB frmdiff_ck_cov13_id1.bc',
  22,
"# Sampling of 1000000 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov13_id1.bc",
"# with a 0.00010000000000000 second (0:00:00:00.000100) step size",
"# within the non-continuous (with 1 gaps) time period",
"#    from '2007 DEC 04 00:27:30.000' TDB (250000050.00020 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056141E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-s with value resulting only in ends of intervals (greater than lenght), one interval',
  'success',
  $frmdiff,
  '-t dumpaa -k frmdiff_mk.tm -c1 PHX_PAYLOAD -f1 J2000 -t1 B1950 -s 101 frmdiff_ck_cov1_id1.bc',
  22,
"# Sampling of 2 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# angle is shown in radians.",
"# time, angle, axis_x, axis_y, axis_z",
"+2.5000000000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000010000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-s with value resulting only in ends of intervals (greater than lenght), more than one interval',
  'success',
  $frmdiff,
  '-t dumpaa -k frmdiff_mk.tm -c1 PHX_PAYLOAD -f1 J2000 -t1 B1950 -s 101 frmdiff_ck_cov13_id1.bc',
  24,
"# Sampling of 4 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov13_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the non-continuous (with 1 gaps) time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# angle is shown in radians.",
"# time, angle, axis_x, axis_y, axis_z",
"+2.5000000000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000010000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000015000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000020000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-s with value resulting only in ends of intervals (exact match to ends), one interval',
  'success',
  $frmdiff,
  '-t dumpaa -k frmdiff_mk.tm -c1 PHX_PAYLOAD -f1 J2000 -t1 B1950 -s 100 frmdiff_ck_cov1_id1.bc',
  22,
"# Sampling of 2 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# angle is shown in radians.",
"# time, angle, axis_x, axis_y, axis_z",
"+2.5000000000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000010000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-s with value resulting only in ends of intervals (exact match to ends), more than one interval',
  'success',
  $frmdiff,
  '-t dumpaa -k frmdiff_mk.tm -c1 PHX_PAYLOAD -f1 J2000 -t1 B1950 -s 100 frmdiff_ck_cov13_id1.bc',
  24,
"# Sampling of 4 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov13_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the non-continuous (with 1 gaps) time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# angle is shown in radians.",
"# time, angle, axis_x, axis_y, axis_z",
"+2.5000000000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000010000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000015000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000020000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-s with value resulting in expected times (exact match to ends), one interval',
  'success',
  $frmdiff,
  '-t dumpaa -k frmdiff_mk.tm -c1 PHX_PAYLOAD -f1 J2000 -t1 B1950 -s 25 frmdiff_ck_cov1_id1.bc',
  25,
"# Sampling of 5 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with a 25.000000000000 second (0:00:00:25.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# angle is shown in radians.",
"# time, angle, axis_x, axis_y, axis_z",
"+2.5000000000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000002500000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000005000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000007500000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000010000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-s with value resulting in expected times (exact match to ends), more than one interval',
  'success',
  $frmdiff,
  '-t dumpaa -k frmdiff_mk.tm -c1 PHX_PAYLOAD -f1 J2000 -t1 B1950 -s 25 frmdiff_ck_cov13_id1.bc',
  28,
"# Sampling of 8 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov13_id1.bc",
"# with a 25.000000000000 second (0:00:00:25.000000) step size",
"# within the non-continuous (with 1 gaps) time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# angle is shown in radians.",
"# time, angle, axis_x, axis_y, axis_z",
"+2.5000000000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000002500000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000005000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000007500000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000010000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000015000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000017500000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000020000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-s with value resulting in expected times (not exact match to ends), one interval',
  'success',
  $frmdiff,
  '-t dumpaa -k frmdiff_mk.tm -c1 PHX_PAYLOAD -f1 J2000 -t1 B1950 -s 26 frmdiff_ck_cov1_id1.bc',
  25,
"# Sampling of 5 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with a 26.000000000000 second (0:00:00:26.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# angle is shown in radians.",
"# time, angle, axis_x, axis_y, axis_z",
"+2.5000000000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000002600000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000005200000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000007800000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000010000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-s with value resulting in expected times (not exact match to ends), more than one interval',
  'success',
  $frmdiff,
  '-t dumpaa -k frmdiff_mk.tm -c1 PHX_PAYLOAD -f1 J2000 -t1 B1950 -s 26 frmdiff_ck_cov13_id1.bc',
  28,
"# Sampling of 8 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov13_id1.bc",
"# with a 26.000000000000 second (0:00:00:26.000000) step size",
"# within the non-continuous (with 1 gaps) time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# angle is shown in radians.",
"# time, angle, axis_x, axis_y, axis_z",
"+2.5000000000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000002600000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000005200000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000007800000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000010000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000015000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000017600000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000020000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-s with value resulting in expected times, point between 1 and 0.5 step from end, one interval',
  'success',
  $frmdiff,
  '-t dumpaa -k frmdiff_mk.tm -c1 PHX_PAYLOAD -f1 J2000 -t1 B1950 -s 28.57142 frmdiff_ck_cov1_id1.bc',
  25,
"# Sampling of 5 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with a 28.571420000000 second (0:00:00:28.571420) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# angle is shown in radians.",
"# time, angle, axis_x, axis_y, axis_z",
"+2.5000000000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000002857142E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000005714284E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000008571426E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000010000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-s with value resulting in expected times, point between 1.5 and 1 step from end, one interval',
  'success',
  $frmdiff,
  '-t dumpaa -k frmdiff_mk.tm -c1 PHX_PAYLOAD -f1 J2000 -t1 B1950 -s 28.57143 frmdiff_ck_cov1_id1.bc',
  24,
"# Sampling of 4 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with a 28.571430000000 second (0:00:00:28.571430) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# angle is shown in radians.",
"# time, angle, axis_x, axis_y, axis_z",
"+2.5000000000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000002857143E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000005714286E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000010000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-n with 1',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -c1 PHX_PAYLOAD -f1 J2000 -t1 B1950 -n 1 frmdiff_ck_cov1_id1.bc',
  22,
"# Sampling of 2 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056036E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-n with 1000000',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -c1 PHX_PAYLOAD -f1 J2000 -t1 B1950 -n 1000000 frmdiff_ck_cov1_id1.bc',
  22,
"# Sampling of 999999 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with a 0.00010000020000040 second (0:00:00:00.000100) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056141E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-n with small value, adjusted/increased to number of interval ends',
  'success',
  $frmdiff,
  '-t dumpaa -k frmdiff_mk.tm -c1 PHX_PAYLOAD -f1 J2000 -t1 B1950 -n 1 frmdiff_ck_cov134_id1.bc',
  25,
"# Sampling of 5 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov134_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the non-continuous (with 2 gaps) time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# angle is shown in radians.",
"# time, angle, axis_x, axis_y, axis_z",
"+2.5000000000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000010000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000012500000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000015000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000020000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-n with value resulting in intervals ends',
  'success',
  $frmdiff,
  '-t dumpaa -k frmdiff_mk.tm -c1 PHX_PAYLOAD -f1 J2000 -t1 B1950 -n 3 frmdiff_ck_cov13_id1.bc',
  24,
"# Sampling of 4 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov13_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the non-continuous (with 1 gaps) time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# angle is shown in radians.",
"# time, angle, axis_x, axis_y, axis_z",
"+2.5000000000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000010000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000015000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000020000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-n with value resulting in expected values including intervals ends',
  'success',
  $frmdiff,
  '-t dumpaa -k frmdiff_mk.tm -c1 PHX_PAYLOAD -f1 J2000 -t1 B1950 -n 7 frmdiff_ck_cov1_id1.bc',
  26,
"# Sampling of 6 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with a 20.000000000000 second (0:00:00:20.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# angle is shown in radians.",
"# time, angle, axis_x, axis_y, axis_z",
"+2.5000000000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000002000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000004000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000006000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000008000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+2.5000010000000E+08 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t with "basIC" (mixedcase)',
  'success',
  $frmdiff,
  '-t basIC -k frmdiff_mk.tm -b 2000-01-01 TDB -e 2000-01-02 TDB -n 1 -f1 J2000 -t1 B1950',
  21,
"# Sampling of 2 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"#    to   '2000 JAN 02 00:00:00.000' TDB (43200.000000000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056036E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t with "staTS" (mixedcase)',
  'success',
  $frmdiff,
  '-t staTS -k frmdiff_mk.tm -b 2000-01-01 TDB -e 2000-01-02 TDB -n 1 -f1 J2000 -t1 B1950',
  33,
"# Sampling of 2 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"#    to   '2000 JAN 02 00:00:00.000' TDB (43200.000000000 TDB seconds)",
"1) Average",
"   1a) Rotation (rad):                               0.012189583056036",
"2) RMS of",
"   2a) Rotation (rad):                               0.012189583056036",
"3) Maximum rotation",
"   3a) Rotation (rad):                               0.012189583056036",
"   3b) Epoch (TDB, seconds past J2000):              -43200.000000000",
"   3c) Epoch (TDB, calendar format):                 2000-JAN-01-00:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t with "dumpAA" (mixedcase)',
  'success',
  $frmdiff,
  '-t dumpAA -k frmdiff_mk.tm -b 2000-01-01 TDB -e 2000-01-02 TDB -n 1 -f1 J2000 -t1 B1950',
  21,
"# Sampling of 2 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"#    to   '2000 JAN 02 00:00:00.000' TDB (43200.000000000 TDB seconds)",
"# angle is shown in radians.",
"# time, angle, axis_x, axis_y, axis_z",
"-4.3200000000000E+04 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01",
"+4.3200000000000E+04 +1.2189583056036E-02 -1.914984018????E-07 +3.9862923433008E-01 -9.1711217064075E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t with "dumPM" (mixedcase)',
  'success',
  $frmdiff,
  '-t dumPM -k frmdiff_mk.tm -b 2000-01-01 TDB -e 2000-01-02 TDB -n 1 -f1 J2000 -t1 B1950',
  19,
"# Sampling of 2 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"#    to   '2000 JAN 02 00:00:00.000' TDB (43200.000000000 TDB seconds)",
"# time, m11, m12, m13, m21, m22, m23, m31, m32, m33",
"-4.3200000000000E+04 +9.9992570795236E-01 +1.1178938126428E-02 +4.8590038414544E-03 -1.1178938137770E-02 +9.9993751334999E-01 -2.7157926258511E-05 -4.8590038153593E-03 -2.7162594714247E-05 +9.9998819460237E-01",
"+4.3200000000000E+04 +9.9992570795236E-01 +1.1178938126428E-02 +4.8590038414544E-03 -1.1178938137770E-02 +9.9993751334999E-01 -2.7157926258511E-05 -4.8590038153593E-03 -2.7162594714247E-05 +9.9998819460237E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t with "dumPQS" (mixedcase)',
  'success',
  $frmdiff,
  '-t dumPQS -k frmdiff_mk.tm -b 2000-01-01 TDB -e 2000-01-02 TDB -n 1 -f1 J2000 -t1 B1950',
  19,
"# Sampling of 2 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"#    to   '2000 JAN 02 00:00:00.000' TDB (43200.000000000 TDB seconds)",
"# time, q_cos, q_sin1, q_sin2, q_sin3",
"-4.3200000000000E+04 +9.99981426815??E-01 -1.167135611????E-09 +2.429547038628?E-03 -5.589572882217?E-03",
"+4.3200000000000E+04 +9.99981426815??E-01 -1.167135611????E-09 +2.429547038628?E-03 -5.589572882217?E-03"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t with "dumPQO" (mixedcase)',
  'success',
  $frmdiff,
  '-t dumPQO -k frmdiff_mk.tm -b 2000-01-01 TDB -e 2000-01-02 TDB -n 1 -f1 J2000 -t1 B1950',
  19,
"# Sampling of 2 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"#    to   '2000 JAN 02 00:00:00.000' TDB (43200.000000000 TDB seconds)",
"# time, q_sin1, q_sin2, q_sin3, q_cos",
"-4.3200000000000E+04 +1.167135611????E-09 -2.429547038628?E-03 +5.589572882217?E-03 +9.99981426815??E-01",
"+4.3200000000000E+04 +1.167135611????E-09 -2.429547038628?E-03 +5.589572882217?E-03 +9.99981426815??E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t with "dumpEA" (mixedcase)',
  'success',
  $frmdiff,
  '-t dumpEA -k frmdiff_mk.tm -b 2000-01-01 TDB -e 2000-01-02 TDB -n 1 -f1 J2000 -t1 B1950',
  21,
"# Sampling of 2 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"#    to   '2000 JAN 02 00:00:00.000' TDB (43200.000000000 TDB seconds)",
"# angles are shown in radians.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X",
"-4.3200000000000E+04 +1.1179302964505E-02 -4.8590229356761E-03 +2.7162915376583E-05",
"+4.3200000000000E+04 +1.1179302964505E-02 -4.8590229356761E-03 +2.7162915376583E-05"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t with "dumPC" (mixedcase)',
  'success',
  $frmdiff,
  '-t dumPC -k frmdiff_mk.tm -b 2000-01-01 TDB -e 2000-01-02 TDB -n 1 -f1 J2000 -t1 B1950',
  18,
"# Coverage for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"#    to   '2000 JAN 02 00:00:00.000' TDB (43200.000000000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"-4.3200000000000E+04 +4.3200000000000E+04       86400.000000     1:00:00:00.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t with "dumPG" (mixedcase)',
  'success',
  $frmdiff,
  '-t dumPG -k frmdiff_mk.tm -b 2000-01-01 TDB -e 2000-01-02 TDB -n 1 -f1 J2000 -t1 B1950',
  19,
"# Coverage for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"#    to   '2000 JAN 02 00:00:00.000' TDB (43200.000000000 TDB seconds)",
"There are no gaps in coverage."
);


&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-f with "eT" (mixedcase)',
  'success',
  $frmdiff,
  '-f eT -n 1 -t dumpc -k frmdiff_mk.tm -f1 J2000 -t1 B1950 -c1 -84100 frmdiff_ck_cov1_id1.bc',
  19,
"# Coverage for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000000000E+08 +2.5000010000000E+08         100.000000     0:00:01:40.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-f with "scLK" (mixedcase)',
  'success',
  $frmdiff,
  '-f scLK -n 1 -t dumpc -k frmdiff_mk.tm -f1 J2000 -t1 B1950 -c1 -84100 frmdiff_ck_cov1_id1.bc',
  19,
"# Coverage for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"1/0250000000.000 1/0250000100.000         100.000000     0:00:01:40.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-f with "scLKD" (mixedcase)',
  'success',
  $frmdiff,
  '-f scLKD -n 1 -t dumpc -k frmdiff_mk.tm -f1 J2000 -t1 B1950 -c1 -84100 frmdiff_ck_cov1_id1.bc',
  19,
"# Coverage for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"2.5000000000000E+08 2.5000010000000E+08         100.000000     0:00:01:40.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-f with "tiCKS" (mixedcase)',
  'success',
  $frmdiff,
  '-f tiCKS -n 1 -t dumpc -k frmdiff_mk.tm -f1 J2000 -t1 B1950 -c1 -84100 frmdiff_ck_cov1_id1.bc',
  19,
"# Coverage for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"2.5000000000000E+11 2.5000010000000E+11         100.000000     0:00:01:40.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-f is ignored when -t is not specified',
  'success',
  $frmdiff,
  '-f sclk -k frmdiff_mk.tm -f1 J2000 -t1 B1950 -b 2000-01-01 TDB -e 2000-01-02 TDB',
  21,
"# Sampling of 999 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"# with a 86.573146292585 second (0:00:01:26.573146) step size",
"# within the continuous time period",
"#    from '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"#    to   '2000 JAN 02 00:00:00.000' TDB (43200.000000000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056037E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-f is ignored when -t is "basic"',
  'success',
  $frmdiff,
  '-f sclk -t basic -k frmdiff_mk.tm -f1 J2000 -t1 B1950 -b 2000-01-01 TDB -e 2000-01-02 TDB',
  21,
"# Sampling of 999 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"# with a 86.573146292585 second (0:00:01:26.573146) step size",
"# within the continuous time period",
"#    from '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"#    to   '2000 JAN 02 00:00:00.000' TDB (43200.000000000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056037E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-f is ignored when -t is "stats"',
  'success',
  $frmdiff,
  '-f sclk -t stats -k frmdiff_mk.tm -f1 J2000 -t1 B1950 -b 2000-01-01 TDB -e 2000-01-02 TDB',
  33,
"# Sampling of 999 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"# with a 86.573146292585 second (0:00:01:26.573146) step size",
"# within the continuous time period",
"#    from '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"#    to   '2000 JAN 02 00:00:00.000' TDB (43200.000000000 TDB seconds)",
"1) Average",
"   1a) Rotation (rad):                               0.012189583056037",
"2) RMS of",
"   2a) Rotation (rad):                               0.012189583056036",
"3) Maximum rotation",
"   3a) Rotation (rad):                               0.012189583056036",
"   3b) Epoch (TDB, seconds past J2000):              -43200.000000000",
"   3c) Epoch (TDB, calendar format):                 2000-JAN-01-00:00:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-f with "sclk", SCLK ID picked based on first "to" frame',
  'success',
  $frmdiff,
  '-f sclk -n 1 -t dumpc -k frmdiff_mk.tm -f1 J2000 -t1 PHX_PAYLOAD -t2 B1950 frmdiff_ck_cov1_id1.bc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"1/0250000000.000 1/0250000100.000         100.000000     0:00:01:40.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-f with "sclk", SCLK ID picked based on first "cov" frame',
  'success',
  $frmdiff,
  '-f sclk -n 1 -t dumpc -k frmdiff_mk.tm -f1 J2000 -t1 ECLIPJ2000 -t2 B1950 -c1 -84100 frmdiff_ck_cov1_id1.bc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"1/0250000000.000 1/0250000100.000         100.000000     0:00:01:40.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-f with "sclk", SCLK ID picked based on second "to" frame',
  'success',
  $frmdiff,
  '-f sclk -n 1 -t dumpc -k frmdiff_mk.tm -f1 J2000 -t2 PHX_PAYLOAD -t1 B1950 frmdiff_ck_cov1_id1.bc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# and rotation",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"1/0250000000.000 1/0250000100.000         100.000000     0:00:01:40.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-f with "sclk", SCLK ID picked based on second "cov" frame',
  'success',
  $frmdiff,
  '-f sclk -n 1 -t dumpc -k frmdiff_mk.tm -f1 J2000 -t2 ECLIPJ2000 -t1 B1950 -c2 -84100 frmdiff_ck_cov1_id1.bc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# and rotation",
"#    from 'J2000' (1) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"1/0250000000.000 1/0250000100.000         100.000000     0:00:01:40.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-f with "sclkd", SCLK ID picked based on first "to" frame',
  'success',
  $frmdiff,
  '-f sclkd -n 1 -t dumpc -k frmdiff_mk.tm -f1 J2000 -t1 PHX_PAYLOAD -t2 B1950 frmdiff_ck_cov1_id1.bc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"2.5000000000000E+08 2.5000010000000E+08         100.000000     0:00:01:40.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-f with "sclkd", SCLK ID picked based on first "cov" frame',
  'success',
  $frmdiff,
  '-f sclkd -n 1 -t dumpc -k frmdiff_mk.tm -f1 J2000 -t1 ECLIPJ2000 -t2 B1950 -c1 -84100 frmdiff_ck_cov1_id1.bc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"2.5000000000000E+08 2.5000010000000E+08         100.000000     0:00:01:40.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-f with "sclkd", SCLK ID picked based on second "to" frame',
  'success',
  $frmdiff,
  '-f sclkd -n 1 -t dumpc -k frmdiff_mk.tm -f1 J2000 -t2 PHX_PAYLOAD -t1 B1950 frmdiff_ck_cov1_id1.bc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# and rotation",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"2.5000000000000E+08 2.5000010000000E+08         100.000000     0:00:01:40.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-f with "sclkd", SCLK ID picked based on second "cov" frame',
  'success',
  $frmdiff,
  '-f sclkd -n 1 -t dumpc -k frmdiff_mk.tm -f1 J2000 -t2 ECLIPJ2000 -t1 B1950 -c2 -84100 frmdiff_ck_cov1_id1.bc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# and rotation",
"#    from 'J2000' (1) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"2.5000000000000E+08 2.5000010000000E+08         100.000000     0:00:01:40.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-f with "ticks", SCLK ID picked based on first "to" frame',
  'success',
  $frmdiff,
  '-f ticks -n 1 -t dumpc -k frmdiff_mk.tm -f1 J2000 -t1 PHX_PAYLOAD -t2 B1950 frmdiff_ck_cov1_id1.bc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"2.5000000000000E+11 2.5000010000000E+11         100.000000     0:00:01:40.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-f with "ticks", SCLK ID picked based on first "cov" frame',
  'success',
  $frmdiff,
  '-f ticks -n 1 -t dumpc -k frmdiff_mk.tm -f1 J2000 -t1 ECLIPJ2000 -t2 B1950 -c1 -84100 frmdiff_ck_cov1_id1.bc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# and rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"2.5000000000000E+11 2.5000010000000E+11         100.000000     0:00:01:40.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-f with "ticks", SCLK ID picked based on second "to" frame',
  'success',
  $frmdiff,
  '-f ticks -n 1 -t dumpc -k frmdiff_mk.tm -f1 J2000 -t2 PHX_PAYLOAD -t1 B1950 frmdiff_ck_cov1_id1.bc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# and rotation",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"2.5000000000000E+11 2.5000010000000E+11         100.000000     0:00:01:40.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-f with "ticks", SCLK ID picked based on second "cov" frame',
  'success',
  $frmdiff,
  '-f ticks -n 1 -t dumpc -k frmdiff_mk.tm -f1 J2000 -t2 ECLIPJ2000 -t1 B1950 -c2 -84100 frmdiff_ck_cov1_id1.bc',
  27,
"# Coverage overlap for rotation",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# and rotation",
"#    from 'J2000' (1) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"2.5000000000000E+11 2.5000010000000E+11         100.000000     0:00:01:40.000000"
);


&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-o with "X y x"',
  'success',
  $frmdiff,
  '-o X y x -k frmdiff_mk.tm -n 1 -t dumpea frmdiff_ck_cov4_id1.bc',
  21,
"# Sampling of 1 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"# angles are shown in radians.",
"# time, ang3_about_X, ang2_about_Y, ang1_about_X",
"+2.5000012500000E+08 -1.5707963267949E+00 +1.5707963267949E+00 +3.1415926535898E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-o with "X y z"',
  'success',
  $frmdiff,
  '-o X y z -k frmdiff_mk.tm -n 1 -t dumpea frmdiff_ck_cov4_id1.bc',
  21,
"# Sampling of 1 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"# angles are shown in radians.",
"# time, ang3_about_X, ang2_about_Y, ang1_about_Z",
"+2.5000012500000E+08 +0.0000000000000E+00 -1.5707963267949E+00 +1.5707963267949E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-o with "X z x"',
  'success',
  $frmdiff,
  '-o X z x -k frmdiff_mk.tm -n 1 -t dumpea frmdiff_ck_cov4_id1.bc',
  21,
"# Sampling of 1 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"# angles are shown in radians.",
"# time, ang3_about_X, ang2_about_Z, ang1_about_X",
"+2.5000012500000E+08 +0.0000000000000E+00 +1.5707963267949E+00 +1.5707963267949E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-o with "X z y"',
  'success',
  $frmdiff,
  '-o X z y -k frmdiff_mk.tm -n 1 -t dumpea frmdiff_ck_cov4_id1.bc',
  21,
"# Sampling of 1 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"# angles are shown in radians.",
"# time, ang3_about_X, ang2_about_Z, ang1_about_Y",
"+2.5000012500000E+08 +1.5707963267949E+00 +0.0000000000000E+00 -1.5707963267949E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-o with "y X y"',
  'success',
  $frmdiff,
  '-o y X y -k frmdiff_mk.tm -n 1 -t dumpea frmdiff_ck_cov4_id1.bc',
  21,
"# Sampling of 1 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"# angles are shown in radians.",
"# time, ang3_about_Y, ang2_about_X, ang1_about_Y",
"+2.5000012500000E+08 +0.0000000000000E+00 +1.5707963267949E+00 -1.5707963267949E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-o with "y X z"',
  'success',
  $frmdiff,
  '-o y X z -k frmdiff_mk.tm -n 1 -t dumpea frmdiff_ck_cov4_id1.bc',
  21,
"# Sampling of 1 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"# angles are shown in radians.",
"# time, ang3_about_Y, ang2_about_X, ang1_about_Z",
"+2.5000012500000E+08 -1.5707963267949E+00 +0.0000000000000E+00 +1.5707963267949E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-o with "y Z x"',
  'success',
  $frmdiff,
  '-o y Z x -k frmdiff_mk.tm -n 1 -t dumpea frmdiff_ck_cov4_id1.bc',
  21,
"# Sampling of 1 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"# angles are shown in radians.",
"# time, ang3_about_Y, ang2_about_Z, ang1_about_X",
"+2.5000012500000E+08 +0.0000000000000E+00 +1.5707963267949E+00 +1.5707963267949E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-o with "y Z y"',
  'success',
  $frmdiff,
  '-o y Z y -k frmdiff_mk.tm -n 1 -t dumpea frmdiff_ck_cov4_id1.bc',
  21,
"# Sampling of 1 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"# angles are shown in radians.",
"# time, ang3_about_Y, ang2_about_Z, ang1_about_Y",
"+2.5000012500000E+08 -1.5707963267949E+00 +1.5707963267949E+00 +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-o with "z x Y"',
  'success',
  $frmdiff,
  '-o z x Y -k frmdiff_mk.tm -n 1 -t dumpea frmdiff_ck_cov4_id1.bc',
  21,
"# Sampling of 1 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"# angles are shown in radians.",
"# time, ang3_about_Z, ang2_about_X, ang1_about_Y",
"+2.5000012500000E+08 +0.0000000000000E+00 +1.5707963267949E+00 -1.5707963267949E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-o with "z x Z"',
  'success',
  $frmdiff,
  '-o z x Z -k frmdiff_mk.tm -n 1 -t dumpea frmdiff_ck_cov4_id1.bc',
  21,
"# Sampling of 1 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"# angles are shown in radians.",
"# time, ang3_about_Z, ang2_about_X, ang1_about_Z",
"+2.5000012500000E+08 +1.5707963267949E+00 +1.5707963267949E+00 +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-o with "z y X"',
  'success',
  $frmdiff,
  '-o z y X -k frmdiff_mk.tm -n 1 -t dumpea frmdiff_ck_cov4_id1.bc',
  21,
"# Sampling of 1 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"# angles are shown in radians.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X",
"+2.5000012500000E+08 +1.5707963267949E+00 +0.0000000000000E+00 +1.5707963267949E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-o with "z y Z"',
  'success',
  $frmdiff,
  '-o z y Z -k frmdiff_mk.tm -n 1 -t dumpea frmdiff_ck_cov4_id1.bc',
  21,
"# Sampling of 1 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"# angles are shown in radians.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_Z",
"+2.5000012500000E+08 +3.1415926535898E+00 +1.5707963267949E+00 -1.5707963267949E+00"
);


&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-x with "radians"',
  'success',
  $frmdiff,
  '-x RADians -o x y z -k frmdiff_mk.tm -n 1 -t dumpea frmdiff_ck_cov4_id1.bc',
  21,
"# Sampling of 1 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"# angles are shown in RADians.",
"# time, ang3_about_X, ang2_about_Y, ang1_about_Z",
"+2.5000012500000E+08 +0.0000000000000E+00 -1.5707963267949E+00 +1.5707963267949E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-x with "degrees"',
  'success',
  $frmdiff,
  '-x DEGrees -o x y z -k frmdiff_mk.tm -n 1 -t dumpea frmdiff_ck_cov4_id1.bc',
  21,
"# Sampling of 1 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"# angles are shown in DEGrees.",
"# time, ang3_about_X, ang2_about_Y, ang1_about_Z",
"+2.5000012500000E+08 +0.0000000000000E+00 -9.0000000000000E+01 +9.0000000000000E+01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-x with "arcminutes"',
  'success',
  $frmdiff,
  '-x ARCminutes -o x y z -k frmdiff_mk.tm -n 1 -t dumpea frmdiff_ck_cov4_id1.bc',
  21,
"# Sampling of 1 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"# angles are shown in ARCminutes.",
"# time, ang3_about_X, ang2_about_Y, ang1_about_Z",
"+2.5000012500000E+08 +0.0000000000000E+00 -5.4000000000000E+03 +5.4000000000000E+03"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-x with "arcseconds"',
  'success',
  $frmdiff,
  '-x ARCseconds -o x y z -k frmdiff_mk.tm -n 1 -t dumpea frmdiff_ck_cov4_id1.bc',
  21,
"# Sampling of 1 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"# angles are shown in ARCseconds.",
"# time, ang3_about_X, ang2_about_Y, ang1_about_Z",
"+2.5000012500000E+08 +0.0000000000000E+00 -3.2400000000000E+05 +3.2400000000000E+05"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-x with "hourangle"',
  'success',
  $frmdiff,
  '-x HOUrangle -o x y z -k frmdiff_mk.tm -n 1 -t dumpea frmdiff_ck_cov4_id1.bc',
  21,
"# Sampling of 1 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"# angles are shown in HOUrangle.",
"# time, ang3_about_X, ang2_about_Y, ang1_about_Z",
"+2.5000012500000E+08 +0.0000000000000E+00 -6.0000000000000E+00 +6.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-x with "minuteangle"',
  'success',
  $frmdiff,
  '-x MINuteangle -o x y z -k frmdiff_mk.tm -n 1 -t dumpea frmdiff_ck_cov4_id1.bc',
  21,
"# Sampling of 1 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"# angles are shown in MINuteangle.",
"# time, ang3_about_X, ang2_about_Y, ang1_about_Z",
"+2.5000012500000E+08 +0.0000000000000E+00 -3.6000000000000E+02 +3.6000000000000E+02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-x with "secondangle"',
  'success',
  $frmdiff,
  '-x SECondangle -o x y z -k frmdiff_mk.tm -n 1 -t dumpea frmdiff_ck_cov4_id1.bc',
  21,
"# Sampling of 1 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"# angles are shown in SECondangle.",
"# time, ang3_about_X, ang2_about_Y, ang1_about_Z",
"+2.5000012500000E+08 +0.0000000000000E+00 -2.1600000000000E+04 +2.1600000000000E+04"
);


&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-o and -x are ignored when -t is not specified',
  'success',
  $frmdiff,
  '-o BOO -x BOO -k frmdiff_mk.tm -n 1 frmdiff_ck_cov4_id1.bc',
  22,
"# Sampling of 1 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.0943951023932E+00      +2.0943951023932E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-o and -x are ignored when -t is "basic"',
  'success',
  $frmdiff,
  '-t basic -o BOO -x BOO -k frmdiff_mk.tm -n 1 frmdiff_ck_cov4_id1.bc',
  22,
"# Sampling of 1 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.0943951023932E+00      +2.0943951023932E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-o and -x are ignored when -t is "stats"',
  'success',
  $frmdiff,
  '-t stats -o BOO -x BOO -k frmdiff_mk.tm -n 1 frmdiff_ck_cov4_id1.bc',
  34,
"# Sampling of 1 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"1) Average",
"   1a) Rotation (rad):                               2.0943951023932",
"2) RMS of",
"   2a) Rotation (rad):                               2.0943951023932",
"3) Maximum rotation",
"   3a) Rotation (rad):                               2.0943951023932",
"   3b) Epoch (TDB, seconds past J2000):              250000125.00000",
"   3c) Epoch (TDB, calendar format):                 2007-DEC-04-00:28:45.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-o and -x are ignored when -t is "dumpm"',
  'success',
  $frmdiff,
  '-t dumpm -o BOO -x BOO -k frmdiff_mk.tm -n 1 frmdiff_ck_cov4_id1.bc',
  19,
"# Sampling of 1 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"# time, m11, m12, m13, m21, m22, m23, m31, m32, m33",
"+2.5000012500000E+08 +0.0000000000000E+00 +0.0000000000000E+00 +1.0000000000000E+00 -1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 -1.0000000000000E+00 +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-o and -x are ignored when -t is "dumpqs"',
  'success',
  $frmdiff,
  '-t dumpqs -o BOO -x BOO -k frmdiff_mk.tm -n 1 frmdiff_ck_cov4_id1.bc',
  19,
"# Sampling of 1 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"# time, q_cos, q_sin1, q_sin2, q_sin3",
"+2.5000012500000E+08 +5.0000000000000E-01 -5.0000000000000E-01 +5.0000000000000E-01 -5.0000000000000E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-o and -x are ignored when -t is "dumpqo"',
  'success',
  $frmdiff,
  '-t dumpqo -o BOO -x BOO -k frmdiff_mk.tm -n 1 frmdiff_ck_cov4_id1.bc',
  19,
"# Sampling of 1 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"# time, q_sin1, q_sin2, q_sin3, q_cos",
"+2.5000012500000E+08 +5.0000000000000E-01 -5.0000000000000E-01 +5.0000000000000E-01 +5.0000000000000E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-o and -x are ignored when -t is "dumpc"',
  'success',
  $frmdiff,
  '-t dumpc -o BOO -x BOO -k frmdiff_mk.tm -n 1 frmdiff_ck_cov4_id1.bc',
  19,
"# Coverage for rotation",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000012500000E+08 +2.5000012500000E+08           0.000000     0:00:00:00.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-o and -x are ignored when -t is "dumpg"',
  'success',
  $frmdiff,
  '-t dumpg -o BOO -x BOO -k frmdiff_mk.tm -n 1 frmdiff_ck_cov4_id1.bc',
  20,
"# Coverage for rotation",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"There are no gaps in coverage."
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-o and -x are used when -t is "dumpaa"',
  'success',
  $frmdiff,
  '-o x y z -x degrees -t dumpaa -k frmdiff_mk.tm -n 1 frmdiff_ck_cov4_id1.bc',
  21,
"# Sampling of 1 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"# angle is shown in degrees.",
"# time, angle, axis_x, axis_y, axis_z",
"+2.5000012500000E+08 +1.2000000000000E+02 -5.7735026918963E-01 +5.7735026918963E-01 -5.7735026918963E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-o and -x are used when -t is "dumpea"',
  'success',
  $frmdiff,
  '-o x y z -x degrees -t dumpea -k frmdiff_mk.tm -n 1 frmdiff_ck_cov4_id1.bc',
  21,
"# Sampling of 1 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"# angles are shown in degrees.",
"# time, ang3_about_X, ang2_about_Y, ang1_about_Z",
"+2.5000012500000E+08 +0.0000000000000E+00 -9.0000000000000E+01 +9.0000000000000E+01"
);


&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'pick step, one singleton, default -n',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -t basic frmdiff_ck_cov4_id1.bc',
  22,
"# Sampling of 1 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.0943951023932E+00      +2.0943951023932E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'pick step, one singleton, -n equal to number of endpoints',
  'success',
  $frmdiff,
  '-n 1 -k frmdiff_mk.tm -t basic frmdiff_ck_cov4_id1.bc',
  22,
"# Sampling of 1 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.0943951023932E+00      +2.0943951023932E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'pick step, one singleton, -n greater than number of endpoints',
  'success',
  $frmdiff,
  '-n 10 -k frmdiff_mk.tm -t basic frmdiff_ck_cov4_id1.bc',
  22,
"# Sampling of 1 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.0943951023932E+00      +2.0943951023932E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'pick step, many singletons, default -n',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -t basic frmdiff_ck_cov5_id1.bc',
  22,
"# Sampling of 6 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov5_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the non-continuous (with 5 gaps) time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:03.000' TDB (250000023.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +0.0000000000000E+00      +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'pick step, many singletons, -n smaller than number of endpoints',
  'success',
  $frmdiff,
  '-n 1 -k frmdiff_mk.tm -t basic frmdiff_ck_cov5_id1.bc',
  22,
"# Sampling of 6 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov5_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the non-continuous (with 5 gaps) time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:03.000' TDB (250000023.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +0.0000000000000E+00      +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'pick step, many singletons, -n equal to number of endpoints',
  'success',
  $frmdiff,
  '-n 6 -k frmdiff_mk.tm -t basic frmdiff_ck_cov5_id1.bc',
  22,
"# Sampling of 6 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov5_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the non-continuous (with 5 gaps) time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:03.000' TDB (250000023.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +0.0000000000000E+00      +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'pick step, many singletons, -n greater than number of endpoints',
  'success',
  $frmdiff,
  '-n 10 -k frmdiff_mk.tm -t basic frmdiff_ck_cov5_id1.bc',
  22,
"# Sampling of 6 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov5_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the non-continuous (with 5 gaps) time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:03.000' TDB (250000023.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +0.0000000000000E+00      +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'pick step, one non-singleton, default -n',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -t basic frmdiff_ck_cov1_id1.bc',
  22,
"# Sampling of 999 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with a 0.10020040080160 second (0:00:00:00.100200) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +0.0000000000000E+00      +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'pick step, one non-singleton, -n smaller than number of endpoints',
  'success',
  $frmdiff,
  '-n 1 -k frmdiff_mk.tm -t basic frmdiff_ck_cov1_id1.bc',
  22,
"# Sampling of 2 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +0.0000000000000E+00      +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'pick step, one non-singleton, -n equal to number of endpoints',
  'success',
  $frmdiff,
  '-n 2 -k frmdiff_mk.tm -t basic frmdiff_ck_cov1_id1.bc',
  22,
"# Sampling of 2 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +0.0000000000000E+00      +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'pick step, one non-singleton, -n greater than number of endpoints',
  'success',
  $frmdiff,
  '-n 102 -k frmdiff_mk.tm -t basic frmdiff_ck_cov1_id1.bc',
  22,
"# Sampling of 101 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with a 1.0000000000000 second (0:00:00:01.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +0.0000000000000E+00      +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'pick step, many non-singletons, default -n',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -t basic frmdiff_ck_cov6_id1.bc',
  22,
"# Sampling of 997 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov6_id1.bc",
"# with a 0.0060362173038229 second (0:00:00:00.006036) step size",
"# within the non-continuous (with 2 gaps) time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:03.000' TDB (250000023.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +0.0000000000000E+00      +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'pick step, many non-singletons, -n smaller than number of endpoints',
  'success',
  $frmdiff,
  '-n 1 -k frmdiff_mk.tm -t basic frmdiff_ck_cov6_id1.bc',
  22,
"# Sampling of 6 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov6_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the non-continuous (with 2 gaps) time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:03.000' TDB (250000023.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +0.0000000000000E+00      +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'pick step, many non-singletons, -n equal to number of endpoints',
  'success',
  $frmdiff,
  '-n 6 -k frmdiff_mk.tm -t basic frmdiff_ck_cov6_id1.bc',
  22,
"# Sampling of 6 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov6_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the non-continuous (with 2 gaps) time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:03.000' TDB (250000023.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +0.0000000000000E+00      +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'pick step, many non-singletons, -n greater than number of endpoints',
  'success',
  $frmdiff,
  '-n 18 -k frmdiff_mk.tm -t basic frmdiff_ck_cov6_id1.bc',
  22,
"# Sampling of 15 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov6_id1.bc",
"# with a 0.50000000000000 second (0:00:00:00.500000) step size",
"# within the non-continuous (with 2 gaps) time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:03.000' TDB (250000023.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +0.0000000000000E+00      +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'pick step, many singletons and non-singletons, default -n',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -t basic frmdiff_ck_cov7_id1.bc',
  22,
"# Sampling of 998 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov7_id1.bc",
"# with a 0.0030181086519115 second (0:00:00:00.003018) step size",
"# within the non-continuous (with 3 gaps) time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:03.000' TDB (250000023.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +0.0000000000000E+00      +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'pick step, many singletons and non-singletons, -n smaller than number of endpoints',
  'success',
  $frmdiff,
  '-n 1 -k frmdiff_mk.tm -t basic frmdiff_ck_cov7_id1.bc',
  22,
"# Sampling of 6 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov7_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the non-continuous (with 3 gaps) time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:03.000' TDB (250000023.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +0.0000000000000E+00      +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'pick step, many singletons and non-singletons, -n equal to number of endpoints',
  'success',
  $frmdiff,
  '-n 6 -k frmdiff_mk.tm -t basic frmdiff_ck_cov7_id1.bc',
  22,
"# Sampling of 6 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov7_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the non-continuous (with 3 gaps) time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:03.000' TDB (250000023.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +0.0000000000000E+00      +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'pick step, many singletons and non-singletons, -n greater than number of endpoints',
  'success',
  $frmdiff,
  '-n 12 -k frmdiff_mk.tm -t basic frmdiff_ck_cov7_id1.bc',
  22,
"# Sampling of 10 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov7_id1.bc",
"# with a 0.50000000000000 second (0:00:00:00.500000) step size",
"# within the non-continuous (with 3 gaps) time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:27:03.000' TDB (250000023.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +0.0000000000000E+00      +0.0000000000000E+00"
);


&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, sampling (same files "from" "to" -k1 -k2), supporting kernels given with -k',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm frmdiff_ck_cov4_id1.bc frmdiff_ck_cov4_id1.bc',
  22,
"# Sampling of 1 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.0943951023932E+00      +2.0943951023932E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, sampling (same files "from" "to" -k1 -k2), supporting kernels given with -k1 and -k2 (same)',
  'success',
  $frmdiff,
  '-k1 frmdiff_mk.tm -k2 frmdiff_mk.tm frmdiff_ck_cov4_id1.bc frmdiff_ck_cov4_id1.bc',
  22,
"# Sampling of 1 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.0943951023932E+00      +2.0943951023932E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, sampling (same files "from" "to" -k1 -k2), inertial "from" and "to" to bypass jeopardized check 0',
  'success',
  $frmdiff,
  '-f1 J2000 -t1 B1950 -c1 -84100 -k1 frmdiff_mk.tm frmdiff_ck_cov4_id1.bc -k2 frmdiff_mk.tm frmdiff_ck_cov4_id1.bc frmdiff_ck_cov4_id1.bc frmdiff_ck_cov4_id1.bc',
  22,
"# Sampling of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm frmdiff_ck_cov4_id1.bc",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056036E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different "from" frames, for first attitude, supporting kernels given with -k',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -f1 PHX_PAYLOAD -f2 J2000 -t1 B1950 -c1 -84100 frmdiff_ck_cov4_id1.bc frmdiff_ck_cov4_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.042994646432?E+00      +2.042994646432?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different "from" frames, for first attitude, supporting kernels given with -k1',
  'success',
  $frmdiff,
  '-k1 frmdiff_mk.tm -k2 frmdiff_mk.tm -f1 PHX_PAYLOAD -f2 J2000 -t1 B1950 -c1 -84100 frmdiff_ck_cov4_id1.bc frmdiff_ck_cov4_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.042994646432?E+00      +2.042994646432?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different "from" frames, for first attitude, supporting kernels given with -k and -k1',
  'success',
  $frmdiff,
  '-k  frmdiff_mk_no_sclk.tm -k1 frmdiff_sclk.tsc -k2 frmdiff_sclk.tsc -f1 PHX_PAYLOAD -f2 J2000 -t1 B1950 -c1 -84100 frmdiff_ck_cov4_id1.bc frmdiff_ck_cov4_id1.bc',
  32,
"# Comparison of 1 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk_no_sclk.tm",
"#       frmdiff_sclk.tsc",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk_no_sclk.tm",
"#       frmdiff_sclk.tsc",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.042994646432?E+00      +2.042994646432?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different "from" frames, for first attitude, inertial "from" and "to" to bypass jeopardized check 1',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm frmdiff_ck_cov4_id1.bc -f1 ECLIPJ2000 -f2 J2000 -t1 B1950 -c1 -84100 frmdiff_ck_cov4_id1.bc frmdiff_ck_cov4_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'ECLIPJ2000' (17) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm frmdiff_ck_cov4_id1.bc",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm frmdiff_ck_cov4_id1.bc",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +4.0909280422233E-01      +4.0909280422233E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different "from" frames, for second attitude, supporting kernels given with -k',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -f2 PHX_PAYLOAD -f1 J2000 -t1 B1950 -c2 -84100 frmdiff_ck_cov4_id1.bc frmdiff_ck_cov4_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.042994646432?E+00      +2.042994646432?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different "from" frames, for second attitude, supporting kernels given with -k2',
  'success',
  $frmdiff,
  '-k1 frmdiff_mk.tm -k2 frmdiff_mk.tm -f2 PHX_PAYLOAD -f1 J2000 -t1 B1950 -c2 -84100 frmdiff_ck_cov4_id1.bc frmdiff_ck_cov4_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.042994646432?E+00      +2.042994646432?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different "from" frames, for second attitude, supporting kernels given with -k and -k2',
  'success',
  $frmdiff,
  '-k frmdiff_mk_no_sclk.tm -k1 frmdiff_sclk.tsc -k2 frmdiff_sclk.tsc -f2 PHX_PAYLOAD -f1 J2000 -t1 B1950 -c2 -84100 frmdiff_ck_cov4_id1.bc frmdiff_ck_cov4_id1.bc',
  32,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk_no_sclk.tm",
"#       frmdiff_sclk.tsc",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk_no_sclk.tm",
"#       frmdiff_sclk.tsc",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.042994646432?E+00      +2.042994646432?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different "from" frames, for second attitude, inertial "from" and "to" to bypass jeopardized check 2',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm frmdiff_ck_cov4_id1.bc -f2 ECLIPJ2000 -f1 J2000 -t1 B1950 -c2 -84100 frmdiff_ck_cov4_id1.bc frmdiff_ck_cov4_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm frmdiff_ck_cov4_id1.bc",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'ECLIPJ2000' (17) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm frmdiff_ck_cov4_id1.bc",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +4.0909280422233E-01      +4.0909280422233E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different "to" frames, for first attitude, supporting kernels given with -k',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -t1 PHX_PAYLOAD -t2 J2000 -f1 B1950 -c1 -84100 frmdiff_ck_cov4_id1.bc frmdiff_ck_cov4_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.042994646432?E+00      +2.042994646432?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different "to" frames, for first attitude, supporting kernels given with -k1',
  'success',
  $frmdiff,
  '-k1 frmdiff_mk.tm -k2 frmdiff_mk.tm -t1 PHX_PAYLOAD -t2 J2000 -f1 B1950 -c1 -84100 frmdiff_ck_cov4_id1.bc frmdiff_ck_cov4_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.042994646432?E+00      +2.042994646432?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different "to" frames, for first attitude, supporting kernels given with -k and -k1',
  'success',
  $frmdiff,
  '-k  frmdiff_mk_no_sclk.tm -k1 frmdiff_sclk.tsc -k2 frmdiff_sclk.tsc -t1 PHX_PAYLOAD -t2 J2000 -f1 B1950 -c1 -84100 frmdiff_ck_cov4_id1.bc frmdiff_ck_cov4_id1.bc',
  32,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk_no_sclk.tm",
"#       frmdiff_sclk.tsc",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_mk_no_sclk.tm",
"#       frmdiff_sclk.tsc",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.042994646432?E+00      +2.042994646432?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different "to" frames, for first attitude, inertial "from" and "to" to bypass jeopardized check 1',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm frmdiff_ck_cov4_id1.bc -t1 ECLIPJ2000 -t2 J2000 -f1 B1950 -c1 -84100 frmdiff_ck_cov4_id1.bc frmdiff_ck_cov4_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm frmdiff_ck_cov4_id1.bc",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_mk.tm frmdiff_ck_cov4_id1.bc",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +4.0909280422233E-01      +4.0909280422233E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different "to" frames, for second attitude, supporting kernels given with -k',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -t2 PHX_PAYLOAD -t1 J2000 -f1 B1950 -c2 -84100 frmdiff_ck_cov4_id1.bc frmdiff_ck_cov4_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.042994646432?E+00      +2.042994646432?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different "to" frames, for second attitude, supporting kernels given with -k2',
  'success',
  $frmdiff,
  '-k1 frmdiff_mk.tm -k2 frmdiff_mk.tm -t2 PHX_PAYLOAD -t1 J2000 -f1 B1950 -c2 -84100 frmdiff_ck_cov4_id1.bc frmdiff_ck_cov4_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.042994646432?E+00      +2.042994646432?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different "to" frames, for second attitude, supporting kernels given with -k and -k2',
  'success',
  $frmdiff,
  '-k frmdiff_mk_no_sclk.tm -k1 frmdiff_sclk.tsc -k2 frmdiff_sclk.tsc -t2 PHX_PAYLOAD -t1 J2000 -f1 B1950 -c2 -84100 frmdiff_ck_cov4_id1.bc frmdiff_ck_cov4_id1.bc',
  32,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_mk_no_sclk.tm",
"#       frmdiff_sclk.tsc",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk_no_sclk.tm",
"#       frmdiff_sclk.tsc",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.042994646432?E+00      +2.042994646432?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different "to" frames, for second attitude, inertial "from" and "to" to bypass jeopardized check 2',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm frmdiff_ck_cov4_id1.bc -t2 ECLIPJ2000 -t1 J2000 -f1 B1950 -c2 -84100 frmdiff_ck_cov4_id1.bc frmdiff_ck_cov4_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_mk.tm frmdiff_ck_cov4_id1.bc",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm frmdiff_ck_cov4_id1.bc",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +4.0909280422233E-01      +4.0909280422233E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different -k1 and -k2, for first attitude, supporting kernels given with -k1',
  'success',
  $frmdiff,
  '-k1 frmdiff_mk_no_sclk.tm frmdiff_sclk.tsc -k2 frmdiff_sclk.tsc frmdiff_mk_no_sclk.tm -t1 PHX_PAYLOAD -f1 B1950 -c1 -84100 frmdiff_ck_cov4_id1.bc frmdiff_ck_cov4_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk_no_sclk.tm frmdiff_sclk.tsc",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_sclk.tsc frmdiff_mk_no_sclk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +?.?????????????E???      +?.?????????????E???"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different -k1 and -k2, for first attitude, supporting kernels given with -k and -k1',
  'success',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_pck.tpc -k1 frmdiff_sclk.tsc frmdiff_fk.tf -k2 frmdiff_fk.tf frmdiff_sclk.tsc -t1 PHX_PAYLOAD -f1 B1950 -c1 -84100 frmdiff_ck_cov4_id1.bc frmdiff_ck_cov4_id1.bc',
  32,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc",
"#       frmdiff_sclk.tsc frmdiff_fk.tf",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc",
"#       frmdiff_fk.tf frmdiff_sclk.tsc",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +?.?????????????E???      +?.?????????????E???"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different -k1 and -k2, for first attitude, inertial "from" and "to" to bypass jeopardized check 1',
  'success',
  $frmdiff,
  '-k1 frmdiff_mk.tm frmdiff_ck_cov4_id1.bc -k2 frmdiff_ck_cov4_id1.bc frmdiff_mk.tm -t1 J2000 -f1 B1950 -c1 -84100 frmdiff_ck_cov4_id1.bc frmdiff_ck_cov4_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_mk.tm frmdiff_ck_cov4_id1.bc",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_ck_cov4_id1.bc frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +0.0000000000000E+00      +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different files, for first attitude, supporting kernels given with -k',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -t1 PHX_PAYLOAD -f1 B1950 -c1 -84100 frmdiff_ck_cov4_id1.bc frmdiff_ck_cov2_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov2_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.0943951023932E+00      +2.0943951023932E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different files, for first attitude, supporting kernels given with -k1',
  'success',
  $frmdiff,
  '-k1 frmdiff_mk.tm -k2 frmdiff_mk.tm -t1 PHX_PAYLOAD -f1 B1950 -c1 -84100 frmdiff_ck_cov4_id1.bc frmdiff_ck_cov2_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov2_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.0943951023932E+00      +2.0943951023932E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different files, for first attitude, supporting kernels given with -k and -k1',
  'success',
  $frmdiff,
  '-k  frmdiff_mk_no_sclk.tm -k1 frmdiff_sclk.tsc -k2 frmdiff_sclk.tsc -t1 PHX_PAYLOAD -f1 B1950 -c1 -84100 frmdiff_ck_cov4_id1.bc frmdiff_ck_cov2_id1.bc',
  32,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk_no_sclk.tm",
"#       frmdiff_sclk.tsc",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk_no_sclk.tm",
"#       frmdiff_sclk.tsc",
"#       frmdiff_ck_cov2_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.0943951023932E+00      +2.0943951023932E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different files, for first attitude, inertial "from" and "to" to bypass jeopardized check 1',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm frmdiff_ck_cov4_id1.bc -t1 ECLIPJ2000 -f1 B1950 -c1 -84100 frmdiff_ck_cov4_id1.bc frmdiff_ck_cov2_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm frmdiff_ck_cov4_id1.bc",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm frmdiff_ck_cov4_id1.bc",
"#       frmdiff_ck_cov2_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +0.0000000000000E+00      +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different files, for second attitude, supporting kernels given with -k',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -t2 PHX_PAYLOAD -f1 B1950 -c1 -84100 frmdiff_ck_cov4_id1.bc frmdiff_ck_cov2_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov2_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.0943951023932E+00      +2.0943951023932E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different files, for second attitude, supporting kernels given with -k2',
  'success',
  $frmdiff,
  '-k1 frmdiff_mk.tm -k2 frmdiff_mk.tm -t2 PHX_PAYLOAD -f1 B1950 -c1 -84100 frmdiff_ck_cov4_id1.bc frmdiff_ck_cov2_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov2_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.0943951023932E+00      +2.0943951023932E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different files, for second attitude, supporting kernels given with -k and -k2',
  'success',
  $frmdiff,
  '-k frmdiff_mk_no_sclk.tm -k1 frmdiff_sclk.tsc -k2 frmdiff_sclk.tsc -t2 PHX_PAYLOAD -f1 B1950 -c1 -84100 frmdiff_ck_cov4_id1.bc frmdiff_ck_cov2_id1.bc',
  32,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk_no_sclk.tm",
"#       frmdiff_sclk.tsc",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk_no_sclk.tm",
"#       frmdiff_sclk.tsc",
"#       frmdiff_ck_cov2_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.0943951023932E+00      +2.0943951023932E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'two files, different files, for second attitude, inertial "from" and "to" to bypass jeopardized check 2',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm frmdiff_ck_cov4_id1.bc -t2 ECLIPJ2000 -f1 B1950 -c1 -84100 frmdiff_ck_cov4_id1.bc frmdiff_ck_cov2_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm frmdiff_ck_cov4_id1.bc",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm frmdiff_ck_cov4_id1.bc",
"#       frmdiff_ck_cov2_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +0.0000000000000E+00      +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, sampling same from-to-k1-k2, supporting kernels given with -k',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 1 frmdiff_ck_cov4_id1.bc',
  22,
"# Sampling of 1 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.0943951023932E+00      +2.0943951023932E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, sampling same from-to-k1-k2, supporting kernels given with -k1 and -k2 (same)',
  'success',
  $frmdiff,
  '-k1 frmdiff_mk.tm -k2 frmdiff_mk.tm -n 1 frmdiff_ck_cov4_id1.bc',
  22,
"# Sampling of 1 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.0943951023932E+00      +2.0943951023932E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, sampling same from-to-k1-k2, inertial "from" and "to" to bypass jeopardized check 3',
  'success',
  $frmdiff,
  '-f1 J2000 -t1 B1950 -c1 -84100 -k1 frmdiff_mk.tm frmdiff_ck_cov4_id1.bc -k2 frmdiff_mk.tm frmdiff_ck_cov4_id1.bc -n 1 frmdiff_ck_cov4_id1.bc',
  22,
"# Sampling of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm frmdiff_ck_cov4_id1.bc",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.2189583056036E-02      +1.2189583056036E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, different "from" frames, for first attitude, supporting kernels given with -k',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -f1 PHX_PAYLOAD -f2 J2000 -t1 B1950 -c1 -84100 -n 1 frmdiff_ck_cov4_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.042994646432?E+00      +2.042994646432?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, different "from" frames, for first attitude, supporting kernels given with -k1',
  'success',
  $frmdiff,
  '-k1 frmdiff_mk.tm -k2 frmdiff_mk.tm -f1 PHX_PAYLOAD -f2 J2000 -t1 B1950 -c1 -84100 -n 1 frmdiff_ck_cov4_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.042994646432?E+00      +2.042994646432?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, different "from" frames, for first attitude, supporting kernels given with -k and -k1',
  'success',
  $frmdiff,
  '-k  frmdiff_mk_no_sclk.tm -k1 frmdiff_sclk.tsc -k2 frmdiff_sclk.tsc -f1 PHX_PAYLOAD -f2 J2000 -t1 B1950 -c1 -84100 -n 1 frmdiff_ck_cov4_id1.bc',
  32,
"# Comparison of 1 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk_no_sclk.tm",
"#       frmdiff_sclk.tsc",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk_no_sclk.tm",
"#       frmdiff_sclk.tsc",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.042994646432?E+00      +2.042994646432?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, different "from" frames, for first attitude, inertial "from" and "to" to bypass jeopardized check 4',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm frmdiff_ck_cov4_id1.bc -f1 ECLIPJ2000 -f2 J2000 -t1 B1950 -c1 -84100 -n 1 frmdiff_ck_cov4_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'ECLIPJ2000' (17) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm frmdiff_ck_cov4_id1.bc",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm frmdiff_ck_cov4_id1.bc",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +4.0909280422233E-01      +4.0909280422233E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, different "from" frames, for second attitude, supporting kernels given with -k',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -f2 PHX_PAYLOAD -f1 J2000 -t1 B1950 -c2 -84100 -n 1 frmdiff_ck_cov4_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.042994646432?E+00      +2.042994646432?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, different "from" frames, for second attitude, supporting kernels given with -k2',
  'success',
  $frmdiff,
  '-k1 frmdiff_mk.tm -k2 frmdiff_mk.tm -f2 PHX_PAYLOAD -f1 J2000 -t1 B1950 -c2 -84100 -n 1 frmdiff_ck_cov4_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.042994646432?E+00      +2.042994646432?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, different "from" frames, for second attitude, supporting kernels given with -k and -k2',
  'success',
  $frmdiff,
  '-k frmdiff_mk_no_sclk.tm -k1 frmdiff_sclk.tsc -k2 frmdiff_sclk.tsc -f2 PHX_PAYLOAD -f1 J2000 -t1 B1950 -c2 -84100 -n 1 frmdiff_ck_cov4_id1.bc',
  32,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk_no_sclk.tm",
"#       frmdiff_sclk.tsc",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk_no_sclk.tm",
"#       frmdiff_sclk.tsc",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.042994646432?E+00      +2.042994646432?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, different "from" frames, for second attitude, inertial "from" and "to" to bypass jeopardized check 5',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm frmdiff_ck_cov4_id1.bc -f2 ECLIPJ2000 -f1 J2000 -t1 B1950 -c2 -84100 frmdiff_ck_cov4_id1.bc frmdiff_ck_cov4_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm frmdiff_ck_cov4_id1.bc",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'ECLIPJ2000' (17) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_mk.tm frmdiff_ck_cov4_id1.bc",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +4.0909280422233E-01      +4.0909280422233E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, different "to" frames, for first attitude, supporting kernels given with -k',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -t1 PHX_PAYLOAD -t2 J2000 -f1 B1950 -c1 -84100 -n 1 frmdiff_ck_cov4_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.042994646432?E+00      +2.042994646432?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, different "to" frames, for first attitude, supporting kernels given with -k1',
  'success',
  $frmdiff,
  '-k1 frmdiff_mk.tm -k2 frmdiff_mk.tm -t1 PHX_PAYLOAD -t2 J2000 -f1 B1950 -c1 -84100 -n 1 frmdiff_ck_cov4_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.042994646432?E+00      +2.042994646432?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, different "to" frames, for first attitude, supporting kernels given with -k and -k1',
  'success',
  $frmdiff,
  '-k  frmdiff_mk_no_sclk.tm -k1 frmdiff_sclk.tsc -k2 frmdiff_sclk.tsc -t1 PHX_PAYLOAD -t2 J2000 -f1 B1950 -c1 -84100 -n 1 frmdiff_ck_cov4_id1.bc',
  32,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk_no_sclk.tm",
"#       frmdiff_sclk.tsc",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_mk_no_sclk.tm",
"#       frmdiff_sclk.tsc",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.042994646432?E+00      +2.042994646432?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, different "to" frames, for first attitude, inertial "from" and "to" to bypass jeopardized check 4',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm frmdiff_ck_cov4_id1.bc -t1 ECLIPJ2000 -t2 J2000 -f1 B1950 -c1 -84100 -n 1 frmdiff_ck_cov4_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm frmdiff_ck_cov4_id1.bc",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_mk.tm frmdiff_ck_cov4_id1.bc",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +4.0909280422233E-01      +4.0909280422233E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, different "to" frames, for second attitude, supporting kernels given with -k',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -t2 PHX_PAYLOAD -t1 J2000 -f1 B1950 -c2 -84100 -n 1 frmdiff_ck_cov4_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.042994646432?E+00      +2.042994646432?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, different "to" frames, for second attitude, supporting kernels given with -k2',
  'success',
  $frmdiff,
  '-k1 frmdiff_mk.tm -k2 frmdiff_mk.tm -t2 PHX_PAYLOAD -t1 J2000 -f1 B1950 -c2 -84100 -n 1 frmdiff_ck_cov4_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.042994646432?E+00      +2.042994646432?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, different "to" frames, for second attitude, supporting kernels given with -k and -k2',
  'success',
  $frmdiff,
  '-k frmdiff_mk_no_sclk.tm -k1 frmdiff_sclk.tsc -k2 frmdiff_sclk.tsc -t2 PHX_PAYLOAD -t1 J2000 -f1 B1950 -c2 -84100 -n 1 frmdiff_ck_cov4_id1.bc',
  32,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_mk_no_sclk.tm",
"#       frmdiff_sclk.tsc",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk_no_sclk.tm",
"#       frmdiff_sclk.tsc",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.042994646432?E+00      +2.042994646432?E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, different "to" frames, for second attitude, inertial "from" and "to" to bypass jeopardized check 5',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm frmdiff_ck_cov4_id1.bc -t2 ECLIPJ2000 -t1 J2000 -f1 B1950 -c2 -84100 -n 1 frmdiff_ck_cov4_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_mk.tm frmdiff_ck_cov4_id1.bc",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_mk.tm frmdiff_ck_cov4_id1.bc",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +4.0909280422233E-01      +4.0909280422233E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, different -k1 and -k2, for first attitude, supporting kernels given with -k1',
  'success',
  $frmdiff,
  '-k1 frmdiff_mk_no_sclk.tm frmdiff_sclk.tsc -k2 frmdiff_sclk.tsc frmdiff_mk_no_sclk.tm -t1 PHX_PAYLOAD -f1 B1950 -c1 -84100 -n 1  frmdiff_ck_cov4_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk_no_sclk.tm frmdiff_sclk.tsc",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_sclk.tsc frmdiff_mk_no_sclk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +?.?????????????E???      +?.?????????????E???"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, different -k1 and -k2, for first attitude, supporting kernels given with -k and -k1',
  'success',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_pck.tpc -k1 frmdiff_sclk.tsc frmdiff_fk.tf -k2 frmdiff_fk.tf frmdiff_sclk.tsc -t1 PHX_PAYLOAD -f1 B1950 -c1 -84100 -n 1 frmdiff_ck_cov4_id1.bc',
  32,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc",
"#       frmdiff_sclk.tsc frmdiff_fk.tf",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc",
"#       frmdiff_fk.tf frmdiff_sclk.tsc",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +?.?????????????E???      +?.?????????????E???"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'only file, different -k1 and -k2, for first attitude, inertial "from" and "to" to bypass jeopardized check 4',
  'success',
  $frmdiff,
  '-k1 frmdiff_mk.tm frmdiff_ck_cov4_id1.bc -k2 frmdiff_ck_cov4_id1.bc frmdiff_mk.tm -t1 J2000 -f1 B1950 -c1 -84100 -n 1 frmdiff_ck_cov4_id1.bc',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_mk.tm frmdiff_ck_cov4_id1.bc",
"#       frmdiff_ck_cov4_id1.bc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_ck_cov4_id1.bc frmdiff_mk.tm",
"#       frmdiff_ck_cov4_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:45.000' TDB (250000125.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +0.0000000000000E+00      +0.0000000000000E+00"
);


&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'no files, sampling same from-to-k1-k2, for first attitude, supporting kernels given with -k',
  'success',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_pck.tpc -f1 J2000 -t1 IAU_MARS -b 2000-01-01 TDB -e 2000-01-01 TDB -n 1',
  21,
"# Sampling of 1 rotations",
"#    from 'J2000' (1) to 'IAU_MARS' (10014)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"#    to   '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.0587912838067E+00      +1.0587912838067E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'no files, sampling same from-to-k1-k2, for first attitude, supporting kernels given with -k1 and -k2',
  'success',
  $frmdiff,
  '-k1 frmdiff_lsk.tls frmdiff_pck.tpc -k2 frmdiff_lsk.tls frmdiff_pck.tpc -f1 J2000 -t1 IAU_MARS -b 2000-01-01 TDB -e 2000-01-01 TDB -n 1',
  21,
"# Sampling of 1 rotations",
"#    from 'J2000' (1) to 'IAU_MARS' (10014)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"#    to   '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.0587912838067E+00      +1.0587912838067E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'no files, different "from" frames, for first attitude, supporting kernels given with -k',
  'success',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_pck.tpc -f1 IAU_MARS -f2 J2000 -t1 B1950 -b 2000-01-01 TDB -e 2000-01-01 TDB -n 1',
  28,
"# Comparison of 1 rotations",
"#    from 'IAU_MARS' (10014) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"#    to   '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.0587912838067E+00      +1.0587912838067E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'no files, different "from" frames, for first attitude, supporting kernels given with -k1',
  'success',
  $frmdiff,
  '-k1 frmdiff_lsk.tls frmdiff_pck.tpc -k2 frmdiff_lsk.tls frmdiff_pck.tpc -f1 IAU_MARS -f2 J2000 -t1 B1950 -b 2000-01-01 TDB -e 2000-01-01 TDB -n 1',
  28,
"# Comparison of 1 rotations",
"#    from 'IAU_MARS' (10014) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"#    to   '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.0587912838067E+00      +1.0587912838067E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'no files, different "from" frames, for first attitude, supporting kernels given with -k and -k1',
  'success',
  $frmdiff,
  '-k frmdiff_lsk.tls -k1 frmdiff_pck.tpc -k2 frmdiff_pck.tpc -f1 IAU_MARS -f2 J2000 -t1 B1950 -b 2000-01-01 TDB -e 2000-01-01 TDB -n 1',
  30,
"# Comparison of 1 rotations",
"#    from 'IAU_MARS' (10014) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck.tpc",
"# with 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"#    to   '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.0587912838067E+00      +1.0587912838067E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'no files, different "from" frames, for second attitude, supporting kernels given with -k',
  'success',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_pck.tpc -f2 IAU_MARS -f1 J2000 -t1 B1950 -b 2000-01-01 TDB -e 2000-01-01 TDB -n 1',
  28,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc",
"# with 1 rotations",
"#    from 'IAU_MARS' (10014) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"#    to   '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.0587912838067E+00      +1.0587912838067E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'no files, different "from" frames, for second attitude, supporting kernels given with -k2',
  'success',
  $frmdiff,
  '-k1 frmdiff_lsk.tls frmdiff_pck.tpc -k2 frmdiff_lsk.tls frmdiff_pck.tpc -f2 IAU_MARS -f1 J2000 -t1 B1950 -b 2000-01-01 TDB -e 2000-01-01 TDB -n 1',
  28,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc",
"# with 1 rotations",
"#    from 'IAU_MARS' (10014) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"#    to   '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.0587912838067E+00      +1.0587912838067E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'no files, different "from" frames, for second attitude, supporting kernels given with -k and -k2',
  'success',
  $frmdiff,
  '-k frmdiff_lsk.tls -k1 frmdiff_pck.tpc -k2 frmdiff_pck.tpc -f2 IAU_MARS -f1 J2000 -t1 B1950 -b 2000-01-01 TDB -e 2000-01-01 TDB -n 1',
  30,
"# Comparison of 1 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck.tpc",
"# with 1 rotations",
"#    from 'IAU_MARS' (10014) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"#    to   '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.0587912838067E+00      +1.0587912838067E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'no files, different "to" frames, for first attitude, supporting kernels given with -k',
  'success',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_pck.tpc -t1 IAU_MARS -t2 J2000 -f1 B1950 -b 2000-01-01 TDB -e 2000-01-01 TDB -n 1',
  28,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'IAU_MARS' (10014)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"#    to   '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.0587912838067E+00      +1.0587912838067E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'no files, different "to" frames, for first attitude, supporting kernels given with -k1',
  'success',
  $frmdiff,
  '-k1 frmdiff_lsk.tls frmdiff_pck.tpc -k2 frmdiff_lsk.tls frmdiff_pck.tpc -t1 IAU_MARS -t2 J2000 -f1 B1950 -b 2000-01-01 TDB -e 2000-01-01 TDB -n 1',
  28,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'IAU_MARS' (10014)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"#    to   '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.0587912838067E+00      +1.0587912838067E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'no files, different "to" frames, for first attitude, supporting kernels given with -k and -k1',
  'success',
  $frmdiff,
  '-k  frmdiff_lsk.tls -k1 frmdiff_pck.tpc -k2 frmdiff_pck.tpc -t1 IAU_MARS -t2 J2000 -f1 B1950 -b 2000-01-01 TDB -e 2000-01-01 TDB -n 1',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'IAU_MARS' (10014)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck.tpc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"#    to   '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.0587912838067E+00      +1.0587912838067E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'no files, different "to" frames, for second attitude, supporting kernels given with -k',
  'success',
  $frmdiff,
  '-k frmdiff_lsk.tls frmdiff_pck.tpc -t2 IAU_MARS -t1 J2000 -f1 B1950 -b 2000-01-01 TDB -e 2000-01-01 TDB -n 1',
  28,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'IAU_MARS' (10014)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"#    to   '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.0587912838067E+00      +1.0587912838067E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'no files, different "to" frames, for second attitude, supporting kernels given with -k2',
  'success',
  $frmdiff,
  '-k1 frmdiff_lsk.tls frmdiff_pck.tpc -k2 frmdiff_lsk.tls frmdiff_pck.tpc -t2 IAU_MARS -t1 J2000 -f1 B1950 -b 2000-01-01 TDB -e 2000-01-01 TDB -n 1',
  28,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'IAU_MARS' (10014)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"#    to   '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.0587912838067E+00      +1.0587912838067E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'no files, different "to" frames, for second attitude, supporting kernels given with -k and -k2',
  'success',
  $frmdiff,
  '-k frmdiff_lsk.tls -k1 frmdiff_pck.tpc -k2 frmdiff_pck.tpc -t2 IAU_MARS -t1 J2000 -f1 B1950 -b 2000-01-01 TDB -e 2000-01-01 TDB -n 1',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'J2000' (1)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck.tpc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'IAU_MARS' (10014)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"#    to   '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +1.0587912838067E+00      +1.0587912838067E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'no files, different -k1 and -k2, for first attitude, supporting kernels given with -k1',
  'success',
  $frmdiff,
  '-k1 frmdiff_lsk.tls frmdiff_pck.tpc -k2 frmdiff_pck.tpc frmdiff_lsk.tls -t1 IAU_MARS -f1 B1950 -b 2000-01-01 TDB -e 2000-01-01 TDB -n 1 ',
  28,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'IAU_MARS' (10014)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_pck.tpc",
"# with 1 rotations",
"#    from 'B1950' (2) to 'IAU_MARS' (10014)",
"#    computed using",
"#       frmdiff_pck.tpc frmdiff_lsk.tls",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"#    to   '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +0.0000000000000E+00      +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'no files, different -k1 and -k2, for first attitude, supporting kernels given with -k and -k1',
  'success',
  $frmdiff,
  '-k frmdiff_lsk.tls -k1 frmdiff_pck.tpc frmdiff_fk.tf -k2 frmdiff_fk.tf frmdiff_pck.tpc -t1 IAU_MARS -f1 B1950 -b 2000-01-01 TDB -e 2000-01-01 TDB -n 1',
  30,
"# Comparison of 1 rotations",
"#    from 'B1950' (2) to 'IAU_MARS' (10014)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck.tpc frmdiff_fk.tf",
"# with 1 rotations",
"#    from 'B1950' (2) to 'IAU_MARS' (10014)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_fk.tf frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"#    to   '2000 JAN 01 00:00:00.000' TDB (-43200.000000000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +0.0000000000000E+00      +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'comparison header, two files, complete header with AVs, "from" frame',
  'success',
  $frmdiff,
  '-t dumpea -x degrees -a yes -m from -n 1 -k frmdiff_lsk.tls -k1 frmdiff_fk.tf frmdiff_sclk.tsc frmdiff_pck.tpc -k2 frmdiff_pck.tpc -f1 J2000 -t1 PHX_PAYLOAD -t2 ITRF93 frmdiff_ck_cov1_id1.bc frmdiff_pck_cov1_id1.bpc',
  34,
"# Comparison of 2 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_fk.tf frmdiff_sclk.tsc frmdiff_pck.tpc",
"#       frmdiff_ck_cov1_id1.bc",
"# with 2 rotations",
"#    from 'J2000' (1) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck.tpc",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# including differences in angular velocities relative to 'from' frames.",
"# Times are TDB seconds past J2000.",
"# angles are shown in degrees.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X, av_x, av_y, av_z",
"+2.5000000000000E+08 +4.989088687????E+01 +3.3218286541???E+01 -1.6428449870???E+02 +3.1566873296872E-05 -2.8805525046121E-05 -1.6400319323430E-05",
"+2.5000010000000E+08 +4.9931522351???E+01 +3.3445052227???E+01 -1.6443412869???E+02 +3.1566873300234E-05 -2.8805524998456E-05 -1.6400313439987E-05"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'comparison header, two files, complete header with AVs, "to" frame',
  'success',
  $frmdiff,
  '-t dumpea -x degrees -a yes -m to -n 1 -k frmdiff_lsk.tls -k1 frmdiff_fk.tf frmdiff_sclk.tsc frmdiff_pck.tpc -k2 frmdiff_pck.tpc -f1 J2000 -t1 PHX_PAYLOAD -t2 ITRF93 frmdiff_ck_cov1_id1.bc frmdiff_pck_cov1_id1.bpc',
  34,
"# Comparison of 2 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_fk.tf frmdiff_sclk.tsc frmdiff_pck.tpc",
"#       frmdiff_ck_cov1_id1.bc",
"# with 2 rotations",
"#    from 'J2000' (1) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck.tpc",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# including differences in angular velocities relative to 'to' frames.",
"# Times are TDB seconds past J2000.",
"# angles are shown in degrees.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X, av_x, av_y, av_z",
"+2.5000000000000E+08 +4.989088687????E+01 +3.3218286541???E+01 -1.6428449870???E+02 +1.6366923437???E-05 +4.2135932464???E-05 -7.2030027996???E-06",
"+2.5000010000000E+08 +4.9931522351???E+01 +3.3445052227???E+01 -1.6443412869???E+02 +1.6088840470???E-05 +4.2224019880???E-05 -7.3128242682???E-06"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'comparison header, two files, complete header no AVs',
  'success',
  $frmdiff,
  '-t dumpea -x degrees -n 1 -k frmdiff_lsk.tls -k1 frmdiff_fk.tf frmdiff_sclk.tsc frmdiff_pck.tpc -k2 frmdiff_pck.tpc -f1 J2000 -t1 PHX_PAYLOAD -t2 ITRF93 frmdiff_ck_cov1_id1.bc frmdiff_pck_cov1_id1.bpc',
  32,
"# Comparison of 2 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_fk.tf frmdiff_sclk.tsc frmdiff_pck.tpc",
"#       frmdiff_ck_cov1_id1.bc",
"# with 2 rotations",
"#    from 'J2000' (1) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck.tpc",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# Times are TDB seconds past J2000.",
"# angles are shown in degrees.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X",
"+2.5000000000000E+08 +4.989088687????E+01 +3.3218286541???E+01 -1.6428449870???E+02",
"+2.5000010000000E+08 +4.9931522351???E+01 +3.3445052227???E+01 -1.6443412869???E+02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'comparison header, two files, step with days/hr/min/sc',
  'success',
  $frmdiff,
  '-t dumpea -x degrees -b 2001-01-01 TDB -e 2001-01-03 TDB -a yes -m from -s 90061 -k frmdiff_lsk.tls -k1 frmdiff_sclk.tsc -k2 frmdiff_pck_cov1_id1.bpc -f1 J2000 -t1 ECLIPJ2000 -t2 IAU_MARS frmdiff_fk.tf frmdiff_pck.tpc',
  35,
"# Comparison of 3 rotations",
"#    from 'J2000' (1) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_sclk.tsc",
"#       frmdiff_fk.tf",
"# with 3 rotations",
"#    from 'J2000' (1) to 'IAU_MARS' (10014)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck_cov1_id1.bpc",
"#       frmdiff_pck.tpc",
"# with a 90061.000000000 second (1:01:01:01.000000) step size",
"# within the continuous time period",
"#    from '2001 JAN 01 00:00:00.000' TDB (31579200.000000 TDB seconds)",
"#    to   '2001 JAN 03 00:00:00.000' TDB (31752000.000000 TDB seconds)",
"# including differences in angular velocities relative to 'from' frames.",
"# angles are shown in degrees.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X, av_x, av_y, av_z",
"+3.1579200000000E+07 +5.3534787034???E+01 -1.9129429869???E+01 +1.9014425501???E+01 -3.1624614653933E-05 +2.8795998511599E-05 -5.6523956752173E-05",
"+3.1669261000000E+07 +4.7704588220???E+01 -2.0912548574???E+01 +1.7016607828???E+01 -3.1624614399900E-05 +2.8796001337260E-05 -5.6523955454776E-05",
"+3.1752000000000E+07 +7.1150139008???E+01 -1.2418868308???E+01 +2.3846588944???E+01 -3.1624614166521E-05 +2.8796003933193E-05 -5.6523954262857E-05"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'comparison header, two files, only -k  kernels',
  'success',
  $frmdiff,
  '-t dumpea -x degrees -a yes -m from -n 1 -k frmdiff_lsk.tls frmdiff_fk.tf frmdiff_sclk.tsc frmdiff_pck.tpc -f1 J2000 -t1 PHX_PAYLOAD -t2 ITRF93 frmdiff_ck_cov1_id1.bc frmdiff_pck_cov1_id1.bpc',
  32,
"# Comparison of 2 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_fk.tf frmdiff_sclk.tsc frmdiff_pck.tpc",
"#       frmdiff_ck_cov1_id1.bc",
"# with 2 rotations",
"#    from 'J2000' (1) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_fk.tf frmdiff_sclk.tsc frmdiff_pck.tpc",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# including differences in angular velocities relative to 'from' frames.",
"# angles are shown in degrees.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X, av_x, av_y, av_z",
"+2.5000000000000E+08 +4.989088687????E+01 +3.3218286541???E+01 -1.6428449870???E+02 +3.1566873296872E-05 -2.8805525046121E-05 -1.6400319323430E-05",
"+2.5000010000000E+08 +4.9931522351???E+01 +3.3445052227???E+01 -1.6443412869???E+02 +3.1566873300234E-05 -2.8805524998456E-05 -1.6400313439987E-05"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'comparison header, two files, only -k  and -k1 kernels',
  'success',
  $frmdiff,
  '-t dumpea -x degrees -a yes -m from -n 1 -k frmdiff_lsk.tls frmdiff_fk.tf frmdiff_sclk.tsc -k1 frmdiff_pck.tpc -f1 J2000 -t1 PHX_PAYLOAD -t2 ITRF93 frmdiff_ck_cov1_id1.bc frmdiff_pck_cov1_id1.bpc',
  33,
"# Comparison of 2 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_fk.tf frmdiff_sclk.tsc",
"#       frmdiff_pck.tpc",
"#       frmdiff_ck_cov1_id1.bc",
"# with 2 rotations",
"#    from 'J2000' (1) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_fk.tf frmdiff_sclk.tsc",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# including differences in angular velocities relative to 'from' frames.",
"# angles are shown in degrees.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X, av_x, av_y, av_z",
"+2.5000000000000E+08 +4.989088687????E+01 +3.3218286541???E+01 -1.6428449870???E+02 +3.1566873296872E-05 -2.8805525046121E-05 -1.6400319323430E-05",
"+2.5000010000000E+08 +4.9931522351???E+01 +3.3445052227???E+01 -1.6443412869???E+02 +3.1566873300234E-05 -2.8805524998456E-05 -1.6400313439987E-05"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'comparison header, two files, only -k  and -k2 kernels',
  'success',
  $frmdiff,
  '-t dumpea -x degrees -a yes -m from -n 1 -k frmdiff_mk.tm -k2 frmdiff_pck.tpc -f1 J2000 -t1 PHX_PAYLOAD -t2 ITRF93 frmdiff_ck_cov1_id1.bc frmdiff_pck_cov1_id1.bpc',
  33,
"# Comparison of 2 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# with 2 rotations",
"#    from 'J2000' (1) to 'ITRF93' (13000)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_pck.tpc",
"#       frmdiff_pck_cov1_id1.bpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# including differences in angular velocities relative to 'from' frames.",
"# angles are shown in degrees.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X, av_x, av_y, av_z",
"+2.5000000000000E+08 +4.989088687????E+01 +3.3218286541???E+01 -1.6428449870???E+02 +3.1566873296872E-05 -2.8805525046121E-05 -1.6400319323430E-05",
"+2.5000010000000E+08 +4.9931522351???E+01 +3.3445052227???E+01 -1.6443412869???E+02 +3.1566873300234E-05 -2.8805524998456E-05 -1.6400313439987E-05"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'comparison header, one file, complete header with AVs',
  'success',
  $frmdiff,
  '-t dumpea -x degrees -a yes -m from -n 1 -k frmdiff_lsk.tls -k1 frmdiff_fk.tf frmdiff_sclk.tsc frmdiff_pck.tpc -k2 frmdiff_pck.tpc -f1 J2000 -t1 PHX_PAYLOAD -t2 B1950 frmdiff_ck_cov1_id1.bc',
  34,
"# Comparison of 2 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_fk.tf frmdiff_sclk.tsc frmdiff_pck.tpc",
"#       frmdiff_ck_cov1_id1.bc",
"# with 2 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck.tpc",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# including differences in angular velocities relative to 'from' frames.",
"# Times are TDB seconds past J2000.",
"# angles are shown in degrees.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X, av_x, av_y, av_z",
"+2.5000000000000E+08 -2.128021672????E+01 -6.5064064156???E+00 -1.4408686171???E+02 +3.162399785629?E-05 -2.880285153518?E-05 +5.652081008126?E-05",
"+2.5000010000000E+08 -2.164205433????E+01 -6.5609833800???E+00 -1.4394712644???E+02 +3.1623997856012E-05 -2.8802851538321E-05 +5.6520810079823E-05"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'comparison header, no files, complete header with AVs',
  'success',
  $frmdiff,
  '-t dumpea -x degrees -a yes -m from -n 1 -k frmdiff_lsk.tls -k1 frmdiff_fk.tf frmdiff_sclk.tsc frmdiff_pck.tpc -k2 frmdiff_pck.tpc -f1 J2000 -t1 ECLIPJ2000 -t2 B1950 -b 2001-01-01 TDB -e 2001-01-03 TDB',
  32,
"# Comparison of 2 rotations",
"#    from 'J2000' (1) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_fk.tf frmdiff_sclk.tsc frmdiff_pck.tpc",
"# with 2 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2001 JAN 01 00:00:00.000' TDB (31579200.000000 TDB seconds)",
"#    to   '2001 JAN 03 00:00:00.000' TDB (31752000.000000 TDB seconds)",
"# including differences in angular velocities relative to 'from' frames.",
"# Times are TDB seconds past J2000.",
"# angles are shown in degrees.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X, av_x, av_y, av_z",
"+3.1579200000000E+07 -6.9841136184936E-01 +6.4874004591???E-04 +2.3439294931347E+01 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
"+3.1752000000000E+07 -6.9841136184936E-01 +6.4874004591???E-04 +2.3439294931347E+01 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'comparison header, no files, complete header, no files for first attitude (only -k2)',
  'success',
  $frmdiff,
  '-t dumpea -x degrees -a yes -m from -n 1 -k2 frmdiff_lsk.tls  -f1 J2000 -t1 ECLIPJ2000 -t2 B1950 -b 2001-01-01 TDB -e 2001-01-03 TDB',
  27,
"# Comparison of 2 rotations",
"#    from 'J2000' (1) to 'ECLIPJ2000' (17)",
"# with 2 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"#    computed using",
"#       frmdiff_lsk.tls",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2001 JAN 01 00:00:00.000' TDB (31579200.000000 TDB seconds)",
"#    to   '2001 JAN 03 00:00:00.000' TDB (31752000.000000 TDB seconds)",
"# including differences in angular velocities relative to 'from' frames.",
"# Times are TDB seconds past J2000.",
"# angles are shown in degrees.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X, av_x, av_y, av_z",
"+3.1579200000000E+07 -6.9841136184936E-01 +6.4874004591???E-04 +2.3439294931347E+01 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
"+3.1752000000000E+07 -6.9841136184936E-01 +6.4874004591???E-04 +2.3439294931347E+01 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'comparison header, no files, complete header, no files for second attitude (only -k1)',
  'success',
  $frmdiff,
  '-t dumpea -x degrees -a yes -m from -n 1 -k1 frmdiff_lsk.tls -f1 J2000 -t1 ECLIPJ2000 -t2 B1950 -b 2001-01-01 TDB -e 2001-01-03 TDB',
  27,
"# Comparison of 2 rotations",
"#    from 'J2000' (1) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_lsk.tls",
"# with 2 rotations",
"#    from 'J2000' (1) to 'B1950' (2)",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2001 JAN 01 00:00:00.000' TDB (31579200.000000 TDB seconds)",
"#    to   '2001 JAN 03 00:00:00.000' TDB (31752000.000000 TDB seconds)",
"# including differences in angular velocities relative to 'from' frames.",
"# Times are TDB seconds past J2000.",
"# angles are shown in degrees.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X, av_x, av_y, av_z",
"+3.1579200000000E+07 -6.9841136184936E-01 +6.4874004591???E-04 +2.3439294931347E+01 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
"+3.1752000000000E+07 -6.9841136184936E-01 +6.4874004591???E-04 +2.3439294931347E+01 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00"
);


&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'sampling header, two files, complete header with AVs, "from" frame',
  'success',
  $frmdiff,
  '-t dumpea -x degrees -a yes -m from -n 1 -k frmdiff_mk_no_sclk.tm -k1 frmdiff_sclk.tsc -k2 frmdiff_sclk.tsc -f1 J2000 -t1 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  25,
"# Sampling of 2 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk_no_sclk.tm",
"#       frmdiff_sclk.tsc",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# including angular velocities relative to 'from' frame.",
"# Times are TDB seconds past J2000.",
"# angles are shown in degrees.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X, av_x, av_y, av_z",
"+2.5000000000000E+08 -2.1966910010???E+01 -6.656158916????E+00 -1.4416556630???E+02 +3.162399785629?E-05 -2.880285153518?E-05 +5.652081008126?E-05",
"+2.5000010000000E+08 -2.2328455664???E+01 -6.7123954286???E+00 -1.4402645693???E+02 +3.1623997856012E-05 -2.8802851538321E-05 +5.6520810079823E-05"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'sampling header, two files, complete header with AVs, "to" frame',
  'success',
  $frmdiff,
  '-t dumpea -x degrees -a yes -m to -n 1 -k frmdiff_mk_no_sclk.tm -k1 frmdiff_sclk.tsc -k2 frmdiff_sclk.tsc -f1 J2000 -t1 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  25,
"# Sampling of 2 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk_no_sclk.tm",
"#       frmdiff_sclk.tsc",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# including angular velocities relative to 'to' frame.",
"# Times are TDB seconds past J2000.",
"# angles are shown in degrees.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X, av_x, av_y, av_z",
"+2.5000000000000E+08 -2.1966910010???E+01 -6.656158916????E+00 -1.441655663040?E+02 +2.6035174355819E-05 +2.42591????????E-13 -6.5927635825025E-05",
"+2.5000010000000E+08 -2.2328455664???E+01 -6.7123954286???E+00 -1.440264569386?E+02 +2.6035174354209E-05 +2.45592????????E-13 -6.5927635825661E-05"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'sampling header, two files, complete header no AVs',
  'success',
  $frmdiff,
  '-t dumpea -x degrees -n 1 -k frmdiff_mk_no_sclk.tm -k1 frmdiff_sclk.tsc -k2 frmdiff_sclk.tsc -f1 J2000 -t1 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  23,
"# Sampling of 2 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk_no_sclk.tm",
"#       frmdiff_sclk.tsc",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# angles are shown in degrees.",
"# Times are TDB seconds past J2000.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X",
"+2.5000000000000E+08 -2.1966910010???E+01 -6.656158916????E+00 -1.4416556630???E+02",
"+2.5000010000000E+08 -2.2328455664???E+01 -6.7123954286???E+00 -1.4402645693???E+02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'sampling header, two files, step with days/hr/min/sc',
  'success',
  $frmdiff,
  '-t dumpea -x degrees -b 2001-01-01 TDB -e 2001-01-05 TDB -a yes -m from -s 180122.2 -k frmdiff_lsk.tls -k1 frmdiff_sclk.tsc -k2 frmdiff_sclk.tsc -f1 J2000 -t1 IAU_MARS frmdiff_pck.tpc frmdiff_pck.tpc',
  26,
"# Sampling of 3 rotations",
"#    from 'J2000' (1) to 'IAU_MARS' (10014)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_sclk.tsc",
"#       frmdiff_pck.tpc",
"# with a 180122.20000000 second (2:02:02:02.200000) step size",
"# within the continuous time period",
"#    from '2001 JAN 01 00:00:00.000' TDB (31579200.000000 TDB seconds)",
"#    to   '2001 JAN 05 00:00:00.000' TDB (31924800.000000 TDB seconds)",
"# including angular velocities relative to 'from' frame.",
"# angles are shown in degrees.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X, av_x, av_y, av_z",
"+3.1579200000000E+07 -5.113967814????E+01 +2.649741720042?E+01 +2.699646227439?E+01 +3.1624614653933E-05 -2.8795998511599E-05 +5.6523956752173E-05",
"+3.1759322200000E+07 -3.96184377074??E+01 +2.649741674153?E+01 +2.699646788634?E+01 +3.1624614145867E-05 -2.8796004162926E-05 +5.6523954157375E-05",
"+3.1924800000000E+07 -8.7571763170???E+01 +2.649741631995?E+01 +2.699647304202?E+01 +3.1624613679107E-05 -2.8796009354786E-05 +5.6523951773541E-05"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'sampling header, two files, only -k  kernels',
  'success',
  $frmdiff,
  '-t dumpea -x degrees -a yes -m from -n 1 -k frmdiff_mk_no_sclk.tm frmdiff_sclk.tsc -f1 J2000 -t1 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  24,
"# Sampling of 2 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk_no_sclk.tm frmdiff_sclk.tsc",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# including angular velocities relative to 'from' frame.",
"# angles are shown in degrees.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X, av_x, av_y, av_z",
"+2.5000000000000E+08 -2.1966910010???E+01 -6.656158916????E+00 -1.4416556630???E+02 +3.162399785629?E-05 -2.880285153518?E-05 +5.652081008126?E-05",
"+2.5000010000000E+08 -2.2328455664???E+01 -6.7123954286???E+00 -1.4402645693???E+02 +3.1623997856012E-05 -2.8802851538321E-05 +5.6520810079823E-05"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'sampling header, two files, only -k1 and -k2 kernels (same list)',
  'success',
  $frmdiff,
  '-t dumpea -x degrees -a yes -m from -n 1 -k1 frmdiff_mk_no_sclk.tm frmdiff_sclk.tsc -k2 frmdiff_mk_no_sclk.tm frmdiff_sclk.tsc -f1 J2000 -t1 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc frmdiff_ck_cov1_id1.bc',
  24,
"# Sampling of 2 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk_no_sclk.tm frmdiff_sclk.tsc",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# including angular velocities relative to 'from' frame.",
"# angles are shown in degrees.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X, av_x, av_y, av_z",
"+2.5000000000000E+08 -2.1966910010???E+01 -6.656158916????E+00 -1.4416556630???E+02 +3.162399785629?E-05 -2.880285153518?E-05 +5.652081008126?E-05",
"+2.5000010000000E+08 -2.2328455664???E+01 -6.7123954286???E+00 -1.4402645693???E+02 +3.1623997856012E-05 -2.8802851538321E-05 +5.6520810079823E-05"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'sampling header, one file, complete header with AVs, "from" frame',
  'success',
  $frmdiff,
  '-t dumpea -x degrees -a yes -m from -n 1 -k frmdiff_mk_no_sclk.tm -k1 frmdiff_sclk.tsc -k2 frmdiff_sclk.tsc -f1 J2000 -t1 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc',
  25,
"# Sampling of 2 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk_no_sclk.tm",
"#       frmdiff_sclk.tsc",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# including angular velocities relative to 'from' frame.",
"# Times are TDB seconds past J2000.",
"# angles are shown in degrees.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X, av_x, av_y, av_z",
"+2.5000000000000E+08 -2.1966910010???E+01 -6.656158916????E+00 -1.4416556630???E+02 +3.162399785629?E-05 -2.880285153518?E-05 +5.652081008126?E-05",
"+2.5000010000000E+08 -2.2328455664???E+01 -6.7123954286???E+00 -1.4402645693???E+02 +3.1623997856012E-05 -2.8802851538321E-05 +5.6520810079823E-05"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'sampling header, one file, complete header with AVs, "to" frame',
  'success',
  $frmdiff,
  '-t dumpea -x degrees -a yes -m to -n 1 -k frmdiff_mk_no_sclk.tm -k1 frmdiff_sclk.tsc -k2 frmdiff_sclk.tsc -f1 J2000 -t1 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc',
  25,
"# Sampling of 2 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk_no_sclk.tm",
"#       frmdiff_sclk.tsc",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# including angular velocities relative to 'to' frame.",
"# Times are TDB seconds past J2000.",
"# angles are shown in degrees.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X, av_x, av_y, av_z",
"+2.5000000000000E+08 -2.1966910010???E+01 -6.656158916????E+00 -1.441655663040?E+02 +2.6035174355819E-05 +2.42591????????E-13 -6.5927635825025E-05",
"+2.5000010000000E+08 -2.2328455664???E+01 -6.7123954286???E+00 -1.440264569386?E+02 +2.6035174354209E-05 +2.45592????????E-13 -6.5927635825661E-05"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'sampling header, one file, complete header no AVs',
  'success',
  $frmdiff,
  '-t dumpea -x degrees -n 1 -k frmdiff_mk_no_sclk.tm -k1 frmdiff_sclk.tsc -k2 frmdiff_sclk.tsc -f1 J2000 -t1 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc',
  23,
"# Sampling of 2 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk_no_sclk.tm",
"#       frmdiff_sclk.tsc",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# Times are TDB seconds past J2000.",
"# angles are shown in degrees.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X",
"+2.5000000000000E+08 -2.1966910010???E+01 -6.656158916????E+00 -1.441655663040?E+02",
"+2.5000010000000E+08 -2.2328455664???E+01 -6.7123954286???E+00 -1.440264569386?E+02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'sampling header, one file, only -k  kernels',
  'success',
  $frmdiff,
  '-t dumpea -x degrees -a yes -m from -n 1 -k frmdiff_mk_no_sclk.tm frmdiff_sclk.tsc -f1 J2000 -t1 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc',
  24,
"# Sampling of 2 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk_no_sclk.tm frmdiff_sclk.tsc",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# including angular velocities relative to 'from' frame.",
"# angles are shown in degrees.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X, av_x, av_y, av_z",
"+2.5000000000000E+08 -2.1966910010???E+01 -6.656158916????E+00 -1.4416556630???E+02 +3.162399785629?E-05 -2.880285153518?E-05 +5.652081008126?E-05",
"+2.5000010000000E+08 -2.2328455664???E+01 -6.7123954286???E+00 -1.4402645693???E+02 +3.1623997856012E-05 -2.8802851538321E-05 +5.6520810079823E-05"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'sampling header, one file, only -k1 and -k2 kernels (same list)',
  'success',
  $frmdiff,
  '-t dumpea -x degrees -a yes -m from -n 1 -k1 frmdiff_mk_no_sclk.tm frmdiff_sclk.tsc -k2 frmdiff_mk_no_sclk.tm frmdiff_sclk.tsc -f1 J2000 -t1 PHX_PAYLOAD frmdiff_ck_cov1_id1.bc',
  24,
"# Sampling of 2 rotations",
"#    from 'J2000' (1) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk_no_sclk.tm frmdiff_sclk.tsc",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# including angular velocities relative to 'from' frame.",
"# angles are shown in degrees.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X, av_x, av_y, av_z",
"+2.5000000000000E+08 -2.1966910010???E+01 -6.656158916????E+00 -1.4416556630???E+02 +3.162399785629?E-05 -2.880285153518?E-05 +5.652081008126?E-05",
"+2.5000010000000E+08 -2.2328455664???E+01 -6.7123954286???E+00 -1.4402645693???E+02 +3.1623997856012E-05 -2.8802851538321E-05 +5.6520810079823E-05"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'sampling header, no files, complete header with AVs',
  'success',
  $frmdiff,
  '-t dumpea -x degrees -a yes -m from -n 1 -k frmdiff_lsk.tls -k1 frmdiff_pck.tpc -k2 frmdiff_pck.tpc -f1 J2000 -t1 ECLIPJ2000 -b 2001-01-01 TDB -e 2001-01-03 TDB',
  24,
"# Sampling of 2 rotations",
"#    from 'J2000' (1) to 'ECLIPJ2000' (17)",
"#    computed using",
"#       frmdiff_lsk.tls",
"#       frmdiff_pck.tpc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2001 JAN 01 00:00:00.000' TDB (31579200.000000 TDB seconds)",
"#    to   '2001 JAN 03 00:00:00.000' TDB (31752000.000000 TDB seconds)",
"# including angular velocities relative to 'from' frame.",
"# angles are shown in degrees.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X, av_x, av_y, av_z",
"+3.1579200000000E+07 +0.0000000000000E+00 +0.0000000000000E+00 +2.3439291111111E+01 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
"+3.1752000000000E+07 +0.0000000000000E+00 +0.0000000000000E+00 +2.3439291111111E+01 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00"
);


&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpc, one interval',
  'success',
  $frmdiff,
  '-t dumpc -k frmdiff_mk.tm -n 1 frmdiff_ck_cov1_id1.bc',
  19,
"# Coverage for rotation",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000000000E+08 +2.5000010000000E+08         100.000000     0:00:01:40.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpc, more than one interval',
  'success',
  $frmdiff,
  '-t dumpc -k frmdiff_mk.tm -n 1 frmdiff_ck_cov134_id1.bc',
  21,
"# Coverage for rotation",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov134_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the non-continuous (with 2 gaps) time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000000000E+08 +2.5000010000000E+08         100.000000     0:00:01:40.000000",
"+2.5000012500000E+08 +2.5000012500000E+08           0.000000     0:00:00:00.000000",
"+2.5000015000000E+08 +2.5000020000000E+08          50.000000     0:00:00:50.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpc, et times',
  'success',
  $frmdiff,
  '-f et -t dumpc -k frmdiff_mk.tm -n 1 frmdiff_ck_cov134_id1.bc',
  21,
"# Coverage for rotation",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov134_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the non-continuous (with 2 gaps) time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"+2.5000000000000E+08 +2.5000010000000E+08         100.000000     0:00:01:40.000000",
"+2.5000012500000E+08 +2.5000012500000E+08           0.000000     0:00:00:00.000000",
"+2.5000015000000E+08 +2.5000020000000E+08          50.000000     0:00:00:50.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpc, sclk times',
  'success',
  $frmdiff,
  '-f sclk -t dumpc -k frmdiff_mk.tm -n 1 frmdiff_ck_cov134_id1.bc',
  21,
"# Coverage for rotation",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov134_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the non-continuous (with 2 gaps) time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"1/0250000000.000 1/0250000100.000         100.000000     0:00:01:40.000000",
"1/0250000125.000 1/0250000125.000           0.000000     0:00:00:00.000000",
"1/0250000150.000 1/0250000200.000          50.000000     0:00:00:50.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpc, sclkd times',
  'success',
  $frmdiff,
  '-f sclkd -t dumpc -k frmdiff_mk.tm -n 1 frmdiff_ck_cov134_id1.bc',
  21,
"# Coverage for rotation",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov134_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the non-continuous (with 2 gaps) time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"2.5000000000000E+08 2.5000010000000E+08         100.000000     0:00:01:40.000000",
"2.5000012500000E+08 2.5000012500000E+08           0.000000     0:00:00:00.000000",
"2.5000015000000E+08 2.5000020000000E+08          50.000000     0:00:00:50.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpc, ticks times',
  'success',
  $frmdiff,
  '-f ticks -t dumpc -k frmdiff_mk.tm -n 1 frmdiff_ck_cov134_id1.bc',
  21,
"# Coverage for rotation",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov134_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the non-continuous (with 2 gaps) time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"2.5000000000000E+11 2.5000010000000E+11         100.000000     0:00:01:40.000000",
"2.5000012500000E+11 2.5000012500000E+11           0.000000     0:00:00:00.000000",
"2.5000015000000E+11 2.5000020000000E+11          50.000000     0:00:00:50.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpc, timout times',
  'success',
  $frmdiff,
  '-f YYYY-MM-DDTHR:MN:SC ::RND -t dumpc -k frmdiff_mk.tm -n 1 frmdiff_ck_cov134_id1.bc',
  21,
"# Coverage for rotation",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov134_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the non-continuous (with 2 gaps) time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# interval_start, interval_stop, interval_duration_sec, interval_duration_string",
"2007-12-04T00:25:35 2007-12-04T00:27:15         100.000000     0:00:01:40.000000",
"2007-12-04T00:27:40 2007-12-04T00:27:40           0.000000     0:00:00:00.000000",
"2007-12-04T00:28:05 2007-12-04T00:28:55          50.000000     0:00:00:50.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpg, no gaps',
  'success',
  $frmdiff,
  '-t dumpg -k frmdiff_mk.tm -n 1 frmdiff_ck_cov1_id1.bc',
  20,
"# Coverage for rotation",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov1_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the continuous time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:28:20.000' TDB (250000100.00000 TDB seconds)",
"There are no gaps in coverage."
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpg, one gap',
  'success',
  $frmdiff,
  '-t dumpg -k frmdiff_mk.tm -n 1 frmdiff_ck_cov13_id1.bc',
  19,
"# Coverage for rotation",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov13_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the non-continuous (with 1 gaps) time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# gap_start, gap_stop, gap_duration_sec, gap_duration_string",
"+2.5000010000000E+08 +2.5000015000000E+08          50.000000     0:00:00:50.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpg, more than one gap',
  'success',
  $frmdiff,
  '-t dumpg -k frmdiff_mk.tm -n 1 frmdiff_ck_cov134_id1.bc',
  20,
"# Coverage for rotation",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov134_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the non-continuous (with 2 gaps) time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# gap_start, gap_stop, gap_duration_sec, gap_duration_string",
"+2.5000010000000E+08 +2.5000012500000E+08          25.000000     0:00:00:25.000000",
"+2.5000012500000E+08 +2.5000015000000E+08          25.000000     0:00:00:25.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpg, et times',
  'success',
  $frmdiff,
  '-f et -t dumpg -k frmdiff_mk.tm -n 1 frmdiff_ck_cov134_id1.bc',
  20,
"# Coverage for rotation",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov134_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the non-continuous (with 2 gaps) time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# gap_start, gap_stop, gap_duration_sec, gap_duration_string",
"+2.5000010000000E+08 +2.5000012500000E+08          25.000000     0:00:00:25.000000",
"+2.5000012500000E+08 +2.5000015000000E+08          25.000000     0:00:00:25.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpg, sclk times',
  'success',
  $frmdiff,
  '-f sclk -t dumpg -k frmdiff_mk.tm -n 1 frmdiff_ck_cov134_id1.bc',
  20,
"# Coverage for rotation",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov134_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the non-continuous (with 2 gaps) time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# gap_start, gap_stop, gap_duration_sec, gap_duration_string",
"1/0250000100.000 1/0250000125.000          25.000000     0:00:00:25.000000",
"1/0250000125.000 1/0250000150.000          25.000000     0:00:00:25.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpg, sclkd times',
  'success',
  $frmdiff,
  '-f sclkd -t dumpg -k frmdiff_mk.tm -n 1 frmdiff_ck_cov134_id1.bc',
  20,
"# Coverage for rotation",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov134_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the non-continuous (with 2 gaps) time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# gap_start, gap_stop, gap_duration_sec, gap_duration_string",
"2.5000010000000E+08 2.5000012500000E+08          25.000000     0:00:00:25.000000",
"2.5000012500000E+08 2.5000015000000E+08          25.000000     0:00:00:25.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpg, ticks times',
  'success',
  $frmdiff,
  '-f ticks -t dumpg -k frmdiff_mk.tm -n 1 frmdiff_ck_cov134_id1.bc',
  20,
"# Coverage for rotation",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov134_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the non-continuous (with 2 gaps) time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# gap_start, gap_stop, gap_duration_sec, gap_duration_string",
"2.5000010000000E+11 2.5000012500000E+11          25.000000     0:00:00:25.000000",
"2.5000012500000E+11 2.5000015000000E+11          25.000000     0:00:00:25.000000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpg, timout times',
  'success',
  $frmdiff,
  '-f YYYY-MM-DDTHR:MN:SC ::RND -t dumpg -k frmdiff_mk.tm -n 1 frmdiff_ck_cov134_id1.bc',
  20,
"# Coverage for rotation",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov134_id1.bc",
"# at continuous coverage intervals' endpoints",
"# within the non-continuous (with 2 gaps) time period",
"#    from '2007 DEC 04 00:26:40.000' TDB (250000000.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# gap_start, gap_stop, gap_duration_sec, gap_duration_string",
"2007-12-04T00:27:15 2007-12-04T00:27:40          25.000000     0:00:00:25.000000",
"2007-12-04T00:27:40 2007-12-04T00:28:05          25.000000     0:00:00:25.000000"
);


&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpaa, comparison, with AVs, "from" frame',
  'success',
  $frmdiff,
  '-a yes -m from -t dumpaa -k frmdiff_mk.tm -n 4 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 PHX_PAYLOAD -t2 PHX_LANDER frmdiff_ck_cov3_id1.bc frmdiff_ck_cov3_id2.bc',
  33,
"# Comparison of 3 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id1.bc",
"# with 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with a 25.000000000000 second (0:00:00:25.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# including differences in angular velocities relative to 'from' frames.",
"# angle is shown in radians.",
"# time, angle, axis_x, axis_y, axis_z, av_x, av_y, av_z, av_magnitude",
"+2.5000015000000E+08 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
"+2.5000017500000E+08 +1.0471975511966E+00 +5.7735026918963E-01 -5.7735026918963E-01 +5.7735026918963E-01 +0.0000000000000E+00 ??.?????????????E??? -8.726646259971?E-03 +8.726646259971?E-03",
"+2.5000020000000E+08 +2.0943951023932E+00 +5.7735026918963E-01 -5.7735026918963E-01 +5.7735026918963E-01 +0.0000000000000E+00 ??.?????????????E??? -1.7453292519943E-02 +1.745329251994?E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpaa, comparison, with AVs, "to" frame',
  'success',
  $frmdiff,
  '-a yes -m to -t dumpaa -k frmdiff_mk.tm -n 4 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 PHX_PAYLOAD -t2 PHX_LANDER frmdiff_ck_cov3_id1.bc frmdiff_ck_cov3_id2.bc',
  33,
"# Comparison of 3 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id1.bc",
"# with 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with a 25.000000000000 second (0:00:00:25.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# including differences in angular velocities relative to 'to' frames.",
"# angle is shown in radians.",
"# time, angle, axis_x, axis_y, axis_z, av_x, av_y, av_z, av_magnitude",
"+2.5000015000000E+08 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
"+2.5000017500000E+08 +1.0471975511966E+00 +5.7735026918963E-01 -5.7735026918963E-01 +5.7735026918963E-01 +0.0000000000000E+00 ??.?????????????E??? -8.726646259971?E-03 +8.726646259971?E-03",
"+2.5000020000000E+08 +2.0943951023932E+00 +5.7735026918963E-01 -5.7735026918963E-01 +5.7735026918963E-01 +0.0000000000000E+00 ??.?????????????E??? -1.7453292519943E-02 +1.745329251994?E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpaa, comparison, no AVs',
  'success',
  $frmdiff,
  '-t dumpaa -k frmdiff_mk.tm -n 4 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 PHX_PAYLOAD -t2 PHX_LANDER frmdiff_ck_cov3_id1.bc frmdiff_ck_cov3_id2.bc',
  31,
"# Comparison of 3 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id1.bc",
"# with 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with a 25.000000000000 second (0:00:00:25.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# angle is shown in radians.",
"# time, angle, axis_x, axis_y, axis_z",
"+2.5000015000000E+08 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +1.0000000000000E+00",
"+2.5000017500000E+08 +1.0471975511966E+00 +5.7735026918963E-01 -5.7735026918963E-01 +5.7735026918963E-01",
"+2.5000020000000E+08 +2.0943951023932E+00 +5.7735026918963E-01 -5.7735026918963E-01 +5.7735026918963E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpaa, sampling, with AVs, "from" frame',
  'success',
  $frmdiff,
  '-a yes -m from -t dumpaa -k frmdiff_mk.tm -n 4 frmdiff_ck_cov3_id2.bc',
  25,
"# Sampling of 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with a 25.000000000000 second (0:00:00:25.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# including angular velocities relative to 'from' frame.",
"# angle is shown in radians.",
"# time, angle, axis_x, axis_y, axis_z, av_x, av_y, av_z, av_magnitude",
"+2.5000015000000E+08 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
"+2.5000017500000E+08 +1.0471975511966E+00 -5.7735026918963E-01 +5.7735026918963E-01 -5.7735026918963E-01 +0.0000000000000E+00 ??.?????????????E??? +8.726646259971?E-03 +8.726646259971?E-03",
"+2.5000020000000E+08 +2.0943951023932E+00 -5.7735026918963E-01 +5.7735026918963E-01 -5.7735026918963E-01 +0.0000000000000E+00 ??.?????????????E??? +1.7453292519943E-02 +1.745329251994?E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpaa, sampling, with AVs, "to" frame',
  'success',
  $frmdiff,
  '-a yes -m to -t dumpaa -k frmdiff_mk.tm -n 4 frmdiff_ck_cov3_id2.bc',
  25,
"# Sampling of 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with a 25.000000000000 second (0:00:00:25.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# including angular velocities relative to 'to' frame.",
"# angle is shown in radians.",
"# time, angle, axis_x, axis_y, axis_z, av_x, av_y, av_z, av_magnitude",
"+2.5000015000000E+08 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
"+2.5000017500000E+08 +1.0471975511966E+00 -5.7735026918963E-01 +5.7735026918963E-01 -5.7735026918963E-01 +5.817764173314?E-03 +2.908882086657?E-03 +5.817764173314?E-03 +8.726646259971?E-03",
"+2.5000020000000E+08 +2.0943951023932E+00 -5.7735026918963E-01 +5.7735026918963E-01 -5.7735026918963E-01 +1.7453292519943E-02 +0.0000000000000E+00 ??.?????????????E??? +1.745329251994?E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpaa, sampling, no AVs',
  'success',
  $frmdiff,
  '-t dumpaa -k frmdiff_mk.tm -n 4 frmdiff_ck_cov3_id2.bc',
  23,
"# Sampling of 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with a 25.000000000000 second (0:00:00:25.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# angle is shown in radians.",
"# time, angle, axis_x, axis_y, axis_z",
"+2.5000015000000E+08 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +1.0000000000000E+00",
"+2.5000017500000E+08 +1.0471975511966E+00 -5.7735026918963E-01 +5.7735026918963E-01 -5.7735026918963E-01",
"+2.5000020000000E+08 +2.0943951023932E+00 -5.7735026918963E-01 +5.7735026918963E-01 -5.7735026918963E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpaa, -x degrees',
  'success',
  $frmdiff,
  '-x degrees -t dumpaa -k frmdiff_mk.tm -n 4 frmdiff_ck_cov3_id2.bc',
  23,
"# Sampling of 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with a 25.000000000000 second (0:00:00:25.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# angle is shown in degrees.",
"# time, angle, axis_x, axis_y, axis_z",
"+2.5000015000000E+08 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +1.0000000000000E+00",
"+2.5000017500000E+08 +6.0000000000000E+01 -5.7735026918963E-01 +5.7735026918963E-01 -5.7735026918963E-01",
"+2.5000020000000E+08 +1.2000000000000E+02 -5.7735026918963E-01 +5.7735026918963E-01 -5.7735026918963E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpaa, sampling, et times',
  'success',
  $frmdiff,
  '-f et -t dumpaa -k frmdiff_mk.tm -n 4 frmdiff_ck_cov3_id2.bc',
  23,
"# Sampling of 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with a 25.000000000000 second (0:00:00:25.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# angle is shown in radians.",
"# Times are TDB seconds past J2000.",
"# time, angle, axis_x, axis_y, axis_z",
"+2.5000015000000E+08 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +1.0000000000000E+00",
"+2.5000017500000E+08 +1.0471975511966E+00 -5.7735026918963E-01 +5.7735026918963E-01 -5.7735026918963E-01",
"+2.5000020000000E+08 +2.0943951023932E+00 -5.7735026918963E-01 +5.7735026918963E-01 -5.7735026918963E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpaa, sampling, sclk times',
  'success',
  $frmdiff,
  '-f sclk -t dumpaa -k frmdiff_mk.tm -n 4 frmdiff_ck_cov3_id2.bc',
  23,
"# Sampling of 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with a 25.000000000000 second (0:00:00:25.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# angle is shown in radians.",
"# Times are SCLKs computed using SCLK ID -84.",
"# time, angle, axis_x, axis_y, axis_z",
"1/0250000150.000 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +1.0000000000000E+00",
"1/0250000175.000 +1.0471975511966E+00 -5.7735026918963E-01 +5.7735026918963E-01 -5.7735026918963E-01",
"1/0250000200.000 +2.0943951023932E+00 -5.7735026918963E-01 +5.7735026918963E-01 -5.7735026918963E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpaa, sampling, sclkd times',
  'success',
  $frmdiff,
  '-f sclkd -t dumpaa -k frmdiff_mk.tm -n 4 frmdiff_ck_cov3_id2.bc',
  23,
"# Sampling of 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with a 25.000000000000 second (0:00:00:25.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# angle is shown in radians.",
"# Times are decimal SCLKs computed using SCLK ID -84.",
"# time, angle, axis_x, axis_y, axis_z",
"2.5000015000000E+08 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +1.0000000000000E+00",
"2.5000017500000E+08 +1.0471975511966E+00 -5.7735026918963E-01 +5.7735026918963E-01 -5.7735026918963E-01",
"2.5000020000000E+08 +2.0943951023932E+00 -5.7735026918963E-01 +5.7735026918963E-01 -5.7735026918963E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpaa, sampling, ticks times',
  'success',
  $frmdiff,
  '-f ticks -t dumpaa -k frmdiff_mk.tm -n 4 frmdiff_ck_cov3_id2.bc',
  23,
"# Sampling of 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with a 25.000000000000 second (0:00:00:25.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# angle is shown in radians.",
"# Times are SCLK ticks computed using SCLK ID -84.",
"# time, angle, axis_x, axis_y, axis_z",
"2.5000015000000E+11 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +1.0000000000000E+00",
"2.5000017500000E+11 +1.0471975511966E+00 -5.7735026918963E-01 +5.7735026918963E-01 -5.7735026918963E-01",
"2.5000020000000E+11 +2.0943951023932E+00 -5.7735026918963E-01 +5.7735026918963E-01 -5.7735026918963E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpaa, sampling, timout times',
  'success',
  $frmdiff,
  '-f YYYY-MM-DDTHR:MN:SC ::RND -t dumpaa -k frmdiff_mk.tm -n 4 frmdiff_ck_cov3_id2.bc',
  23,
"# Sampling of 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with a 25.000000000000 second (0:00:00:25.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# angle is shown in radians.",
"# Times were generated by TIMOUT using 'YYYY-MM-DDTHR:MN:SC ::RND' format.",
"# time, angle, axis_x, axis_y, axis_z",
"2007-12-04T00:28:05 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +1.0000000000000E+00",
"2007-12-04T00:28:30 +1.0471975511966E+00 -5.7735026918963E-01 +5.7735026918963E-01 -5.7735026918963E-01",
"2007-12-04T00:28:55 +2.0943951023932E+00 -5.7735026918963E-01 +5.7735026918963E-01 -5.7735026918963E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpaa, comparison, et times',
  'success',
  $frmdiff,
  '-f et -t dumpaa -k frmdiff_mk.tm -n 4 frmdiff_ck_cov3_id2.bc frmdiff_ck_cov2_id2.bc',
  31,
"# Comparison of 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov2_id2.bc",
"# with a 12.500000000000 second (0:00:00:12.500000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:29:35.000' TDB (250000175.00000 TDB seconds)",
"# Times are TDB seconds past J2000.",
"# angle is shown in radians.",
"# time, angle, axis_x, axis_y, axis_z",
"+2.5000015000000E+08 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +1.0000000000000E+00",
"+2.5000016250000E+08 +5.2359877559830E-01 -5.7735026918963E-01 +5.7735026918963E-01 -5.7735026918963E-01",
"+2.5000017500000E+08 +1.0471975511966E+00 -5.7735026918963E-01 +5.7735026918963E-01 -5.7735026918963E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpaa, comparison, sclk times',
  'success',
  $frmdiff,
  '-f sclk -t dumpaa -k frmdiff_mk.tm -n 4 frmdiff_ck_cov3_id2.bc frmdiff_ck_cov2_id2.bc',
  31,
"# Comparison of 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov2_id2.bc",
"# with a 12.500000000000 second (0:00:00:12.500000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:29:35.000' TDB (250000175.00000 TDB seconds)",
"# Times are SCLKs computed using SCLK ID -84.",
"# angle is shown in radians.",
"# time, angle, axis_x, axis_y, axis_z",
"1/0250000150.000 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +1.0000000000000E+00",
"1/0250000162.500 +5.2359877559830E-01 -5.7735026918963E-01 +5.7735026918963E-01 -5.7735026918963E-01",
"1/0250000175.000 +1.0471975511966E+00 -5.7735026918963E-01 +5.7735026918963E-01 -5.7735026918963E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpaa, comparison, sclkd times',
  'success',
  $frmdiff,
  '-f sclkd -t dumpaa -k frmdiff_mk.tm -n 4 frmdiff_ck_cov3_id2.bc frmdiff_ck_cov2_id2.bc',
  31,
"# Comparison of 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov2_id2.bc",
"# with a 12.500000000000 second (0:00:00:12.500000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:29:35.000' TDB (250000175.00000 TDB seconds)",
"# Times are decimal SCLKs computed using SCLK ID -84.",
"# angle is shown in radians.",
"# time, angle, axis_x, axis_y, axis_z",
"2.5000015000000E+08 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +1.0000000000000E+00",
"2.5000016250000E+08 +5.2359877559830E-01 -5.7735026918963E-01 +5.7735026918963E-01 -5.7735026918963E-01",
"2.5000017500000E+08 +1.0471975511966E+00 -5.7735026918963E-01 +5.7735026918963E-01 -5.7735026918963E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpaa, comparison, ticks times',
  'success',
  $frmdiff,
  '-f ticks -t dumpaa -k frmdiff_mk.tm -n 4 frmdiff_ck_cov3_id2.bc frmdiff_ck_cov2_id2.bc',
  31,
"# Comparison of 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov2_id2.bc",
"# with a 12.500000000000 second (0:00:00:12.500000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:29:35.000' TDB (250000175.00000 TDB seconds)",
"# Times are SCLK ticks computed using SCLK ID -84.",
"# angle is shown in radians.",
"# time, angle, axis_x, axis_y, axis_z",
"2.5000015000000E+11 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +1.0000000000000E+00",
"2.5000016250000E+11 +5.2359877559830E-01 -5.7735026918963E-01 +5.7735026918963E-01 -5.7735026918963E-01",
"2.5000017500000E+11 +1.0471975511966E+00 -5.7735026918963E-01 +5.7735026918963E-01 -5.7735026918963E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpaa, comparison, timout times',
  'success',
  $frmdiff,
  '-f YYYY-MM-DDTHR:MN:SC ::RND -t dumpaa -k frmdiff_mk.tm -n 4 frmdiff_ck_cov3_id2.bc frmdiff_ck_cov2_id2.bc',
  31,
"# Comparison of 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov2_id2.bc",
"# with a 12.500000000000 second (0:00:00:12.500000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:29:35.000' TDB (250000175.00000 TDB seconds)",
"# Times were generated by TIMOUT using 'YYYY-MM-DDTHR:MN:SC ::RND' format.",
"# angle is shown in radians.",
"# time, angle, axis_x, axis_y, axis_z",
"2007-12-04T00:28:05 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +1.0000000000000E+00",
"2007-12-04T00:28:17 +5.2359877559830E-01 -5.7735026918963E-01 +5.7735026918963E-01 -5.7735026918963E-01",
"2007-12-04T00:28:30 +1.0471975511966E+00 -5.7735026918963E-01 +5.7735026918963E-01 -5.7735026918963E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpea, with AVs',
  'success',
  $frmdiff,
  '-a yes -m to -t dumpea -k frmdiff_mk.tm -n 4 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 PHX_PAYLOAD -t2 PHX_LANDER frmdiff_ck_cov3_id1.bc frmdiff_ck_cov3_id2.bc',
  33,
"# Comparison of 3 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id1.bc",
"# with 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with a 25.000000000000 second (0:00:00:25.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# including differences in angular velocities relative to 'to' frames.",
"# angles are shown in radians.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X, av_x, av_y, av_z",
"+2.5000015000000E+08 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
"+2.5000017500000E+08 -4.6364760900081E-01 +7.2972765622697E-01 -4.6364760900081E-01 +0.0000000000000E+00 ??.?????????????E??? -8.726646259971?E-03",
"+2.5000020000000E+08 +0.0000000000000E+00 +1.5707963267949E+00 -1.5707963267949E+00 +0.0000000000000E+00 ??.?????????????E??? -1.745329251994?E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpea, no AVs',
  'success',
  $frmdiff,
  '-t dumpea -k frmdiff_mk.tm -n 4 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 PHX_PAYLOAD -t2 PHX_LANDER frmdiff_ck_cov3_id1.bc frmdiff_ck_cov3_id2.bc',
  31,
"# Comparison of 3 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id1.bc",
"# with 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with a 25.000000000000 second (0:00:00:25.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# angles are shown in radians.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X",
"+2.5000015000000E+08 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
"+2.5000017500000E+08 -4.6364760900081E-01 +7.2972765622697E-01 -4.6364760900081E-01",
"+2.5000020000000E+08 +0.0000000000000E+00 +1.5707963267949E+00 -1.5707963267949E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpea, -x degrees',
  'success',
  $frmdiff,
  '-x degrees -t dumpea -k frmdiff_mk.tm -n 4 frmdiff_ck_cov3_id2.bc',
  23,
"# Sampling of 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with a 25.000000000000 second (0:00:00:25.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# angles are shown in degrees.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X",
"+2.5000015000000E+08 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
"+2.5000017500000E+08 +4.5000000000000E+01 -1.9471220634491E+01 +4.5000000000000E+01",
"+2.5000020000000E+08 +9.0000000000000E+01 +0.0000000000000E+00 +9.0000000000000E+01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpea, -o X Y Z',
  'success',
  $frmdiff,
  '-o x y z -x degrees -t dumpea -k frmdiff_mk.tm -n 4 frmdiff_ck_cov3_id2.bc',
  23,
"# Sampling of 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with a 25.000000000000 second (0:00:00:25.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# angles are shown in degrees.",
"# time, ang3_about_X, ang2_about_Y, ang1_about_Z",
"+2.5000015000000E+08 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
"+2.5000017500000E+08 +2.6565051177078E+01 -4.1810314895779E+01 +2.6565051177078E+01",
"+2.5000020000000E+08 +0.0000000000000E+00 -9.0000000000000E+01 +9.0000000000000E+01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpm, with AVs',
  'success',
  $frmdiff,
  '-a yes -m to -t dumpm -k frmdiff_mk.tm -n 4 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 PHX_PAYLOAD -t2 PHX_LANDER frmdiff_ck_cov3_id1.bc frmdiff_ck_cov3_id2.bc',
  31,
"# Comparison of 3 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id1.bc",
"# with 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with a 25.000000000000 second (0:00:00:25.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# including differences in angular velocities relative to 'to' frames.",
"# time, m11, m12, m13, m21, m22, m23, m31, m32, m33, av_x, av_y, av_z",
"+2.5000015000000E+08 +1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
"+2.5000017500000E+08 +6.6666666666667E-01 -6.6666666666667E-01 -3.3333333333333E-01 +3.3333333333333E-01 +6.6666666666667E-01 -6.6666666666667E-01 +6.6666666666667E-01 +3.3333333333333E-01 +6.6666666666667E-01 +0.0000000000000E+00 ??.?????????????E??? -8.726646259971?E-03",
"+2.5000020000000E+08 +0.0000000000000E+00 -1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 -1.0000000000000E+00 +1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 ??.?????????????E??? -1.745329251994?E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpm, no AVs',
  'success',
  $frmdiff,
  '-t dumpm -k frmdiff_mk.tm -n 4 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 PHX_PAYLOAD -t2 PHX_LANDER frmdiff_ck_cov3_id1.bc frmdiff_ck_cov3_id2.bc',
  29,
"# Comparison of 3 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id1.bc",
"# with 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with a 25.000000000000 second (0:00:00:25.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# time, m11, m12, m13, m21, m22, m23, m31, m32, m33",
"+2.5000015000000E+08 +1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +1.0000000000000E+00",
"+2.5000017500000E+08 +6.6666666666667E-01 -6.6666666666667E-01 -3.3333333333333E-01 +3.3333333333333E-01 +6.6666666666667E-01 -6.6666666666667E-01 +6.6666666666667E-01 +3.3333333333333E-01 +6.6666666666667E-01",
"+2.5000020000000E+08 +0.0000000000000E+00 -1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 -1.0000000000000E+00 +1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpqs, with AVs',
  'success',
  $frmdiff,
  '-a yes -m to -t dumpqs -k frmdiff_mk.tm -n 4 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 PHX_PAYLOAD -t2 PHX_LANDER frmdiff_ck_cov3_id1.bc frmdiff_ck_cov3_id2.bc',
  31,
"# Comparison of 3 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id1.bc",
"# with 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with a 25.000000000000 second (0:00:00:25.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# including differences in angular velocities relative to 'to' frames.",
"# time, q_cos, q_sin1, q_sin2, q_sin3, av_x, av_y, av_z",
"+2.5000015000000E+08 +1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
"+2.5000017500000E+08 +8.6602540378444E-01 +2.8867513459481E-01 -2.8867513459481E-01 +2.8867513459481E-01 +0.0000000000000E+00 ??.?????????????E??? -8.726646259971?E-03",
"+2.5000020000000E+08 +5.0000000000000E-01 +5.0000000000000E-01 -5.0000000000000E-01 +5.0000000000000E-01 +0.0000000000000E+00 ??.?????????????E??? -1.745329251994?E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpqs, no AVs',
  'success',
  $frmdiff,
  '-t dumpqs -k frmdiff_mk.tm -n 4 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 PHX_PAYLOAD -t2 PHX_LANDER frmdiff_ck_cov3_id1.bc frmdiff_ck_cov3_id2.bc',
  29,
"# Comparison of 3 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id1.bc",
"# with 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with a 25.000000000000 second (0:00:00:25.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# time, q_cos, q_sin1, q_sin2, q_sin3",
"+2.5000015000000E+08 +1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
"+2.5000017500000E+08 +8.6602540378444E-01 +2.8867513459481E-01 -2.8867513459481E-01 +2.8867513459481E-01",
"+2.5000020000000E+08 +5.0000000000000E-01 +5.0000000000000E-01 -5.0000000000000E-01 +5.0000000000000E-01"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpqo, with AVs',
  'success',
  $frmdiff,
  '-a yes -m to -t dumpqo -k frmdiff_mk.tm -n 4 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 PHX_PAYLOAD -t2 PHX_LANDER frmdiff_ck_cov3_id1.bc frmdiff_ck_cov3_id2.bc',
  31,
"# Comparison of 3 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id1.bc",
"# with 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with a 25.000000000000 second (0:00:00:25.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# including differences in angular velocities relative to 'to' frames.",
"# time, q_sin1, q_sin2, q_sin3, q_cos, av_x, av_y, av_z",
"+2.5000015000000E+08 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +1.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
"+2.5000017500000E+08 -2.8867513459481E-01 +2.8867513459481E-01 -2.8867513459481E-01 +8.6602540378444E-01 +0.0000000000000E+00 ??.?????????????E??? -8.726646259971?E-03",
"+2.5000020000000E+08 -5.0000000000000E-01 +5.0000000000000E-01 -5.0000000000000E-01 +5.0000000000000E-01 +0.0000000000000E+00 ??.?????????????E??? -1.745329251994?E-02"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t dumpqo, no AVs',
  'success',
  $frmdiff,
  '-t dumpqo -k frmdiff_mk.tm -n 4 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 PHX_PAYLOAD -t2 PHX_LANDER frmdiff_ck_cov3_id1.bc frmdiff_ck_cov3_id2.bc',
  29,
"# Comparison of 3 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id1.bc",
"# with 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with a 25.000000000000 second (0:00:00:25.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# time, q_sin1, q_sin2, q_sin3, q_cos",
"+2.5000015000000E+08 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00 +1.0000000000000E+00",
"+2.5000017500000E+08 -2.8867513459481E-01 +2.8867513459481E-01 -2.8867513459481E-01 +8.6602540378444E-01",
"+2.5000020000000E+08 -5.0000000000000E-01 +5.0000000000000E-01 -5.0000000000000E-01 +5.0000000000000E-01"
);


&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'no -t, comparison, with AVs',
  'success',
  $frmdiff,
  '-a yes -m to -k frmdiff_mk.tm -n 4 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 PHX_PAYLOAD -t2 PHX_LANDER frmdiff_ck_cov3_id1.bc frmdiff_ck_cov3_id2.bc',
  33,
"# Comparison of 3 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id1.bc",
"# with 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with a 25.000000000000 second (0:00:00:25.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# including differences in angular velocities relative to 'to' frames.",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.0943951023932E+00      +1.0471975511966E+00",
"  Angular Velocity (rad/s):   +1.7453292519943E-02      +8.7266462599716E-03"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'no -t, comparison, no AVs',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 4 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 PHX_PAYLOAD -t2 PHX_LANDER frmdiff_ck_cov3_id1.bc frmdiff_ck_cov3_id2.bc',
  30,
"# Comparison of 3 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id1.bc",
"# with 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with a 25.000000000000 second (0:00:00:25.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.0943951023932E+00      +1.0471975511966E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'no -t, sampling, with AVs',
  'success',
  $frmdiff,
  '-a yes -m to -k frmdiff_mk.tm -n 4 frmdiff_ck_cov3_id2.bc',
  25,
"# Sampling of 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with a 25.000000000000 second (0:00:00:25.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# including angular velocities relative to 'to' frame.",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.0943951023932E+00      +1.0471975511966E+00",
"  Angular Velocity (rad/s):   +1.7453292519943E-02      +8.7266462599716E-03"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  'no -t, sampling, no AVs',
  'success',
  $frmdiff,
  '-k frmdiff_mk.tm -n 4 frmdiff_ck_cov3_id2.bc',
  22,
"# Sampling of 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with a 25.000000000000 second (0:00:00:25.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.0943951023932E+00      +1.0471975511966E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t basic, comparison, with AVs',
  'success',
  $frmdiff,
  '-t basic -a yes -m to -k frmdiff_mk.tm -n 4 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 PHX_PAYLOAD -t2 PHX_LANDER frmdiff_ck_cov3_id1.bc frmdiff_ck_cov3_id2.bc',
  33,
"# Comparison of 3 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id1.bc",
"# with 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with a 25.000000000000 second (0:00:00:25.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# including differences in angular velocities relative to 'to' frames.",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.0943951023932E+00      +1.0471975511966E+00",
"  Angular Velocity (rad/s):   +1.7453292519943E-02      +8.7266462599716E-03"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t basic, comparison,  no AVs',
  'success',
  $frmdiff,
  '-t basic -k frmdiff_mk.tm -n 4 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 PHX_PAYLOAD -t2 PHX_LANDER frmdiff_ck_cov3_id1.bc frmdiff_ck_cov3_id2.bc',
  30,
"# Comparison of 3 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id1.bc",
"# with 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with a 25.000000000000 second (0:00:00:25.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"Absolute difference magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.0943951023932E+00      +1.0471975511966E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t basic, sampling, with AVs',
  'success',
  $frmdiff,
  '-t basic -a yes -m to -k frmdiff_mk.tm -n 4 frmdiff_ck_cov3_id2.bc',
  25,
"# Sampling of 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with a 25.000000000000 second (0:00:00:25.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# including angular velocities relative to 'to' frame.",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.0943951023932E+00      +1.0471975511966E+00",
"  Angular Velocity (rad/s):   +1.7453292519943E-02      +8.7266462599716E-03"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t basic, sampling,  no AVs',
  'success',
  $frmdiff,
  '-t basic -k frmdiff_mk.tm -n 4 frmdiff_ck_cov3_id2.bc',
  22,
"# Sampling of 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with a 25.000000000000 second (0:00:00:25.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"Absolute magnitudes:",
"                                     maximum                 average",
"  Rotation (rad):             +2.0943951023932E+00      +1.0471975511966E+00"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t stats, comparison, with AVs',
  'success',
  $frmdiff,
  '-t stats -a yes -m to -k frmdiff_mk.tm -n 4 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 PHX_PAYLOAD -t2 PHX_LANDER frmdiff_ck_cov3_id1.bc frmdiff_ck_cov3_id2.bc',
  57,
"# Comparison of 3 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id1.bc",
"# with 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with a 25.000000000000 second (0:00:00:25.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# including differences in angular velocities relative to 'to' frames.",
"1) Average difference",
"   1a) Rotation (rad):                               1.0471975511966",
"   1b) Angular velocity (rad/s):                     0.0087266462599716",
"2) RMS of difference",
"   2a) Rotation (rad):                               1.3519262253245",
"   2b) Angular velocity (rad/s):                     0.011266051877704",
"3) Maximum rotation difference",
"   3a) Rotation (rad):                               2.0943951023932",
"   3b) Epoch (TDB, seconds past J2000):              250000200.00000",
"   3c) Epoch (TDB, calendar format):                 2007-DEC-04-00:30:00.000",
"4) Maximum angular velocity difference",
"   4a) Angular velocity (rad/s):                     0.017453292519943",
"   4b) Epoch (TDB, seconds past J2000):              250000200.00000",
"   4c) Epoch (TDB, calendar format):                 2007-DEC-04-00:30:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t stats, comparison, no AVs',
  'success',
  $frmdiff,
  '-t stats -k frmdiff_mk.tm -n 4 -f1 PHX_LL -t1 PHX_PAYLOAD -f2 PHX_PAYLOAD -t2 PHX_LANDER frmdiff_ck_cov3_id1.bc frmdiff_ck_cov3_id2.bc',
  42,
"# Comparison of 3 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id1.bc",
"# with 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with a 25.000000000000 second (0:00:00:25.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"1) Average difference",
"   1a) Rotation (rad):                               1.0471975511966",
"2) RMS of difference",
"   2a) Rotation (rad):                               1.3519262253245",
"3) Maximum rotation difference",
"   3a) Rotation (rad):                               2.0943951023932",
"   3b) Epoch (TDB, seconds past J2000):              250000200.00000",
"   3c) Epoch (TDB, calendar format):                 2007-DEC-04-00:30:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t stats, sampling, with AVs',
  'success',
  $frmdiff,
  '-t stats -a yes -m to -k frmdiff_mk.tm -n 4 frmdiff_ck_cov3_id2.bc',
  49,
"# Sampling of 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with a 25.000000000000 second (0:00:00:25.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"# including angular velocities relative to 'to' frame.",
"1) Average",
"   1a) Rotation (rad):                               1.0471975511966",
"   1b) Angular velocity (rad/s):                     0.0087266462599716",
"2) RMS of",
"   2a) Rotation (rad):                               1.3519262253245",
"   2b) Angular velocity (rad/s):                     0.011266051877704",
"3) Maximum rotation",
"   3a) Rotation (rad):                               2.0943951023932",
"   3b) Epoch (TDB, seconds past J2000):              250000200.00000",
"   3c) Epoch (TDB, calendar format):                 2007-DEC-04-00:30:00.000",
"4) Maximum angular velocity",
"   4a) Angular velocity (rad/s):                     0.017453292519943",
"   4b) Epoch (TDB, seconds past J2000):              250000200.00000",
"   4c) Epoch (TDB, calendar format):                 2007-DEC-04-00:30:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-t stats, sampling, no AVs',
  'success',
  $frmdiff,
  '-t stats -k frmdiff_mk.tm -n 4 frmdiff_ck_cov3_id2.bc',
  34,
"# Sampling of 3 rotations",
"#    from 'PHX_PAYLOAD' (-84100) to 'PHX_LANDER' (-84001)",
"#    computed using",
"#       frmdiff_mk.tm",
"#       frmdiff_ck_cov3_id2.bc",
"# with a 25.000000000000 second (0:00:00:25.000000) step size",
"# within the continuous time period",
"#    from '2007 DEC 04 00:29:10.000' TDB (250000150.00000 TDB seconds)",
"#    to   '2007 DEC 04 00:30:00.000' TDB (250000200.00000 TDB seconds)",
"1) Average",
"   1a) Rotation (rad):                               1.0471975511966",
"2) RMS of",
"   2a) Rotation (rad):                               1.3519262253245",
"3) Maximum rotation",
"   3a) Rotation (rad):                               2.0943951023932",
"   3b) Epoch (TDB, seconds past J2000):              250000200.00000",
"   3c) Epoch (TDB, calendar format):                 2007-DEC-04-00:30:00.000"
);

&run_test (
  $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
  '-f sclkd, multi-field clock',
  'success',
  $frmdiff,
  '-f sclkd -t dumpea -k frmdiff_lsk.tls frmdiff_fk.tf frmdiff_sclk_3fields.tsc frmdiff_pck.tpc -n 5 frmdiff_ck_cov1_id1.bc',
  24,
"# Sampling of 4 rotations",
"#    from 'PHX_LL' (-84903) to 'PHX_PAYLOAD' (-84100)",
"#    computed using",
"#       frmdiff_lsk.tls frmdiff_fk.tf frmdiff_sclk_3fields.tsc frmdiff_pck.tpc",
"#       frmdiff_ck_cov1_id1.bc",
"# with a 0.033333333?????? second (0:00:00:00.033333) step size",
"# within the continuous time period",
"#    from '2000 JAN 04 09:26:40.000' TDB (250000.00000000 TDB seconds)",
"#    to   '2000 JAN 04 09:26:40.099' TDB (250000.10000000 TDB seconds)",
"# angles are shown in radians.",
"# time, ang3_about_Z, ang2_about_Y, ang1_about_X",
"2.5000000000000E+05 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
"2.5000003333300E+05 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
"2.5000006666700E+05 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00",
"2.5000010000000E+05 +0.0000000000000E+00 +0.0000000000000E+00 +0.0000000000000E+00"
);


#
# Delete test data
#
print "\n";
print "Deleting test data ...\n";
print "\n";
&test_data( $msopck, $tobin, "delete" );

#
# All done.
#
print "\n";
print "Total: $counttotal --- Passed: $countpass  --- Failed: $countfail\n";
print "\n";

exit;

#
# This routine runs the specified test and prints results to the screen.
#
sub run_test {

  #
  # All argument are inputs. Output is via displaying report message to
  # the screen. Arguments are:
  #
  #    $reporttype  -- lists all types of info to be included into the report
  #                    (possible values are "command", "output", "expvalues")
  #    $maxtocompare - maximum number of characters from each @expvalue line
  #                    to check in inputs; if "", check complete lines
  #    $shortonly   -- flag indicating whether only 'SPICE(...)' line from
  #                    @expvalue should be checked in the output for 
  #                    failure-type cases; "yes" or "no"
  #    $checkcount  -- flag indicating whether the count of output lines
  #                    should be checked; "yes" or "no"
  #    $logname     -- the name of a log file, the contents of which should be
  #                    checked instead of captured STDOUT output; if "",
  #                    STDOUT is checked
  #    $testdesc    -- text line describing test
  #    $testtype    -- "success" or "failure" for expected status 0 or non 0
  #    $progname    -- name of program to run
  #    $commandline -- complete command line
  #    $expcount    -- expected count of output lines
  #    @expvalue    -- an array of strings to look for in the output.
  #                    "?" in these string stands for "any one character".
  #
  ( $reporttype, $maxtocompare, $shortonly, $checkcount, $logname,
    $testdesc,
    $testtype,
    $progname,
    $commandline,
    $expcount,
    @expvalue ) = @_;
  $infotypes = $reporttype;
  $report = "";

  $counttotal++;

  #
  # Run the test and save screen output.
  #
  $result = `$progname $commandline 2>&1`;

  #
  # Check exit status vs expected status and reflect then in the report.
  #
  $status = ( $? >> 8 );
  if (    ( ( ! $status ) && $testtype eq "success" ) ||
          ( (   $status ) && $testtype eq "failure" )    ) {
    #
    # Expected status matches returned status. Good.
    #
    $report = "";
  } elsif ( ( ! $status ) && $testtype eq "failure" ) {
    #
    # Expected failure, got success. Bad.
    #
    $report = "\n   ERROR: expected failure but returned with success.\n ";
  } elsif ( (   $status ) && $testtype eq "success" ) {
    #
    # Expected success, got failure. Bad.
    #
    $report = "\n   ERROR: expected success but returned with failure.\n ";
  }

  #
  # Check that output has expected number of lines.
  #
  if ( $checkcount eq "yes" ) {
    $rescount = 0;
    while( $result =~ m/\n/g ) {
      $rescount++;
    }
    if ( $rescount != $expcount ) {
      $report = $report.
      "\n   ERROR: expected $expcount output lines but got $rescount.\n";
    }
  }

  #
  # Check that each of expected lines is present in the output.
  #
  $checkedcount = 0;

  for ($i = 0; $i <= $#expvalue; $i++ ) {

    #
    # Take all or a part of expected value based on $maxtocompare.
    #
    if ( $maxtocompare eq "" ) {
      $shortexpvalue = $expvalue[$i];
    } else {
      $shortexpvalue = substr( $expvalue[$i], 0, $maxtocompare );
    }

    #
    # Pre-process expected value to escape all special regex characters
    # except "?" which, from this routine's point of view, stands for
    # "any one character" and, therefore, get replaced with ".".
    #
    $modexpvalue = $shortexpvalue;
    $modexpvalue =~ s/\\/\\\\/g;
    $modexpvalue =~ s/\n/\\n/g;
    $modexpvalue =~ s/\./\\./g;
    $modexpvalue =~ s/\^/\\^/g;
    $modexpvalue =~ s/\$/\\\$/g;
    $modexpvalue =~ s/\*/\\*/g;
    $modexpvalue =~ s/\+/\\+/g;
    $modexpvalue =~ s/\{/\\{/g;
    $modexpvalue =~ s/\}/\\}/g;
    $modexpvalue =~ s/\[/\\[/g;
    $modexpvalue =~ s/\]/\\]/g;
    $modexpvalue =~ s/\(/\\(/g;
    $modexpvalue =~ s/\)/\\)/g;
    $modexpvalue =~ s/\|/\\|/g;

    $modexpvalue =~ s/\?/\./g;

    #
    # Check if the output contained expected string. First, make an exception
    # for failure-type runs checking only short error messages.
    #
    if ( $testtype  eq "failure" &&
         $shortonly eq "yes"     &&
         ! ( $shortexpvalue =~ /^SPICE\(.+\)$/ ) ) {

      #
      # Don't check this line because it is not a short error message.
      #

    } else {

      if ( $result =~ /$modexpvalue/ ) {

	#
	# Expected string is present in the output. Good.
	#

      } else {

	#
	# Expected string is NOT present in the output. Bad.
	#
	$report = $report.
	 "\n   ERROR: expected string '$shortexpvalue' was not in the output.\n";

      }

      $checkedcount++;

    }

  }

  #
  # Safety belt against poor test setups: verify that we checked at
  # least one line.
  #
  if ( $checkedcount == "0" ) {
    $report = $report.
      "\n   ERROR: bad test case setup: no lines from expected values were checked.\n";
  }

  #
  # Finalize report.
  #
  if ( $report eq "" ) {

    $countpass++;
    $report = "--- passed --- ($testtype) $testdesc\n";

  } else {

    $countfail++;
    $report = "\n".
              "--- FAILED --- ($testtype) $testdesc\n".
              "$report";

    $infotypes = "command output expvalues";

  }

  #
  # Add additonal information to the report as needed.
  #
  if ( $infotypes =~ /command/ ) {
    $report = "$report".
              "\n".
              "   COMMAND --- \n".
              "\n".
              "$progname $commandline\n".
              "\n";
  }

  if ( $infotypes =~ /output/ ) {
    $report = "$report".
              "\n".
              "   OUTPUT --- \n".
              "\n".
              "$result\n".
              "\n";
  }

  if ( $infotypes =~ /expvalues/ ) {
    $report = "$report".
              "\n".
              "   EXPECTED VALUES --- \n".
              "\n";

    for ($i = 0; $i <= $#expvalue; $i++ ) {
      if ( $maxtocompare eq "" ) {
	$report = "$report".
	          "$expvalue[$i]\n";
      } else {
	$report = "$report".
	          substr( $expvalue[$i], 0, $maxtocompare )."\n";
      }
    }
    $report = "$report\n";
  }

  #
  # Display report.
  #
  print $report;

}

#
# This routine generates all necessary kernels.
#
sub test_data {

  #
  # The only inputs are MSOPCK and TOBIN exe locations and action
  # ("make" or "delete"). Outputs are files needed for the test.
  #
  ( $msopck, $tobin, $action ) = @_;
  $myaction = $action;

  #
  # The following files will be made
  #
  #    naif0008.tls --- LSK
  #
  #    frmdiff_sc_1seg.bsp --- SPK with ...
  #
  #
  # LSK and any other text kernels that are needed should be at the
  # top of the list to be made first):
  #
  @files = (
	     "frmdiff_t.txt",
	     "frmdiff_lsk.tls",
	     "frmdiff_pck.tpc",
	     "frmdiff_fk.tf",
	     "frmdiff_ik.ti",
	     "frmdiff_fk_no_kpl.tf",
	     "frmdiff_sclk.tsc",
	     "frmdiff_sclk_tdt.tsc",
	     "frmdiff_sclk_too_few_offsets.tsc",
	     "frmdiff_sclk_id3.tsc",
	     "frmdiff_sclk_3fields.tsc",
	     "frmdiff_mk.tm",
	     "frmdiff_mk_no_sclk.tm",
	     "frmdiff_pck_cov12_id12.bpc",
	     "frmdiff_pck_cov13_id12.bpc",
	     "frmdiff_pck_cov1_id1.bpc",
	     "frmdiff_pck_cov1_id2.bpc",
	     "frmdiff_pck_cov2_id1.bpc",
	     "frmdiff_pck_cov2_id2.bpc",
	     "frmdiff_pck_cov3_id1.bpc",
	     "frmdiff_pck_cov3_id2.bpc",
	     "frmdiff_pck_no_seg.bpc",
	     "frmdiff_pck_unk_obj.bpc",
	     "frmdiff_pck_unk_ref.bpc",
	     "frmdiff_spk.bsp",
	     "frmdiff_ek.bes",
	     "frmdiff_ck_no_seg.bc",
	     "frmdiff_ck_cov1_id1.xc",
	     "frmdiff_pck_cov1_id1.xpc",
	     "frmdiff_spk.xsp",
	     "frmdiff_ck_cov1_id1.bc",
	     "frmdiff_ck_cov2_id1.bc",
	     "frmdiff_ck_cov3_id1.bc",
	     "frmdiff_ck_cov4_id1.bc",
	     "frmdiff_ck_cov5_id1.bc",
	     "frmdiff_ck_cov6_id1.bc",
	     "frmdiff_ck_cov7_id1.bc",
	     "frmdiff_ck_cov1_id2.bc",
	     "frmdiff_ck_cov2_id2.bc",
	     "frmdiff_ck_cov3_id2.bc",
	     "frmdiff_ck_cov1_id3.bc",
	     "frmdiff_ck_discrete.bc",
	     "frmdiff_ck_cov12_id12.bc",
	     "frmdiff_ck_cov13_id12.bc",
	     "frmdiff_ck_cov13_id1.bc",
	     "frmdiff_ck_cov134_id1.bc",
             "frmdiff_ck_cov1_id1_no_av.bc"
           );

  #
  # Loop through the file list.
  #
  foreach $file ( @files ) {

    #
    # Check if there is anything to be done for this file. Report if
    # there is.
    #
    $myaction = $action;
    if (      (   -e $file && $myaction eq "make"   ) ) {
      print "--- no need to make existing $file ... \n";
      $myaction = "do nothing";
    } elsif ( ( ! -e $file && $myaction eq "delete" )   ) {
      print "--- no need to delete non-existing $file ... \n";
      $myaction = "do nothing";
    } elsif ( ( ! -e $file && $myaction eq "make"   ) ) {
      print "--- creating $file ...\n";
    } elsif ( (   -e $file && $myaction eq "delete" ) ) {
      print "--- deleting $file ...\n";
    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_lsk.tls" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_lsk.tls" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
KPL/LSK

\\begindata

DELTET/DELTA_T_A       =   32.184
DELTET/K               =    1.657D-3
DELTET/EB              =    1.671D-2
DELTET/M               = (  6.239996D0   1.99096871D-7 )

DELTET/DELTA_AT        = ( 10,   \@1972-JAN-1
                           11,   \@1972-JUL-1
                           12,   \@1973-JAN-1
                           13,   \@1974-JAN-1
                           14,   \@1975-JAN-1
                           15,   \@1976-JAN-1
                           16,   \@1977-JAN-1
                           17,   \@1978-JAN-1
                           18,   \@1979-JAN-1
                           19,   \@1980-JAN-1
                           20,   \@1981-JUL-1
                           21,   \@1982-JUL-1
                           22,   \@1983-JUL-1
                           23,   \@1985-JUL-1
                           24,   \@1988-JAN-1
                           25,   \@1990-JAN-1
                           26,   \@1991-JAN-1
                           27,   \@1992-JUL-1
                           28,   \@1993-JUL-1
                           29,   \@1994-JUL-1
                           30,   \@1996-JAN-1
                           31,   \@1997-JUL-1
                           32,   \@1999-JAN-1
                           33,   \@2006-JAN-1 )


\\begintext
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_t.txt" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_t.txt" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;

   FRMDIFF provides a simple way of sampling orientation of a frame or
   comparing orientations of two frames known to SPICE and supported by
   data from SPICE kernels.

   To compare orientations the program computes a set of
   transformations from one frame to another frame over an interval of
   time with a fixed or variable time step using one set of kernels,
   computes a set of transformations for the same or a different
   from/to frame combination at the same times using the same or a
   different set of kernels, and then computes difference in rotation
   and angular velocity between corresponding transformations.
   Depending on the requested type of output report the program prints
   to the screen only maximum differences in rotation and angular
   velocity, or a complete table of rotation and angular velocity
   differences expressed as matrices, quaternions, or Euler angles, or
   results of a simple statistical analysis of the rotation
   differences.

   To sample orientation the program computes a set of transformations
   from one frame to another frame over an interval of time with fixed
   or variable time step using a given set of kernel files. Then,
   depending on type of output report, it prints to the screen a table
   containing these transformations represented as rotations expressed
   as quaternions, matrices or Euler angles and angular velocities, or
   only magnitude of the maximum rotation and angular velocity, or
   results of a simple statistical analysis of rotations.

EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_pck.tpc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_pck.tpc" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
KPL/PCK

\\begindata

BODY499_POLE_RA          = (  317.68143   -0.1061      0.  )
BODY499_POLE_DEC         = (   52.88650   -0.0609      0.  )
BODY499_PM               = (  176.630    350.89198226  0.  )

\\begintext
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_fk.tf" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_fk.tf" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
KPL/FK

\\begindata

FRAME_PHX_TOPO              = -84900
FRAME_-84900_NAME           = 'PHX_TOPO'
FRAME_-84900_CLASS          =  4
FRAME_-84900_CLASS_ID       =  -84900
FRAME_-84900_CENTER         =  -84900
TKFRAME_-84900_RELATIVE     = 'IAU_MARS'
TKFRAME_-84900_SPEC         = 'ANGLES'
TKFRAME_-84900_UNITS        = 'DEGREES'
TKFRAME_-84900_AXES         = (    3,   2,   3 )
TKFRAME_-84900_ANGLES       = ( -234.24871, -21.549327, 180.000 )

FRAME_PHX_LL                =  -84903
FRAME_-84903_NAME           = 'PHX_LL'
FRAME_-84903_CLASS          =  4
FRAME_-84903_CLASS_ID       =  -84903
FRAME_-84903_CENTER         =  -84
TKFRAME_-84903_RELATIVE     = 'PHX_TOPO'
TKFRAME_-84903_SPEC         = 'ANGLES'
TKFRAME_-84903_UNITS        = 'DEGREES'
TKFRAME_-84903_AXES         = (   1,  2,  3 )
TKFRAME_-84903_ANGLES       = ( 180,  0,  0 )

FRAME_PHX_LANDER            = -84001
FRAME_-84001_NAME           = 'PHX_LANDER'
FRAME_-84001_CLASS          =  3
FRAME_-84001_CLASS_ID       = -84001
FRAME_-84001_CENTER         = -84
CK_-84001_SCLK              = -84
CK_-84001_SPK               = -84

FRAME_PHX_PAYLOAD           = -84100
FRAME_-84100_NAME           = 'PHX_PAYLOAD'
FRAME_-84100_CLASS          =  3
FRAME_-84100_CLASS_ID       = -84100
FRAME_-84100_CENTER         = -84
CK_-84100_SCLK              = -84
CK_-84100_SPK               = -84

FRAME_PHX_TOPO_R            =  -84905
FRAME_-84905_NAME           = 'PHX_TOPO_R'
FRAME_-84905_CLASS          =  5
FRAME_-84905_CLASS_ID       =  -84905
FRAME_-84905_CENTER         =  -84900
FRAME_-84905_RELATIVE       = 'J2000'
FRAME_-84905_DEF_STYLE      = 'PARAMETERIZED'
FRAME_-84905_FAMILY         = 'TWO-VECTOR'
FRAME_-84905_PRI_AXIS       = 'Z'
FRAME_-84905_PRI_VECTOR_DEF = 'OBSERVER_TARGET_POSITION'
FRAME_-84905_PRI_OBSERVER   = 'MARS'
FRAME_-84905_PRI_TARGET     = '-84900'
FRAME_-84905_PRI_ABCORR     = 'NONE'
FRAME_-84905_SEC_AXIS       = 'X'
FRAME_-84905_SEC_VECTOR_DEF = 'CONSTANT'
FRAME_-84905_SEC_FRAME      = 'IAU_MARS'
FRAME_-84905_SEC_SPEC       = 'RECTANGULAR'
FRAME_-84905_SEC_VECTOR     =  ( 0, 0, 1 )

FRAME_PCK3001               = 3001
FRAME_3001_NAME             = 'PCK3001'
FRAME_3001_CLASS            = 2
FRAME_3001_CLASS_ID         = 3001
FRAME_3001_CENTER           = 399

FRAME_FIXED3002             =  3002
FRAME_3002_NAME             = 'FIXED3002'
FRAME_3002_CLASS            =  4
FRAME_3002_CLASS_ID         =  3002
FRAME_3002_CENTER           =  399
TKFRAME_3002_RELATIVE       = 'ITRF93'
TKFRAME_3002_SPEC           = 'ANGLES'
TKFRAME_3002_UNITS          = 'DEGREES'
TKFRAME_3002_AXES           = (   1,  2,  3 )
TKFRAME_3002_ANGLES         = (   0,  0,  0 )

\\begintext
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_ik.ti" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_ik.ti" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
KPL/IK

\\begindata

FRAME_PHX_TOPO              = -84900
FRAME_-84900_NAME           = 'PHX_TOPO'
FRAME_-84900_CLASS          =  4
FRAME_-84900_CLASS_ID       =  -84900
FRAME_-84900_CENTER         =  -84900
TKFRAME_-84900_RELATIVE     = 'IAU_MARS'
TKFRAME_-84900_SPEC         = 'ANGLES'
TKFRAME_-84900_UNITS        = 'DEGREES'
TKFRAME_-84900_AXES         = (    3,   2,   3 )
TKFRAME_-84900_ANGLES       = ( -234.24871, -21.549327, 180.000 )

FRAME_PHX_LL                =  -84903
FRAME_-84903_NAME           = 'PHX_LL'
FRAME_-84903_CLASS          =  4
FRAME_-84903_CLASS_ID       =  -84903
FRAME_-84903_CENTER         =  -84
TKFRAME_-84903_RELATIVE     = 'PHX_TOPO'
TKFRAME_-84903_SPEC         = 'ANGLES'
TKFRAME_-84903_UNITS        = 'DEGREES'
TKFRAME_-84903_AXES         = (   1,  2,  3 )
TKFRAME_-84903_ANGLES       = ( 180,  0,  0 )

FRAME_PHX_LANDER            = -84001
FRAME_-84001_NAME           = 'PHX_LANDER'
FRAME_-84001_CLASS          =  3
FRAME_-84001_CLASS_ID       = -84001
FRAME_-84001_CENTER         = -84
CK_-84001_SCLK              = -84
CK_-84001_SPK               = -84

FRAME_PHX_PAYLOAD           = -84100
FRAME_-84100_NAME           = 'PHX_PAYLOAD'
FRAME_-84100_CLASS          =  3
FRAME_-84100_CLASS_ID       = -84100
FRAME_-84100_CENTER         = -84
CK_-84100_SCLK              = -84
CK_-84100_SPK               = -84

FRAME_PHX_TOPO_R            =  -84905
FRAME_-84905_NAME           = 'PHX_TOPO_R'
FRAME_-84905_CLASS          =  5
FRAME_-84905_CLASS_ID       =  -84905
FRAME_-84905_CENTER         =  -84900
FRAME_-84905_RELATIVE       = 'J2000'
FRAME_-84905_DEF_STYLE      = 'PARAMETERIZED'
FRAME_-84905_FAMILY         = 'TWO-VECTOR'
FRAME_-84905_PRI_AXIS       = 'Z'
FRAME_-84905_PRI_VECTOR_DEF = 'OBSERVER_TARGET_POSITION'
FRAME_-84905_PRI_OBSERVER   = 'MARS'
FRAME_-84905_PRI_TARGET     = '-84900'
FRAME_-84905_PRI_ABCORR     = 'NONE'
FRAME_-84905_SEC_AXIS       = 'X'
FRAME_-84905_SEC_VECTOR_DEF = 'CONSTANT'
FRAME_-84905_SEC_FRAME      = 'IAU_MARS'
FRAME_-84905_SEC_SPEC       = 'RECTANGULAR'
FRAME_-84905_SEC_VECTOR     =  ( 0, 0, 1 )

\\begintext
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_fk_no_kpl.tf" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_fk_no_kpl.tf" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;

\\begindata

FRAME_PHX_TOPO             = -84900
FRAME_-84900_NAME           = 'PHX_TOPO'
FRAME_-84900_CLASS          =  4
FRAME_-84900_CLASS_ID       =  -84900
FRAME_-84900_CENTER         =  -84900

TKFRAME_-84900_RELATIVE     = 'IAU_MARS'
TKFRAME_-84900_SPEC         = 'ANGLES'
TKFRAME_-84900_UNITS        = 'DEGREES'
TKFRAME_-84900_AXES         = ( 3, 2, 3 )
TKFRAME_-84900_ANGLES       = ( -130, -22.261561, 180.000  )

\\begintext

\\begindata

NAIF_BODY_NAME += ( 'PHX' )
NAIF_BODY_CODE += ( -84 )

NAIF_BODY_NAME += ( 'PHX_LANDING_SITE' )
NAIF_BODY_CODE += ( -84900 )

\\begintext
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_sclk.tsc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_sclk.tsc" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
KPL/SCLK

   \\begindata

      SCLK_KERNEL_ID                = (  \@20-JUL-2008     )

      SCLK_DATA_TYPE_84             = (                 1 )

      SCLK01_TIME_SYSTEM_84         = (                 1 )
      SCLK01_N_FIELDS_84            = (                 2 )
      SCLK01_MODULI_84              = ( 10000000000  1000 )
      SCLK01_OFFSETS_84             = (           0     0 )
      SCLK01_OUTPUT_DELIM_84        = (                 1 )

      SCLK_PARTITION_START_84       = ( 0.0000000000000E+00 )
      SCLK_PARTITION_END_84         = ( 1.00000000E+14      )
      SCLK01_COEFFICIENTS_84        = ( 0.00000000E+00
                                        \@01-JAN-2000-12:00:00
                                        1  )

   \\begintext
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_sclk_tdt.tsc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_sclk_tdt.tsc" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
KPL/SCLK

   \\begindata

      SCLK_KERNEL_ID                = (  \@20-JUL-2008     )

      SCLK_DATA_TYPE_84             = (                 1 )

      SCLK01_TIME_SYSTEM_84         = (                 2 )
      SCLK01_N_FIELDS_84            = (                 2 )
      SCLK01_MODULI_84              = ( 10000000000  1000 )
      SCLK01_OFFSETS_84             = (           0     0 )
      SCLK01_OUTPUT_DELIM_84        = (                 1 )

      SCLK_PARTITION_START_84       = ( 0.0000000000000E+00 )
      SCLK_PARTITION_END_84         = ( 1.00000000E+14      )
      SCLK01_COEFFICIENTS_84        = ( 0.00000000E+00
                                        \@01-JAN-2000-12:00:00
                                        1  )

   \\begintext
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_sclk_too_few_offsets.tsc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_sclk_too_few_offsets.tsc" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
KPL/SCLK

   \\begindata

      SCLK_KERNEL_ID                = (  \@20-JUL-2008     )

      SCLK_DATA_TYPE_84             = (                 1 )

      SCLK01_TIME_SYSTEM_84         = (                 1 )
      SCLK01_N_FIELDS_84            = (                 2 )
      SCLK01_MODULI_84              = ( 10000000000  1000 )
      SCLK01_OFFSETS_84             = (           0       )
      SCLK01_OUTPUT_DELIM_84        = (                 1 )

      SCLK_PARTITION_START_84       = ( 0.0000000000000E+00 )
      SCLK_PARTITION_END_84         = ( 1.00000000E+14      )
      SCLK01_COEFFICIENTS_84        = ( 0.00000000E+00
                                        \@01-JAN-2000-12:00:00
                                        1  )

   \\begintext
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_sclk_id3.tsc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_sclk_id3.tsc" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
KPL/SCLK

   \\begindata

      SCLK_KERNEL_ID                = (  \@20-JUL-2008     )

      SCLK_DATA_TYPE_85             = (                 1 )

      SCLK01_TIME_SYSTEM_85         = (                 1 )
      SCLK01_N_FIELDS_85            = (                 2 )
      SCLK01_MODULI_85              = ( 10000000000  1000 )
      SCLK01_OFFSETS_85             = (           0     0 )
      SCLK01_OUTPUT_DELIM_85        = (                 1 )

      SCLK_PARTITION_START_85       = ( 0.0000000000000E+00 )
      SCLK_PARTITION_END_85         = ( 1.00000000E+14      )
      SCLK01_COEFFICIENTS_85        = ( 0.00000000E+00
                                        \@01-JAN-2000-12:00:10
                                        1  )

   \\begintext
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_sclk_3fields.tsc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_sclk_3fields.tsc" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
KPL/SCLK

   \\begindata

      SCLK_KERNEL_ID                = (  \@20-JUL-2008     )

      SCLK_DATA_TYPE_84             = (                  1 )

      SCLK01_TIME_SYSTEM_84         = (                  1 )
      SCLK01_N_FIELDS_84            = (                  3 )
      SCLK01_MODULI_84              = ( 10000000 1000 1000 )
      SCLK01_OFFSETS_84             = (        0    0    0 )
      SCLK01_OUTPUT_DELIM_84        = (                  1 )

      SCLK_PARTITION_START_84       = ( 0.0000000000000E+00 )
      SCLK_PARTITION_END_84         = ( 1.00000000E+14      )
      SCLK01_COEFFICIENTS_84        = ( 0.00000000E+00
                                        \@01-JAN-2000-12:00:00
                                        1  )

   \\begintext
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_mk.tm" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_mk.tm" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
KPL/MK

\\begindata

KERNELS_TO_LOAD = (
'frmdiff_lsk.tls',
'frmdiff_pck.tpc',
'frmdiff_fk.tf',
'frmdiff_sclk.tsc'
)

\\begintext
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_mk_no_sclk.tm" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_mk_no_sclk.tm" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
KPL/MK

\\begindata

KERNELS_TO_LOAD = (
'frmdiff_lsk.tls',
'frmdiff_pck.tpc',
'frmdiff_fk.tf'
)

\\begintext
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_pck_cov12_id12.bpc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_pck_cov12_id12.bpc" && $myaction eq "make" ) {

      $xfrfile = $file;
      $xfrfile =~ s/\.bpc$/.xfr/;

      open ( OUTPUT, ">$xfrfile" ) || die "ERROR: cannot open $xfrfile.\n";
      print OUTPUT <<EndBlock;
DAFETF NAIF DAF ENCODED TRANSFER FILE
'DAF/PCK '
'2'
'5'
' < DAFCAT: PCK CONCATENATION >                              '
BEGIN_ARRAY 1 69
'Earth PCK, ITRF93 Frame                 '
'EE6B28^7'
'EE6B2E4^7'
'BB8'
'11'
'2'
69
'EE6B2B2^7'
'32^2'
'323BE870C24D1E^1'
'DA1A871E0CCCD^-7'
'-8FC2BDFAE147B^-9'
'-8101C28F5C28F8^-C'
'-1CCE147AE147AE^-C'
'-A028F5C28F5C28^-E'
'-1369999999999A^-C'
'F78F5C28F5C29^-D'
'-11928F5C28F5C3^-C'
'4EC6B851EB852^-C'
'-7944F5C28F5C28^-C'
'D73D70A3D70A4^-D'
'F84CCCCCCCCCD^-D'
'3B7570A3D70A3E^-C'
'-24D30A3D70A3D8^-C'
'6E947AE147AE14^-D'
'-16270A3D70A3D7^-C'
'B8F851EB851EB8^-D'
'-119EB851EB851F^-C'
'-CE1A3D70A3D708^-C'
'1E5ED99999999A^-B'
'68BCC71E96F3^0'
'-FBE53FB0061478^-7'
'-15D4FC4C7AE148^-9'
'8FEF28F5C28F6^-C'
'-D633333333333^-E'
'-1D5A3D70A3D70A^-D'
'-350F0A3D70A3D8^-D'
'65A66666666668^-D'
'FF47AE147AE148^-E'
'8288A3D70A3D7^-D'
'-C754CCCCCCCCD^-D'
'-D79EB851EB852^-E'
'2E751EB851EB86^-D'
'A7A66666666668^-D'
'-3C3CCCCCCCCCCC^-D'
'-522E147AE147B^-E'
'-54A7AE147AE148^-D'
'2E76147AE147AE^-D'
'16F2E147AE147B^-D'
'-1B6D5C28F5C28F^-C'
'42881EB851EB84^-C'
'485766AF246CCC^1'
'EEF2A5445E785^-2'
'7F545CFAE147B^-9'
'-2D3A8666666666^-A'
'-117A6C28F5C28F^-A'
'6B87B5C28F5C28^-A'
'-B35FB33333333^-B'
'-49CD8EB851EB84^-A'
'-839BD428F5C29^-A'
'47081666666668^-A'
'DC7FFAE147AE18^-B'
'-4ED4E999999998^-A'
'6E52A3D70A3D7^-A'
'-63DED1EB851EB8^-B'
'-2F09EDC28F5C28^-A'
'3EEF6A3D70A3D8^-A'
'-5E02451EB851EC^-A'
'-17AA07D70A3D71^-A'
'-3FDB787AE147AE^-A'
'-37764BAE147AE2^-A'
'A47A570A3D70A^-B'
'EE6B28^7'
'64^2'
'41^2'
'1^1'
END_ARRAY 1 69
BEGIN_ARRAY 2 69
'Earth PCK, ITRF93 Frame                 '
'EE6B2CB^7'
'EE6B32F^7'
'18F'
'11'
'2'
69
'EE6B2FD^7'
'32^2'
'323BE87206ED66^1'
'D6BB174EBD70A^-7'
'-90109AA6666668^-9'
'-6F173333333334^-C'
'-11CC28F5C28F5C^-C'
'C128F5C28F5C28^-D'
'-1059C28F5C28F6^-C'
'D233333333333^-D'
'-12EB5C28F5C28F^-C'
'570947AE147AE^-C'
'-6E5428F5C28F5C^-C'
'D8C7AE147AE148^-D'
'12DC7AE147AE14^-C'
'3ECDC28F5C28F6^-C'
'-2E16147AE147AE^-C'
'EC428F5C28F5C^-D'
'-15CCCCCCCCCCCD^-C'
'A62B851EB851E8^-D'
'-B5F5C28F5C28F8^-D'
'-D4D75C28F5C29^-C'
'1E4A8A3D70A3D7^-B'
'68BCC706F35B38^0'
'-FC674BCA8CCCD^-7'
'-1584AEE999999A^-9'
'92D0851EB851E8^-C'
'-1AA6147AE147AE^-D'
'C047AE147AE148^-E'
'-1A1BD70A3D70A4^-D'
'-1D2EB851EB851F^-D'
'-74FA3D70A3D70C^-D'
'A96947AE147AE^-D'
'-F4A147AE147AE^-D'
'591E6666666668^-D'
'1D6^-D'
'70C1EB851EB85^-D'
'-5997AE147AE148^-D'
'1B3A3D70A3D70A^-D'
'-4BE6147AE147B^-D'
'422C28F5C28F5C^-D'
'-7ACA3D70A3D70C^-D'
'-1CACCCCCCCCCCD^-C'
'40500A3D70A3D8^-C'
'486DCD6EA5235C^1'
'EEF2A5766AA828^-2'
'78ED270A3D70A4^-9'
'-D56FA9EB851EB8^-A'
'-3BA82B851EB852^-A'
'-67EF1^-A'
'-80219EB851EB88^-B'
'59BB9333333334^-A'
'265B88F5C28F5C^-A'
'10F5EFA8F5C28F^-9'
'4E19^-B'
'-132E070A3D70A4^-A'
'-388A4333333334^-A'
'-90A5A47AE147B^-A'
'-7D403333333334^-B'
'5641D4CCCCCCCC^-A'
'1D5F3CA3D70A3D^-A'
'70C58170A3D70C^-A'
'3AE7B333333334^-B'
'-28BA351EB851EC^-A'
'25916828F5C29^-A'
'EE6B2CB^7'
'64^2'
'41^2'
'1^1'
END_ARRAY 2 69
TOTAL_ARRAYS 2
 ~NAIF/SPC BEGIN COMMENTS~
 ~NAIF/SPC END COMMENTS~
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $xfrfile.\n";

      $result = `$tobin $xfrfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: TOBIN failed. Error was: $result\n";
      }

      unlink( "$xfrfile" ) || die "ERROR: cannot delete $xfrfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_pck_cov13_id12.bpc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_pck_cov13_id12.bpc" && $myaction eq "make" ) {

      $xfrfile = $file;
      $xfrfile =~ s/\.bpc$/.xfr/;

      open ( OUTPUT, ">$xfrfile" ) || die "ERROR: cannot open $xfrfile.\n";
      print OUTPUT <<EndBlock;
DAFETF NAIF DAF ENCODED TRANSFER FILE
'DAF/PCK '
'2'
'5'
' < DAFCAT: PCK CONCATENATION >                              '
BEGIN_ARRAY 1 69
'Earth PCK, ITRF93 Frame                 '
'EE6B28^7'
'EE6B2E4^7'
'BB8'
'11'
'2'
69
'EE6B2B2^7'
'32^2'
'323BE870C24D1E^1'
'DA1A871E0CCCD^-7'
'-8FC2BDFAE147B^-9'
'-8101C28F5C28F8^-C'
'-1CCE147AE147AE^-C'
'-A028F5C28F5C28^-E'
'-1369999999999A^-C'
'F78F5C28F5C29^-D'
'-11928F5C28F5C3^-C'
'4EC6B851EB852^-C'
'-7944F5C28F5C28^-C'
'D73D70A3D70A4^-D'
'F84CCCCCCCCCD^-D'
'3B7570A3D70A3E^-C'
'-24D30A3D70A3D8^-C'
'6E947AE147AE14^-D'
'-16270A3D70A3D7^-C'
'B8F851EB851EB8^-D'
'-119EB851EB851F^-C'
'-CE1A3D70A3D708^-C'
'1E5ED99999999A^-B'
'68BCC71E96F3^0'
'-FBE53FB0061478^-7'
'-15D4FC4C7AE148^-9'
'8FEF28F5C28F6^-C'
'-D633333333333^-E'
'-1D5A3D70A3D70A^-D'
'-350F0A3D70A3D8^-D'
'65A66666666668^-D'
'FF47AE147AE148^-E'
'8288A3D70A3D7^-D'
'-C754CCCCCCCCD^-D'
'-D79EB851EB852^-E'
'2E751EB851EB86^-D'
'A7A66666666668^-D'
'-3C3CCCCCCCCCCC^-D'
'-522E147AE147B^-E'
'-54A7AE147AE148^-D'
'2E76147AE147AE^-D'
'16F2E147AE147B^-D'
'-1B6D5C28F5C28F^-C'
'42881EB851EB84^-C'
'485766AF246CCC^1'
'EEF2A5445E785^-2'
'7F545CFAE147B^-9'
'-2D3A8666666666^-A'
'-117A6C28F5C28F^-A'
'6B87B5C28F5C28^-A'
'-B35FB33333333^-B'
'-49CD8EB851EB84^-A'
'-839BD428F5C29^-A'
'47081666666668^-A'
'DC7FFAE147AE18^-B'
'-4ED4E999999998^-A'
'6E52A3D70A3D7^-A'
'-63DED1EB851EB8^-B'
'-2F09EDC28F5C28^-A'
'3EEF6A3D70A3D8^-A'
'-5E02451EB851EC^-A'
'-17AA07D70A3D71^-A'
'-3FDB787AE147AE^-A'
'-37764BAE147AE2^-A'
'A47A570A3D70A^-B'
'EE6B28^7'
'64^2'
'41^2'
'1^1'
END_ARRAY 1 69
BEGIN_ARRAY 2 69
'Earth PCK, ITRF93 Frame                 '
'EE6B316^7'
'EE6B348^7'
'18F'
'11'
'2'
69
'EE6B32F^7'
'19^2'
'323BE872DCF452^1'
'6A3D4987199998^-7'
'-2410FE1C28F5C2^-9'
'17851EB851EB85^-E'
'-A2828F5C28F5C^-D'
'1D2FAE147AE148^-C'
'-127A6666666666^-C'
'11A147AE147AE1^-C'
'-A77D70A3D70A4^-D'
'556FAE147AE148^-C'
'-722F851EB851EC^-C'
'FC5EB851EB852^-D'
'E291EB851EB85^-D'
'3D5C51EB851EB8^-C'
'-2A0147AE147AE2^-C'
'E223D70A3D70A^-D'
'-17E91EB851EB85^-C'
'CA0F5C28F5C29^-D'
'-14B66666666666^-C'
'-D64147AE147AE^-C'
'1E2CA3D70A3D71^-B'
'68BCC6F72B3974^0'
'-7E5E83DF48A3D8^-7'
'-5540FF66666668^-A'
'134751EB851EB8^-C'
'-13666666666666^-D'
'C83D70A3D70A4^-E'
'3D0A3D70A3D70A^-E'
'75CCCCCCCCCCCC^-E'
'-182B851EB851EC^-D'
'D6A70A3D70A3D8^-D'
'-102E75C28F5C29^-C'
'1B1051EB851EB8^-D'
'1733D70A3D70A4^-D'
'911051EB851EB8^-D'
'-2C4A8F5C28F5C2^-D'
'1DEA8F5C28F5C3^-D'
'-E1B851EB851EB8^-E'
'41BC7AE147AE14^-D'
'-3F266666666666^-D'
'-1C21CCCCCCCCCD^-C'
'3E54B333333334^-C'
'487CBC98FD2F9^1'
'777952CAE44F28^-2'
'29272A3D70A3D8^-9'
'D0B5E5C28F5C28^-A'
'-3FC6F947AE147A^-A'
'1E82DCCCCCCCCD^-A'
'-261C5F0A3D70A4^-A'
'-48A158F5C28F5C^-A'
'-787E2570A3D70C^-A'
'48B770A3D70A3C^-A'
'169A36147AE148^-A'
'-9A23D70A3D70A^-B'
'F6EF1EB851EB88^-B'
'-1CCB4FAE147AE1^-A'
'3B52D51EB851EC^-A'
'A342523D70A3D8^-A'
'1E5BBAB851EB85^-A'
'-3E904428F5C29^-A'
'-940743D70A3D7^-A'
'1470AF851EB852^-A'
'509B7E3D70A3D8^-A'
'EE6B316^7'
'32^2'
'41^2'
'1^1'
END_ARRAY 2 69
TOTAL_ARRAYS 2
 ~NAIF/SPC BEGIN COMMENTS~
 ~NAIF/SPC END COMMENTS~
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $xfrfile.\n";

      $result = `$tobin $xfrfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: TOBIN failed. Error was: $result\n";
      }

      unlink( "$xfrfile" ) || die "ERROR: cannot delete $xfrfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_pck_cov1_id1.bpc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_pck_cov1_id1.bpc" && $myaction eq "make" ) {

      $xfrfile = $file;
      $xfrfile =~ s/\.bpc$/.xfr/;

      open ( OUTPUT, ">$xfrfile" ) || die "ERROR: cannot open $xfrfile.\n";
      print OUTPUT <<EndBlock;
DAFETF NAIF DAF ENCODED TRANSFER FILE
'DAF/PCK '
'2'
'5'
'test_pck_cov1_id1.bpc                                       '
BEGIN_ARRAY 1 69
'Earth PCK, ITRF93 Frame                 '
'EE6B28^7'
'EE6B2E4^7'
'BB8'
'11'
'2'
69
'EE6B2B2^7'
'32^2'
'323BE870C24D1E^1'
'DA1A871E0CCCD^-7'
'-8FC2BDFAE147B^-9'
'-8101C28F5C28F8^-C'
'-1CCE147AE147AE^-C'
'-A028F5C28F5C28^-E'
'-1369999999999A^-C'
'F78F5C28F5C29^-D'
'-11928F5C28F5C3^-C'
'4EC6B851EB852^-C'
'-7944F5C28F5C28^-C'
'D73D70A3D70A4^-D'
'F84CCCCCCCCCD^-D'
'3B7570A3D70A3E^-C'
'-24D30A3D70A3D8^-C'
'6E947AE147AE14^-D'
'-16270A3D70A3D7^-C'
'B8F851EB851EB8^-D'
'-119EB851EB851F^-C'
'-CE1A3D70A3D708^-C'
'1E5ED99999999A^-B'
'68BCC71E96F3^0'
'-FBE53FB0061478^-7'
'-15D4FC4C7AE148^-9'
'8FEF28F5C28F6^-C'
'-D633333333333^-E'
'-1D5A3D70A3D70A^-D'
'-350F0A3D70A3D8^-D'
'65A66666666668^-D'
'FF47AE147AE148^-E'
'8288A3D70A3D7^-D'
'-C754CCCCCCCCD^-D'
'-D79EB851EB852^-E'
'2E751EB851EB86^-D'
'A7A66666666668^-D'
'-3C3CCCCCCCCCCC^-D'
'-522E147AE147B^-E'
'-54A7AE147AE148^-D'
'2E76147AE147AE^-D'
'16F2E147AE147B^-D'
'-1B6D5C28F5C28F^-C'
'42881EB851EB84^-C'
'485766AF246CCC^1'
'EEF2A5445E785^-2'
'7F545CFAE147B^-9'
'-2D3A8666666666^-A'
'-117A6C28F5C28F^-A'
'6B87B5C28F5C28^-A'
'-B35FB33333333^-B'
'-49CD8EB851EB84^-A'
'-839BD428F5C29^-A'
'47081666666668^-A'
'DC7FFAE147AE18^-B'
'-4ED4E999999998^-A'
'6E52A3D70A3D7^-A'
'-63DED1EB851EB8^-B'
'-2F09EDC28F5C28^-A'
'3EEF6A3D70A3D8^-A'
'-5E02451EB851EC^-A'
'-17AA07D70A3D71^-A'
'-3FDB787AE147AE^-A'
'-37764BAE147AE2^-A'
'A47A570A3D70A^-B'
'EE6B28^7'
'64^2'
'41^2'
'1^1'
END_ARRAY 1 69
TOTAL_ARRAYS 1
 ~NAIF/SPC BEGIN COMMENTS~
 ~NAIF/SPC END COMMENTS~
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $xfrfile.\n";

      $result = `$tobin $xfrfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: TOBIN failed. Error was: $result\n";
      }

      unlink( "$xfrfile" ) || die "ERROR: cannot delete $xfrfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_pck_cov1_id2.bpc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_pck_cov1_id2.bpc" && $myaction eq "make" ) {

      $xfrfile = $file;
      $xfrfile =~ s/\.bpc$/.xfr/;

      open ( OUTPUT, ">$xfrfile" ) || die "ERROR: cannot open $xfrfile.\n";
      print OUTPUT <<EndBlock;
DAFETF NAIF DAF ENCODED TRANSFER FILE
'DAF/PCK '
'2'
'5'
'test_pck_cov1_id1.bpc                                       '
BEGIN_ARRAY 1 69
'Earth PCK, ITRF93 Frame                 '
'EE6B28^7'
'EE6B2E4^7'
'18F'
'11'
'2'
69
'EE6B2B2^7'
'32^2'
'323BE870C24D1E^1'
'DA1A871E0CCCD^-7'
'-8FC2BDFAE147B^-9'
'-8101C28F5C28F8^-C'
'-1CCE147AE147AE^-C'
'-A028F5C28F5C28^-E'
'-1369999999999A^-C'
'F78F5C28F5C29^-D'
'-11928F5C28F5C3^-C'
'4EC6B851EB852^-C'
'-7944F5C28F5C28^-C'
'D73D70A3D70A4^-D'
'F84CCCCCCCCCD^-D'
'3B7570A3D70A3E^-C'
'-24D30A3D70A3D8^-C'
'6E947AE147AE14^-D'
'-16270A3D70A3D7^-C'
'B8F851EB851EB8^-D'
'-119EB851EB851F^-C'
'-CE1A3D70A3D708^-C'
'1E5ED99999999A^-B'
'68BCC71E96F3^0'
'-FBE53FB0061478^-7'
'-15D4FC4C7AE148^-9'
'8FEF28F5C28F6^-C'
'-D633333333333^-E'
'-1D5A3D70A3D70A^-D'
'-350F0A3D70A3D8^-D'
'65A66666666668^-D'
'FF47AE147AE148^-E'
'8288A3D70A3D7^-D'
'-C754CCCCCCCCD^-D'
'-D79EB851EB852^-E'
'2E751EB851EB86^-D'
'A7A66666666668^-D'
'-3C3CCCCCCCCCCC^-D'
'-522E147AE147B^-E'
'-54A7AE147AE148^-D'
'2E76147AE147AE^-D'
'16F2E147AE147B^-D'
'-1B6D5C28F5C28F^-C'
'42881EB851EB84^-C'
'485766AF246CCC^1'
'EEF2A5445E785^-2'
'7F545CFAE147B^-9'
'-2D3A8666666666^-A'
'-117A6C28F5C28F^-A'
'6B87B5C28F5C28^-A'
'-B35FB33333333^-B'
'-49CD8EB851EB84^-A'
'-839BD428F5C29^-A'
'47081666666668^-A'
'DC7FFAE147AE18^-B'
'-4ED4E999999998^-A'
'6E52A3D70A3D7^-A'
'-63DED1EB851EB8^-B'
'-2F09EDC28F5C28^-A'
'3EEF6A3D70A3D8^-A'
'-5E02451EB851EC^-A'
'-17AA07D70A3D71^-A'
'-3FDB787AE147AE^-A'
'-37764BAE147AE2^-A'
'A47A570A3D70A^-B'
'EE6B28^7'
'64^2'
'41^2'
'1^1'
END_ARRAY 1 69
TOTAL_ARRAYS 1
 ~NAIF/SPC BEGIN COMMENTS~
 ~NAIF/SPC END COMMENTS~
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $xfrfile.\n";

      $result = `$tobin $xfrfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: TOBIN failed. Error was: $result\n";
      }

      unlink( "$xfrfile" ) || die "ERROR: cannot delete $xfrfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_pck_cov2_id1.bpc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_pck_cov2_id1.bpc" && $myaction eq "make" ) {

      $xfrfile = $file;
      $xfrfile =~ s/\.bpc$/.xfr/;

      open ( OUTPUT, ">$xfrfile" ) || die "ERROR: cannot open $xfrfile.\n";
      print OUTPUT <<EndBlock;
DAFETF NAIF DAF ENCODED TRANSFER FILE
'DAF/PCK '
'2'
'5'
'test_pck_cov2_id1.bpc                                       '
BEGIN_ARRAY 1 69
'Earth PCK, ITRF93 Frame                 '
'EE6B2CB^7'
'EE6B32F^7'
'BB8'
'11'
'2'
69
'EE6B2FD^7'
'32^2'
'323BE87206ED66^1'
'D6BB174EBD70A^-7'
'-90109AA6666668^-9'
'-6F173333333334^-C'
'-11CC28F5C28F5C^-C'
'C128F5C28F5C28^-D'
'-1059C28F5C28F6^-C'
'D233333333333^-D'
'-12EB5C28F5C28F^-C'
'570947AE147AE^-C'
'-6E5428F5C28F5C^-C'
'D8C7AE147AE148^-D'
'12DC7AE147AE14^-C'
'3ECDC28F5C28F6^-C'
'-2E16147AE147AE^-C'
'EC428F5C28F5C^-D'
'-15CCCCCCCCCCCD^-C'
'A62B851EB851E8^-D'
'-B5F5C28F5C28F8^-D'
'-D4D75C28F5C29^-C'
'1E4A8A3D70A3D7^-B'
'68BCC706F35B38^0'
'-FC674BCA8CCCD^-7'
'-1584AEE999999A^-9'
'92D0851EB851E8^-C'
'-1AA6147AE147AE^-D'
'C047AE147AE148^-E'
'-1A1BD70A3D70A4^-D'
'-1D2EB851EB851F^-D'
'-74FA3D70A3D70C^-D'
'A96947AE147AE^-D'
'-F4A147AE147AE^-D'
'591E6666666668^-D'
'1D6^-D'
'70C1EB851EB85^-D'
'-5997AE147AE148^-D'
'1B3A3D70A3D70A^-D'
'-4BE6147AE147B^-D'
'422C28F5C28F5C^-D'
'-7ACA3D70A3D70C^-D'
'-1CACCCCCCCCCCD^-C'
'40500A3D70A3D8^-C'
'486DCD6EA5235C^1'
'EEF2A5766AA828^-2'
'78ED270A3D70A4^-9'
'-D56FA9EB851EB8^-A'
'-3BA82B851EB852^-A'
'-67EF1^-A'
'-80219EB851EB88^-B'
'59BB9333333334^-A'
'265B88F5C28F5C^-A'
'10F5EFA8F5C28F^-9'
'4E19^-B'
'-132E070A3D70A4^-A'
'-388A4333333334^-A'
'-90A5A47AE147B^-A'
'-7D403333333334^-B'
'5641D4CCCCCCCC^-A'
'1D5F3CA3D70A3D^-A'
'70C58170A3D70C^-A'
'3AE7B333333334^-B'
'-28BA351EB851EC^-A'
'25916828F5C29^-A'
'EE6B2CB^7'
'64^2'
'41^2'
'1^1'
END_ARRAY 1 69
TOTAL_ARRAYS 1
 ~NAIF/SPC BEGIN COMMENTS~
 ~NAIF/SPC END COMMENTS~
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $xfrfile.\n";

      $result = `$tobin $xfrfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: TOBIN failed. Error was: $result\n";
      }

      unlink( "$xfrfile" ) || die "ERROR: cannot delete $xfrfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_pck_cov2_id2.bpc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_pck_cov2_id2.bpc" && $myaction eq "make" ) {

      $xfrfile = $file;
      $xfrfile =~ s/\.bpc$/.xfr/;

      open ( OUTPUT, ">$xfrfile" ) || die "ERROR: cannot open $xfrfile.\n";
      print OUTPUT <<EndBlock;
DAFETF NAIF DAF ENCODED TRANSFER FILE
'DAF/PCK '
'2'
'5'
'test_pck_cov2_id1.bpc                                       '
BEGIN_ARRAY 1 69
'Earth PCK, ITRF93 Frame                 '
'EE6B2CB^7'
'EE6B32F^7'
'18F'
'11'
'2'
69
'EE6B2FD^7'
'32^2'
'323BE87206ED66^1'
'D6BB174EBD70A^-7'
'-90109AA6666668^-9'
'-6F173333333334^-C'
'-11CC28F5C28F5C^-C'
'C128F5C28F5C28^-D'
'-1059C28F5C28F6^-C'
'D233333333333^-D'
'-12EB5C28F5C28F^-C'
'570947AE147AE^-C'
'-6E5428F5C28F5C^-C'
'D8C7AE147AE148^-D'
'12DC7AE147AE14^-C'
'3ECDC28F5C28F6^-C'
'-2E16147AE147AE^-C'
'EC428F5C28F5C^-D'
'-15CCCCCCCCCCCD^-C'
'A62B851EB851E8^-D'
'-B5F5C28F5C28F8^-D'
'-D4D75C28F5C29^-C'
'1E4A8A3D70A3D7^-B'
'68BCC706F35B38^0'
'-FC674BCA8CCCD^-7'
'-1584AEE999999A^-9'
'92D0851EB851E8^-C'
'-1AA6147AE147AE^-D'
'C047AE147AE148^-E'
'-1A1BD70A3D70A4^-D'
'-1D2EB851EB851F^-D'
'-74FA3D70A3D70C^-D'
'A96947AE147AE^-D'
'-F4A147AE147AE^-D'
'591E6666666668^-D'
'1D6^-D'
'70C1EB851EB85^-D'
'-5997AE147AE148^-D'
'1B3A3D70A3D70A^-D'
'-4BE6147AE147B^-D'
'422C28F5C28F5C^-D'
'-7ACA3D70A3D70C^-D'
'-1CACCCCCCCCCCD^-C'
'40500A3D70A3D8^-C'
'486DCD6EA5235C^1'
'EEF2A5766AA828^-2'
'78ED270A3D70A4^-9'
'-D56FA9EB851EB8^-A'
'-3BA82B851EB852^-A'
'-67EF1^-A'
'-80219EB851EB88^-B'
'59BB9333333334^-A'
'265B88F5C28F5C^-A'
'10F5EFA8F5C28F^-9'
'4E19^-B'
'-132E070A3D70A4^-A'
'-388A4333333334^-A'
'-90A5A47AE147B^-A'
'-7D403333333334^-B'
'5641D4CCCCCCCC^-A'
'1D5F3CA3D70A3D^-A'
'70C58170A3D70C^-A'
'3AE7B333333334^-B'
'-28BA351EB851EC^-A'
'25916828F5C29^-A'
'EE6B2CB^7'
'64^2'
'41^2'
'1^1'
END_ARRAY 1 69
TOTAL_ARRAYS 1
 ~NAIF/SPC BEGIN COMMENTS~
 ~NAIF/SPC END COMMENTS~
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $xfrfile.\n";

      $result = `$tobin $xfrfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: TOBIN failed. Error was: $result\n";
      }

      unlink( "$xfrfile" ) || die "ERROR: cannot delete $xfrfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_pck_cov3_id1.bpc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_pck_cov3_id1.bpc" && $myaction eq "make" ) {

      $xfrfile = $file;
      $xfrfile =~ s/\.bpc$/.xfr/;

      open ( OUTPUT, ">$xfrfile" ) || die "ERROR: cannot open $xfrfile.\n";
      print OUTPUT <<EndBlock;
DAFETF NAIF DAF ENCODED TRANSFER FILE
'DAF/PCK '
'2'
'5'
'test_pck_cov3_id1.bpc                                       '
BEGIN_ARRAY 1 69
'Earth PCK, ITRF93 Frame                 '
'EE6B316^7'
'EE6B348^7'
'BB8'
'11'
'2'
69
'EE6B32F^7'
'19^2'
'323BE872DCF452^1'
'6A3D4987199998^-7'
'-2410FE1C28F5C2^-9'
'17851EB851EB85^-E'
'-A2828F5C28F5C^-D'
'1D2FAE147AE148^-C'
'-127A6666666666^-C'
'11A147AE147AE1^-C'
'-A77D70A3D70A4^-D'
'556FAE147AE148^-C'
'-722F851EB851EC^-C'
'FC5EB851EB852^-D'
'E291EB851EB85^-D'
'3D5C51EB851EB8^-C'
'-2A0147AE147AE2^-C'
'E223D70A3D70A^-D'
'-17E91EB851EB85^-C'
'CA0F5C28F5C29^-D'
'-14B66666666666^-C'
'-D64147AE147AE^-C'
'1E2CA3D70A3D71^-B'
'68BCC6F72B3974^0'
'-7E5E83DF48A3D8^-7'
'-5540FF66666668^-A'
'134751EB851EB8^-C'
'-13666666666666^-D'
'C83D70A3D70A4^-E'
'3D0A3D70A3D70A^-E'
'75CCCCCCCCCCCC^-E'
'-182B851EB851EC^-D'
'D6A70A3D70A3D8^-D'
'-102E75C28F5C29^-C'
'1B1051EB851EB8^-D'
'1733D70A3D70A4^-D'
'911051EB851EB8^-D'
'-2C4A8F5C28F5C2^-D'
'1DEA8F5C28F5C3^-D'
'-E1B851EB851EB8^-E'
'41BC7AE147AE14^-D'
'-3F266666666666^-D'
'-1C21CCCCCCCCCD^-C'
'3E54B333333334^-C'
'487CBC98FD2F9^1'
'777952CAE44F28^-2'
'29272A3D70A3D8^-9'
'D0B5E5C28F5C28^-A'
'-3FC6F947AE147A^-A'
'1E82DCCCCCCCCD^-A'
'-261C5F0A3D70A4^-A'
'-48A158F5C28F5C^-A'
'-787E2570A3D70C^-A'
'48B770A3D70A3C^-A'
'169A36147AE148^-A'
'-9A23D70A3D70A^-B'
'F6EF1EB851EB88^-B'
'-1CCB4FAE147AE1^-A'
'3B52D51EB851EC^-A'
'A342523D70A3D8^-A'
'1E5BBAB851EB85^-A'
'-3E904428F5C29^-A'
'-940743D70A3D7^-A'
'1470AF851EB852^-A'
'509B7E3D70A3D8^-A'
'EE6B316^7'
'32^2'
'41^2'
'1^1'
END_ARRAY 1 69
TOTAL_ARRAYS 1
 ~NAIF/SPC BEGIN COMMENTS~
 ~NAIF/SPC END COMMENTS~
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $xfrfile.\n";

      $result = `$tobin $xfrfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: TOBIN failed. Error was: $result\n";
      }

      unlink( "$xfrfile" ) || die "ERROR: cannot delete $xfrfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_pck_cov3_id2.bpc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_pck_cov3_id2.bpc" && $myaction eq "make" ) {

      $xfrfile = $file;
      $xfrfile =~ s/\.bpc$/.xfr/;

      open ( OUTPUT, ">$xfrfile" ) || die "ERROR: cannot open $xfrfile.\n";
      print OUTPUT <<EndBlock;
DAFETF NAIF DAF ENCODED TRANSFER FILE
'DAF/PCK '
'2'
'5'
'test_pck_cov3_id1.bpc                                       '
BEGIN_ARRAY 1 69
'Earth PCK, ITRF93 Frame                 '
'EE6B316^7'
'EE6B348^7'
'18F'
'11'
'2'
69
'EE6B32F^7'
'19^2'
'323BE872DCF452^1'
'6A3D4987199998^-7'
'-2410FE1C28F5C2^-9'
'17851EB851EB85^-E'
'-A2828F5C28F5C^-D'
'1D2FAE147AE148^-C'
'-127A6666666666^-C'
'11A147AE147AE1^-C'
'-A77D70A3D70A4^-D'
'556FAE147AE148^-C'
'-722F851EB851EC^-C'
'FC5EB851EB852^-D'
'E291EB851EB85^-D'
'3D5C51EB851EB8^-C'
'-2A0147AE147AE2^-C'
'E223D70A3D70A^-D'
'-17E91EB851EB85^-C'
'CA0F5C28F5C29^-D'
'-14B66666666666^-C'
'-D64147AE147AE^-C'
'1E2CA3D70A3D71^-B'
'68BCC6F72B3974^0'
'-7E5E83DF48A3D8^-7'
'-5540FF66666668^-A'
'134751EB851EB8^-C'
'-13666666666666^-D'
'C83D70A3D70A4^-E'
'3D0A3D70A3D70A^-E'
'75CCCCCCCCCCCC^-E'
'-182B851EB851EC^-D'
'D6A70A3D70A3D8^-D'
'-102E75C28F5C29^-C'
'1B1051EB851EB8^-D'
'1733D70A3D70A4^-D'
'911051EB851EB8^-D'
'-2C4A8F5C28F5C2^-D'
'1DEA8F5C28F5C3^-D'
'-E1B851EB851EB8^-E'
'41BC7AE147AE14^-D'
'-3F266666666666^-D'
'-1C21CCCCCCCCCD^-C'
'3E54B333333334^-C'
'487CBC98FD2F9^1'
'777952CAE44F28^-2'
'29272A3D70A3D8^-9'
'D0B5E5C28F5C28^-A'
'-3FC6F947AE147A^-A'
'1E82DCCCCCCCCD^-A'
'-261C5F0A3D70A4^-A'
'-48A158F5C28F5C^-A'
'-787E2570A3D70C^-A'
'48B770A3D70A3C^-A'
'169A36147AE148^-A'
'-9A23D70A3D70A^-B'
'F6EF1EB851EB88^-B'
'-1CCB4FAE147AE1^-A'
'3B52D51EB851EC^-A'
'A342523D70A3D8^-A'
'1E5BBAB851EB85^-A'
'-3E904428F5C29^-A'
'-940743D70A3D7^-A'
'1470AF851EB852^-A'
'509B7E3D70A3D8^-A'
'EE6B316^7'
'32^2'
'41^2'
'1^1'
END_ARRAY 1 69
TOTAL_ARRAYS 1
 ~NAIF/SPC BEGIN COMMENTS~
 ~NAIF/SPC END COMMENTS~
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $xfrfile.\n";

      $result = `$tobin $xfrfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: TOBIN failed. Error was: $result\n";
      }

      unlink( "$xfrfile" ) || die "ERROR: cannot delete $xfrfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_pck_no_seg.bpc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_pck_no_seg.bpc" && $myaction eq "make" ) {

      $xfrfile = $file;
      $xfrfile =~ s/\.bpc$/.xfr/;

      open ( OUTPUT, ">$xfrfile" ) || die "ERROR: cannot open $xfrfile.\n";
      print OUTPUT <<EndBlock;
DAFETF NAIF DAF ENCODED TRANSFER FILE
'DAF/PCK '
'2'
'5'
'test                                                        '
TOTAL_ARRAYS 0
 ~NAIF/SPC BEGIN COMMENTS~

This is a special, invalid binary PCK file. It contains no segments.
This is a special, invalid binary PCK file. It contains no segments.
This is a special, invalid binary PCK file. It contains no segments.
This is a special, invalid binary PCK file. It contains no segments.
This is a special, invalid binary PCK file. It contains no segments.
This is a special, invalid binary PCK file. It contains no segments.
This is a special, invalid binary PCK file. It contains no segments.
This is a special, invalid binary PCK file. It contains no segments.
This is a special, invalid binary PCK file. It contains no segments.
This is a special, invalid binary PCK file. It contains no segments.
This is a special, invalid binary PCK file. It contains no segments.
This is a special, invalid binary PCK file. It contains no segments.
This is a special, invalid binary PCK file. It contains no segments.

 ~NAIF/SPC END COMMENTS~
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $xfrfile.\n";

      $result = `$tobin $xfrfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: TOBIN failed. Error was: $result\n";
      }

      unlink( "$xfrfile" ) || die "ERROR: cannot delete $xfrfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_pck_unk_obj.bpc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_pck_unk_obj.bpc" && $myaction eq "make" ) {

      $xfrfile = $file;
      $xfrfile =~ s/\.bpc$/.xfr/;

      open ( OUTPUT, ">$xfrfile" ) || die "ERROR: cannot open $xfrfile.\n";
      print OUTPUT <<EndBlock;
DAFETF NAIF DAF ENCODED TRANSFER FILE
'DAF/PCK '
'2'
'5'
'test_pck_cov1_id1.bpc                                       '
BEGIN_ARRAY 1 69
'Earth PCK, ITRF93 Frame                 '
'EE6B28^7'
'EE6B2E4^7'
'BB9'
'11'
'2'
69
'EE6B2B2^7'
'32^2'
'323BE870C24D1E^1'
'DA1A871E0CCCD^-7'
'-8FC2BDFAE147B^-9'
'-8101C28F5C28F8^-C'
'-1CCE147AE147AE^-C'
'-A028F5C28F5C28^-E'
'-1369999999999A^-C'
'F78F5C28F5C29^-D'
'-11928F5C28F5C3^-C'
'4EC6B851EB852^-C'
'-7944F5C28F5C28^-C'
'D73D70A3D70A4^-D'
'F84CCCCCCCCCD^-D'
'3B7570A3D70A3E^-C'
'-24D30A3D70A3D8^-C'
'6E947AE147AE14^-D'
'-16270A3D70A3D7^-C'
'B8F851EB851EB8^-D'
'-119EB851EB851F^-C'
'-CE1A3D70A3D708^-C'
'1E5ED99999999A^-B'
'68BCC71E96F3^0'
'-FBE53FB0061478^-7'
'-15D4FC4C7AE148^-9'
'8FEF28F5C28F6^-C'
'-D633333333333^-E'
'-1D5A3D70A3D70A^-D'
'-350F0A3D70A3D8^-D'
'65A66666666668^-D'
'FF47AE147AE148^-E'
'8288A3D70A3D7^-D'
'-C754CCCCCCCCD^-D'
'-D79EB851EB852^-E'
'2E751EB851EB86^-D'
'A7A66666666668^-D'
'-3C3CCCCCCCCCCC^-D'
'-522E147AE147B^-E'
'-54A7AE147AE148^-D'
'2E76147AE147AE^-D'
'16F2E147AE147B^-D'
'-1B6D5C28F5C28F^-C'
'42881EB851EB84^-C'
'485766AF246CCC^1'
'EEF2A5445E785^-2'
'7F545CFAE147B^-9'
'-2D3A8666666666^-A'
'-117A6C28F5C28F^-A'
'6B87B5C28F5C28^-A'
'-B35FB33333333^-B'
'-49CD8EB851EB84^-A'
'-839BD428F5C29^-A'
'47081666666668^-A'
'DC7FFAE147AE18^-B'
'-4ED4E999999998^-A'
'6E52A3D70A3D7^-A'
'-63DED1EB851EB8^-B'
'-2F09EDC28F5C28^-A'
'3EEF6A3D70A3D8^-A'
'-5E02451EB851EC^-A'
'-17AA07D70A3D71^-A'
'-3FDB787AE147AE^-A'
'-37764BAE147AE2^-A'
'A47A570A3D70A^-B'
'EE6B28^7'
'64^2'
'41^2'
'1^1'
END_ARRAY 1 69
TOTAL_ARRAYS 1
 ~NAIF/SPC BEGIN COMMENTS~
 ~NAIF/SPC END COMMENTS~
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $xfrfile.\n";

      $result = `$tobin $xfrfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: TOBIN failed. Error was: $result\n";
      }

      unlink( "$xfrfile" ) || die "ERROR: cannot delete $xfrfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_pck_unk_ref.bpc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_pck_unk_ref.bpc" && $myaction eq "make" ) {

      $xfrfile = $file;
      $xfrfile =~ s/\.bpc$/.xfr/;

      open ( OUTPUT, ">$xfrfile" ) || die "ERROR: cannot open $xfrfile.\n";
      print OUTPUT <<EndBlock;
DAFETF NAIF DAF ENCODED TRANSFER FILE
'DAF/PCK '
'2'
'5'
'test_pck_cov1_id1.bpc                                       '
BEGIN_ARRAY 1 69
'Earth PCK, ITRF93 Frame                 '
'EE6B28^7'
'EE6B2E4^7'
'BB8'
'14D'
'2'
69
'EE6B2B2^7'
'32^2'
'323BE870C24D1E^1'
'DA1A871E0CCCD^-7'
'-8FC2BDFAE147B^-9'
'-8101C28F5C28F8^-C'
'-1CCE147AE147AE^-C'
'-A028F5C28F5C28^-E'
'-1369999999999A^-C'
'F78F5C28F5C29^-D'
'-11928F5C28F5C3^-C'
'4EC6B851EB852^-C'
'-7944F5C28F5C28^-C'
'D73D70A3D70A4^-D'
'F84CCCCCCCCCD^-D'
'3B7570A3D70A3E^-C'
'-24D30A3D70A3D8^-C'
'6E947AE147AE14^-D'
'-16270A3D70A3D7^-C'
'B8F851EB851EB8^-D'
'-119EB851EB851F^-C'
'-CE1A3D70A3D708^-C'
'1E5ED99999999A^-B'
'68BCC71E96F3^0'
'-FBE53FB0061478^-7'
'-15D4FC4C7AE148^-9'
'8FEF28F5C28F6^-C'
'-D633333333333^-E'
'-1D5A3D70A3D70A^-D'
'-350F0A3D70A3D8^-D'
'65A66666666668^-D'
'FF47AE147AE148^-E'
'8288A3D70A3D7^-D'
'-C754CCCCCCCCD^-D'
'-D79EB851EB852^-E'
'2E751EB851EB86^-D'
'A7A66666666668^-D'
'-3C3CCCCCCCCCCC^-D'
'-522E147AE147B^-E'
'-54A7AE147AE148^-D'
'2E76147AE147AE^-D'
'16F2E147AE147B^-D'
'-1B6D5C28F5C28F^-C'
'42881EB851EB84^-C'
'485766AF246CCC^1'
'EEF2A5445E785^-2'
'7F545CFAE147B^-9'
'-2D3A8666666666^-A'
'-117A6C28F5C28F^-A'
'6B87B5C28F5C28^-A'
'-B35FB33333333^-B'
'-49CD8EB851EB84^-A'
'-839BD428F5C29^-A'
'47081666666668^-A'
'DC7FFAE147AE18^-B'
'-4ED4E999999998^-A'
'6E52A3D70A3D7^-A'
'-63DED1EB851EB8^-B'
'-2F09EDC28F5C28^-A'
'3EEF6A3D70A3D8^-A'
'-5E02451EB851EC^-A'
'-17AA07D70A3D71^-A'
'-3FDB787AE147AE^-A'
'-37764BAE147AE2^-A'
'A47A570A3D70A^-B'
'EE6B28^7'
'64^2'
'41^2'
'1^1'
END_ARRAY 1 69
TOTAL_ARRAYS 1
 ~NAIF/SPC BEGIN COMMENTS~
 ~NAIF/SPC END COMMENTS~
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $xfrfile.\n";

      $result = `$tobin $xfrfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: TOBIN failed. Error was: $result\n";
      }

      unlink( "$xfrfile" ) || die "ERROR: cannot delete $xfrfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_spk.bsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_spk.bsp" && $myaction eq "make" ) {

      $xfrfile = $file;
      $xfrfile =~ s/\.bsp$/.xfr/;

      open ( OUTPUT, ">$xfrfile" ) || die "ERROR: cannot open $xfrfile.\n";
      print OUTPUT <<EndBlock;
DAFETF NAIF DAF ENCODED TRANSFER FILE
'NAIF/DAF'
'2'
'6'
'LandmarksSPK                                                '
BEGIN_ARRAY 1 16
'LS                                      '
'1E1DC4^7'
'BC186AC^8'
'-14BA4'
'1F3'
'271E'
'8'
16
'-2DC012D87331D2^3'
'-3F8C52F60D6E98^3'
'C3F49570653768^3'
'0^0'
'0^0'
'0^0'
'-2DC012D87331D2^3'
'-3F8C52F60D6E98^3'
'C3F49570653768^3'
'0^0'
'0^0'
'0^0'
'1E1DC4^7'
'BA368E8^8'
'1^1'
'2^1'
END_ARRAY 1 16
TOTAL_ARRAYS 1
 ~NAIF/SPC BEGIN COMMENTS~

This file contains landing site location defined by with the following
Gaussian coordinates:

Lon =  234.248710 degrees East
Lat =  68.450673 degrees North
Alt =  -2.591214 km

These Gaussian coordinates correspond to the following areocentric
coordinates (R, LON, LAT) = (3376.340, 234.248710, 68.218394) and Mars radii
(Re, Re, Rp) = (3396.19, 3396.19, 3376.20).

The corresponding XYZ coordinates were computed by PINPOINT for the
triaxial ellipsoid surface defined by the body 499 radii from
PcK file 'mars_iau2000_v0.tpc'.

 ~NAIF/SPC END COMMENTS~
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $xfrfile.\n";

      $result = `$tobin $xfrfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: TOBIN failed. Error was: $result\n";
      }

      unlink( "$xfrfile" ) || die "ERROR: cannot delete $xfrfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_ek.bes" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_ek.bes" && $myaction eq "make" ) {

      $xfrfile = $file;
      $xfrfile =~ s/\.bes$/.xfr/;

      open ( OUTPUT, ">$xfrfile" ) || die "ERROR: cannot open $xfrfile.\n";
      print OUTPUT <<EndBlock;
DASETF NAIF DAS ENCODED TRANSFER FILE
'DAS/EK  '
'DSK type 3 test kernel                                      '
'0'
'0'
'0'
'0'
'0'
'D3'
'E'
BEGIN_DP_BLOCK 1 211
'270F^4'
'1^1'
'0^0'
'1^1'
'3^1'
'-3243F6A8885A3^1'
'3243F6A8885A3^1'
'-1921FB54442D18^1'
'1921FB54442D18^1'
'F4391FE8EF202^0'
'11D8C7E110394F^1'
'11D8C7E110394F^1'
'10787CBE7AAFCD^1'
'FA637FD3B151E8^0'
'F43929306B6B7^0'
'F4392A2EBCCD3^0'
'FA6382EF125AA^0'
'10787D18BFABFB^1'
'FFD06592B414B8^0'
'FB2A532519DC8^0'
'FCCBCF7AF7C888^0'
'FCCBCEC080AAD8^0'
'FB2A4A5280EBB^0'
'FFD0543D629DA^0'
'10787C1D7EC0B8^1'
'FA63764A8AA74^0'
'F4391FE8EF2038^0'
'F43920ECABE3F^0'
'FA637976DEB9E^0'
'10787C79B02F8C^1'
'11D8C7C5EB1E6C^1'
'11D8C7DDE25211^1'
'10787CB66C1561^1'
'FA637F14EB541^0'
'F43928389DA22^0'
'F43928FAB9C4F^0'
'FA638173FF72A^0'
'10787CFB522D64^1'
'FFD068B59BA028^0'
'FB2A5C9CBB54D^0'
'FCCBDF5CDA8C68^0'
'FCCBE049D1FB58^0'
'FB2A5B34F62F28^0'
'FFD064E1B7EE2^0'
'10787CBEABBCCB^1'
'FA637E66BB327^0'
'F439267FEABE1^0'
'F4392639E51D3^0'
'FA637D8BBCCEA8^0'
'10787CA5D11521^1'
'11D8C7D754E01B^1'
'11D8C7DC7D51AA^1'
'10787CB2E35DAE^1'
'FA637EC13D92^0'
'F43927CBEBFBA^0'
'F43928739F6C7^0'
'FA6380CDB99EE^0'
'10787CEE69C4C8^1'
'FFD067606A9D68^0'
'FB2A5B4290AA68^0'
'FCCBDDF552F738^0'
'FCCBDDF552F738^0'
'FB2A5B4290AA78^0'
'FFD067606A9D78^0'
'10787CEE69C4C8^1'
'FA6380CDB99EE^0'
'F43928739F6C88^0'
'F43927CBEBFBA8^0'
'FA637EC13D92^0'
'10787CB2E35DAD^1'
'11D8C7DC7D51A9^1'
'11D8C7D754E01B^1'
'10787CA5D1152^1'
'FA637D8BBCCEA8^0'
'F4392639E51D2^0'
'F439267FEABE08^0'
'FA637E66BB328^0'
'10787CBEABBCC9^1'
'FFD064E1B7EE2^0'
'FB2A5B34F62F38^0'
'FCCBE049D1FB48^0'
'FCCBDF5CDA8C78^0'
'FB2A5C9CBB54B8^0'
'FFD068B59BA028^0'
'10787CFB522D65^1'
'FA638173FF72A8^0'
'F43928FAB9C4E^0'
'F43928389DA22^0'
'FA637F14EB541^0'
'10787CB66C156^1'
'11D8C7DDE25212^1'
'11D8C7C5EB1E6C^1'
'10787C79B02F8D^1'
'FA637976DEB9E^0'
'F43920ECABE3E^0'
'F4391FE8EF202^0'
'FA63764A8AA75^0'
'10787C1D7EC0B8^1'
'FFD0543D629DA8^0'
'FB2A4A5280EBC^0'
'FCCBCEC080AAE8^0'
'FCCBCF7AF7C88^0'
'FB2A532519DC8^0'
'FFD06592B414B^0'
'10787D18BFABFB^1'
'FA6382EF125AA^0'
'F4392A2EBCCD3^0'
'F43929306B6B7^0'
'FA637FD3B151D^0'
'10787CBE7AAFCC^1'
'11D8C7E110394F^1'
'11D8C7C5EB1E6C^1'
'10787C79B02F8C^1'
'FA637976DEB9E^0'
'F43920ECABE3E^0'
'F4391FE8EF202^0'
'FA63764A8AA75^0'
'10787C1D7EC0B8^1'
'FFD0543D629DA8^0'
'FB2A4A5280EBC^0'
'FCCBCEC080AAE8^0'
'FCCBCF7AF7C88^0'
'FB2A532519DC8^0'
'FFD06592B414B^0'
'10787D18BFABFB^1'
'FA6382EF125AB^0'
'F4392A2EBCCD3^0'
'F43929306B6B7^0'
'FA637FD3B151D^0'
'10787CBE7AAFCC^1'
'11D8C7E110394F^1'
'11D8C7D754E01B^1'
'10787CA5D1152^1'
'FA637D8BBCCEA8^0'
'F4392639E51D2^0'
'F439267FEABE08^0'
'FA637E66BB328^0'
'10787CBEABBCC9^1'
'FFD064E1B7EE2^0'
'FB2A5B34F62F38^0'
'FCCBE049D1FB58^0'
'FCCBDF5CDA8C78^0'
'FB2A5C9CBB54B8^0'
'FFD068B59BA028^0'
'10787CFB522D65^1'
'FA638173FF72A8^0'
'F43928FAB9C4D^0'
'F43928389DA22^0'
'FA637F14EB541^0'
'10787CB66C156^1'
'11D8C7DDE25212^1'
'11D8C7DC7D51A9^1'
'10787CB2E35DAE^1'
'FA637EC13D92^0'
'F43927CBEBFBA8^0'
'F43928739F6C7^0'
'FA6380CDB99EE^0'
'10787CEE69C4C8^1'
'FFD067606A9D68^0'
'FB2A5B4290AA68^0'
'FCCBDDF552F738^0'
'FCCBDDF552F738^0'
'FB2A5B4290AA78^0'
'FFD067606A9D78^0'
'10787CEE69C4C8^1'
'FA6380CDB99EE^0'
'F43928739F6C7^0'
'F43927CBEBFBA^0'
'FA637EC13D92^0'
'10787CB2E35DAE^1'
'11D8C7DC7D51AA^1'
'11D8C7DDE25212^1'
'10787CB66C156^1'
'FA637F14EB541^0'
'F43928389DA21^0'
'F43928FAB9C4F^0'
'FA638173FF72A^0'
'10787CFB522D64^1'
'FFD068B59BA028^0'
'FB2A5C9CBB54D^0'
'FCCBDF5CDA8C78^0'
'FCCBE049D1FB58^0'
'FB2A5B34F62F28^0'
'FFD064E1B7EE2^0'
'10787CBEABBCCA^1'
'FA637E66BB327^0'
'F439267FEABE1^0'
'F4392639E51D2^0'
'FA637D8BBCCEA8^0'
'10787CA5D1152^1'
'11D8C7D754E01B^1'
'11D8C7E110394F^1'
'10787CBE7AAFCD^1'
'FA637FD3B151E8^0'
'F43929306B6B7^0'
'F4392A2EBCCD3^0'
'FA6382EF125AA^0'
'10787D18BFABFA^1'
'FFD06592B414B8^0'
'FB2A532519DC7^0'
'FCCBCF7AF7C888^0'
'FCCBCEC080AAD8^0'
'FB2A4A5280EBB^0'
'FFD0543D629DA^0'
'10787C1D7EC0B7^1'
'FA63764A8AA75^0'
'F4391FE8EF2038^0'
'F43920ECABE3E^0'
'FA637976DEB9F^0'
'10787C79B02F8D^1'
'11D8C7C5EB1E6C^1'
END_DP_BLOCK 1 211
TOTAL_DP_BLOCKS 1 211
BEGIN_INTEGER_BLOCK 1 14
'F4240'
'4'
'4'
'-1'
'-1'
'B'
'3'
'0'
'D3'
'0'
'0'
'14'
'A'
'1'
END_INTEGER_BLOCK 1 14
TOTAL_INTEGER_BLOCKS 1 14
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $xfrfile.\n";

      $result = `$tobin $xfrfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: TOBIN failed. Error was: $result\n";
      }

      unlink( "$xfrfile" ) || die "ERROR: cannot delete $xfrfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_ck_no_seg.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_ck_no_seg.bc" && $myaction eq "make" ) {

      $xfrfile = $file;
      $xfrfile =~ s/\.bc$/.xfr/;

      open ( OUTPUT, ">$xfrfile" ) || die "ERROR: cannot open $xfrfile.\n";
      print OUTPUT <<EndBlock;
DAFETF NAIF DAF ENCODED TRANSFER FILE
'DAF/CK  '
'2'
'6'
'test                                                        '
TOTAL_ARRAYS 0
 ~NAIF/SPC BEGIN COMMENTS~

This is a special, invalid binary CK file. It contains no segments.
This is a special, invalid binary CK file. It contains no segments.
This is a special, invalid binary CK file. It contains no segments.
This is a special, invalid binary CK file. It contains no segments.
This is a special, invalid binary CK file. It contains no segments.
This is a special, invalid binary CK file. It contains no segments.
This is a special, invalid binary CK file. It contains no segments.
This is a special, invalid binary CK file. It contains no segments.
This is a special, invalid binary CK file. It contains no segments.
This is a special, invalid binary CK file. It contains no segments.
This is a special, invalid binary CK file. It contains no segments.
This is a special, invalid binary CK file. It contains no segments.
This is a special, invalid binary CK file. It contains no segments.
This is a special, invalid binary CK file. It contains no segments.
This is a special, invalid binary CK file. It contains no segments.
This is a special, invalid binary CK file. It contains no segments.

 ~NAIF/SPC END COMMENTS~
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $xfrfile.\n";

      $result = `$tobin $xfrfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: TOBIN failed. Error was: $result\n";
      }

      unlink( "$xfrfile" ) || die "ERROR: cannot delete $xfrfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_ck_cov1_id1.xc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_ck_cov1_id1.xc" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
DAFETF NAIF DAF ENCODED TRANSFER FILE
'DAF/CK  '
'2'
'6'
'CK FOR FRMDIFF TESTING                                      '
BEGIN_ARRAY 1 19
'CK FOR FRMDIFF TESTING                  '
'3A352944^A'
'3A352ACAA^A'
'-14884'
'-14BA7'
'3'
'1'
19
'1^1'
'0^0'
'0^0'
'0^0'
'0^0'
'0^0'
'0^0'
'1^1'
'0^0'
'0^0'
'0^0'
'0^0'
'0^0'
'0^0'
'3A352944^A'
'3A352ACAA^A'
'3A352944^A'
'1^1'
'2^1'
END_ARRAY 1 19
TOTAL_ARRAYS 1
 ~NAIF/SPC BEGIN COMMENTS~
 ~NAIF/SPC END COMMENTS~
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_pck_cov1_id1.xpc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_pck_cov1_id1.xpc" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
DAFETF NAIF DAF ENCODED TRANSFER FILE
'DAF/PCK '
'2'
'5'
'test_pck_cov1_id1.bpc                                       '
BEGIN_ARRAY 1 69
'Earth PCK, ITRF93 Frame                 '
'EE6B28^7'
'EE6B2E4^7'
'BB8'
'11'
'2'
69
'EE6B2B2^7'
'32^2'
'323BE870C24D1E^1'
'DA1A871E0CCCD^-7'
'-8FC2BDFAE147B^-9'
'-8101C28F5C28F8^-C'
'-1CCE147AE147AE^-C'
'-A028F5C28F5C28^-E'
'-1369999999999A^-C'
'F78F5C28F5C29^-D'
'-11928F5C28F5C3^-C'
'4EC6B851EB852^-C'
'-7944F5C28F5C28^-C'
'D73D70A3D70A4^-D'
'F84CCCCCCCCCD^-D'
'3B7570A3D70A3E^-C'
'-24D30A3D70A3D8^-C'
'6E947AE147AE14^-D'
'-16270A3D70A3D7^-C'
'B8F851EB851EB8^-D'
'-119EB851EB851F^-C'
'-CE1A3D70A3D708^-C'
'1E5ED99999999A^-B'
'68BCC71E96F3^0'
'-FBE53FB0061478^-7'
'-15D4FC4C7AE148^-9'
'8FEF28F5C28F6^-C'
'-D633333333333^-E'
'-1D5A3D70A3D70A^-D'
'-350F0A3D70A3D8^-D'
'65A66666666668^-D'
'FF47AE147AE148^-E'
'8288A3D70A3D7^-D'
'-C754CCCCCCCCD^-D'
'-D79EB851EB852^-E'
'2E751EB851EB86^-D'
'A7A66666666668^-D'
'-3C3CCCCCCCCCCC^-D'
'-522E147AE147B^-E'
'-54A7AE147AE148^-D'
'2E76147AE147AE^-D'
'16F2E147AE147B^-D'
'-1B6D5C28F5C28F^-C'
'42881EB851EB84^-C'
'485766AF246CCC^1'
'EEF2A5445E785^-2'
'7F545CFAE147B^-9'
'-2D3A8666666666^-A'
'-117A6C28F5C28F^-A'
'6B87B5C28F5C28^-A'
'-B35FB33333333^-B'
'-49CD8EB851EB84^-A'
'-839BD428F5C29^-A'
'47081666666668^-A'
'DC7FFAE147AE18^-B'
'-4ED4E999999998^-A'
'6E52A3D70A3D7^-A'
'-63DED1EB851EB8^-B'
'-2F09EDC28F5C28^-A'
'3EEF6A3D70A3D8^-A'
'-5E02451EB851EC^-A'
'-17AA07D70A3D71^-A'
'-3FDB787AE147AE^-A'
'-37764BAE147AE2^-A'
'A47A570A3D70A^-B'
'EE6B28^7'
'64^2'
'41^2'
'1^1'
END_ARRAY 1 69
TOTAL_ARRAYS 1
 ~NAIF/SPC BEGIN COMMENTS~
 ~NAIF/SPC END COMMENTS~
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_spk.xsp" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_spk.xsp" && $myaction eq "make" ) {

      open ( OUTPUT, ">$file" ) || die "ERROR: cannot open $file.\n";
      print OUTPUT <<EndBlock;
DAFETF NAIF DAF ENCODED TRANSFER FILE
'NAIF/DAF'
'2'
'6'
'LandmarksSPK                                                '
BEGIN_ARRAY 1 16
'LS                                      '
'1E1DC4^7'
'BC186AC^8'
'-14BA4'
'1F3'
'271E'
'8'
16
'-2DC012D87331D2^3'
'-3F8C52F60D6E98^3'
'C3F49570653768^3'
'0^0'
'0^0'
'0^0'
'-2DC012D87331D2^3'
'-3F8C52F60D6E98^3'
'C3F49570653768^3'
'0^0'
'0^0'
'0^0'
'1E1DC4^7'
'BA368E8^8'
'1^1'
'2^1'
END_ARRAY 1 16
TOTAL_ARRAYS 1
 ~NAIF/SPC BEGIN COMMENTS~

This file contains landing site location defined by with the following
Gaussian coordinates:

Lon =  234.248710 degrees East
Lat =  68.450673 degrees North
Alt =  -2.591214 km

These Gaussian coordinates correspond to the following areocentric
coordinates (R, LON, LAT) = (3376.340, 234.248710, 68.218394) and Mars radii
(Re, Re, Rp) = (3396.19, 3396.19, 3376.20).

The corresponding XYZ coordinates were computed by PINPOINT for the
triaxial ellipsoid surface defined by the body 499 radii from
PcK file 'mars_iau2000_v0.tpc'.

 ~NAIF/SPC END COMMENTS~
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $file.\n";

    }


    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_ck_cov1_id1.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_ck_cov1_id1.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'frmdiff_lsk.tls'
SCLK_FILE_NAME        = 'frmdiff_sclk.tsc'
FRAMES_FILE_NAME      = 'frmdiff_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR FRMDIFF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR FRMDIFF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_ck_cov2_id1.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_ck_cov2_id1.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'frmdiff_lsk.tls'
SCLK_FILE_NAME        = 'frmdiff_sclk.tsc'
FRAMES_FILE_NAME      = 'frmdiff_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR FRMDIFF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR FRMDIFF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000075.000 0 0 0 0 0 0
250000175.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000075.000 0 0 0 0 0 0
250000175.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_ck_cov3_id1.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_ck_cov3_id1.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'frmdiff_lsk.tls'
SCLK_FILE_NAME        = 'frmdiff_sclk.tsc'
FRAMES_FILE_NAME      = 'frmdiff_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR FRMDIFF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR FRMDIFF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000150.000 0 0 0 0 0 0
250000200.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000150.000 0 0 0 0 0 0
250000200.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_ck_cov4_id1.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_ck_cov4_id1.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'frmdiff_lsk.tls'
SCLK_FILE_NAME        = 'frmdiff_sclk.tsc'
FRAMES_FILE_NAME      = 'frmdiff_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR FRMDIFF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR FRMDIFF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000125.000 0 -90 90 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000125.000 0 -90 90 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_ck_cov5_id1.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_ck_cov5_id1.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'frmdiff_lsk.tls'
SCLK_FILE_NAME        = 'frmdiff_sclk.tsc'
FRAMES_FILE_NAME      = 'frmdiff_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR FRMDIFF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR FRMDIFF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 0.5

PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000000.000 0 0 0 0 0 0
250000001.000 0 0 0 0 0 0
250000010.000 0 0 0 0 0 0
250000012.000 0 0 0 0 0 0
250000020.000 0 0 0 0 0 0
250000023.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000000.000 0 0 0 0 0 0
250000001.000 0 0 0 0 0 0
250000010.000 0 0 0 0 0 0
250000012.000 0 0 0 0 0 0
250000020.000 0 0 0 0 0 0
250000023.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_ck_cov6_id1.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_ck_cov6_id1.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'frmdiff_lsk.tls'
SCLK_FILE_NAME        = 'frmdiff_sclk.tsc'
FRAMES_FILE_NAME      = 'frmdiff_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR FRMDIFF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR FRMDIFF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 5

PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000000.000 0 0 0 0 0 0
250000001.000 0 0 0 0 0 0
250000010.000 0 0 0 0 0 0
250000012.000 0 0 0 0 0 0
250000020.000 0 0 0 0 0 0
250000023.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000000.000 0 0 0 0 0 0
250000001.000 0 0 0 0 0 0
250000010.000 0 0 0 0 0 0
250000012.000 0 0 0 0 0 0
250000020.000 0 0 0 0 0 0
250000023.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_ck_cov7_id1.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_ck_cov7_id1.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'frmdiff_lsk.tls'
SCLK_FILE_NAME        = 'frmdiff_sclk.tsc'
FRAMES_FILE_NAME      = 'frmdiff_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR FRMDIFF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR FRMDIFF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

MAXIMUM_VALID_INTERVAL = 2.5

PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000000.000 0 0 0 0 0 0
250000001.000 0 0 0 0 0 0
250000010.000 0 0 0 0 0 0
250000012.000 0 0 0 0 0 0
250000020.000 0 0 0 0 0 0
250000023.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000000.000 0 0 0 0 0 0
250000001.000 0 0 0 0 0 0
250000010.000 0 0 0 0 0 0
250000012.000 0 0 0 0 0 0
250000020.000 0 0 0 0 0 0
250000023.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_ck_cov1_id2.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_ck_cov1_id2.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'frmdiff_lsk.tls'
SCLK_FILE_NAME        = 'frmdiff_sclk.tsc'
FRAMES_FILE_NAME      = 'frmdiff_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR FRMDIFF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR FRMDIFF TESTING'
INSTRUMENT_ID         = -84001
REFERENCE_FRAME_NAME  = 'PHX_PAYLOAD'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_ck_cov2_id2.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_ck_cov2_id2.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'frmdiff_lsk.tls'
SCLK_FILE_NAME        = 'frmdiff_sclk.tsc'
FRAMES_FILE_NAME      = 'frmdiff_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR FRMDIFF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR FRMDIFF TESTING'
INSTRUMENT_ID         = -84001
REFERENCE_FRAME_NAME  = 'PHX_PAYLOAD'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000075.000 0 0 0 0 0 0
250000175.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000075.000 0 0 0 0 0 0
250000175.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_ck_cov3_id2.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_ck_cov3_id2.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'frmdiff_lsk.tls'
SCLK_FILE_NAME        = 'frmdiff_sclk.tsc'
FRAMES_FILE_NAME      = 'frmdiff_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR FRMDIFF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR FRMDIFF TESTING'
INSTRUMENT_ID         = -84001
REFERENCE_FRAME_NAME  = 'PHX_PAYLOAD'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000150.000 0   0  0 0 0 0
250000200.000 0 -90 90 0 0 1
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000150.000 0   0  0 0 0 0
250000200.000 0 -90 90 0 0 1
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_ck_cov1_id3.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_ck_cov1_id3.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'frmdiff_lsk.tls'
SCLK_FILE_NAME        = 'frmdiff_sclk_id3.tsc'
FRAMES_FILE_NAME      = 'frmdiff_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR FRMDIFF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR FRMDIFF TESTING'
INSTRUMENT_ID         = -85100
REFERENCE_FRAME_NAME  = 'J2000'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_ck_discrete.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_ck_discrete.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'frmdiff_lsk.tls'
SCLK_FILE_NAME        = 'frmdiff_sclk_tdt.tsc'
FRAMES_FILE_NAME      = 'frmdiff_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR FRMDIFF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR FRMDIFF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'UTC'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

2008-01-01T00:04:00.3333333 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
2008-01-01T00:04:00.3333333 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_ck_cov12_id12.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_ck_cov12_id12.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'frmdiff_lsk.tls'
SCLK_FILE_NAME        = 'frmdiff_sclk.tsc'
FRAMES_FILE_NAME      = 'frmdiff_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR FRMDIFF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR FRMDIFF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'frmdiff_lsk.tls'
SCLK_FILE_NAME        = 'frmdiff_sclk.tsc'
FRAMES_FILE_NAME      = 'frmdiff_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR FRMDIFF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR FRMDIFF TESTING'
INSTRUMENT_ID         = -84001
REFERENCE_FRAME_NAME  = 'PHX_PAYLOAD'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000075.000 0 0 0 0 0 0
250000175.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000075.000 0 0 0 0 0 0
250000175.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_ck_cov13_id12.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_ck_cov13_id12.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'frmdiff_lsk.tls'
SCLK_FILE_NAME        = 'frmdiff_sclk.tsc'
FRAMES_FILE_NAME      = 'frmdiff_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR FRMDIFF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR FRMDIFF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'frmdiff_lsk.tls'
SCLK_FILE_NAME        = 'frmdiff_sclk.tsc'
FRAMES_FILE_NAME      = 'frmdiff_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR FRMDIFF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR FRMDIFF TESTING'
INSTRUMENT_ID         = -84001
REFERENCE_FRAME_NAME  = 'PHX_PAYLOAD'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000150.000 0 0 0 0 0 0
250000200.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000150.000 0 0 0 0 0 0
250000200.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_ck_cov13_id1.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_ck_cov13_id1.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'frmdiff_lsk.tls'
SCLK_FILE_NAME        = 'frmdiff_sclk.tsc'
FRAMES_FILE_NAME      = 'frmdiff_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR FRMDIFF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR FRMDIFF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'frmdiff_lsk.tls'
SCLK_FILE_NAME        = 'frmdiff_sclk.tsc'
FRAMES_FILE_NAME      = 'frmdiff_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR FRMDIFF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR FRMDIFF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000150.000 0 0 0 0 0 0
250000200.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000150.000 0 0 0 0 0 0
250000200.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_ck_cov134_id1.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_ck_cov134_id1.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'frmdiff_lsk.tls'
SCLK_FILE_NAME        = 'frmdiff_sclk.tsc'
FRAMES_FILE_NAME      = 'frmdiff_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR FRMDIFF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR FRMDIFF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000000.000 0 0 0 0 0 0
250000100.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'frmdiff_lsk.tls'
SCLK_FILE_NAME        = 'frmdiff_sclk.tsc'
FRAMES_FILE_NAME      = 'frmdiff_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR FRMDIFF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR FRMDIFF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000150.000 0 0 0 0 0 0
250000200.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000150.000 0 0 0 0 0 0
250000200.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'frmdiff_lsk.tls'
SCLK_FILE_NAME        = 'frmdiff_sclk.tsc'
FRAMES_FILE_NAME      = 'frmdiff_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR FRMDIFF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR FRMDIFF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'YES'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000125.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000125.000 0 0 0 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

    #
    # ------------------------------------------------------------------------
    #
    if ( $file eq "frmdiff_ck_cov1_id1_no_av.bc" && $myaction eq "delete" ) {
      unlink( "$file" ) || die "ERROR: cannot delete $file.\n";
    }

    if ( $file eq "frmdiff_ck_cov1_id1_no_av.bc" && $myaction eq "make" ) {

      $setfile = $file;
      $setfile =~ s/\.bc$/.msopck/;

      open ( OUTPUT, ">$setfile" ) || die "ERROR: cannot open $setfile.\n";
      print OUTPUT <<EndBlock;
\\begindata

LSK_FILE_NAME         = 'frmdiff_lsk.tls'
SCLK_FILE_NAME        = 'frmdiff_sclk.tsc'
FRAMES_FILE_NAME      = 'frmdiff_fk.tf'

INTERNAL_FILE_NAME    = 'CK FOR FRMDIFF TESTING'

CK_TYPE               = 3
CK_SEGMENT_ID         = 'CK FOR FRMDIFF TESTING'
INSTRUMENT_ID         = -84100
REFERENCE_FRAME_NAME  = 'PHX_LL'
ANGULAR_RATE_PRESENT  = 'NO'

INPUT_TIME_TYPE       = 'ET'
INPUT_DATA_TYPE       = 'EULER ANGLES'
EULER_ANGLE_UNITS     = 'DEGREES'
EULER_ROTATIONS_ORDER = ( 'X' 'Y' 'Z' )
ANGULAR_RATE_FRAME    = 'REFERENCE'

PRODUCER_ID           = 'Boris Semenov, NAIF/JPL, x4-8136'

\\begintext

Inputs to MSOPCK are at the end of these comments.

250000000.000 0 0 0
250000100.000 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $setfile.\n";

      $inpfile = $file;
      $inpfile =~ s/\.bc$/.input/;

      open ( OUTPUT, ">$inpfile" ) || die "ERROR: cannot open $inpfile.\n";
      print OUTPUT <<EndBlock;
250000000.000 0 0 0
250000100.000 0 0 0
EndBlock
      close ( OUTPUT ) || die "ERROR: cannot close $inpfile.\n";

      $result = `$msopck $setfile $inpfile $file 2>&1`;
      $status = ( $? >> 8 );
      if ( $status ) {
        print "ERROR: MSOPCK failed. Error was: $result\n";
      }

      unlink( "$setfile" ) || die "ERROR: cannot delete $setfile.\n";
      unlink( "$inpfile" ) || die "ERROR: cannot delete $inpfile.\n";

    }

  }

}
